(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    701036,      18460]*)
(*NotebookOutlinePosition[    701988,      18489]*)
(*  CellTagsIndexPosition[    701944,      18485]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Set-Up", "Subsection"],

Cell["\<\
Begin with the constants, in reduced variables to make things \
simple. Also, set the barrier height to 1 and offset V by 1e-3 for \
convenience. \
\>", "Text"],

Cell[BoxData[{
    \(hbar := 1\), "\[IndentingNewLine]", 
    \(me := 1\), "\[IndentingNewLine]", 
    \(V0 := 1\), "\[IndentingNewLine]", 
    \(En =. \)}], "Input"],

Cell["Enter the values for the wavenumber, following CTDL pg. 84", "Text"],

Cell[BoxData[{
    \(k1 =. \), "\[IndentingNewLine]", 
    \(k2 =. \)}], "Input"],

Cell[BoxData[{
    \(K0 := \@\(\(2*me*V0\)\/\((hbar^2)\)\)\), "\[IndentingNewLine]", 
    \(k1[k_] := k\), "\[IndentingNewLine]", 
    \(k2[k_] := \@\(k\^2 - K0\^2\)\)}], "Input"],

Cell["\<\
The coefficients for reflection have already been calculated for \
this problem - set them up as recommended in CTDL. Notice that this makes A1 \
and A2 functions of k.\
\>", "Text"],

Cell[BoxData[{
    \(A1 =. \), "\[IndentingNewLine]", 
    \(A2 =. \)}], "Input"],

Cell[BoxData[{
    \(A1[k_] := \((k1[k] - k2[k])\)\/\((k1[k] + k2[k])\)\), "\
\[IndentingNewLine]", 
    \(A2[k_] := \(2*k1[k]\)\/\((k1[k] + k2[k])\)\)}], "Input"],

Cell["\<\
Define \[CapitalDelta]k, from the problem set. From this, construct \
g(k). Also throw in \[Omega](k) - this will be convenient later on.\
\>", \
"Text"],

Cell[BoxData[{
    \(deltak := \@\(0.1*V0\)\), "\[IndentingNewLine]", 
    \(a := \@2/deltak\), "\[IndentingNewLine]", 
    \(g[k_] := 
      Exp[\(-\((\((a^2)\)/
                4)\)\)*\((\((k - k0)\)^2)\)]\), "\[IndentingNewLine]", 
    \(\[Omega][k_] := \(hbar*\((k^2)\)\)\/\(2*me\)\)}], "Input"],

Cell["\<\
Define the last parameters, k0, x0, and the location of the step.\
\
\>", "Text"],

Cell[BoxData[{
    \(k0 := \@2.1\), "\[IndentingNewLine]", 
    \(x0 := \(-10\)\), "\[IndentingNewLine]", 
    \(steploc := 0\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wave functions", "Subsection"],

Cell[TextData[{
  "Now: the wavefunctions. I separated the incident wave from the reflected \
and transmitted waves (maybe it's inappropriate to call it the 'initial' \
wave, but that's what I started with). ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " starts making some inconvenient assumptions when the 'Conj' function is \
called, so it is usually more convenient to flip the signs in front of the \
i's manually and name a new function. Let me know if you have an easier way \
to do this."
}], "Text"],

Cell[BoxData[{
    \(\[CapitalPsi]initial[x_, t_, k_] := 
      1\/\@\(2*\[Pi]\)*g[k]*
        Exp[\[ImaginaryI]*\((\((k*x)\) - \[Omega][k]*t)\)]*
        Exp[\(-\[ImaginaryI]\)*\((k - k0)\)*x0]\), "\[IndentingNewLine]", 
    \(\[CapitalPsi]initialconj[x_, t_, k_] := 
      1\/\@\(2*\[Pi]\)*g[k]*
        Exp[\(-\[ImaginaryI]\)*\((\((k*x - \[Omega][k]*t)\))\)]*
        Exp[\[ImaginaryI]*\((k - k0)\)*x0]\), "\[IndentingNewLine]", 
    \(\[CapitalPsi]reflected[x_, t_, k_] := 
      1\/\@\(2*\[Pi]\)*g[k]*A1[k]*
        Exp[\(-\[ImaginaryI]\)*\((\((k*x)\) + \[Omega][k]*t)\)]*
        Exp[\(-\[ImaginaryI]\)*\((k - k0)\)*x0]\), "\[IndentingNewLine]", 
    \(\[CapitalPsi]reflectedconj[x_, t_, k_] := 
      1\/\@\(2*\[Pi]\)*g[k]*A1[k]*
        Exp[\[ImaginaryI]*\((\((k*x)\) + \[Omega][k]*t)\)]*
        Exp[\[ImaginaryI]*\((k - k0)\)*x0]\), "\[IndentingNewLine]", 
    \(\[CapitalPsi]transmitted[x_, t_, k_] := 
      1\/\@\(2*\[Pi]\)*g[k]*A2[k]*
        Exp[\[ImaginaryI]*\((\((\@\(k\^2 - K0\^2\)*x)\) - \[Omega][k]*t)\)]*
        Exp[\(-\[ImaginaryI]\)*\((k - k0)\)*x0]\), "\[IndentingNewLine]", 
    \(\[CapitalPsi]transmittedconj[x_, t_, k_] := 
      1\/\@\(2*\[Pi]\)*g[k]*A2[k]*
        Exp[\(-\[ImaginaryI]\)*\((\((\@\(k\^2 - K0\^2\)*x)\) - \[Omega][k]*
                  t)\)]*Exp[\[ImaginaryI]*\((k - k0)\)*x0]\)}], "Input"],

Cell["\<\
I ended up summing k over nine locations because this made for \
better pictures. Again, it looks cluttered due to manual complex \
conjugate-ing. The function names are long, but I wanted to make them \
clear.\
\>", "Text"],

Cell[BoxData[{
    \(\[CapitalPsi]initial[x_, t_] := 
      UnitStep[\(-\((x)\)\)]*\((\[CapitalPsi]initial[x, t, 
              k0]\[IndentingNewLine] + \[CapitalPsi]initial[x, t, 
              k0 + deltak/2]\[IndentingNewLine] + \[CapitalPsi]initial[x, t, 
              k0 - deltak/2]\[IndentingNewLine] + \[CapitalPsi]initial[x, t, 
              k0 + deltak]\[IndentingNewLine] + \[CapitalPsi]initial[x, t, 
              k0 - deltak]\[IndentingNewLine] + \[CapitalPsi]initial[x, t, 
              k0 + 3*deltak/2]\[IndentingNewLine] + \[CapitalPsi]initial[x, 
              t, k0 - 3*deltak/2]\[IndentingNewLine] + \[CapitalPsi]initial[
              x, t, k0 + 2*deltak]\[IndentingNewLine] + \[CapitalPsi]initial[
              x, t, k0 - 2*deltak])\)\), "\[IndentingNewLine]", 
    \(\[CapitalPsi]initialconj[x_, t_] := 
      UnitStep[\(-\((x)\)\)]*\((\[CapitalPsi]initialconj[x, t, 
              k0]\[IndentingNewLine] + \[CapitalPsi]initialconj[x, t, 
              k0 + deltak/2]\[IndentingNewLine] + \[CapitalPsi]initialconj[x, 
              t, k0 - deltak/2]\[IndentingNewLine] + \[CapitalPsi]initialconj[
              x, t, k0 + 
                deltak]\[IndentingNewLine] + \[CapitalPsi]initialconj[x, t, 
              k0 - deltak]\[IndentingNewLine] + \[CapitalPsi]initialconj[x, 
              t, k0 + 3*
                  deltak/2]\[IndentingNewLine] + \[CapitalPsi]initialconj[x, 
              t, k0 - 3*
                  deltak/2]\[IndentingNewLine] + \[CapitalPsi]initialconj[x, 
              t, k0 + 2*deltak]\[IndentingNewLine] + \[CapitalPsi]initialconj[
              x, t, k0 - 2*deltak])\)\), "\[IndentingNewLine]", 
    \(\[CapitalPsi]reflected[x_, t_] := 
      UnitStep[\(-\((x)\)\)]*\((\[CapitalPsi]reflected[x, t, 
              k0]\[IndentingNewLine] + \[CapitalPsi]reflected[x, t, 
              k0 + deltak/2]\[IndentingNewLine] + \[CapitalPsi]reflected[x, 
              t, k0 - deltak/2]\[IndentingNewLine] + \[CapitalPsi]reflected[
              x, t, k0 + deltak]\[IndentingNewLine] + \[CapitalPsi]reflected[
              x, t, k0 - deltak]\[IndentingNewLine] + \[CapitalPsi]reflected[
              x, t, k0 + 
                3*deltak/2]\[IndentingNewLine] + \[CapitalPsi]reflected[x, t, 
              k0 - 3*deltak/2]\[IndentingNewLine] + \[CapitalPsi]reflected[x, 
              t, k0 + 2*deltak]\[IndentingNewLine] + \[CapitalPsi]reflected[
              x, t, k0 - 2*deltak])\)\), "\[IndentingNewLine]", 
    \(\[CapitalPsi]reflectedconj[x_, t_] := 
      UnitStep[\(-\((x)\)\)]*\((\[CapitalPsi]reflectedconj[x, t, 
              k0]\[IndentingNewLine] + \[CapitalPsi]reflectedconj[x, t, 
              k0 + deltak/2]\[IndentingNewLine] + \[CapitalPsi]reflectedconj[
              x, t, k0 - 
                deltak/2]\[IndentingNewLine] + \[CapitalPsi]reflectedconj[x, 
              t, k0 + deltak]\[IndentingNewLine] + \[CapitalPsi]reflectedconj[
              x, t, k0 - 
                deltak]\[IndentingNewLine] + \[CapitalPsi]reflectedconj[x, t, 
              k0 + 3*deltak/
                    2]\[IndentingNewLine] + \[CapitalPsi]reflectedconj[x, t, 
              k0 - 3*deltak/
                    2]\[IndentingNewLine] + \[CapitalPsi]reflectedconj[x, t, 
              k0 + 2*deltak]\[IndentingNewLine] + \[CapitalPsi]reflectedconj[
              x, t, k0 - 2*deltak])\)\), "\[IndentingNewLine]", 
    \(\[CapitalPsi]transmitted[x_, t_] := 
      UnitStep[\((x)\)]*\[IndentingNewLine]\((\[CapitalPsi]transmitted[x, t, 
              k0] + \[IndentingNewLine]\[CapitalPsi]transmitted[x, t, 
              k0 + deltak/2] + \[IndentingNewLine]\[CapitalPsi]transmitted[x, 
              t, k0 - deltak/2] + \[IndentingNewLine]\[CapitalPsi]transmitted[
              x, t, k0 + 
                deltak] + \[IndentingNewLine]\[CapitalPsi]transmitted[x, t, 
              k0 - deltak] + \[IndentingNewLine]\[CapitalPsi]transmitted[x, 
              t, k0 + 3*
                  deltak/2] + \[IndentingNewLine]\[CapitalPsi]transmitted[x, 
              t, k0 - 3*
                  deltak/2] + \[IndentingNewLine]\[CapitalPsi]transmitted[x, 
              t, k0 + 2*deltak] + \[IndentingNewLine]\[CapitalPsi]transmitted[
              x, t, k0 - 2*deltak])\)\), "\[IndentingNewLine]", 
    \(\[CapitalPsi]transmittedconj[x_, t_] := 
      UnitStep[\((x)\)]*\((\[CapitalPsi]transmittedconj[x, t, 
              k0]\[IndentingNewLine] + \[CapitalPsi]transmittedconj[x, t, 
              k0 + deltak/
                  2]\[IndentingNewLine] + \[CapitalPsi]transmittedconj[x, t, 
              k0 - deltak/
                  2]\[IndentingNewLine] + \[CapitalPsi]transmittedconj[x, t, 
              k0 + deltak]\[IndentingNewLine] + \[CapitalPsi]transmittedconj[
              x, t, k0 - 
                deltak]\[IndentingNewLine] + \[CapitalPsi]transmittedconj[x, 
              t, 
              k0 + 3*deltak/
                    2]\[IndentingNewLine] + \[CapitalPsi]transmittedconj[x, 
              t, k0 - 3*
                  deltak/2]\[IndentingNewLine] + \[CapitalPsi]transmittedconj[
              x, t, k0 + 
                2*deltak]\[IndentingNewLine] + \[CapitalPsi]transmittedconj[
              x, t, k0 - 2*deltak])\)\)}], "Input"],

Cell["\<\
Test to see how the transmission and reflection coefficients (or \
their precursors) look.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(A1[k0]\), "\[IndentingNewLine]", 
    \(A2[k0]\)}], "Input"],

Cell[BoxData[
    \(0.868225531212423`\)], "Output"],

Cell[BoxData[
    \(1.868225531212423`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Movies", "Subsection"],

Cell["A movie of the incident wave and its reflection.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(For[time = 0, 
      time < 15, \(time++\), \
\[IndentingNewLine]Plot[\[IndentingNewLine]Re[\((\[CapitalPsi]initial[x, 
                  time] + \[CapitalPsi]reflected[x, 
                  time])\)*\((\[CapitalPsi]initialconj[x, 
                  time] + \[CapitalPsi]reflectedconj[x, 
                  time])\)], \[IndentingNewLine]{x, \(-20\), 
          0}, \[IndentingNewLine]PlotRange \[Rule] {0, 4}]]\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.97619 0.047619 0 0.154508 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.96369 .07725 -18 -4.5 ]
[.96369 .07725 0 4.5 ]
[.96369 .15451 -6 -4.5 ]
[.96369 .15451 0 4.5 ]
[.96369 .23176 -18 -4.5 ]
[.96369 .23176 0 4.5 ]
[.96369 .30902 -6 -4.5 ]
[.96369 .30902 0 4.5 ]
[.96369 .38627 -18 -4.5 ]
[.96369 .38627 0 4.5 ]
[.96369 .46353 -6 -4.5 ]
[.96369 .46353 0 4.5 ]
[.96369 .54078 -18 -4.5 ]
[.96369 .54078 0 4.5 ]
[.96369 .61803 -6 -4.5 ]
[.96369 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-15)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(-10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(-5)] .7381 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.97619 .07725 m
.98244 .07725 L
s
[(0.5)] .96369 .07725 1 0 Mshowa
.97619 .15451 m
.98244 .15451 L
s
[(1)] .96369 .15451 1 0 Mshowa
.97619 .23176 m
.98244 .23176 L
s
[(1.5)] .96369 .23176 1 0 Mshowa
.97619 .30902 m
.98244 .30902 L
s
[(2)] .96369 .30902 1 0 Mshowa
.97619 .38627 m
.98244 .38627 L
s
[(2.5)] .96369 .38627 1 0 Mshowa
.97619 .46353 m
.98244 .46353 L
s
[(3)] .96369 .46353 1 0 Mshowa
.97619 .54078 m
.98244 .54078 L
s
[(3.5)] .96369 .54078 1 0 Mshowa
.97619 .61803 m
.98244 .61803 L
s
[(4)] .96369 .61803 1 0 Mshowa
.125 Mabswid
.97619 .01545 m
.97994 .01545 L
s
.97619 .0309 m
.97994 .0309 L
s
.97619 .04635 m
.97994 .04635 L
s
.97619 .0618 m
.97994 .0618 L
s
.97619 .09271 m
.97994 .09271 L
s
.97619 .10816 m
.97994 .10816 L
s
.97619 .12361 m
.97994 .12361 L
s
.97619 .13906 m
.97994 .13906 L
s
.97619 .16996 m
.97994 .16996 L
s
.97619 .18541 m
.97994 .18541 L
s
.97619 .20086 m
.97994 .20086 L
s
.97619 .21631 m
.97994 .21631 L
s
.97619 .24721 m
.97994 .24721 L
s
.97619 .26266 m
.97994 .26266 L
s
.97619 .27812 m
.97994 .27812 L
s
.97619 .29357 m
.97994 .29357 L
s
.97619 .32447 m
.97994 .32447 L
s
.97619 .33992 m
.97994 .33992 L
s
.97619 .35537 m
.97994 .35537 L
s
.97619 .37082 m
.97994 .37082 L
s
.97619 .40172 m
.97994 .40172 L
s
.97619 .41717 m
.97994 .41717 L
s
.97619 .43262 m
.97994 .43262 L
s
.97619 .44807 m
.97994 .44807 L
s
.97619 .47898 m
.97994 .47898 L
s
.97619 .49443 m
.97994 .49443 L
s
.97619 .50988 m
.97994 .50988 L
s
.97619 .52533 m
.97994 .52533 L
s
.97619 .55623 m
.97994 .55623 L
s
.97619 .57168 m
.97994 .57168 L
s
.97619 .58713 m
.97994 .58713 L
s
.97619 .60258 m
.97994 .60258 L
s
.25 Mabswid
.97619 0 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.1506 0 m
.1533 .0006 L
.16385 .00303 L
.16895 .00399 L
.17147 .00439 L
.1738 .00469 L
.17608 .00494 L
.17815 .00511 L
.17925 .00518 L
.18045 .00524 L
.18171 .00529 L
.18289 .00533 L
.18404 .00534 L
.18526 .00535 L
.18642 .00535 L
.18747 .00534 L
.18871 .00531 L
.19006 .00528 L
.1925 .00519 L
.19506 .0051 L
.19646 .00505 L
.19777 .00502 L
.19888 .00499 L
.20008 .00497 L
.20073 .00497 L
.20142 .00497 L
.20264 .00499 L
.20378 .00502 L
.20481 .00507 L
.206 .00514 L
.20713 .00524 L
.20914 .00547 L
.21027 .00565 L
.21131 .00584 L
.2135 .00633 L
.21591 .00705 L
.21843 .008 L
.22078 .0091 L
.22577 .01215 L
.23121 .01665 L
.24111 .02792 L
.25965 .05632 L
.27902 .08586 L
.3004 .11243 L
.31014 .12618 L
.32063 .14606 L
.33054 .17159 L
.33964 .20102 L
.36014 .28023 L
.37923 .34947 L
Mistroke
.39763 .39907 L
.41731 .44291 L
.4372 .49353 L
.44767 .52225 L
.45877 .55007 L
.46866 .56959 L
.47428 .57779 L
.47698 .58094 L
.47955 .58348 L
.48186 .58539 L
.48438 .58709 L
.48666 .5883 L
.48879 .58916 L
.49009 .58957 L
.49131 .58988 L
.49241 .5901 L
.4936 .59027 L
.4949 .59039 L
.49555 .59042 L
.49627 .59044 L
.49754 .59042 L
.49872 .59034 L
.49999 .59021 L
.50133 .59001 L
.50373 .58951 L
.50633 .58879 L
.50918 .58777 L
.51429 .58544 L
.51909 .58261 L
.52802 .57534 L
.53305 .56979 L
.53765 .56356 L
.54746 .54596 L
.55659 .52395 L
.57729 .45885 L
.61636 .34552 L
.65788 .2294 L
.6787 .15689 L
.68783 .12942 L
.69788 .10522 L
.70754 .08824 L
.71658 .07699 L
.72612 .06813 L
.73637 .05969 L
.75613 .04059 L
.76656 .02885 L
.77766 .01695 L
.78325 .01183 L
.7885 .00777 L
.79322 .00484 L
Mistroke
.79565 .0036 L
.79831 .00245 L
.80065 .00162 L
.80316 .0009 L
.80581 .00033 L
.807 .00013 L
Mfstroke
.807 .00013 m
.80797 0 L
s
.82416 0 m
.82754 .00027 L
.83033 .0005 L
.83328 .00073 L
.83602 .0009 L
.83735 .00097 L
.83857 .00102 L
.83963 .00106 L
.84079 .00109 L
.84201 .00111 L
.84317 .00112 L
.84444 .00112 L
.84508 .00111 L
.84579 .0011 L
.84704 .00107 L
.84822 .00103 L
.84949 .00097 L
.85084 .0009 L
.85324 .00074 L
.85866 .00024 L
s
.85866 .00024 m
.86059 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`004`3oool4000000<0oooo0P00000e0?ooo`@000000P3oool3000003@0
oooo100000030?ooo`800000>03oool3000004h0oooo000C0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool00000=P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0B`3oool001@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000f0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1;0?ooo`003@3oool40000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02`0oooo10000004
0?ooo`040000003oool0oooo0?ooo`<00000;P3oool4000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo02l0oooo100000020?ooo`<00000CP3oool001H0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`050000003oool0oooo0?ooo`00
0000>03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`1>0?ooo`004`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000003@0oooo0`0000030?ooo`030000003oool0oooo03@0oooo0`0000030?ooo`040000003oool0
oooo000003L0oooo00<000000?ooo`3oool0CP3oool001@0oooo0P0000040?ooo`800000=`3oool0
10000000oooo0?ooo`3oool4000003D0oooo00<000000?ooo`3oool00P3oool2000003P0oooo1000
001=0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003`3ooooo000000D00000
3@3oool001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00P0oooo3P00000<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool010000000oooo0000000000090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo00170?ooo`800000TP3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo00190?ooo`800000SP3oool2
00000340oooo00<000000?ooo`3oool04@3oool004/0oooo00<000000?ooo`3oool0RP3oool00`00
0000oooo0?ooo`0a0?ooo`8000004P3oool004`0oooo00<000000?ooo`3oool0R03oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo0140oooo001<0?ooo`030000003oool0oooo08P0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0A0?ooo`00C@3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool04@3oool004h0oooo00<00000
0?ooo`3oool0Q03oool00`000000oooo0?ooo`0d0?ooo`8000004P3oool004h0oooo00<000000?oo
o`3oool0P`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0140oooo001?0?ooo`03
0000003oool0oooo0840oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0A0?ooo`00
D03oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
4@3oool00540oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0h0?ooo`8000004P3o
ool00540oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo0140oooo001B0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0A0?ooo`00D`3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool04@3oool005<0oooo00<000000?ooo`3oool0MP3oool2000003h0oooo
0P00000B0?ooo`00E03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool04@3oool005D0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0/
0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`0A
0?ooo`00E@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo02/0oooo00@000000?oo
o`3oool000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo001F0?oo
o`030000003oool0oooo0700oooo00<000000?ooo`3oool0;03oool010000000oooo0?ooo`00000;
0?ooo`030000003oool0oooo0080oooo0P00000B0?ooo`00EP3oool00`000000oooo0?ooo`1_0?oo
o`030000003oool0oooo02d0oooo00@000000?ooo`3oool00000203oool3000000D0oooo00<00000
0?ooo`3oool04@3oool005L0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0^0?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A
0?ooo`00F03oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo02l0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo001I0?oo
o`030000003oool0oooo06X0oooo00<000000?ooo`3oool0<03oool2000000T0oooo100000040?oo
o`8000004P3oool005X0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo0140oooo001J0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0
A03oool00`000000oooo0?ooo`0A0?ooo`00F`3oool00`000000oooo0?ooo`1V0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool04@3oool005`0oooo00<000000?ooo`3oool0I@3oool0
0`000000oooo0?ooo`150?ooo`8000004P3oool005d0oooo00<000000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`160?ooo`030000003oool0oooo0140oooo001N0?ooo`030000003oool0oooo0680
oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0A0?ooo`00GP3oool00`000000oooo
0?ooo`1Q0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool04@3oool005l0oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`170?ooo`8000004P3oool005l0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0140oooo001P0?oo
o`030000003oool0oooo05h0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0A0?oo
o`00H03oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool04@3oool00640oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`190?ooo`800000
4P3oool00640oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo0140oooo001R0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0@@3oool4
000000@0oooo00<000000?ooo`3oool04@3oool00680oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool006<0
oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00<0
oooo0P00000B0?ooo`00H`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`00H`3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0A0?ooo`00I03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo04<0oooo0`000005
0?ooo`030000003oool0oooo0140oooo001T0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`030?ooo`8000004P3oool006@0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0140oooo001U0?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0A0?ooo`00I@3o
ool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool04@3o
ool006H0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`1=0?ooo`8000004P3oool0
06H0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
0140oooo001V0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0C@3oool00`000000
oooo0?ooo`0A0?ooo`00I`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool04@3oool006L0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?oo
o`1>0?ooo`8000004P3oool006L0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo0140oooo001X0?ooo`030000003oool0oooo0500oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`0A0?ooo`00J03oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool006P0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`1?0?ooo`8000004P3oool006P0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo001Y0?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool0?03oool4000000<0oooo00<000000?ooo`3oool00P3oool3
000000D0oooo00<000000?ooo`3oool04@3oool006T0oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0A0?ooo`00J@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`8000004P3oool006T0oooo
00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00L0oooo
0`0000050?ooo`030000003oool0oooo0140oooo001Z0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool04@3oool006X0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0m
0?ooo`<000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo001Z0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`070?oo
o`@00000103oool200000180oooo001Z0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`0A0?ooo`00J`3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool04@3oool006/0oooo00<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo001[0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool0D`3oool200000180oooo001[0?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`00K03oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool006`0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo
001/0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0E03oool200000180oooo001/
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0A
0?ooo`00K@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool04@3oool006d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo0140oooo001]0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
EP3oool200000180oooo001]0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0A0?ooo`00KP3oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo04h0oooo100000040?ooo`030000003oool0oooo0140oooo001^0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0140oooo001^0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0D03oool00`000000
oooo0?ooo`040?ooo`8000004P3oool006l0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool006l0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool04@3oool006l0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`1@
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool04@3oool006l0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`1A0?ooo`8000001@3oool200000180oooo001`0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0A0?oo
o`00L03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool04@3oool00700oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo0140oooo001`0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0FP3o
ool200000180oooo001a0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0FP3oool0
0`000000oooo0?ooo`0A0?ooo`00L@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool04@3oool00740oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`1K0?ooo`030000003oool0oooo0140oooo001b0?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0F`3oool200000180oooo001b0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0F`3oool00`000000oooo0?ooo`0A0?ooo`00L`3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool04@3oool007<0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0140oooo001c0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool0G@3oool200000180oooo001d0?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0A0?ooo`00M03o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo04T0oooo100000030?ooo`030000003o
ool0oooo0080oooo0`0000050?ooo`030000003oool0oooo0140oooo001d0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool04@3oool007D0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool20000
0180oooo001e0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0C03oool00`000000
oooo0?ooo`070?ooo`<000001@3oool00`000000oooo0?ooo`0A0?ooo`00MP3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0140oooo001f0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0B`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool04@3oool007H0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`1<0?ooo`8000002@3oool4000000@0oooo0P00000B0?ooo`00M`3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool04@3oool007L0oooo00<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0140oooo001h0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0A0?ooo`00
N03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0640oooo0P00000B0?ooo`00N@3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool04@3o
ool007T0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0
oooo0140oooo001i0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`0A0?ooo`00NP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0680
oooo0P00000B0?ooo`00NP3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool04@3oool007/0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`1S0?ooo`030000003oool0oooo0140oooo001k0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`0A0?ooo`00N`3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo06@0oooo0P00000B0?ooo`00O03oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo06@0oooo00<000000?ooo`3oool04@3oool007`0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`1N0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`00O@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo05d0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0A0?ooo`00O@3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo0600oooo00<000000?ooo`3oool00P3oool200000180oooo001m0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0G`3oool2000000D0oooo00<000000?ooo`3oool04@3oool0
07h0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool04@3oool007h0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`1N0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool04@3oool007h0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1O0?ooo`8000001@3oool200000180
oooo001o0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0I`3oool00`000000oooo
0?ooo`0A0?ooo`00O`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool04@3oool00800oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1W
0?ooo`030000003oool0oooo0140oooo00200?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0J03oool200000180oooo00200?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0J03oool00`000000oooo0?ooo`0A0?ooo`00P@3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool04@3oool00840oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0140oooo00220?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0J@3oool200000180oooo00220?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0A0?ooo`00P`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool04@3oool008<0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0140oooo
00230?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0JP3oool200000180oooo0024
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0A
0?ooo`00Q03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05P0oooo0P0000040?oo
o`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo0140oooo00250?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0E`3oool010000000oooo0?ooo`00000;0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool008D0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00P3oool200000180oooo00260?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
F@3oool2000000T0oooo0`0000050?ooo`030000003oool0oooo0140oooo00260?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool04@3oool008H0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`1I0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0A0?ooo`00Q`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo05/0oooo0P0000090?ooo`@00000103oool200000180oooo00270?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0A0?ooo`00R03oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool04@3oool008P0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0140oooo
00290?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0L03oool200000180oooo0029
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0A
0?ooo`00RP3oool00`000000oooo0?ooo`090?ooo`800000M03oool00`000000oooo0?ooo`0A0?oo
o`00R`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool04@3oool008`0oooo0P0000040?ooo`<00000M`3oool200000180oooo002>0?ooo`@00000NP3o
ool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?oo
o`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool200000180oooo003o0?ooo`d0oooo
00<000000?ooo`3oool04@3oool00?l0oooo1`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0140oooo003o0?ooo`L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A
0?ooo`00o`3oool40?ooo`D00000103oool200000180oooo003o0?ooo`@0oooo00@000000?ooo`3o
ool000006@3oool00?l0oooo1@3oool00`000000oooo0000000I0?ooo`00o`3oool60?ooo`800000
6@3oool00?l0oooo1`3oool00`000000oooo0?ooo`0G0?ooo`00\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {347.188, 205.875}} -> {-31.0405, \
6.13135, 0.0811648, 0.0250148}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.97619 0.047619 0 0.154508 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.96369 .07725 -18 -4.5 ]
[.96369 .07725 0 4.5 ]
[.96369 .15451 -6 -4.5 ]
[.96369 .15451 0 4.5 ]
[.96369 .23176 -18 -4.5 ]
[.96369 .23176 0 4.5 ]
[.96369 .30902 -6 -4.5 ]
[.96369 .30902 0 4.5 ]
[.96369 .38627 -18 -4.5 ]
[.96369 .38627 0 4.5 ]
[.96369 .46353 -6 -4.5 ]
[.96369 .46353 0 4.5 ]
[.96369 .54078 -18 -4.5 ]
[.96369 .54078 0 4.5 ]
[.96369 .61803 -6 -4.5 ]
[.96369 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-15)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(-10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(-5)] .7381 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.97619 .07725 m
.98244 .07725 L
s
[(0.5)] .96369 .07725 1 0 Mshowa
.97619 .15451 m
.98244 .15451 L
s
[(1)] .96369 .15451 1 0 Mshowa
.97619 .23176 m
.98244 .23176 L
s
[(1.5)] .96369 .23176 1 0 Mshowa
.97619 .30902 m
.98244 .30902 L
s
[(2)] .96369 .30902 1 0 Mshowa
.97619 .38627 m
.98244 .38627 L
s
[(2.5)] .96369 .38627 1 0 Mshowa
.97619 .46353 m
.98244 .46353 L
s
[(3)] .96369 .46353 1 0 Mshowa
.97619 .54078 m
.98244 .54078 L
s
[(3.5)] .96369 .54078 1 0 Mshowa
.97619 .61803 m
.98244 .61803 L
s
[(4)] .96369 .61803 1 0 Mshowa
.125 Mabswid
.97619 .01545 m
.97994 .01545 L
s
.97619 .0309 m
.97994 .0309 L
s
.97619 .04635 m
.97994 .04635 L
s
.97619 .0618 m
.97994 .0618 L
s
.97619 .09271 m
.97994 .09271 L
s
.97619 .10816 m
.97994 .10816 L
s
.97619 .12361 m
.97994 .12361 L
s
.97619 .13906 m
.97994 .13906 L
s
.97619 .16996 m
.97994 .16996 L
s
.97619 .18541 m
.97994 .18541 L
s
.97619 .20086 m
.97994 .20086 L
s
.97619 .21631 m
.97994 .21631 L
s
.97619 .24721 m
.97994 .24721 L
s
.97619 .26266 m
.97994 .26266 L
s
.97619 .27812 m
.97994 .27812 L
s
.97619 .29357 m
.97994 .29357 L
s
.97619 .32447 m
.97994 .32447 L
s
.97619 .33992 m
.97994 .33992 L
s
.97619 .35537 m
.97994 .35537 L
s
.97619 .37082 m
.97994 .37082 L
s
.97619 .40172 m
.97994 .40172 L
s
.97619 .41717 m
.97994 .41717 L
s
.97619 .43262 m
.97994 .43262 L
s
.97619 .44807 m
.97994 .44807 L
s
.97619 .47898 m
.97994 .47898 L
s
.97619 .49443 m
.97994 .49443 L
s
.97619 .50988 m
.97994 .50988 L
s
.97619 .52533 m
.97994 .52533 L
s
.97619 .55623 m
.97994 .55623 L
s
.97619 .57168 m
.97994 .57168 L
s
.97619 .58713 m
.97994 .58713 L
s
.97619 .60258 m
.97994 .60258 L
s
.25 Mabswid
.97619 0 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.23687 0 m
.2461 .00257 L
.26621 .01027 L
.28644 .01801 L
.29635 .02163 L
.30545 .02559 L
.31428 .03086 L
.31872 .03432 L
.32359 .03887 L
.33373 .05125 L
.34316 .06638 L
.38218 .14962 L
.42364 .25442 L
.46359 .38025 L
.50203 .48847 L
.52149 .5454 L
.52682 .55937 L
.53255 .57249 L
.53793 .58243 L
.54291 .58922 L
.54536 .59161 L
.54661 .59259 L
.54796 .59346 L
.54873 .59388 L
.54944 .5942 L
.55011 .59445 L
.55084 .59467 L
.55212 .59493 L
.55281 .59499 L
.55346 .59501 L
.55476 .59491 L
.55599 .59467 L
.55709 .59432 L
.5583 .59381 L
.56099 .59218 L
.56348 .59014 L
.56781 .5855 L
.5726 .57915 L
.58228 .56435 L
.59172 .55054 L
.60165 .53945 L
.60685 .53531 L
.61253 .53178 L
.62251 .52625 L
.6278 .52237 L
.63279 .51726 L
.63728 .511 L
.64213 .50202 L
.64743 .48931 L
.65304 .47241 L
Mistroke
.66309 .43394 L
.6829 .34217 L
.69156 .30453 L
.701 .27054 L
.70618 .25561 L
.71098 .24409 L
.72046 .22672 L
.73123 .21155 L
.74136 .19621 L
.75125 .17615 L
.76193 .14748 L
.78056 .08904 L
.79091 .06095 L
.79595 .05022 L
.80055 .04248 L
.80541 .03644 L
.80808 .03401 L
.81061 .03226 L
.81194 .03154 L
.81336 .03091 L
.81458 .03047 L
.81589 .03011 L
.81663 .02995 L
.8173 .02982 L
.81862 .02966 L
.81936 .0296 L
.82017 .02956 L
.82093 .02955 L
.82163 .02956 L
.82292 .02961 L
.82356 .02966 L
.82427 .02972 L
.8267 .03002 L
.82935 .03042 L
.83219 .03085 L
.83358 .03104 L
.83488 .03119 L
.83606 .0313 L
.83734 .03138 L
.83855 .03142 L
.83984 .03142 L
.84093 .03138 L
.84215 .03128 L
.84332 .03114 L
.84455 .03093 L
.84676 .0304 L
.84914 .02962 L
.85174 .02849 L
.85641 .02577 L
.86075 .02254 L
Mistroke
.87948 .00523 L
.88461 .00101 L
Mfstroke
.88461 .00101 m
.88613 0 L
s
.93505 0 m
.93627 .00028 L
.93887 .00075 L
.94127 .00109 L
.94223 .0012 L
.94328 .0013 L
.94418 .00138 L
.94516 .00144 L
.94625 .00149 L
.9474 .00152 L
.94846 .00153 L
.94945 .00152 L
.95058 .00149 L
.95165 .00145 L
.95261 .0014 L
.95365 .00133 L
.95598 .00111 L
.95813 .00086 L
s
.95813 .00086 m
.96354 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`004`3oool4000000<0oooo0P00000e0?ooo`@000000P3oool3000003@0
oooo100000030?ooo`800000>03oool3000004h0oooo000C0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool00000=P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0B`3oool001@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000f0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1;0?ooo`003@3oool40000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02`0oooo10000004
0?ooo`040000003oool0oooo0?ooo`<00000;P3oool4000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo02l0oooo100000020?ooo`<00000CP3oool001H0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`050000003oool0oooo0?ooo`00
0000>03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`1>0?ooo`004`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000003@0oooo0`0000030?ooo`030000003oool0oooo03@0oooo0`0000030?ooo`040000003oool0
oooo000003L0oooo00<000000?ooo`3oool0CP3oool001@0oooo0P0000040?ooo`800000=`3oool0
10000000oooo0?ooo`3oool4000003D0oooo00<000000?ooo`3oool00P3oool2000003P0oooo1000
001=0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003`3ooooo000000D00000
3@3oool001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`<000002`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3o
ool005<0oooo0`00002L0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool0
05H0oooo0P00002I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool04@3oool005P0
oooo0`00002E0?ooo`030000003oool0oooo01T0oooo0P00000B0?ooo`00F`3oool300000940oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0A0?ooo`00GP3oool00`000000oooo0?oo
o`2<0?ooo`8000007@3oool00`000000oooo0?ooo`0A0?ooo`00G`3oool00`000000oooo0?ooo`21
0?ooo`8000001P3oool2000001l0oooo00<000000?ooo`3oool04@3oool00600oooo00<000000?oo
o`3oool0OP3oool:00000240oooo0P00000B0?ooo`00H@3oool2000007d0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`0A0?ooo`00H`3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool04@3oool006@0oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0140oooo001T0?ooo`030000003oool0
oooo07L0oooo00<000000?ooo`3oool0:`3oool200000180oooo001U0?ooo`030000003oool0oooo
07D0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0A0?ooo`00IP3oool00`000000
oooo0?ooo`1d0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool04@3oool006L0oooo
00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0140oooo
001W0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0;@3oool200000180oooo001X
0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0A
0?ooo`00J03oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo01/0oooo0P0000040?oo
o`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo0140oooo001Y0?ooo`03
0000003oool0oooo06l0oooo00<000000?ooo`3oool06P3oool010000000oooo0?ooo`00000;0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool006T0oooo00<000000?ooo`3o
ool0KP3oool00`000000oooo0?ooo`0K0?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`3oool00P3oool200000180oooo001Z0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3o
ool06`3oool010000000oooo0?ooo`0000080?ooo`<000001@3oool00`000000oooo0?ooo`0A0?oo
o`00JP3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo01`0oooo00@000000?ooo`3o
ool00000203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo001[0?ooo`03
0000003oool0oooo06/0oooo00<000000?ooo`3oool0703oool010000000oooo0?ooo`0000080?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool006/0oooo00<000000?ooo`3o
ool0J`3oool00`000000oooo0?ooo`0M0?ooo`8000002@3oool4000000@0oooo0P00000B0?ooo`00
K03oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
4@3oool006`0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo0140oooo001]0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0A0?ooo`00K@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo
0380oooo0P00000B0?ooo`00K@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool04@3oool006h0oooo00<000000?ooo`3oool0IP3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo0140oooo001^0?ooo`030000003oool0oooo06D0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0A0?ooo`00K`3oool00`000000oooo0?ooo`1T
0?ooo`030000003oool0oooo03<0oooo0P00000B0?ooo`00K`3oool00`000000oooo0?ooo`1T0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool04@3oool00700oooo00<000000?ooo`3o
ool0HP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo001`0?ooo`030000
003oool0oooo0680oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`00L@3o
ool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo03@0oooo0P00000B0?ooo`00L@3oool0
0`000000oooo0?ooo`1P0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool04@3oool0
0780oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0]0?ooo`@00000103oool00`00
0000oooo0?ooo`0A0?ooo`00LP3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`00LP3oool00`000000oooo
0?ooo`1N0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool00`3oool200000180oooo
001c0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0140oooo001c0?ooo`030000003oool0oooo05d0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo001d0?oo
o`030000003oool0oooo05`0oooo00<000000?ooo`3oool0;P3oool3000000D0oooo00<000000?oo
o`3oool04@3oool007@0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo00<0oooo0P00000B0?ooo`00M03oool00`000000oooo0?ooo`1K0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool04@3oool007D0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0140oooo001e0?ooo`030000003oool0
oooo05T0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0A0?ooo`00MP3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo03P0oooo0P00000B0?ooo`00MP3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool04@3oool007H0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0140oooo
001g0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`0A0?ooo`00M`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo03/0oooo0P00000B
0?ooo`00N03oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool04@3oool007P0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo0140oooo001i0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0A0?ooo`00N@3oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo03d0oooo0P00000B0?ooo`00N@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool04@3oool007X0oooo00<000000?ooo`3oool0CP3oool00`00
0000oooo0?ooo`0Z0?ooo`@000000`3oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`00
0000oooo0?ooo`0A0?ooo`00NP3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140
oooo001k0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0080oooo0P00000B0?ooo`00N`3oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool01`3oool3000000D0oooo00<0
00000?ooo`3oool04@3oool007/0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A
0?ooo`00O03oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02h0oooo0`0000090?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool007`0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00L0oooo100000040?ooo`80
00004P3oool007d0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`130?ooo`030000
003oool0oooo0140oooo001m0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`0A0?ooo`00O@3oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool04@3oool007h0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`130?ooo`8000004P3oool007h0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo0140oooo001n0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0A0?ooo`00O`3oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool04@3oool007l0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`150?ooo`8000004P3oool007l0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0140oooo00200?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0A0?ooo`00
P03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
4@3oool00800oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`160?ooo`8000004P3o
ool00800oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo0140oooo00210?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0?`3oool40000
00@0oooo00<000000?ooo`3oool04@3oool00840oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00840oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00@0oooo
0P00000B0?ooo`00PP3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`00PP3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A
0?ooo`00PP3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0400oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0A0?ooo`00P`3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo0440oooo0P0000050?ooo`8000004P3oool008<0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0140oooo00230?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0A0?ooo`00Q03o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool04@3o
ool008@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`190?ooo`8000004P3oool0
08@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
0140oooo00250?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`0A0?ooo`00Q@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool04@3oool008D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`1:0?ooo`8000004P3oool008D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo0140oooo00260?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`0A0?ooo`00QP3oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool04@3oool008H0oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`1;0?ooo`8000004P3oool008L0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0140oooo00270?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0=`3oool4000000<0oooo00<000000?ooo`3oool00P3oool3
000000D0oooo00<000000?ooo`3oool04@3oool008L0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0A0?ooo`00R03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`8000004P3oool008P0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00L0oooo
0`0000050?ooo`030000003oool0oooo0140oooo00280?ooo`030000003oool0oooo0380oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool04@3oool008T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0h
0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0A0?ooo`00R@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo03T0oooo0P000009
0?ooo`@00000103oool200000180oooo002:0?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`0A0?ooo`00RP3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool04@3oool008X0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0140oooo002;0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool0C@3oool200000180oooo002;0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0A0?ooo`00R`3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool04@3oool008`0
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0140
oooo002<0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0CP3oool200000180oooo
002<0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`0A0?ooo`00S@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool04@3oool008d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo0140oooo002=0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0C`3oool200000180oooo002>0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0A0?ooo`00SP3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo04T0oooo0P0000050?ooo`030000003oool0oooo0140oooo002?0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0B03oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0140oooo002?0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`020?ooo`8000004P3oool008l0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`1:0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`00T03oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0A0?ooo`00T03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04T0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0A0?ooo`00T03oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo04X0oooo0P0000050?ooo`8000004P3oool00940oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo002A
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A
0?ooo`00T@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0580oooo00<000000?oo
o`3oool04@3oool00980oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1C0?ooo`80
00004P3oool00980oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo0140oooo002B0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`0A0?ooo`00T`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool04@3oool009<0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`1E0?ooo`8000004P3oool009<0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo0140oooo002D0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0A0?ooo`00U03oool00`000000oooo0?oo
o`0J0?ooo`800000F@3oool00`000000oooo0?ooo`0A0?ooo`00U03oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo05T0oooo0P00000B0?ooo`00U@3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo05X0oooo00<000000?ooo`3oool04@3oool009D0oooo00<000000?ooo`3o
ool05@3oool2000004X0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`03
0000003oool0oooo0140oooo002E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
B@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool04@3oool009H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool200000180oooo002F0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0C03oool2000000T0oooo0`0000050?ooo`030000003o
ool0oooo0140oooo002F0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool0
09L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1=0?ooo`040000003oool0oooo
000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00U`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo04l0oooo0P0000090?ooo`@00000103oool20000
0180oooo002G0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0HP3oool00`000000
oooo0?ooo`0A0?ooo`00V03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool04@3oool009P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo0140oooo002I0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0I03oool200000180oooo002I0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0I@3oool00`000000oooo0?ooo`0A0?ooo`00VP3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo06H0oooo00<000000?ooo`3oool04@3oool009X0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0140oooo002K0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0I`3oool200000180oooo002L0?ooo`040000003oool0
oooo0?ooo`800000JP3oool00`000000oooo0?ooo`0A0?ooo`00W@3oool4000006/0oooo00<00000
0?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`80
00004P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool70?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool04@3oool00?l0oooo1`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0140oooo003o0?ooo`@0oooo1@0000040?ooo`8000004P3oool00?l0
oooo103oool010000000oooo0?ooo`00000I0?ooo`00o`3oool50?ooo`030000003oool0000001T0
oooo003o0?ooo`H0oooo0P00000I0?ooo`00o`3oool70?ooo`030000003oool0oooo01L0oooo0000
\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {495.875, 354.562}} -> {-31.0405, \
10.7806, 0.0811648, 0.0250148}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.97619 0.047619 0 0.154508 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.96369 .07725 -18 -4.5 ]
[.96369 .07725 0 4.5 ]
[.96369 .15451 -6 -4.5 ]
[.96369 .15451 0 4.5 ]
[.96369 .23176 -18 -4.5 ]
[.96369 .23176 0 4.5 ]
[.96369 .30902 -6 -4.5 ]
[.96369 .30902 0 4.5 ]
[.96369 .38627 -18 -4.5 ]
[.96369 .38627 0 4.5 ]
[.96369 .46353 -6 -4.5 ]
[.96369 .46353 0 4.5 ]
[.96369 .54078 -18 -4.5 ]
[.96369 .54078 0 4.5 ]
[.96369 .61803 -6 -4.5 ]
[.96369 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-15)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(-10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(-5)] .7381 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.97619 .07725 m
.98244 .07725 L
s
[(0.5)] .96369 .07725 1 0 Mshowa
.97619 .15451 m
.98244 .15451 L
s
[(1)] .96369 .15451 1 0 Mshowa
.97619 .23176 m
.98244 .23176 L
s
[(1.5)] .96369 .23176 1 0 Mshowa
.97619 .30902 m
.98244 .30902 L
s
[(2)] .96369 .30902 1 0 Mshowa
.97619 .38627 m
.98244 .38627 L
s
[(2.5)] .96369 .38627 1 0 Mshowa
.97619 .46353 m
.98244 .46353 L
s
[(3)] .96369 .46353 1 0 Mshowa
.97619 .54078 m
.98244 .54078 L
s
[(3.5)] .96369 .54078 1 0 Mshowa
.97619 .61803 m
.98244 .61803 L
s
[(4)] .96369 .61803 1 0 Mshowa
.125 Mabswid
.97619 .01545 m
.97994 .01545 L
s
.97619 .0309 m
.97994 .0309 L
s
.97619 .04635 m
.97994 .04635 L
s
.97619 .0618 m
.97994 .0618 L
s
.97619 .09271 m
.97994 .09271 L
s
.97619 .10816 m
.97994 .10816 L
s
.97619 .12361 m
.97994 .12361 L
s
.97619 .13906 m
.97994 .13906 L
s
.97619 .16996 m
.97994 .16996 L
s
.97619 .18541 m
.97994 .18541 L
s
.97619 .20086 m
.97994 .20086 L
s
.97619 .21631 m
.97994 .21631 L
s
.97619 .24721 m
.97994 .24721 L
s
.97619 .26266 m
.97994 .26266 L
s
.97619 .27812 m
.97994 .27812 L
s
.97619 .29357 m
.97994 .29357 L
s
.97619 .32447 m
.97994 .32447 L
s
.97619 .33992 m
.97994 .33992 L
s
.97619 .35537 m
.97994 .35537 L
s
.97619 .37082 m
.97994 .37082 L
s
.97619 .40172 m
.97994 .40172 L
s
.97619 .41717 m
.97994 .41717 L
s
.97619 .43262 m
.97994 .43262 L
s
.97619 .44807 m
.97994 .44807 L
s
.97619 .47898 m
.97994 .47898 L
s
.97619 .49443 m
.97994 .49443 L
s
.97619 .50988 m
.97994 .50988 L
s
.97619 .52533 m
.97994 .52533 L
s
.97619 .55623 m
.97994 .55623 L
s
.97619 .57168 m
.97994 .57168 L
s
.97619 .58713 m
.97994 .58713 L
s
.97619 .60258 m
.97994 .60258 L
s
.25 Mabswid
.97619 0 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.27238 0 m
.27852 .00024 L
.28357 .00041 L
.28898 .0006 L
.29408 .00083 L
.29872 .00111 L
.30366 .00152 L
.30901 .00211 L
.31407 .00287 L
.31874 .00376 L
.32898 .00645 L
.33983 .01049 L
.35938 .02066 L
.37768 .03348 L
.38807 .04282 L
.39795 .05378 L
.41647 .08113 L
.45469 .15576 L
.47602 .2001 L
.49535 .25162 L
.51552 .32594 L
.5345 .40375 L
.54428 .43819 L
.54961 .45377 L
.5546 .46593 L
.55921 .47511 L
.56341 .48185 L
.56807 .48774 L
.57307 .49259 L
.58312 .50012 L
.58862 .5045 L
.59379 .50971 L
.59817 .51537 L
.60289 .52298 L
.61294 .54446 L
.63126 .5922 L
.63628 .60305 L
.63903 .60788 L
.64164 .61153 L
.64406 .61405 L
.64473 .61458 L
.64543 .61505 L
.64669 .61571 L
.64783 .61606 L
.64888 .61618 L
.65004 .61608 L
.65129 .61571 L
.65194 .6154 L
.65262 .61499 L
.65386 .61402 L
Mistroke
.65533 .6125 L
.65667 .61077 L
.6593 .60639 L
.66177 .60113 L
.66637 .58862 L
.67134 .57166 L
.68141 .53028 L
.69245 .48398 L
.69745 .46595 L
.7028 .45007 L
.70539 .4438 L
.70785 .43878 L
.71003 .43503 L
.71244 .43166 L
.71499 .42892 L
.71629 .42782 L
.71769 .42683 L
.719 .42609 L
.7202 .42555 L
.72134 .42514 L
.72255 .4248 L
.72394 .42451 L
.72524 .42432 L
.72603 .42423 L
.72678 .42416 L
.72817 .42405 L
.72942 .42395 L
.73074 .42383 L
.73143 .42375 L
.73219 .42364 L
.73352 .42339 L
.73483 .42306 L
.73603 .42264 L
.73735 .42205 L
.73876 .42124 L
.74112 .4194 L
.74372 .41655 L
.74603 .4132 L
.74852 .40863 L
.75302 .39762 L
.75834 .37991 L
.76393 .35592 L
.77394 .30236 L
.7842 .24156 L
.79389 .1894 L
.79812 .17059 L
.80259 .15409 L
.80493 .14698 L
.8075 .14036 L
.80983 .13547 L
Mistroke
.81203 .13175 L
.81325 .13006 L
.81458 .12852 L
.8158 .12735 L
.81691 .12649 L
.81823 .12571 L
.81895 .12539 L
.81963 .12515 L
.82085 .12486 L
.82216 .12474 L
.8233 .12479 L
.82456 .12498 L
.82587 .12533 L
.82709 .12576 L
.83163 .12796 L
.83412 .12933 L
.83683 .13074 L
.83807 .1313 L
.83939 .13181 L
.84051 .13216 L
.84175 .13246 L
.84248 .13257 L
.84316 .13264 L
.8439 .13267 L
.84467 .13264 L
.84598 .13246 L
.84673 .13228 L
.84742 .13206 L
.84873 .1315 L
.84991 .13081 L
.85258 .12863 L
.8549 .12601 L
.85744 .12232 L
.86258 .11238 L
.87179 .08749 L
.88267 .05211 L
.8926 .02223 L
.89739 .01082 L
.89991 .00585 L
.9026 .00145 L
Mfstroke
.9026 .00145 m
.9037 0 L
s
.92609 0 m
.92726 .00106 L
.93298 .0075 L
.93774 .01298 L
.94294 .01829 L
.94531 .0203 L
.94784 .02206 L
.94907 .02277 L
.95023 .02333 L
.95126 .02376 L
.9524 .02413 L
.95304 .02429 L
.95372 .02444 L
.95445 .02455 L
.95512 .02462 L
.95644 .02466 L
.95763 .02457 L
.95836 .02447 L
.95903 .02434 L
.96054 .02392 L
.96188 .02342 L
.9633 .02275 L
.96804 .01961 L
.97328 .01487 L
.97619 .01185 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`004`3oool4000000<0oooo0P00000e0?ooo`@000000P3oool3000003@0
oooo100000030?ooo`800000>03oool3000004h0oooo000C0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool00000=P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0B`3oool001@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000f0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1;0?ooo`003@3oool40000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02`0oooo10000004
0?ooo`040000003oool0oooo0?ooo`<00000;P3oool4000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo02l0oooo100000020?ooo`<00000CP3oool001H0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`050000003oool0oooo0?ooo`00
0000>03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`1>0?ooo`004`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000003@0oooo0`0000030?ooo`030000003oool0oooo03@0oooo0`0000030?ooo`040000003oool0
oooo000003L0oooo00<000000?ooo`3oool0CP3oool001@0oooo0P0000040?ooo`800000=`3oool0
10000000oooo0?ooo`3oool4000003D0oooo00<000000?ooo`3oool00P3oool2000003P0oooo1000
001=0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003`3ooooo000000D00000
3@3oool001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo1P0000060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0A0?ooo`00I@3oool200000940oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo001W0?ooo`800000SP3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool006T0
oooo0P00002<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool300000180
oooo001[0?ooo`800000R@3oool00`000000oooo0?ooo`0:0?ooo`8000001@3oool00`000000oooo
0000000C0?ooo`00K@3oool2000008L0oooo00<000000?ooo`3oool02`3oool600000080oooo00<0
00000?ooo`3oool04@3oool006l0oooo0P0000250?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool04@3oool00740oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0D0?oo
o`8000004P3oool00780oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo0140oooo001b0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0A0?ooo`00L`3oool00`000000oooo0?ooo`1o0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool04@3oool007@0oooo00<000000?ooo`3oool0O@3oool0
0`000000oooo0?ooo`0E0?ooo`8000004P3oool007D0oooo00<000000?ooo`3oool0O03oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo001f0?ooo`030000003oool0oooo07/0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`00M`3oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool007L0oooo00<0
00000?ooo`3oool0N@3oool00`000000oooo0?ooo`0F0?ooo`8000004P3oool007P0oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo001i0?oo
o`030000003oool0oooo07H0oooo00<000000?ooo`3oool0103oool2000000@0oooo00<000000?oo
o`3oool00P3oool3000000D0oooo00<000000?ooo`3oool04@3oool007X0oooo00<000000?ooo`3o
ool0M@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`00NP3oool00`000000oooo0?ooo`1e0?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?oo
o`8000004P3oool007/0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`040?ooo`04
0000003oool0oooo000000P0oooo0`0000050?ooo`030000003oool0oooo0140oooo001l0?ooo`03
0000003oool0oooo0780oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000080?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool007`0oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00O@3oool00`000000oooo0?ooo`1`0?ooo`03
0000003oool0oooo00H0oooo0P0000090?ooo`@00000103oool200000180oooo001m0?ooo`030000
003oool0oooo0700oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0A0?ooo`00OP3o
ool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool04@3o
ool007h0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo0140oooo001o0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool06`3oool20000
0180oooo001o0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0A0?ooo`00P03oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool04@3oool00800oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo0140oooo00210?ooo`030000003oool0oooo05l0oooo0`000006
0?ooo`8000007P3oool200000180oooo00210?ooo`030000003oool0oooo05h0oooo0P0000020?oo
o`800000103oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo00220?ooo`03
0000003oool0oooo05`0oooo0P0000050?ooo`@00000803oool00`000000oooo0?ooo`0A0?ooo`00
PP3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
4@3oool008<0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0Y0?ooo`8000004P3o
ool008<0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo0140oooo00240?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool08P3oool40000
00@0oooo00<000000?ooo`3oool04@3oool008@0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool008D0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00<0oooo
0P00000B0?ooo`00Q@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`00QP3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A
0?ooo`00QP3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo02<0oooo0`0000050?oo
o`030000003oool0oooo0140oooo00270?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`030?ooo`8000004P3oool008L0oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0140oooo00280?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0A0?ooo`00R03oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool04@3oool0
08P0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0/0?ooo`8000004P3oool008T0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0140
oooo00290?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`0A0?ooo`00RP3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool04@3oool008X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0]
0?ooo`8000004P3oool008X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo0140oooo002;0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0A0?ooo`00R`3oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool04@3oool008`0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`0^0?ooo`8000004P3oool008`0oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo002<0?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool06P3oool4000000<0oooo00<000000?ooo`3oool00P3oool30000
00D0oooo00<000000?ooo`3oool04@3oool008d0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0A0?ooo`00S@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`8000004P3oool008d0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo0`00
00050?ooo`030000003oool0oooo0140oooo002>0?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool04@3oool008h0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0K0?oo
o`<000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo002?0?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`@0
0000103oool200000180oooo002?0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0A0?ooo`00S`3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool04@3oool00900oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0140oooo002@0?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool0<03oool200000180oooo002@0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0A0?ooo`00T03oool00`000000oooo
0?ooo`160?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool04@3oool00940oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0140oooo002A
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0<@3oool200000180oooo002A0?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0A0?oo
o`00T@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool04@3oool00980oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0140oooo002B0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0<P3o
ool200000180oooo002B0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0A0?ooo`00TP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
02X0oooo100000040?ooo`030000003oool0oooo0140oooo002C0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140
oooo002C0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`040?ooo`8000004P3oool009<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool009<0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool04@3oool009@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0[0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool04@3oool009@0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0/0?ooo`8000001@3oool200000180oooo002D0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0A0?ooo`00
U@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
4@3oool009D0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo0140oooo002E0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool2
00000180oooo002E0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0A0?ooo`00UP3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool04@3oool009H0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo0140oooo002F0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool0=03oool200000180oooo002F0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`00U`3oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo03D0oooo00<000000?ooo`3oool04@3oool009L0oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0140oooo002G0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool0=@3oool200000180oooo002G0?ooo`030000003o
ool0oooo03T0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0A0?ooo`00V03oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0280oooo100000030?ooo`030000003oool0
oooo0080oooo0`0000050?ooo`030000003oool0oooo0140oooo002H0?ooo`030000003oool0oooo
03P0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool04@3oool009P0oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool200000180
oooo002H0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`070?ooo`<000001@3oool00`000000oooo0?ooo`0A0?ooo`00V@3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0140oooo002I0?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool08`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool04@3oool009T0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0T
0?ooo`8000002@3oool4000000@0oooo0P00000B0?ooo`00V@3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool04@3oool009X0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0140oooo002J0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0A0?ooo`00VP3o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo03T0oooo0P00000B0?ooo`00V`3oool0
0`000000oooo0?ooo`0_0?ooo`<00000?03oool00`000000oooo0?ooo`0A0?ooo`00V`3oool00`00
0000oooo0?ooo`0[0?ooo`D00000?P3oool00`000000oooo0?ooo`0A0?ooo`00V`3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool04@3oool009`0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`120?ooo`8000004P3oool009`0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0140oooo002L
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0A
0?ooo`00W@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool04@3oool009d0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`140?ooo`80
00004P3oool009d0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo0140oooo002N0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0?@3o
ool2000000D0oooo00<000000?ooo`3oool04@3oool009h0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0m0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool04@3o
ool009l0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo0080oooo0P00000B0?ooo`00W`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
03h0oooo0P0000050?ooo`030000003oool0oooo0140oooo002P0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140
oooo002P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0?P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0140oooo002Q0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0?`3oool2000000D0oooo0P00000B0?ooo`00X@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool04@3oool00:80oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0140oooo002S0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0A0?oo
o`00Y03oool2000001/0oooo00<000000?ooo`3oool0B03oool200000180oooo002V0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0A0?ooo`00Y`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool04@3o
ool00:L0oooo0P00000H0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool04@3oool0
0:T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`190?ooo`8000004P3oool00:X0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0140
oooo002[0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`0A0?ooo`00Z`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool04@3oool00:`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1:
0?ooo`8000004P3oool00:`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo0140oooo002]0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0=`3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3o
ool04@3oool00:d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0f0?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`00
[P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`020?ooo`8000004P3oool00:h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0h0?ooo`8000002@3oool3000000D0oooo00<000000?ooo`3oool04@3o
ool00:h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00[`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo03L0oooo00@000000?ooo`3oool00000203oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo002_0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0>03oool2000000T0oooo100000040?ooo`8000004P3oool00:l0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0140
oooo002`0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0C03oool00`000000oooo
0?ooo`0A0?ooo`00/03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool04@3oool00;00oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1<
0?ooo`8000004P3oool00;40oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo0140oooo002a0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0C03oool00`000000oooo0?ooo`0A0?ooo`00/@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool04@3oool00;80oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`1=0?ooo`8000004P3oool00;80oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0140oooo002c0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0A0?ooo`00/`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool04@3oool00;@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1?0?ooo`8000004P3oool00;@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo002e
0?ooo`050000003oool0oooo0?ooo`000000C03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0140oooo002f0?ooo`@00000C03oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0140oooo002g0?ooo`030000003oool0oooo04T0oooo1@0000040?ooo`8000004P3oool00?l0
oooo103oool010000000oooo0?ooo`00000I0?ooo`00o`3oool50?ooo`030000003oool0000001T0
oooo003o0?ooo`H0oooo0P00000I0?ooo`00o`3oool70?ooo`030000003oool0oooo01L0oooo0000
\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {644.562, 503.25}} -> {-31.0405, \
15.4298, 0.0811648, 0.0250148}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.97619 0.047619 0 0.154508 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.96369 .07725 -18 -4.5 ]
[.96369 .07725 0 4.5 ]
[.96369 .15451 -6 -4.5 ]
[.96369 .15451 0 4.5 ]
[.96369 .23176 -18 -4.5 ]
[.96369 .23176 0 4.5 ]
[.96369 .30902 -6 -4.5 ]
[.96369 .30902 0 4.5 ]
[.96369 .38627 -18 -4.5 ]
[.96369 .38627 0 4.5 ]
[.96369 .46353 -6 -4.5 ]
[.96369 .46353 0 4.5 ]
[.96369 .54078 -18 -4.5 ]
[.96369 .54078 0 4.5 ]
[.96369 .61803 -6 -4.5 ]
[.96369 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-15)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(-10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(-5)] .7381 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.97619 .07725 m
.98244 .07725 L
s
[(0.5)] .96369 .07725 1 0 Mshowa
.97619 .15451 m
.98244 .15451 L
s
[(1)] .96369 .15451 1 0 Mshowa
.97619 .23176 m
.98244 .23176 L
s
[(1.5)] .96369 .23176 1 0 Mshowa
.97619 .30902 m
.98244 .30902 L
s
[(2)] .96369 .30902 1 0 Mshowa
.97619 .38627 m
.98244 .38627 L
s
[(2.5)] .96369 .38627 1 0 Mshowa
.97619 .46353 m
.98244 .46353 L
s
[(3)] .96369 .46353 1 0 Mshowa
.97619 .54078 m
.98244 .54078 L
s
[(3.5)] .96369 .54078 1 0 Mshowa
.97619 .61803 m
.98244 .61803 L
s
[(4)] .96369 .61803 1 0 Mshowa
.125 Mabswid
.97619 .01545 m
.97994 .01545 L
s
.97619 .0309 m
.97994 .0309 L
s
.97619 .04635 m
.97994 .04635 L
s
.97619 .0618 m
.97994 .0618 L
s
.97619 .09271 m
.97994 .09271 L
s
.97619 .10816 m
.97994 .10816 L
s
.97619 .12361 m
.97994 .12361 L
s
.97619 .13906 m
.97994 .13906 L
s
.97619 .16996 m
.97994 .16996 L
s
.97619 .18541 m
.97994 .18541 L
s
.97619 .20086 m
.97994 .20086 L
s
.97619 .21631 m
.97994 .21631 L
s
.97619 .24721 m
.97994 .24721 L
s
.97619 .26266 m
.97994 .26266 L
s
.97619 .27812 m
.97994 .27812 L
s
.97619 .29357 m
.97994 .29357 L
s
.97619 .32447 m
.97994 .32447 L
s
.97619 .33992 m
.97994 .33992 L
s
.97619 .35537 m
.97994 .35537 L
s
.97619 .37082 m
.97994 .37082 L
s
.97619 .40172 m
.97994 .40172 L
s
.97619 .41717 m
.97994 .41717 L
s
.97619 .43262 m
.97994 .43262 L
s
.97619 .44807 m
.97994 .44807 L
s
.97619 .47898 m
.97994 .47898 L
s
.97619 .49443 m
.97994 .49443 L
s
.97619 .50988 m
.97994 .50988 L
s
.97619 .52533 m
.97994 .52533 L
s
.97619 .55623 m
.97994 .55623 L
s
.97619 .57168 m
.97994 .57168 L
s
.97619 .58713 m
.97994 .58713 L
s
.97619 .60258 m
.97994 .60258 L
s
.25 Mabswid
.97619 0 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.32437 0 m
.34247 .00102 L
.35184 .0016 L
.36173 .00238 L
.3669 .00291 L
.37258 .00366 L
.37774 .00453 L
.38256 .00554 L
.38757 .00683 L
.39302 .00855 L
.40292 .0126 L
.42148 .02326 L
.44088 .03675 L
.46229 .05139 L
.47204 .05868 L
.48255 .06873 L
.49248 .08211 L
.50157 .09902 L
.51139 .12291 L
.52051 .1499 L
.54122 .21821 L
.55175 .24902 L
.56169 .27187 L
.57061 .28719 L
.58028 .30065 L
.58524 .30768 L
.59056 .3164 L
.60017 .33789 L
.60541 .35384 L
.6102 .37132 L
.62122 .42124 L
.63122 .47323 L
.64187 .52527 L
.64704 .5458 L
.64958 .55418 L
.65191 .56076 L
.654 .5657 L
.65628 .57004 L
.65858 .57323 L
.65983 .57448 L
.661 .57533 L
.66224 .57591 L
.66339 .57614 L
.66464 .57607 L
.66528 .57592 L
.66598 .57565 L
.66714 .57498 L
.6684 .57396 L
.67068 .57139 L
.67304 .56782 L
Mistroke
.67528 .56368 L
.67949 .55438 L
.68986 .52828 L
.69438 .5183 L
.69675 .51396 L
.69927 .51027 L
.70049 .50885 L
.70183 .50759 L
.70306 .50673 L
.7042 .50618 L
.70537 .50589 L
.70644 .50586 L
.70768 .50612 L
.70885 .50665 L
.71008 .50751 L
.71139 .50876 L
.71374 .51187 L
.71627 .5164 L
.71906 .5227 L
.73745 .58158 L
.74236 .59521 L
.74483 .6005 L
.74625 .60295 L
.74753 .60477 L
.74872 .60608 L
.74985 .60697 L
.75104 .60754 L
.75233 .6077 L
.75345 .60743 L
.75465 .60673 L
.75566 .60578 L
.75678 .60436 L
.75818 .60204 L
.7595 .59925 L
.76198 .59251 L
.76465 .58305 L
.76756 .57023 L
.77764 .50861 L
.78864 .42397 L
.79899 .34825 L
.80351 .32136 L
.80828 .29894 L
.81078 .28993 L
.81351 .28229 L
.81471 .27968 L
.816 .27738 L
.81722 .27568 L
.81832 .27452 L
.81948 .2737 L
.82075 .27324 L
Mistroke
.8214 .27318 L
.82209 .27323 L
.82333 .27366 L
.82451 .27441 L
.82575 .27556 L
.82797 .27844 L
.83056 .28296 L
.83297 .28804 L
.83845 .30137 L
.84319 .31301 L
.84766 .32217 L
.85013 .32588 L
.85153 .32742 L
.85281 .32846 L
.8539 .32902 L
.85509 .32929 L
.85633 .32916 L
.85749 .32864 L
.85875 .32765 L
.85938 .32696 L
.86008 .32607 L
.86248 .32184 L
.86383 .31868 L
.86529 .31462 L
.86792 .30557 L
.87308 .28179 L
.87781 .25369 L
.89636 .11642 L
.90108 .08419 L
.90614 .0552 L
.90859 .04369 L
.91091 .03453 L
.91297 .02785 L
.91525 .02215 L
.91654 .01969 L
.91775 .01789 L
.91903 .01654 L
.91975 .01601 L
.92041 .01567 L
.92157 .01542 L
.92285 .01564 L
.92405 .0163 L
.92517 .01729 L
.92658 .01903 L
.9279 .02115 L
.93038 .02624 L
.93594 .04193 L
.9457 .07591 L
.95104 .09279 L
.95364 .09957 L
Mistroke
.95602 .10464 L
.95707 .10649 L
.9582 .10822 L
.95919 .10948 L
.96027 .1106 L
.96142 .11146 L
.96264 .11202 L
.96377 .1122 L
.96483 .11207 L
.96601 .11158 L
.96726 .11068 L
.96832 .1096 L
.96948 .10809 L
.97208 .10356 L
.97449 .09797 L
.97619 .09332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`004`3oool4000000<0oooo0P00000e0?ooo`@000000P3oool3000003@0
oooo100000030?ooo`800000>03oool3000004h0oooo000C0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool00000=P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0B`3oool001@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000f0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1;0?ooo`003@3oool40000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02`0oooo10000004
0?ooo`040000003oool0oooo0?ooo`<00000;P3oool4000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo02l0oooo100000020?ooo`<00000CP3oool001H0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`050000003oool0oooo0?ooo`00
0000>03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`1>0?ooo`004`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000003@0oooo0`0000030?ooo`030000003oool0oooo03@0oooo0`0000030?ooo`040000003oool0
oooo000003L0oooo00<000000?ooo`3oool0CP3oool001@0oooo0P0000040?ooo`800000=`3oool0
10000000oooo0?ooo`3oool4000003D0oooo00<000000?ooo`3oool00P3oool2000003P0oooo1000
001=0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003`3ooooo000000D00000
3@3oool001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`05000000D0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool04@3oool007<0oooo1000002E0?ooo`030000003oool0oooo0140oooo001g0?oo
o`030000003oool0oooo0980oooo00<000000?ooo`3oool04@3oool007P0oooo0P0000230?ooo`<0
0000303oool200000180oooo001j0?ooo`800000P03oool010000000oooo0?ooo`00000<0?ooo`03
0000003oool0oooo0140oooo001l0?ooo`030000003oool0oooo07d0oooo00D000000?ooo`3oool0
oooo0000000;0?ooo`030000003oool0oooo0140oooo001m0?ooo`800000O03oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3oool007l0oooo0P00
001j0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool200000180oooo0021
0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0140oooo00220?ooo`800000M`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool008@0oooo00<000000?ooo`3o
ool0L`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool04@3oool008D0oooo0P00001c0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
203oool200000180oooo00270?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00280?ooo`030000003oool0
oooo06l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0140oooo00290?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo002:0?ooo`030000003oool0oooo06d0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`8000004P3oool008/0oooo
00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool04@3oool008`0oooo00<000000?ooo`3oool0JP3oool2000000@0oooo00<0
00000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool04@3oool008d0oooo00<00000
0?ooo`3oool0J03oool2000000030?ooo`000000oooo00L0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`0A0?ooo`00S@3oool00`000000oooo0?ooo`1X0?ooo`80000000<0oooo
0000003oool01`3oool010000000oooo0?ooo`0000040?ooo`8000004P3oool008h0oooo00<00000
0?ooo`3oool0I`3oool010000000oooo0?ooo`0000080?ooo`<000001@3oool00`000000oooo0?oo
o`0A0?ooo`00S`3oool00`000000oooo0?ooo`1V0?ooo`040000003oool0oooo000000P0oooo0P00
00060?ooo`030000003oool0oooo0140oooo002@0?ooo`030000003oool0oooo06D0oooo00@00000
0?ooo`3oool00000203oool2000000H0oooo00<000000?ooo`3oool04@3oool00900oooo00<00000
0?ooo`3oool0I@3oool3000000T0oooo100000040?ooo`8000004P3oool00940oooo00<000000?oo
o`3oool0I03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo0P00000C0?oo
o`00T@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00P3oool2000001<0oooo002B0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0
3@3oool010000000oooo0?ooo`3oool2000001<0oooo002B0?ooo`030000003oool0oooo0680oooo
00<000000?ooo`3oool03@3oool2000000030?ooo`000000oooo008000004P3oool00980oooo00<0
00000?ooo`3oool0HP3oool00`000000oooo0?ooo`0>0?ooo`8000000P3oool00`000000oooo0?oo
o`0A0?ooo`00TP3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool04@3oool009<0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0140oooo002C0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3o
ool04P3oool200000180oooo002C0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0A0?ooo`00U03oool00`000000oooo0?ooo`1O0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool04@3oool009@0oooo00<000000?ooo`3oool0G`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo002E0?ooo`030000003oool0oooo
05h0oooo00<000000?ooo`3oool04`3oool200000180oooo002E0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0A0?ooo`00UP3oool00`000000oooo
0?ooo`1M0?ooo`030000003oool0oooo00/0oooo100000040?ooo`030000003oool0oooo0140oooo
002F0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0140oooo002F0?ooo`030000003oool0oooo05d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`8000004P3oool009L0oooo00<000000?oo
o`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool04@3oool009L0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool009L0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`0<0?ooo`<000001@3oool00`000000oooo0?ooo`0A0?ooo`00U`3o
ool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3o
ool200000180oooo002H0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0A0?ooo`00V03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool04@3oool009P0oooo00<000000?ooo`3oool0FP3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0140oooo002I0?ooo`030000003oool0oooo05T0oooo
00<000000?ooo`3oool0503oool200000180oooo002I0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`00V@3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool009X0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo002J0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool200000180oooo002J0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`00VP3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3o
ool009/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo0140oooo002K0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool05P3oool20000
0180oooo002K0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0A0?ooo`00W03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0080oooo
100000030?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo0140oooo
002L0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool009d0oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00P3oool200000180oooo002M0?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`070?ooo`<000001@3oool00`000000oooo0?ooo`0A0?oo
o`00W@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo002N0?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool00`3oool3000000T0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0A0?ooo`00WP3oool00`000000oooo0?ooo`1A0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool4000000@0oooo0P00000B0?ooo`00WP3oool0
0`000000oooo0?ooo`1A0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool0
09l0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
0140oooo002O0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0A0?ooo`00W`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo01L0oooo
0P00000B0?ooo`00X03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool04@3oool00:00oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo0140oooo002Q0?ooo`030000003oool0oooo03l0oooo0`00000;0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool04@3oool00:80oooo00<000000?ooo`3o
ool0?@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo01P0oooo0P00000B0?oo
o`00XP3oool00`000000oooo0?ooo`0m0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo0140oooo002S0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool04@3oool00:@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0A0?ooo`00Y03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0H0?ooo`8000004P3oool00:D0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0A0?ooo`00Y@3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?oo
o`@00000103oool00`000000oooo0?ooo`0A0?ooo`00YP3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00:L0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`040?ooo`8000004P3oool00:P0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo002X0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`00Z03oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool000005@3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0140oooo002Y0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00000F0?ooo`8000001@3o
ool200000180oooo002Y0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02P3oool3
000001d0oooo00<000000?ooo`3oool04@3oool00:X0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo0140oooo002Z0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0A0?ooo`00ZP3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo02/0oooo0P00000B0?ooo`00Z`3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool04@3oool00:/0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0140oooo002/0?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0A0?oo
o`00[03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02/0oooo0P00000B0?ooo`00
[03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
4@3oool00:d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo0140oooo002]0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0A0?ooo`00[@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
02`0oooo0P00000B0?ooo`00[@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool04@3oool00:d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0H0?ooo`@000000`3oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo
0?ooo`0A0?ooo`00[P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo002^
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0080oooo0P00000B0?ooo`00[P3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool01`3oool3000000D0oooo00<000000?oo
o`3oool04@3oool00:h0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00
[`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool0
0000203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo002_0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool06P3oool2000000T0oooo100000040?ooo`800000
4P3oool00:l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo0140oooo002_0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0A0?ooo`00/03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool04@3oool00;00oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0^0?ooo`8000004P3oool00;00oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo0140oooo002`0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0A0?ooo`00/03oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool04@3oool00;00oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0^0?ooo`8000004P3oool00;40oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo002a0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`00/@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool04@3o
ool00;40oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0_0?ooo`8000004P3oool0
0;40oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
0140oooo002a0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0:03oool2000000D0
oooo00<000000?ooo`3oool04@3oool00;80oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0W0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool04@3oool00;80oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0080oooo
0P00000B0?ooo`00/P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02P0oooo0P00
00050?ooo`030000003oool0oooo0140oooo002b0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo002b0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0:03oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0140oooo002b0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0:@3oool2000000D0oooo0P00000B0?ooo`00/`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool04@3oool00;<0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0140oooo002c0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0A0?ooo`00/`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0300oooo0P00000B0?ooo`00]03oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool04@3oool00;@0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0140
oooo002d0?ooo`030000003oool0oooo00h0oooo0`00000@0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool04@3oool00;@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`02000000l0oooo00<000000?ooo`3oool0<@3oool200000180oooo002d0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool04@3oool00;D0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0A0?ooo`00]@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0140
oooo002e0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0340oooo0P00000B0?ooo`00]@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo0140oooo002f0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01l0oooo0P000004
0?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo0140oooo002f0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01h0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0140oooo002g0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`020?ooo`8000004P3oool00;L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool07`3oool2000000T0oooo0`0000050?ooo`030000003oool0oooo0140oooo002g0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0140oooo002g0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0oooo00@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo002h0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo01l0oooo0P0000090?ooo`@00000103oool200000180oooo002h0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool04@3oool00;P0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0A0?ooo`00^@3oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0140oooo002i0?ooo`80
00000P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0<`3oool200000180oooo002j0?ooo`<00000403oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool04@3oool00<h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0140oooo003>0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0A0?ooo`00cP3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo03@0oooo0P00000B0?ooo`00c`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool04@3oool00<l0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0140oooo
003@0?ooo`050000003oool0oooo0?ooo`000000=`3oool00`000000oooo0?ooo`0A0?ooo`00d03o
ool010000000oooo0?ooo`00000h0?ooo`8000004P3oool00=40oooo0`00000h0?ooo`030000003o
ool0oooo0140oooo003o0?ooo`L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A
0?ooo`00o`3oool70?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00?l0
oooo103oool5000000@0oooo0P00000B0?ooo`00o`3oool40?ooo`040000003oool0oooo000001T0
oooo003o0?ooo`D0oooo00<000000?ooo`0000006@3oool00?l0oooo1P3oool2000001T0oooo003o
0?ooo`L0oooo00<000000?ooo`3oool05`3oool00001\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {216.5, 75.1875}} -> {-31.0405, \
2.04494, 0.0811648, 0.0250148}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.97619 0.047619 0 0.154508 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.96369 .07725 -18 -4.5 ]
[.96369 .07725 0 4.5 ]
[.96369 .15451 -6 -4.5 ]
[.96369 .15451 0 4.5 ]
[.96369 .23176 -18 -4.5 ]
[.96369 .23176 0 4.5 ]
[.96369 .30902 -6 -4.5 ]
[.96369 .30902 0 4.5 ]
[.96369 .38627 -18 -4.5 ]
[.96369 .38627 0 4.5 ]
[.96369 .46353 -6 -4.5 ]
[.96369 .46353 0 4.5 ]
[.96369 .54078 -18 -4.5 ]
[.96369 .54078 0 4.5 ]
[.96369 .61803 -6 -4.5 ]
[.96369 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-15)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(-10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(-5)] .7381 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.97619 .07725 m
.98244 .07725 L
s
[(0.5)] .96369 .07725 1 0 Mshowa
.97619 .15451 m
.98244 .15451 L
s
[(1)] .96369 .15451 1 0 Mshowa
.97619 .23176 m
.98244 .23176 L
s
[(1.5)] .96369 .23176 1 0 Mshowa
.97619 .30902 m
.98244 .30902 L
s
[(2)] .96369 .30902 1 0 Mshowa
.97619 .38627 m
.98244 .38627 L
s
[(2.5)] .96369 .38627 1 0 Mshowa
.97619 .46353 m
.98244 .46353 L
s
[(3)] .96369 .46353 1 0 Mshowa
.97619 .54078 m
.98244 .54078 L
s
[(3.5)] .96369 .54078 1 0 Mshowa
.97619 .61803 m
.98244 .61803 L
s
[(4)] .96369 .61803 1 0 Mshowa
.125 Mabswid
.97619 .01545 m
.97994 .01545 L
s
.97619 .0309 m
.97994 .0309 L
s
.97619 .04635 m
.97994 .04635 L
s
.97619 .0618 m
.97994 .0618 L
s
.97619 .09271 m
.97994 .09271 L
s
.97619 .10816 m
.97994 .10816 L
s
.97619 .12361 m
.97994 .12361 L
s
.97619 .13906 m
.97994 .13906 L
s
.97619 .16996 m
.97994 .16996 L
s
.97619 .18541 m
.97994 .18541 L
s
.97619 .20086 m
.97994 .20086 L
s
.97619 .21631 m
.97994 .21631 L
s
.97619 .24721 m
.97994 .24721 L
s
.97619 .26266 m
.97994 .26266 L
s
.97619 .27812 m
.97994 .27812 L
s
.97619 .29357 m
.97994 .29357 L
s
.97619 .32447 m
.97994 .32447 L
s
.97619 .33992 m
.97994 .33992 L
s
.97619 .35537 m
.97994 .35537 L
s
.97619 .37082 m
.97994 .37082 L
s
.97619 .40172 m
.97994 .40172 L
s
.97619 .41717 m
.97994 .41717 L
s
.97619 .43262 m
.97994 .43262 L
s
.97619 .44807 m
.97994 .44807 L
s
.97619 .47898 m
.97994 .47898 L
s
.97619 .49443 m
.97994 .49443 L
s
.97619 .50988 m
.97994 .50988 L
s
.97619 .52533 m
.97994 .52533 L
s
.97619 .55623 m
.97994 .55623 L
s
.97619 .57168 m
.97994 .57168 L
s
.97619 .58713 m
.97994 .58713 L
s
.97619 .60258 m
.97994 .60258 L
s
.25 Mabswid
.97619 0 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.38588 0 m
.39273 .00087 L
.40181 .00241 L
.42245 .00658 L
.42744 .00752 L
.43287 .00842 L
.43766 .00908 L
.44276 .00964 L
.44536 .00986 L
.44781 .01003 L
.45019 .01016 L
.45238 .01026 L
.45667 .0104 L
.4613 .01051 L
.46372 .01057 L
.46602 .01065 L
.46729 .0107 L
.46866 .01077 L
.47107 .01092 L
.47337 .01112 L
.4758 .01141 L
.47788 .01173 L
.48017 .01218 L
.48286 .01284 L
.48532 .01361 L
.49085 .01595 L
.49598 .01904 L
.50086 .02291 L
.51044 .03331 L
.52065 .04823 L
.53904 .08003 L
.54932 .09609 L
.55472 .10298 L
.56044 .10886 L
.56545 .11288 L
.57094 .11634 L
.58061 .12157 L
.58584 .12517 L
.59081 .12994 L
.59526 .13592 L
.60011 .14475 L
.60537 .15758 L
.61097 .17524 L
.62102 .21705 L
.6407 .31921 L
.64932 .3593 L
.65421 .3775 L
.65876 .39067 L
.66114 .39601 L
.66331 .3999 L
Mistroke
.66451 .40166 L
.66581 .40326 L
.66703 .40446 L
.66818 .40535 L
.66937 .40602 L
.67068 .40647 L
.67196 .40664 L
.67268 .40662 L
.67334 .40653 L
.6745 .40622 L
.67578 .40568 L
.67698 .40498 L
.6781 .40418 L
.68326 .39913 L
.68884 .39259 L
.6914 .38983 L
.6928 .3885 L
.69411 .38743 L
.69531 .3866 L
.69642 .386 L
.69764 .38554 L
.69895 .38529 L
.70022 .38533 L
.70087 .38547 L
.70158 .3857 L
.70283 .38637 L
.70401 .3873 L
.70539 .38877 L
.70666 .39051 L
.70951 .39585 L
.71184 .40174 L
.71438 .40979 L
.7195 .43111 L
.72915 .48769 L
.73812 .55199 L
.74318 .58852 L
Mfstroke
.74318 .58852 m
.74768 .61803 L
s
.78209 .61803 m
.78247 .6157 L
.78745 .57765 L
.79678 .49692 L
.80166 .45589 L
.80682 .418 L
.80952 .40166 L
.81249 .38706 L
.81379 .3819 L
.81519 .37724 L
.81649 .37377 L
.81772 .37128 L
.81836 .37028 L
.81905 .36945 L
.82026 .36858 L
.82094 .36842 L
.82167 .36852 L
.82296 .36938 L
.82416 .37094 L
.82528 .37307 L
.82651 .37612 L
.82783 .38021 L
.83079 .39235 L
.8336 .40726 L
.83886 .44235 L
.8486 .5188 L
.85394 .55737 L
.85655 .57318 L
.85895 .5852 L
.86117 .59385 L
.86229 .5972 L
.86351 .60005 L
.86474 .60203 L
.86605 .6031 L
.86729 .60311 L
.86842 .60223 L
.86907 .60134 L
.86976 .60009 L
.871 .59703 L
.87233 .59258 L
.87379 .58628 L
.87641 .5714 L
.87887 .5534 L
.88351 .50938 L
.88775 .45951 L
.89729 .32732 L
.90651 .201 L
.91156 .14435 L
.91404 .1217 L
.91632 .10434 L
Mistroke
.91903 .08827 L
.92046 .08193 L
.92119 .07927 L
.92197 .07684 L
.92323 .07386 L
.92441 .07212 L
.92513 .07155 L
.92581 .07136 L
.92708 .07188 L
.92829 .07341 L
.92957 .07612 L
.93066 .07927 L
.93186 .08362 L
.93454 .09634 L
.93706 .11167 L
.94655 .18885 L
.95156 .2332 L
.95692 .27522 L
.95956 .29214 L
.96205 .30504 L
.96429 .31373 L
.96555 .31734 L
.96671 .31979 L
.9678 .32133 L
.96881 .32208 L
.96993 .32212 L
.97113 .32127 L
.97238 .31938 L
.97357 .31664 L
.97464 .3134 L
.9758 .30907 L
.97619 .30744 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`004`3oool4000000<0oooo0P00000e0?ooo`@000000P3oool3000003@0
oooo100000030?ooo`800000>03oool3000004h0oooo000C0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool00000=P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0B`3oool001@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000f0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1;0?ooo`003@3oool40000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02`0oooo10000004
0?ooo`040000003oool0oooo0?ooo`<00000;P3oool4000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo02l0oooo100000020?ooo`<00000CP3oool001H0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`050000003oool0oooo0?ooo`00
0000>03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`1>0?ooo`004`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000003@0oooo0`0000030?ooo`030000003oool0oooo03@0oooo0`0000030?ooo`040000003oool0
oooo000003L0oooo00<000000?ooo`3oool0CP3oool001@0oooo0P0000040?ooo`800000=`3oool0
10000000oooo0?ooo`3oool4000003D0oooo00<000000?ooo`3oool00P3oool2000003P0oooo1000
001=0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003`3ooooo000000D00000
3@3oool001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`<000002@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3o
ool007/0oooo2`0000260?ooo`030000003oool0oooo0140oooo00260?ooo`P00000OP3oool00`00
0000oooo0?ooo`0A0?ooo`00SP3oool00`000000oooo0?ooo`1k0?ooo`8000004P3oool008l0oooo
0P00001k0?ooo`030000003oool0oooo0140oooo002A0?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool04@3oool00980oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0A
0?ooo`00T`3oool00`000000oooo0?ooo`1f0?ooo`8000004P3oool009@0oooo00<000000?ooo`3o
ool0M@3oool00`000000oooo0?ooo`0A0?ooo`00U@3oool00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo0140oooo002E0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool04@3o
ool009H0oooo00<000000?ooo`3oool0L`3oool200000180oooo002G0?ooo`030000003oool0oooo
0780oooo00<000000?ooo`3oool04@3oool009L0oooo00<000000?ooo`3oool0LP3oool00`000000
oooo0?ooo`0A0?ooo`00V03oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0140oooo
002H0?ooo`030000003oool0oooo0740oooo0P00000B0?ooo`00V@3oool00`000000oooo0?ooo`1`
0?ooo`030000003oool0oooo0140oooo002I0?ooo`030000003oool0oooo05d0oooo0P0000030?oo
o`800000103oool3000000D0oooo00<000000?ooo`3oool04@3oool009X0oooo00<000000?ooo`3o
ool0F`3oool010000000oooo0?ooo`0000020?ooo`8000001`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0140oooo002J0?ooo`030000003oool0oooo05/0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo000000060?ooo`030000003oool0oooo0080oooo0P00000B0?oo
o`00V`3oool00`000000oooo0?ooo`1J0?ooo`060000003oool0oooo0000003oool000000P3oool0
10000000oooo0?ooo`3oool3000000D0oooo00<000000?ooo`3oool04@3oool009`0oooo00<00000
0?ooo`3oool0F@3oool01P000000oooo0?ooo`000000oooo00000080oooo00D000000?ooo`3oool0
oooo000000070?ooo`030000003oool0oooo0140oooo002L0?ooo`030000003oool0oooo05T0oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo000000L0oooo00<00000
0?ooo`3oool04@3oool009d0oooo00<000000?ooo`3oool0F@3oool200000080oooo00D000000?oo
o`3oool0oooo000000020?ooo`@00000103oool200000180oooo002M0?ooo`800000GP3oool01@00
0000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool04@3oool009l0oooo00<000000?oo
o`3oool0FP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool04@3oool00:00oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00:00oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo0P00000B0?ooo`00X@3o
ool2000005T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0140oooo002S0?ooo`800000E`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool04@3oool00:D0oooo0P00001E0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`00Y`3oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool200000180
oooo002X0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0140oooo002Y0?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo002Y
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0140oooo002Z0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`060?ooo`8000004P3oool00:X0oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool04@3oool00:/0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`050?ooo`D00000
103oool00`000000oooo0?ooo`0A0?ooo`00Z`3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo00D0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0A0?ooo`00[03o
ool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000
1@3oool200000180oooo002/0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool01@3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0140oooo002/0?ooo`030000003o
ool0oooo04`0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo0140oooo002]0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool01@3o
ool4000000D0oooo00<000000?ooo`3oool04@3oool00:d0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0000000D0oooo0P00000B0?ooo`00[@3oool00`00
0000oooo0?ooo`1:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0A0?ooo`00[@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00[P3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0A0?ooo`00[P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01@3oool200000180oooo002^0?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo002^0?oo
o`030000003oool0oooo04T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0140oooo002_0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo002_0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`800000
4P3oool00:l0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool04@3oool00:l0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool0
0;00oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool04@3oool00;00oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo0P00000B0?ooo`00/03oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0A0?ooo`00/03oool00`000000oooo0?ooo`150?ooo`@000000`3oool00`000000oooo0?oo
o`020?ooo`<000001@3oool00`000000oooo0?ooo`0A0?ooo`00/@3oool00`000000oooo0?ooo`15
0?ooo`8000002P3oool00`000000oooo000000040?ooo`030000003oool0oooo0140oooo002a0?oo
o`030000003oool0oooo04D0oooo0P00000:0?ooo`030000003oool0000000@0oooo0P00000B0?oo
o`00/@3oool00`000000oooo0?ooo`150?ooo`8000002@3oool3000000D0oooo00<000000?ooo`3o
ool04@3oool00;40oooo00<000000?ooo`3oool0A@3oool2000000T0oooo0P0000060?ooo`030000
003oool0oooo0140oooo002a0?ooo`030000003oool0oooo04@0oooo0`0000090?ooo`030000003o
ool0000000D0oooo00<000000?ooo`3oool04@3oool00;40oooo00<000000?ooo`3oool0A@3oool2
000000T0oooo100000040?ooo`8000004P3oool00;80oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00;80
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool04@3oool00;80oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00;80oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo0P00
000B0?ooo`00/P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`00/`3oool00`000000oooo0?ooo`120?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?oo
o`00/`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0A0?ooo`00/`3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool200000180oooo002c0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0140oooo002c0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03@3oool0
1@000000oooo0?ooo`3oool0000001<0oooo002d0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000001<0oooo002d0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`3oool200000180oooo002d
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3o
ool0000001<0oooo002d0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool02@3oool5
000000<0oooo00<000000?ooo`3oool04@3oool00;@0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0A
0?ooo`00]03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00/0oooo00D000000?oo
o`3oool0oooo000000020?ooo`8000004P3oool00;D0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0<0?ooo`050000003oool0oooo0000003oool00P00000C0?ooo`00]@3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`000000oooo0P00000C
0?ooo`00]@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00X0oooo00D000000?oo
o`3oool000000?ooo`04000001<0oooo002e0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool02`3oool2000000D0oooo0P00000B0?ooo`00]@3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00;H0oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo002f0?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`00]P3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0P00000B0?ooo`00]P3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00;H0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140
oooo002g0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0A0?ooo`00]`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0180oooo0P00
000B0?ooo`00]`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool04@3oool00;L0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo0140oooo002g0?ooo`030000003oool0oooo02T0oooo0P00000A0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool04@3oool00;P0oooo00<000000?ooo`3oool0
:03oool200000140oooo00<000000?ooo`3oool04`3oool200000180oooo002h0?ooo`030000003o
ool0oooo02L0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo0140oooo002h0?ooo`030000003oool0oooo02L0oooo00@000000?ooo`3oool00000
403oool00`000000oooo00000003000000<0oooo00<000000?ooo`3oool00P3oool3000000D0oooo
00<000000?ooo`3oool04@3oool00;T0oooo00<000000?ooo`3oool09P3oool010000000oooo0?oo
o`00000@0?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0A0?ooo`00^@3oool00`000000oooo0?ooo`070?ooo`<000006`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000003@3oool00`000000oooo
0?ooo`020?ooo`8000004P3oool00;X0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?oo
o`3oool0000001X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`050000
003oool0oooo0?ooo`0000002@3oool3000000D0oooo00<000000?ooo`3oool04@3oool00;X0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo
002k0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0000
00020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0A0?ooo`00^`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool00P0000090?ooo`@00000103oool200000180oooo002l0?ooo`@00000203oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo00380?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool04@3oool00<P0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0A0?ooo`00b03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0C0?ooo`8000004P3oool00<T0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0A0?ooo`00b@3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo0140oooo00390?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool04@3oool00<T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0503oool200000180oooo00390?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool04@3oool00<T0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0A0?ooo`00bP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
0140oooo003:0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo01@0oooo0P00000B0?ooo`00bP3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo0140oooo003:0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo0P00
00050?ooo`030000003oool0oooo0140oooo003;0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0A0?ooo`00b`3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0080oooo0P00000B0?ooo`00b`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?oo
o`8000001@3oool00`000000oooo0?ooo`0A0?ooo`00b`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00</0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
303oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0140oooo003<0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00d0oooo0P0000050?ooo`8000004P3oool00<`0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0A0?ooo`00c03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo0140oooo003<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool00<`0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool05@3oool200000180oooo003<0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool04@3oool00<`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0A0?ooo`00c@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo003=0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo01D0oooo0P00000B0?ooo`00c@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo0140oooo003=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
4@3oool00<d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`00c@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0E0?ooo`8000004P3oool00<d0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0A0?ooo`00c@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`800000103oool00`000000
oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`0A0?ooo`00cP3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0A0?ooo`00cP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00P3oool200000180oooo003>0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0P00
00090?ooo`<000001@3oool00`000000oooo0?ooo`0A0?ooo`00cP3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A
0?ooo`00cP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000P0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00cP3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`8000002@3oool4000000@0oooo0P00000B0?ooo`00cP3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo0140oooo003>0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
4@3oool00<h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`00c`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0G0?ooo`8000004P3oool00<l0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0A0?ooo`00c`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0140
oooo003?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool01@000000oooo
0?ooo`3oool0000001X0oooo00<000000?ooo`3oool04@3oool00<l0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0000006P3oool200000180
oooo003?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0403oool010000000oooo
0?ooo`00000J0?ooo`030000003oool0oooo0140oooo003@0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000J0?ooo`030000003oool0oooo0140
oooo003@0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool4000001X0oooo
00<000000?ooo`3oool04@3oool00=00oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0B0?ooo`8000006`3oool200000180oooo003@0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0A0?ooo`00d@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?oo
o`00d@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0A0?ooo`00d@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo02H0oooo1@0000040?ooo`8000004P3oool00?l0oooo103oool010000000oooo0?oo
o`00000I0?ooo`00o`3oool50?ooo`030000003oool0000001T0oooo003o0?ooo`H0oooo0P00000I
0?ooo`00o`3oool70?ooo`030000003oool0oooo01L0oooo0000\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {365.188, 223.875}} -> {-31.0405, \
6.69418, 0.0811648, 0.0250148}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.97619 0.047619 0 0.154508 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.96369 .07725 -18 -4.5 ]
[.96369 .07725 0 4.5 ]
[.96369 .15451 -6 -4.5 ]
[.96369 .15451 0 4.5 ]
[.96369 .23176 -18 -4.5 ]
[.96369 .23176 0 4.5 ]
[.96369 .30902 -6 -4.5 ]
[.96369 .30902 0 4.5 ]
[.96369 .38627 -18 -4.5 ]
[.96369 .38627 0 4.5 ]
[.96369 .46353 -6 -4.5 ]
[.96369 .46353 0 4.5 ]
[.96369 .54078 -18 -4.5 ]
[.96369 .54078 0 4.5 ]
[.96369 .61803 -6 -4.5 ]
[.96369 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-15)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(-10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(-5)] .7381 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.97619 .07725 m
.98244 .07725 L
s
[(0.5)] .96369 .07725 1 0 Mshowa
.97619 .15451 m
.98244 .15451 L
s
[(1)] .96369 .15451 1 0 Mshowa
.97619 .23176 m
.98244 .23176 L
s
[(1.5)] .96369 .23176 1 0 Mshowa
.97619 .30902 m
.98244 .30902 L
s
[(2)] .96369 .30902 1 0 Mshowa
.97619 .38627 m
.98244 .38627 L
s
[(2.5)] .96369 .38627 1 0 Mshowa
.97619 .46353 m
.98244 .46353 L
s
[(3)] .96369 .46353 1 0 Mshowa
.97619 .54078 m
.98244 .54078 L
s
[(3.5)] .96369 .54078 1 0 Mshowa
.97619 .61803 m
.98244 .61803 L
s
[(4)] .96369 .61803 1 0 Mshowa
.125 Mabswid
.97619 .01545 m
.97994 .01545 L
s
.97619 .0309 m
.97994 .0309 L
s
.97619 .04635 m
.97994 .04635 L
s
.97619 .0618 m
.97994 .0618 L
s
.97619 .09271 m
.97994 .09271 L
s
.97619 .10816 m
.97994 .10816 L
s
.97619 .12361 m
.97994 .12361 L
s
.97619 .13906 m
.97994 .13906 L
s
.97619 .16996 m
.97994 .16996 L
s
.97619 .18541 m
.97994 .18541 L
s
.97619 .20086 m
.97994 .20086 L
s
.97619 .21631 m
.97994 .21631 L
s
.97619 .24721 m
.97994 .24721 L
s
.97619 .26266 m
.97994 .26266 L
s
.97619 .27812 m
.97994 .27812 L
s
.97619 .29357 m
.97994 .29357 L
s
.97619 .32447 m
.97994 .32447 L
s
.97619 .33992 m
.97994 .33992 L
s
.97619 .35537 m
.97994 .35537 L
s
.97619 .37082 m
.97994 .37082 L
s
.97619 .40172 m
.97994 .40172 L
s
.97619 .41717 m
.97994 .41717 L
s
.97619 .43262 m
.97994 .43262 L
s
.97619 .44807 m
.97994 .44807 L
s
.97619 .47898 m
.97994 .47898 L
s
.97619 .49443 m
.97994 .49443 L
s
.97619 .50988 m
.97994 .50988 L
s
.97619 .52533 m
.97994 .52533 L
s
.97619 .55623 m
.97994 .55623 L
s
.97619 .57168 m
.97994 .57168 L
s
.97619 .58713 m
.97994 .58713 L
s
.97619 .60258 m
.97994 .60258 L
s
.25 Mabswid
.97619 0 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.41338 0 m
.42034 .00063 L
.42274 .0008 L
.42532 .00096 L
.42776 .00107 L
.42885 .00111 L
.43 .00115 L
.43124 .00118 L
.43239 .0012 L
.43309 .00121 L
.43376 .00121 L
.435 .00121 L
.43632 .0012 L
.43753 .00117 L
.43816 .00116 L
.43886 .00114 L
.44026 .00109 L
.44266 .00097 L
.44485 .00084 L
.44978 .00043 L
s
.44978 .00043 m
.45394 0 L
s
.48858 0 m
.48859 0 L
.49335 .00141 L
.49847 .00346 L
.50857 .00904 L
.51959 .01679 L
.53013 .02448 L
.53968 .03033 L
.54454 .03252 L
.54728 .03347 L
.5498 .03415 L
.55202 .03459 L
.55327 .03478 L
.55444 .03491 L
.55568 .03501 L
.55681 .03506 L
.55811 .03507 L
.55934 .03504 L
.56055 .03498 L
.56123 .03493 L
.56187 .03487 L
.56456 .03454 L
.56688 .03415 L
.56939 .03366 L
.57505 .03246 L
.57781 .03195 L
.57901 .03177 L
.58031 .0316 L
.58155 .03149 L
.58269 .03142 L
.58378 .0314 L
.58494 .03143 L
.58615 .03152 L
.58729 .03166 L
.58854 .0319 L
.58988 .03225 L
.59122 .0327 L
.59268 .03332 L
.59535 .03484 L
.59794 .03684 L
.60035 .03919 L
.60571 .04631 L
.61056 .05516 L
.62144 .0832 L
.64234 .15715 L
.6515 .18741 L
.6567 .20108 L
.65919 .20644 L
.66155 .2107 L
.66382 .21405 L
Mistroke
.66502 .21551 L
.66629 .21681 L
.66736 .21772 L
.66854 .21851 L
.66961 .21906 L
.67061 .21941 L
.6718 .21964 L
.67305 .21967 L
.67412 .21952 L
.67529 .21918 L
.67655 .21862 L
.6779 .21781 L
.68032 .21585 L
.69064 .2031 L
.69516 .19739 L
.69774 .1948 L
.69897 .19381 L
.70014 .19307 L
.7014 .19249 L
.70254 .1922 L
.70378 .19215 L
.70448 .19226 L
.70513 .19245 L
.70634 .19305 L
.70703 .19355 L
.70768 .19412 L
.70899 .19558 L
.7104 .19766 L
.71322 .20349 L
.7162 .21221 L
.71873 .22187 L
.72152 .23487 L
.72656 .26491 L
.73195 .30569 L
.74168 .39613 L
.7519 .49781 L
.75728 .54518 L
.76023 .56727 L
.76299 .58479 L
.76559 .59807 L
.76797 .6072 L
.76933 .61102 L
.77062 .6137 L
.77132 .61476 L
.77198 .61549 L
.7727 .616 L
.77346 .61621 L
.77472 .61581 L
.77542 .61517 L
.77607 .61433 L
Mistroke
.77727 .61212 L
.77853 .60889 L
.78072 .60112 L
.78313 .58955 L
.79399 .5053 L
.80428 .40439 L
.80876 .3654 L
.81121 .34739 L
.81352 .3333 L
.816 .32169 L
.81731 .31719 L
.81799 .31535 L
.81873 .31371 L
.81996 .31191 L
.82125 .31127 L
.82245 .31185 L
.82356 .31341 L
.82483 .31642 L
.826 .32036 L
.82728 .32598 L
.82863 .33339 L
.83091 .3492 L
.83342 .37126 L
.83805 .42368 L
.84238 .48399 L
Mfstroke
.84238 .48399 m
.85078 .61803 L
s
.89466 .61803 m
.90131 .48454 L
.90626 .38164 L
.91168 .28034 L
.91415 .24073 L
.91679 .20449 L
.91926 .17693 L
.92154 .15752 L
.9227 .14991 L
.92394 .14362 L
.92518 .13916 L
.92588 .13746 L
.92654 .13641 L
.92772 .13585 L
.92881 .13684 L
.93006 .13972 L
.93125 .14416 L
.93231 .14951 L
.93344 .15657 L
.93546 .17269 L
.94006 .2237 L
s
.94006 .2237 m
.9748 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`004`3oool4000000<0oooo0P00000e0?ooo`@000000P3oool3000003@0
oooo100000030?ooo`800000>03oool3000004h0oooo000C0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool00000=P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0B`3oool001@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000f0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1;0?ooo`003@3oool40000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02`0oooo10000004
0?ooo`040000003oool0oooo0?ooo`<00000;P3oool4000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo02l0oooo100000020?ooo`<00000CP3oool001H0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`050000003oool0oooo0?ooo`00
0000>03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`1>0?ooo`004`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000003@0oooo0`0000030?ooo`030000003oool0oooo03@0oooo0`0000030?ooo`040000003oool0
oooo000003L0oooo00<000000?ooo`3oool0CP3oool001@0oooo0P0000040?ooo`800000=`3oool0
10000000oooo0?ooo`3oool4000003D0oooo00<000000?ooo`3oool00P3oool2000003P0oooo1000
001=0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003`3ooooo000000D00000
3@3oool001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool2000000/0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3o
ool00980oooo0P00001h0?ooo`030000003oool0oooo0140oooo002D0?ooo`030000003oool0oooo
07D0oooo00<000000?ooo`3oool04@3oool009D0oooo00<000000?ooo`3oool0M03oool200000180
oooo002F0?ooo`800000M03oool00`000000oooo0?ooo`0A0?ooo`00V03oool00`000000oooo0?oo
o`1a0?ooo`030000003oool0oooo0140oooo002I0?ooo`800000L@3oool00`000000oooo0?ooo`0A
0?ooo`00V`3oool3000000D0oooo1P00001S0?ooo`8000004P3oool009d0oooo1P0000060?ooo`80
0000H@3oool00`000000oooo0?ooo`0A0?ooo`00ZP3oool00`000000oooo0?ooo`1O0?ooo`030000
003oool0oooo0140oooo002[0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool04@3o
ool00:`0oooo00<000000?ooo`3oool0G@3oool200000180oooo002]0?ooo`030000003oool0oooo
05`0oooo00<000000?ooo`3oool04@3oool00:d0oooo00<000000?ooo`3oool0G03oool00`000000
oooo0?ooo`0A0?ooo`00[@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0140oooo
002^0?ooo`030000003oool0oooo05/0oooo0P00000B0?ooo`00[P3oool00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo0140oooo002_0?ooo`030000003oool0oooo04L0oooo0P0000040?oo
o`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo0140oooo002_0?ooo`03
0000003oool0oooo04H0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0140oooo002`0?ooo`030000003oool0oooo04D0oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo0?ooo`020?ooo`8000004P3oool00;00oooo00<000000?ooo`3o
ool0A@3oool010000000oooo0?ooo`0000080?ooo`<000001@3oool00`000000oooo0?ooo`0A0?oo
o`00/03oool00`000000oooo0?ooo`150?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00/@3oool00`000000oooo0?ooo`140?ooo`04
0000003oool0oooo000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?oo
o`00/@3oool00`000000oooo0?ooo`150?ooo`8000002@3oool4000000@0oooo0P00000B0?ooo`00
/@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0140oooo002a0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04@3oool00;80oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0A0?ooo`00/P3oool00`000000oooo0?ooo`1G0?ooo`8000004P3oool00;80
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0A0?ooo`00/P3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo0140oooo002c0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool04@3oool00;<0oooo00<000000?ooo`3oool0EP3oool200000180oooo002c0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool04@3oool00;<0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0A0?ooo`00]03oool00`000000oooo0?ooo`180?ooo`800000
2`3oool00`000000oooo0?ooo`0A0?ooo`00]03oool00`000000oooo0?ooo`180?ooo`8000002`3o
ool200000180oooo002d0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`0000002`3oool0
0`000000oooo0?ooo`0A0?ooo`00]03oool00`000000oooo0?ooo`170?ooo`030000003oool00000
00<0oooo100000040?ooo`030000003oool0oooo0140oooo002e0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140
oooo002e0?ooo`030000003oool0oooo04H0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`030?ooo`8000004P3oool00;D0oooo00<000000?ooo`3oool0AP3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00;D0oooo
00<000000?ooo`3oool0AP3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool04@3oool00;H0oooo00<000000?ooo`3oool0A@3oool010000000oooo
0?ooo`0000020?ooo`<000001@3oool00`000000oooo0?ooo`0A0?ooo`00]P3oool00`000000oooo
0?ooo`140?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`80
00004P3oool00;L0oooo00<000000?ooo`3oool0@`3oool01@000000oooo0?ooo`3oool0000000X0
oooo00<000000?ooo`3oool04@3oool00;L0oooo00<000000?ooo`3oool0@`3oool01@000000oooo
0?ooo`3oool0000000X0oooo00<000000?ooo`3oool04@3oool00;P0oooo00<000000?ooo`3oool0
@P3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool04@3oool00;P0oooo
00<000000?ooo`3oool0@P3oool01@000000oooo0?ooo`3oool0000000X0oooo0P00000B0?ooo`00
^03oool00`000000oooo0?ooo`120?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000
oooo0?ooo`0A0?ooo`00^@3oool00`000000oooo0?ooo`080?ooo`@00000=03oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool00;T0oooo00<0
00000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000003@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo002i0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01`3oool200000180oooo002j0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`00^P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00;/0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140
oooo002k0?ooo`80000000<0oooo0000000000002@3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool200000180oooo002l0?ooo`<000002P3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0A0?ooo`00b@3oool00`000000oooo0?ooo`0/0?ooo`D000000P3oool0
1@000000oooo0?ooo`000000oooo00<000001@3oool00`000000oooo0?ooo`0A0?ooo`00bP3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo003:0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo0P00000B0?ooo`00bP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0000000D0
oooo00<000000?ooo`0000000P0000050?ooo`030000003oool0oooo0140oooo003:0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`0000001@3oool00`000000oooo000000070?ooo`030000
003oool0oooo0140oooo003:0?ooo`030000003oool0oooo02/0oooo0`0000000`3oool000000?oo
o`040?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool04@3oool00<X0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo000000060?ooo`D00000103oool200000180oooo003;0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0140oooo003;0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo003;0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0140oooo003;0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`8000004P3oool00</0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool0
0</0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool04@3oool00<`0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00<`0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
0P00000B0?ooo`00c03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`00c03oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A
0?ooo`00c03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00c03oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool200000180oooo003=0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0140oooo003=0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool01P3o
ool4000000@0oooo00<000000?ooo`3oool04@3oool00<d0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool0
0<d0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00H0oooo0P0000060?ooo`8000004P3oool00<d0oooo00<000000?ooo`3oool04`3oool2000001H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo000000050?ooo`030000003oool0oooo0140
oooo003=0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`0000005@3oool00`000000oooo
0?ooo`060?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool04@3oool00<d0oooo
00<000000?ooo`3oool04P3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo00H0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0A0?ooo`00c@3oool00`000000
oooo0?ooo`0B0?ooo`040000003oool0oooo000001D0oooo00<000000?ooo`3oool01P3oool30000
00D0oooo0P00000B0?ooo`00cP3oool00`000000oooo0?ooo`0A0?ooo`050000003oool0oooo0?oo
o`000000503oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool04@3oool00<h0oooo00<000000?ooo`3oool04@3oool01@000000oooo0?ooo`3oool00000
01<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0140oooo003>0?ooo`030000003oool0oooo0140oooo00D000000?ooo`3oool0oooo0000000C0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0A0?oo
o`00cP3oool00`000000oooo0?ooo`0A0?ooo`050000003oool0oooo0?ooo`0000004`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo0P00000B0?ooo`00cP3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00<h0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0140oooo
003>0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0A0?ooo`00cP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo0P00000B
0?ooo`00cP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool04@3oool00<h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0140oooo003>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0A0?ooo`00cP3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00@0oooo0P00000B0?ooo`00c`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool04@3oool00<l0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo100000030?ooo`030000003oool0oooo
0080oooo0`0000050?ooo`030000003oool0oooo0140oooo003?0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000/0
oooo0P0000040?ooo`030000003oool0oooo0140oooo003?0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`8000002`3oool2000000@0oooo
0P00000B0?ooo`00c`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`070?ooo`<000001@3oool00`000000oooo0?oo
o`0A0?ooo`00c`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0403oool2000000P0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0A
0?ooo`00c`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool03@3oool010000000oooo0000000000080?ooo`030000003oool0000000D0oooo00<00000
0?ooo`3oool04@3oool00<l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00h0oooo0P0000090?ooo`@00000103oool200000180oooo003?0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`00
c`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
4@3oool00=00oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0140oooo003@0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool2
00000180oooo003@0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0A0?ooo`00d03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool04@3oool00=00oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0140oooo003@0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00P3oool200000180oooo003@0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`00d03oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00=00oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo003A0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool200000180oooo003A0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`00d@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`090?ooo`<00000103oool00`000000oooo0?ooo`0A0?ooo`00d@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool04@3oool0
0=40oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`8000004P3oool00=40
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool02P3oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`3o
ool04@3oool00=40oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool2000000<0oooo00<000000?ooo`3oool0
4@3oool00=40oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`02000000<0oooo00<0
00000?ooo`3oool04@3oool00=40oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool2000000030?ooo`000000
oooo0080oooo0P00000B0?ooo`00dP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo
0?ooo`0000004`3oool00=80oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0
000001<0oooo003B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo0000000C
0?ooo`00dP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo0?ooo`8000004P3oool0
0=80oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000001<0oooo003B0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`00dP3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000004`3oool00=80oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0200000180oooo003B0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00h0
oooo00@000000?ooo`3oool000004`3oool00=80oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool010000000
oooo0?ooo`00000C0?ooo`00d`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo0000
01<0oooo003C0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P00000B0?ooo`00
d`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000001<0oooo003C0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`<00000
103oool00`000000oooo0?ooo`020?ooo`<000000P3oool010000000oooo0?ooo`00000C0?ooo`00
d`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool04@3oool00=<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00/0oooo00@000000?ooo`3oool000002`3oool00`000000oooo000000020?ooo`80
00004P3oool00=<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00/0oooo0`0000090?ooo`<000000P3oool010000000oooo0?ooo`00000C0?ooo`00
d`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000004`3oool00=<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00X0oooo0P0000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0000000C0?ooo`00e03oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool010000000oooo0000000000090?ooo`@0
00000P3oool010000000oooo00000000000B0?ooo`00e03oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0000001<0oooo003D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`000000
4`3oool00=@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0403oool00`000000oooo0000000C0?ooo`00e03oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0@0?ooo`040000003oool0000000000180oooo003E0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`0000004`3oool00=D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0000000C0?ooo`00e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0000001<0
oooo003E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0100oooo00@000000?ooo`00000000004P3oool00=D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0403oool00`000000oooo0000000C0?ooo`00e@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0000001<0oooo003E0?ooo`050000003oool0oooo0?ooo`0000004@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo0P00000C0?ooo`00eP3oool0
10000000oooo0?ooo`00000A0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3o
ool300000180oooo003F0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0A0?ooo`8000004`3oool00=H0oooo00@000000?ooo`00000000004@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3o
ool2000001<0oooo003G0?ooo`8000004P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool00P3oool2000001<0oooo003G0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`D000000`3oool30000
0180oooo003o0?ooo`@0oooo00@000000?ooo`3oool000006@3oool00?l0oooo1@3oool00`000000
oooo0000000I0?ooo`00o`3oool60?ooo`8000006@3oool00?l0oooo1`3oool00`000000oooo0?oo
o`0G0?ooo`00\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {513.875, 372.562}} -> {-31.0405, \
11.3434, 0.0811648, 0.0250148}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.97619 0.047619 0 0.154508 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.96369 .07725 -18 -4.5 ]
[.96369 .07725 0 4.5 ]
[.96369 .15451 -6 -4.5 ]
[.96369 .15451 0 4.5 ]
[.96369 .23176 -18 -4.5 ]
[.96369 .23176 0 4.5 ]
[.96369 .30902 -6 -4.5 ]
[.96369 .30902 0 4.5 ]
[.96369 .38627 -18 -4.5 ]
[.96369 .38627 0 4.5 ]
[.96369 .46353 -6 -4.5 ]
[.96369 .46353 0 4.5 ]
[.96369 .54078 -18 -4.5 ]
[.96369 .54078 0 4.5 ]
[.96369 .61803 -6 -4.5 ]
[.96369 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-15)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(-10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(-5)] .7381 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.97619 .07725 m
.98244 .07725 L
s
[(0.5)] .96369 .07725 1 0 Mshowa
.97619 .15451 m
.98244 .15451 L
s
[(1)] .96369 .15451 1 0 Mshowa
.97619 .23176 m
.98244 .23176 L
s
[(1.5)] .96369 .23176 1 0 Mshowa
.97619 .30902 m
.98244 .30902 L
s
[(2)] .96369 .30902 1 0 Mshowa
.97619 .38627 m
.98244 .38627 L
s
[(2.5)] .96369 .38627 1 0 Mshowa
.97619 .46353 m
.98244 .46353 L
s
[(3)] .96369 .46353 1 0 Mshowa
.97619 .54078 m
.98244 .54078 L
s
[(3.5)] .96369 .54078 1 0 Mshowa
.97619 .61803 m
.98244 .61803 L
s
[(4)] .96369 .61803 1 0 Mshowa
.125 Mabswid
.97619 .01545 m
.97994 .01545 L
s
.97619 .0309 m
.97994 .0309 L
s
.97619 .04635 m
.97994 .04635 L
s
.97619 .0618 m
.97994 .0618 L
s
.97619 .09271 m
.97994 .09271 L
s
.97619 .10816 m
.97994 .10816 L
s
.97619 .12361 m
.97994 .12361 L
s
.97619 .13906 m
.97994 .13906 L
s
.97619 .16996 m
.97994 .16996 L
s
.97619 .18541 m
.97994 .18541 L
s
.97619 .20086 m
.97994 .20086 L
s
.97619 .21631 m
.97994 .21631 L
s
.97619 .24721 m
.97994 .24721 L
s
.97619 .26266 m
.97994 .26266 L
s
.97619 .27812 m
.97994 .27812 L
s
.97619 .29357 m
.97994 .29357 L
s
.97619 .32447 m
.97994 .32447 L
s
.97619 .33992 m
.97994 .33992 L
s
.97619 .35537 m
.97994 .35537 L
s
.97619 .37082 m
.97994 .37082 L
s
.97619 .40172 m
.97994 .40172 L
s
.97619 .41717 m
.97994 .41717 L
s
.97619 .43262 m
.97994 .43262 L
s
.97619 .44807 m
.97994 .44807 L
s
.97619 .47898 m
.97994 .47898 L
s
.97619 .49443 m
.97994 .49443 L
s
.97619 .50988 m
.97994 .50988 L
s
.97619 .52533 m
.97994 .52533 L
s
.97619 .55623 m
.97994 .55623 L
s
.97619 .57168 m
.97994 .57168 L
s
.97619 .58713 m
.97994 .58713 L
s
.97619 .60258 m
.97994 .60258 L
s
.25 Mabswid
.97619 0 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.50142 0 m
.51937 .00669 L
.52421 .00847 L
.5293 .01009 L
.53364 .01118 L
.5361 .01164 L
.53839 .01197 L
.53953 .01209 L
.54076 .01219 L
.54193 .01225 L
.543 .01229 L
.54397 .01229 L
.54503 .01227 L
.54614 .01223 L
.54718 .01216 L
.5484 .01205 L
.54955 .01191 L
.55171 .01157 L
.55404 .0111 L
.55657 .01046 L
.56674 .00693 L
.57616 .00322 L
.58126 .0016 L
.58266 .00126 L
.58413 .00096 L
.58539 .00075 L
.5861 .00066 L
.58677 .00059 L
.58807 .0005 L
.58926 .00048 L
.59054 .00052 L
.59126 .00058 L
.59193 .00066 L
.59304 .00083 L
.59426 .00109 L
.59554 .00144 L
.59674 .00186 L
.59914 .00293 L
.60142 .00428 L
.60571 .0077 L
.61032 .01274 L
.61536 .01987 L
.62567 .03922 L
.63503 .06046 L
.64595 .0851 L
.65074 .09422 L
.65327 .09832 L
.656 .10204 L
.65853 .10479 L
.66083 .10664 L
Mistroke
.66194 .10729 L
.66315 .10783 L
.66429 .10815 L
.66535 .1083 L
.66652 .10829 L
.66763 .10811 L
.66884 .10772 L
.67014 .10707 L
.67144 .10621 L
.6728 .10505 L
.67523 .10239 L
.68038 .09446 L
.68517 .08481 L
.69039 .07291 L
.69605 .06009 L
.69871 .05475 L
.70152 .04995 L
.70392 .0468 L
.70529 .04548 L
.70657 .04459 L
.70785 .04406 L
.70907 .04393 L
.71016 .04413 L
.71135 .04472 L
.71265 .04581 L
.71337 .04664 L
.71402 .04753 L
.71523 .04951 L
.7165 .05211 L
.7189 .0585 L
.7211 .06613 L
.72607 .08976 L
.73037 .11726 L
.73508 .15441 L
.74596 .26006 L
.75626 .36412 L
.76074 .40263 L
.7655 .43482 L
.76799 .44718 L
.7693 .45236 L
.77072 .45679 L
.77202 .45979 L
.77321 .46162 L
.77435 .46254 L
.77555 .46261 L
.77681 .46169 L
.77799 .4599 L
.77906 .45751 L
.78021 .45412 L
.78281 .44348 L
Mistroke
.78519 .43014 L
.78955 .39797 L
.79416 .35514 L
.80397 .25112 L
.80937 .19928 L
.81203 .1784 L
.8145 .16285 L
.81572 .15669 L
.81687 .15194 L
.81807 .14813 L
.81871 .14659 L
.8194 .14533 L
.82005 .14453 L
.82076 .14409 L
.8215 .14412 L
.82219 .14461 L
.82342 .14663 L
.82474 .15044 L
.82595 .15544 L
.82726 .16252 L
.82964 .17981 L
.83196 .20209 L
.8341 .22729 L
.843 .37374 L
.85242 .57402 L
Mfstroke
.85242 .57402 m
.85458 .61803 L
s
.89837 .61803 m
.90849 .39529 L
.91348 .29227 L
.91611 .24687 L
.91887 .20742 L
.92129 .18076 L
.92267 .16928 L
.92395 .16104 L
.92513 .1556 L
.9262 .15247 L
.92744 .15104 L
.9286 .15184 L
.92975 .15465 L
.931 .16004 L
.93231 .16819 L
.93354 .17812 L
.93574 .20122 L
.9381 .23323 L
.94347 .33016 L
.94838 .43981 L
s
.94838 .43981 m
.95584 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`004`3oool4000000<0oooo0P00000e0?ooo`@000000P3oool3000003@0
oooo100000030?ooo`800000>03oool3000004h0oooo000C0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool00000=P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0B`3oool001@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000f0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1;0?ooo`003@3oool40000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02`0oooo10000004
0?ooo`040000003oool0oooo0?ooo`<00000;P3oool4000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo02l0oooo100000020?ooo`<00000CP3oool001H0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`050000003oool0oooo0?ooo`00
0000>03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`1>0?ooo`004`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000003@0oooo0`0000030?ooo`030000003oool0oooo03@0oooo0`0000030?ooo`040000003oool0
oooo000003L0oooo00<000000?ooo`3oool0CP3oool001@0oooo0P0000040?ooo`800000=`3oool0
10000000oooo0?ooo`3oool4000003D0oooo00<000000?ooo`3oool00P3oool2000003P0oooo1000
001=0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003`3ooooo000000D00000
3@3oool001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`02000000P0oooo00<0
00000?ooo`3oool00`3oool2000000@0oooo0`0000090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool04@3oool009D0oooo100000080?ooo`8000002@3oool00`000000oooo0?ooo`1M
0?ooo`030000003oool0oooo0140oooo002I0?ooo`P00000303oool00`000000oooo0?ooo`1L0?oo
o`030000003oool0oooo0140oooo002^0?ooo`030000003oool0oooo05/0oooo0P00000B0?ooo`00
[P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0140oooo002_0?ooo`030000003o
ool0oooo05X0oooo00<000000?ooo`3oool04@3oool00:l0oooo00<000000?ooo`3oool0FP3oool0
0`000000oooo0?ooo`0A0?ooo`00/03oool00`000000oooo0?ooo`1I0?ooo`8000004P3oool00;00
oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0A0?ooo`00/@3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo0140oooo002a0?ooo`030000003oool0oooo0180oooo0P00
00140?ooo`030000003oool0oooo0140oooo002b0?ooo`030000003oool0oooo0100oooo0P000000
0`3oool000000?ooo`120?ooo`8000004P3oool00;80oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0200000480oooo00<000000?ooo`3oool04@3oool00;<0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool04@3oool00;<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool04@3oool00;<0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03l0oooo0P00000B0?ooo`00]03oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0A0?ooo`00]03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0;03oool2000000@0oooo00<000000?ooo`3oool00P3oool30000
00D0oooo00<000000?ooo`3oool04@3oool00;D0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo02/0oooo00@000000?ooo`3oool000002`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo002e0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0oooo0000
00/0oooo00<000000?ooo`3oool00P3oool200000180oooo002f0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0oooo0000
00P0oooo0`0000050?ooo`030000003oool0oooo0140oooo002f0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0oooo0000
00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00]`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0:P3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00;L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02/0
oooo0P0000090?ooo`@00000103oool200000180oooo002h0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0140oooo
002i0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo0140oooo002j0?ooo`040000003oool0oooo000000h0oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`0A0?ooo`00^P3oool4000000h0oooo00<00000
0?ooo`3oool0?@3oool200000180oooo003<0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool04@3oool00<`0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0A0?ooo`00
c03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0140oooo003<0?ooo`030000003o
ool0oooo03d0oooo0P00000B0?ooo`00c03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo0140oooo003<0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool04@3oool00<d0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0A0?ooo`00c@3oool00`000000oooo
0?ooo`0l0?ooo`8000004P3oool00<d0oooo00<000000?ooo`3oool04`3oool2000002L0oooo00<0
00000?ooo`3oool04@3oool00<d0oooo00<000000?ooo`3oool04`3oool2000001l0oooo10000004
0?ooo`030000003oool0oooo0140oooo003=0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`0000006@3oool2000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?oo
o`00c@3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo000001T0oooo0P0000050?oo
o`030000003oool0oooo00<0oooo0P00000B0?ooo`00c@3oool00`000000oooo0?ooo`0B0?ooo`04
0000003oool0oooo000001T0oooo0P0000050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool04@3oool00<d0oooo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`00000H0?oo
o`030000003oool0000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?oo
o`00c@3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo000001P0oooo00<000000?oo
o`0000000`3oool3000000D0oooo00<000000?ooo`3oool04@3oool00<d0oooo00<000000?ooo`3o
ool04P3oool01@000000oooo0?ooo`3oool0000001L0oooo00<000000?ooo`0000001@3oool00`00
0000oooo0?ooo`030?ooo`8000004P3oool00<h0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3oool000002P3oool00`00
0000oooo0?ooo`0A0?ooo`00cP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool05@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
0140oooo003>0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0E0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool04@3oool00<h0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0
oooo00@000000?ooo`3oool000002P3oool200000180oooo003>0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0E0?ooo`040000003oool0oooo0000
00X0oooo00<000000?ooo`3oool04@3oool00<h0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3oool000002P3oool00`00
0000oooo0?ooo`0A0?ooo`00cP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?oo
o`3oool04@3oool00<h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`8000004P3oool00<h0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0
oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0140oooo003?0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0D0?ooo`05
0000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`0A0?ooo`00c`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool01@000000
oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool04@3oool00<l0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`8000004P3oool00<l0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo003?0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`@0000000@0
oooo0000003oool000000P3oool00`000000oooo00000002000000D0oooo00<000000?ooo`3oool0
4@3oool00<l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0100oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00<l0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0100oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P00000B0?ooo`00c`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0403oool0
0`000000oooo000000050?ooo`030000003oool00000008000001@3oool00`000000oooo0?ooo`0A
0?ooo`00c`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0403oool00`000000oooo000000050?ooo`030000003oool0000000L0oooo00<000000?oo
o`3oool04@3oool00=00oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00h0oooo0`0000000`3oool000000?ooo`040?ooo`030000003oool0000000L0
oooo00<000000?ooo`3oool04@3oool00=00oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0100oooo00<000000?ooo`0000001@3oool00`000000oooo
00000003000000@0oooo0P00000B0?ooo`00d03oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool04@3oool00=00oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo003@0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`00d03oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo0P00000B0?ooo`00d03oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00=00oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo003@
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A
0?ooo`00d@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo0P00000B0?oo
o`00d@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool04@3oool00=40oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0140oooo003A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0A0?ooo`00d@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00H0oooo0P00000B0?ooo`00d@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool04@3oool00=40oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool5000000@0
oooo00<000000?ooo`3oool04@3oool00=40oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool2000000L0oooo
00<000000?ooo`3oool04@3oool00=40oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool00`000000oooo0000
00060?ooo`8000004P3oool00=80oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo0140oooo003B0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0140oooo003B0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00D0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool0
0=80oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool01@3oool010000000oooo0000000000050?ooo`8000004P3oool0
0=80oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0140oooo003B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0A0?ooo`00dP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool04@3oool00=80oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`8000004P3oool00=80oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0140oooo003C0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`00d`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00=<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`8000004P3oool00=<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo003C0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00d`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00=<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`8000004P3oool00=<0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo
003C0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0<0?ooo`@000000`3oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?oo
o`0A0?ooo`00e03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0303oool00`000000oooo000000090?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool04@3oool00=@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00d0oooo0P0000090?ooo`040000003oool0oooo000000@0oooo0P00
000B0?ooo`00e03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`<000001@3oool00`000000oooo0?ooo`0A
0?ooo`00e03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool03P3oool2000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?oo
o`00e03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0303oool010000000oooo0000000000080?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool04@3oool00=@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00d0oooo0P0000090?ooo`@00000103oool200000180oooo003D0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00e03o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3o
ool00=@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0140oooo003D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool20000
0180oooo003E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0A0?ooo`00e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool04@3oool00=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0140oooo003E0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0103oool200000180oooo003E0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0A0?ooo`00e@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00=H0oooo00D000000?ooo`3oool0
oooo0000000?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0140oooo003F0?ooo`050000003oool0oooo0?ooo`00
00003`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0103oool200000180oooo003F0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool04@3oool00=L0oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00T0oooo0P0000050?ooo`030000003oool0oooo0140oooo003G0?ooo`8000004@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?oo
o`030?ooo`030000003oool0oooo0140oooo003H0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0000000@0oooo0P00000B
0?ooo`00jP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo0P0000050?oo
o`030000003oool0oooo0140oooo003Z0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo000000040?ooo`030000003oool0oooo0140oooo003[0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo00<0oooo
00<000000?ooo`3oool04@3oool00>/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`090?ooo`8000001@3oool200000180oooo003[0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0140oooo003[0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0140oooo003[0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo003[0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`800000
4P3oool00>/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool04@3oool00>/0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool0
0>/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool04@3oool00>/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo0P00000B0?ooo`00j`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0A0?ooo`00j`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`00j`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A
0?ooo`00j`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00`3oool200000180oooo003[0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo003[0?ooo`030000
003oool0oooo00/0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000
003oool0oooo0140oooo003[0?ooo`030000003oool0oooo00X0oooo0P0000000`3oool000000?oo
o`090?ooo`800000103oool00`000000oooo0?ooo`0A0?ooo`00j`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0000000X0oooo0P0000040?ooo`8000004P3oool00>`0oooo00<000000?oo
o`3oool02P3oool2000000T0oooo0`0000050?ooo`030000003oool0oooo0140oooo003/0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`000000203oool00`000000oooo000000050?ooo`03
0000003oool0oooo0140oooo003/0?ooo`030000003oool0oooo00T0oooo0P0000000`3oool00000
0?ooo`070?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool04@3oool00>`0oooo00<0
00000?ooo`3oool02P3oool2000000T0oooo100000040?ooo`8000004P3oool00>`0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool04@3oool00>`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00>`0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool04@3oool00>`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00<0oooo0P00000B0?ooo`00k03oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`00k03oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0A0?ooo`00k03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`00k03oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool200000180
oooo003/0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0140oooo003/0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo003/
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0140oooo003/0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`020?ooo`8000004P3oool00>`0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool04@3oool00>`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`800000
103oool00`000000oooo0?ooo`0A0?ooo`00k03oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00/0oooo0P0000040?ooo`030000003oool0oooo0140oooo003/0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool5000000@0oooo0P00000B0?ooo`00o`3oool40?oo
o`040000003oool0oooo000001T0oooo003o0?ooo`D0oooo00<000000?ooo`0000006@3oool00?l0
oooo1P3oool2000001T0oooo003o0?ooo`L0oooo00<000000?ooo`3oool05`3oool00001\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {662.562, 521.25}} -> {-31.0405, \
15.9926, 0.0811648, 0.0250148}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.97619 0.047619 0 0.154508 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.96369 .07725 -18 -4.5 ]
[.96369 .07725 0 4.5 ]
[.96369 .15451 -6 -4.5 ]
[.96369 .15451 0 4.5 ]
[.96369 .23176 -18 -4.5 ]
[.96369 .23176 0 4.5 ]
[.96369 .30902 -6 -4.5 ]
[.96369 .30902 0 4.5 ]
[.96369 .38627 -18 -4.5 ]
[.96369 .38627 0 4.5 ]
[.96369 .46353 -6 -4.5 ]
[.96369 .46353 0 4.5 ]
[.96369 .54078 -18 -4.5 ]
[.96369 .54078 0 4.5 ]
[.96369 .61803 -6 -4.5 ]
[.96369 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-15)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(-10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(-5)] .7381 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.97619 .07725 m
.98244 .07725 L
s
[(0.5)] .96369 .07725 1 0 Mshowa
.97619 .15451 m
.98244 .15451 L
s
[(1)] .96369 .15451 1 0 Mshowa
.97619 .23176 m
.98244 .23176 L
s
[(1.5)] .96369 .23176 1 0 Mshowa
.97619 .30902 m
.98244 .30902 L
s
[(2)] .96369 .30902 1 0 Mshowa
.97619 .38627 m
.98244 .38627 L
s
[(2.5)] .96369 .38627 1 0 Mshowa
.97619 .46353 m
.98244 .46353 L
s
[(3)] .96369 .46353 1 0 Mshowa
.97619 .54078 m
.98244 .54078 L
s
[(3.5)] .96369 .54078 1 0 Mshowa
.97619 .61803 m
.98244 .61803 L
s
[(4)] .96369 .61803 1 0 Mshowa
.125 Mabswid
.97619 .01545 m
.97994 .01545 L
s
.97619 .0309 m
.97994 .0309 L
s
.97619 .04635 m
.97994 .04635 L
s
.97619 .0618 m
.97994 .0618 L
s
.97619 .09271 m
.97994 .09271 L
s
.97619 .10816 m
.97994 .10816 L
s
.97619 .12361 m
.97994 .12361 L
s
.97619 .13906 m
.97994 .13906 L
s
.97619 .16996 m
.97994 .16996 L
s
.97619 .18541 m
.97994 .18541 L
s
.97619 .20086 m
.97994 .20086 L
s
.97619 .21631 m
.97994 .21631 L
s
.97619 .24721 m
.97994 .24721 L
s
.97619 .26266 m
.97994 .26266 L
s
.97619 .27812 m
.97994 .27812 L
s
.97619 .29357 m
.97994 .29357 L
s
.97619 .32447 m
.97994 .32447 L
s
.97619 .33992 m
.97994 .33992 L
s
.97619 .35537 m
.97994 .35537 L
s
.97619 .37082 m
.97994 .37082 L
s
.97619 .40172 m
.97994 .40172 L
s
.97619 .41717 m
.97994 .41717 L
s
.97619 .43262 m
.97994 .43262 L
s
.97619 .44807 m
.97994 .44807 L
s
.97619 .47898 m
.97994 .47898 L
s
.97619 .49443 m
.97994 .49443 L
s
.97619 .50988 m
.97994 .50988 L
s
.97619 .52533 m
.97994 .52533 L
s
.97619 .55623 m
.97994 .55623 L
s
.97619 .57168 m
.97994 .57168 L
s
.97619 .58713 m
.97994 .58713 L
s
.97619 .60258 m
.97994 .60258 L
s
.25 Mabswid
.97619 0 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.51047 0 m
.51698 .0009 L
.52209 .00162 L
.52687 .00222 L
.52947 .00249 L
.53185 .00269 L
.53311 .00277 L
.53448 .00284 L
.53524 .00288 L
.53594 .0029 L
.5366 .00292 L
.53731 .00293 L
.53863 .00294 L
.53937 .00293 L
.54004 .00292 L
.54129 .00288 L
.54261 .00282 L
.54406 .00272 L
.5454 .00259 L
.54846 .00221 L
.55106 .00177 L
.55342 .00128 L
s
.55342 .00128 m
.55826 0 L
s
.60733 0 m
.60798 .00058 L
.61367 .00747 L
.61885 .01528 L
.62891 .0333 L
.63958 .05273 L
.64397 .05942 L
.64869 .06503 L
.65001 .06623 L
.6514 .06731 L
.65268 .06811 L
.65388 .0687 L
.655 .06909 L
.6562 .06935 L
.65688 .06942 L
.65753 .06943 L
.65874 .0693 L
.65989 .06901 L
.66096 .06859 L
.66213 .06795 L
.6634 .06706 L
.66597 .06461 L
.66833 .06163 L
.67286 .05402 L
.67716 .04484 L
.68683 .01999 L
.69213 .00626 L
s
.69213 .00626 m
.69494 0 L
s
.71777 0 m
.7215 .0127 L
.72642 .03644 L
.73539 .09596 L
.74637 .18502 L
.75176 .22777 L
.75672 .26222 L
.76123 .28703 L
.76351 .29651 L
.766 .30425 L
.76731 .30712 L
.76851 .30898 L
.76917 .3097 L
.76989 .31023 L
.7712 .31049 L
.77242 .30991 L
.77371 .30842 L
.77482 .30643 L
.77604 .30347 L
.77851 .29508 L
.78111 .28286 L
.78576 .2531 L
.79623 .15959 L
.80134 .10953 L
.80616 .06617 L
.81049 .03449 L
.81293 .02097 L
.81409 .01585 L
.81518 .01188 L
.81625 .00882 L
.81739 .00648 L
.81866 .00508 L
.81982 .00493 L
.82103 .00598 L
.82234 .00853 L
.82358 .01234 L
.82473 .01709 L
.82732 .03217 L
.82967 .05105 L
.83493 .11077 L
.83948 .17996 L
.84439 .26894 L
.8533 .4485 L
.85829 .54622 L
s
.85829 .54622 m
.86253 .61803 L
s
.89193 .61803 m
.89436 .57907 L
.90322 .40212 L
.91272 .21778 L
.91552 .17453 L
.91817 .14083 L
.92056 .11755 L
.9219 .10758 L
.92315 .10052 L
.9243 .09589 L
.92539 .09327 L
.92658 .09235 L
.92787 .09367 L
.92914 .09738 L
.92978 .10015 L
.93049 .10387 L
.93173 .11223 L
.93289 .12202 L
.93548 .15077 L
.93793 .18617 L
.94252 .27151 L
.95281 .52266 L
s
.95281 .52266 m
.95649 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`004`3oool4000000<0oooo0P00000e0?ooo`@000000P3oool3000003@0
oooo100000030?ooo`800000>03oool3000004h0oooo000C0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool00000=P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0B`3oool001@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000f0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1;0?ooo`003@3oool40000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02`0oooo10000004
0?ooo`040000003oool0oooo0?ooo`<00000;P3oool4000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo02l0oooo100000020?ooo`<00000CP3oool001H0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`050000003oool0oooo0?ooo`00
0000>03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`1>0?ooo`004`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000003@0oooo0`0000030?ooo`030000003oool0oooo03@0oooo0`0000030?ooo`040000003oool0
oooo000003L0oooo00<000000?ooo`3oool0CP3oool001@0oooo0P0000040?ooo`800000=`3oool0
10000000oooo0?ooo`3oool4000003D0oooo00<000000?ooo`3oool00P3oool2000003P0oooo1000
001=0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003`3ooooo000000D00000
3@3oool001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`D000002`3o
ool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`060?ooo`8000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`00[P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0000
000W0?ooo`030000003oool0oooo0140oooo002_0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0000002L0oooo00<00000
0?ooo`3oool04@3oool00:l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo01D0oooo00@000000?ooo`3oool000009P3oool200000180oooo002`0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?oo
o`040000003oool0oooo000002H0oooo00<000000?ooo`3oool04@3oool00;40oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01@0oooo00@000000?oo
o`3oool000009P3oool00`000000oooo0?ooo`0A0?ooo`00/@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`00000V
0?ooo`030000003oool0oooo0140oooo002b0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000009P3oool2
00000180oooo002c0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000009P3oool00`000000oooo0?ooo`0A
0?ooo`00/`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool04`3oool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool04@3oool0
0;@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0140oooo002d0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08`3oool200000180
oooo002e0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0A0?ooo`00]P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool04@3oool00;H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0140oooo002g0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool08`3oool200000180oooo002g0?ooo`80000000<0oooo000000000000403oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0A0?ooo`00^03oool300000140oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0100oooo0P0000040?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`030000003oool0oooo0140oooo003<0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`00c03oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo0080oooo0P00000B0?ooo`00c@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool010000000oooo0?oo
o`0000080?ooo`<000001@3oool00`000000oooo0?ooo`0A0?ooo`00c@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool010000000oooo0?oo
o`0000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00<d0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo
003=0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0?0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`@00000103oool200000180oooo003=
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool04@3oool00<d0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`0000002`3oool00`000000oooo0?ooo`0A0?ooo`00c@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`000000oooo0000000;0?ooo`03
0000003oool0oooo0140oooo003=0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0000000/0oooo0P00000B0?ooo`00cP3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0000000;0?ooo`030000003oool0oooo0140oooo003>0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`050000003oool0
oooo0?ooo`0000002P3oool00`000000oooo0?ooo`0A0?ooo`00cP3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3o
ool0000000X0oooo00<000000?ooo`3oool04@3oool00<h0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo0000
000:0?ooo`8000004P3oool00<h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003o
ool0oooo0140oooo003>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?oo
o`0A0?ooo`00cP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool04`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool04@3o
ool00<h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo01<0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`8000004P3oool00<l0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01<0oooo00D00000
0?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0140oooo003?0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`050000003oool0
oooo0?ooo`0000000P3oool4000000@0oooo00<000000?ooo`3oool04@3oool00<l0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0180oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3o
ool00<l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0180oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo0P00
000B0?ooo`00c`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`00c`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?oo
o`00c`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<000001@3oool00`000000
oooo0?ooo`0A0?ooo`00c`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
00001@3oool200000180oooo003@0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0A0?ooo`00d03oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool04@3oool00=00oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo003@0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool200000180oooo003@0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`00d03oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00=40oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo003A
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool200000180oooo003A0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?oo
o`00d@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool04@3oool00=40oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0140oooo003A0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3o
ool200000180oooo003B0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0A0?ooo`00dP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0303oool4000000<0oooo00D000000?ooo`3oool000000?ooo`03
000000D0oooo00<000000?ooo`3oool04@3oool00=80oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo0P0000070?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`0A0?ooo`00dP3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool03P3oool2000000L0oooo00D000000?oo
o`3oool0oooo000000040?ooo`8000004P3oool00=80oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo0P0000070?ooo`@000001@3oool00`00
0000oooo0?ooo`0A0?ooo`00dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool03P3oool2000000L0oooo0P0000070?ooo`030000003oool0oooo0140
oooo003B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0<0?ooo`@000001`3oool2000000L0oooo00<000000?ooo`3oool04@3oool00=<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo0P00
00070?ooo`D00000103oool200000180oooo003C0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`00d`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00=<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo003C0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool200000180oooo003C0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`00d`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool0
0=@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0140oooo003D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool200000180
oooo003D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0A0?ooo`00e03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool04@3oool00=@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0140oooo003E0?ooo`050000003oool0oooo0?ooo`000000403oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool2
00000180oooo003E0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A
0?ooo`00e@3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool01P3oool5000000@0oooo00<000000?ooo`3oool04@3oool00=D0oooo0P0000000`3o
ool000000?ooo`0@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool20000
00L0oooo00<000000?ooo`3oool04@3oool00=H0oooo0P00000B0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01P3oool00`000000oooo000000060?ooo`8000004P3oool00>X0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000D0oooo
00<000000?ooo`3oool04@3oool00>/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`070?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool04@3oool00>/0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool04@3oool00>/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`070?ooo`<000001@3oool200000180oooo003[0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo003[0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0140oooo003[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo003[0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`800000
4P3oool00>/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool04@3oool00>/0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool0
0>/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool04@3oool00>/0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo0P00000B0?ooo`00j`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0A0?ooo`00j`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00j`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A
0?ooo`00j`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01@3oool200000180oooo003[0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo003[0?ooo`030000
003oool0oooo00X0oooo100000030?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000
003oool0oooo0140oooo003[0?ooo`030000003oool0oooo00X0oooo0P00000:0?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool04@3oool00>/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000@0oooo0P00000B0?ooo`00j`3o
ool00`000000oooo0?ooo`0;0?ooo`8000002@3oool3000000D0oooo00<000000?ooo`3oool04@3o
ool00>/0oooo00<000000?ooo`3oool02`3oool00`000000oooo000000080?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool04@3oool00>/0oooo00<000000?ooo`3oool02P3oool20000
00030?ooo`000000oooo00L0oooo0P0000060?ooo`030000003oool0oooo0140oooo003[0?ooo`03
0000003oool0oooo00/0oooo0P0000090?ooo`@00000103oool200000180oooo003/0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0140oooo003/0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0140oooo003/0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0140oooo003/0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`040?ooo`8000004P3oool00>`0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00>`0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool04@3oool00>`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00>`0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo0P00000B
0?ooo`00k03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0A0?ooo`00k03oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0A0?ooo`00
k03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0A0?ooo`00k03oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0103oool200000180oooo003/0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0140oooo003/0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool20000
00D0oooo00<000000?ooo`3oool04@3oool00>`0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`80000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0A0?ooo`00
k03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`000000
103oool200000180oooo003/0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3o
ool2000000D0oooo00<000000?ooo`3oool04@3oool00>`0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool04@3oool0
0>`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`80000000<0oooo0000
003oool00`3oool00`000000oooo0?ooo`0A0?ooo`00k03oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00X0oooo0P0000050?ooo`8000004P3oool00>`0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
4@3oool00>`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool04@3oool00>`0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool0
0>`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00<0oooo0P00000B0?ooo`00k@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`00k@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0A0?ooo`00k@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`00k@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool200000180oooo003]0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0140oooo003]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo003]0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0140oooo003]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`030?ooo`8000004P3oool00>d0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool0
0>d0oooo00<000000?ooo`3oool0203oool3000000@0oooo00<000000?ooo`3oool00P3oool30000
00D0oooo00<000000?ooo`3oool04@3oool00>d0oooo00<000000?ooo`3oool01`3oool200000080
oooo00<000000?ooo`3oool0203oool2000000@0oooo00<000000?ooo`3oool04@3oool00>d0oooo
00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000X0oooo0P0000040?ooo`80
00004P3oool00>d0oooo00<000000?ooo`3oool01`3oool010000000oooo0000000000090?ooo`<0
00001@3oool00`000000oooo0?ooo`0A0?ooo`00k@3oool00`000000oooo0?ooo`070?ooo`050000
003oool0oooo0?ooo`000000203oool00`000000oooo000000050?ooo`030000003oool0oooo0140
oooo003]0?ooo`030000003oool0oooo00L0oooo0P0000020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0A0?ooo`00k@3oool00`000000oooo0?oo
o`070?ooo`040000003oool00000000000T0oooo100000040?ooo`8000004P3oool00>d0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool04@3oool00>d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00>d0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool04@3oool00>d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0080oooo0P00000B0?ooo`00k@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`00k@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0A0?ooo`00kP3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`00kP3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool20000
0180oooo003^0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0140oooo003^0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo
003^0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0140oooo003^0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`8000004P3oool00>h0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool04@3oool00>h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`80
0000103oool00`000000oooo0?ooo`0A0?ooo`00kP3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00d0oooo0P0000040?ooo`030000003oool0oooo0140oooo003^0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool02P3oool5000000@0oooo0P00000B0?ooo`00o`3oool4
0?ooo`040000003oool0oooo000001T0oooo003o0?ooo`D0oooo00<000000?ooo`0000006@3oool0
0?l0oooo1P3oool2000001T0oooo003o0?ooo`L0oooo00<000000?ooo`3oool05`3oool00001\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {216.5, 75.1875}} -> {-31.0405, \
2.04494, 0.0811648, 0.0250148}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.97619 0.047619 0 0.154508 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.96369 .07725 -18 -4.5 ]
[.96369 .07725 0 4.5 ]
[.96369 .15451 -6 -4.5 ]
[.96369 .15451 0 4.5 ]
[.96369 .23176 -18 -4.5 ]
[.96369 .23176 0 4.5 ]
[.96369 .30902 -6 -4.5 ]
[.96369 .30902 0 4.5 ]
[.96369 .38627 -18 -4.5 ]
[.96369 .38627 0 4.5 ]
[.96369 .46353 -6 -4.5 ]
[.96369 .46353 0 4.5 ]
[.96369 .54078 -18 -4.5 ]
[.96369 .54078 0 4.5 ]
[.96369 .61803 -6 -4.5 ]
[.96369 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-15)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(-10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(-5)] .7381 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.97619 .07725 m
.98244 .07725 L
s
[(0.5)] .96369 .07725 1 0 Mshowa
.97619 .15451 m
.98244 .15451 L
s
[(1)] .96369 .15451 1 0 Mshowa
.97619 .23176 m
.98244 .23176 L
s
[(1.5)] .96369 .23176 1 0 Mshowa
.97619 .30902 m
.98244 .30902 L
s
[(2)] .96369 .30902 1 0 Mshowa
.97619 .38627 m
.98244 .38627 L
s
[(2.5)] .96369 .38627 1 0 Mshowa
.97619 .46353 m
.98244 .46353 L
s
[(3)] .96369 .46353 1 0 Mshowa
.97619 .54078 m
.98244 .54078 L
s
[(3.5)] .96369 .54078 1 0 Mshowa
.97619 .61803 m
.98244 .61803 L
s
[(4)] .96369 .61803 1 0 Mshowa
.125 Mabswid
.97619 .01545 m
.97994 .01545 L
s
.97619 .0309 m
.97994 .0309 L
s
.97619 .04635 m
.97994 .04635 L
s
.97619 .0618 m
.97994 .0618 L
s
.97619 .09271 m
.97994 .09271 L
s
.97619 .10816 m
.97994 .10816 L
s
.97619 .12361 m
.97994 .12361 L
s
.97619 .13906 m
.97994 .13906 L
s
.97619 .16996 m
.97994 .16996 L
s
.97619 .18541 m
.97994 .18541 L
s
.97619 .20086 m
.97994 .20086 L
s
.97619 .21631 m
.97994 .21631 L
s
.97619 .24721 m
.97994 .24721 L
s
.97619 .26266 m
.97994 .26266 L
s
.97619 .27812 m
.97994 .27812 L
s
.97619 .29357 m
.97994 .29357 L
s
.97619 .32447 m
.97994 .32447 L
s
.97619 .33992 m
.97994 .33992 L
s
.97619 .35537 m
.97994 .35537 L
s
.97619 .37082 m
.97994 .37082 L
s
.97619 .40172 m
.97994 .40172 L
s
.97619 .41717 m
.97994 .41717 L
s
.97619 .43262 m
.97994 .43262 L
s
.97619 .44807 m
.97994 .44807 L
s
.97619 .47898 m
.97994 .47898 L
s
.97619 .49443 m
.97994 .49443 L
s
.97619 .50988 m
.97994 .50988 L
s
.97619 .52533 m
.97994 .52533 L
s
.97619 .55623 m
.97994 .55623 L
s
.97619 .57168 m
.97994 .57168 L
s
.97619 .58713 m
.97994 .58713 L
s
.97619 .60258 m
.97994 .60258 L
s
.25 Mabswid
.97619 0 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.48615 0 m
.49328 .00108 L
.49785 .00163 L
.50272 .00208 L
.50543 .00226 L
.50789 .00238 L
.50908 .00242 L
.51036 .00245 L
.51157 .00247 L
.51269 .00248 L
.51383 .00248 L
.51489 .00248 L
.51605 .00246 L
.51729 .00243 L
.5186 .00239 L
.51984 .00234 L
.52216 .00222 L
.52736 .00184 L
.53217 .00138 L
.54305 5e-05 L
s
.54305 5e-05 m
.54341 0 L
s
.59154 0 m
.5925 .0004 L
.59782 .0033 L
.60356 .00764 L
.61404 .0188 L
.62367 .03169 L
.6328 .04401 L
.63782 .04972 L
.64028 .05203 L
.64256 .05379 L
.64384 .05461 L
.64525 .05535 L
.64667 .05592 L
.64744 .05615 L
.64817 .05632 L
.64945 .0565 L
.65063 .05651 L
.65128 .05646 L
.65198 .05635 L
.65327 .05602 L
.65458 .05551 L
.65578 .05488 L
.65845 .05292 L
.66092 .05042 L
.66325 .04749 L
.68163 .01077 L
s
.68163 .01077 m
.68667 0 L
s
.7128 0 m
.71673 .01167 L
.72175 .03225 L
.73198 .08708 L
.74282 .15093 L
.74741 .1748 L
.75235 .19552 L
.75518 .20439 L
.75777 .21026 L
.75901 .21226 L
.75967 .21309 L
.76037 .2138 L
.76165 .21464 L
.76284 .21485 L
.76409 .2145 L
.76524 .21364 L
.7665 .2121 L
.76783 .2098 L
.77007 .20438 L
.77252 .19625 L
.77706 .17556 L
.78129 .1505 L
.79036 .08455 L
.79997 .01329 L
s
.79997 .01329 m
.80222 0 L
s
.82692 0 m
.82839 .01081 L
.83134 .03721 L
.84155 .15955 L
.852 .30709 L
.8566 .36733 L
.86168 .42355 L
.86405 .4447 L
.86661 .46322 L
.86801 .47135 L
.8693 .47744 L
.87054 .48201 L
.87184 .48545 L
.87316 .48748 L
.8739 .48796 L
.87458 .488 L
.87588 .48694 L
.87712 .48459 L
.87782 .48267 L
.87856 .48018 L
.87989 .47455 L
.88133 .46685 L
.8829 .45645 L
.88791 .41109 L
.89329 .34506 L
.90302 .20272 L
.90792 .13293 L
.91313 .07008 L
.91614 .04215 L
.91886 .02335 L
.92018 .01673 L
.92087 .01392 L
.9216 .01148 L
.92224 .00978 L
.92294 .00841 L
.92417 .00725 L
.92482 .00729 L
.92552 .00785 L
.9268 .01023 L
.92804 .01427 L
.92919 .01951 L
.93043 .02679 L
.9318 .03676 L
.93457 .06299 L
.93957 .1296 L
.94427 .21105 L
s
.94427 .21105 m
.96776 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`004`3oool4000000<0oooo0P00000e0?ooo`@000000P3oool3000003@0
oooo100000030?ooo`800000>03oool3000004h0oooo000C0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool00000=P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0B`3oool001@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000f0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1;0?ooo`003@3oool40000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02`0oooo10000004
0?ooo`040000003oool0oooo0?ooo`<00000;P3oool4000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo02l0oooo100000020?ooo`<00000CP3oool001H0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`050000003oool0oooo0?ooo`00
0000>03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`1>0?ooo`004`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000003@0oooo0`0000030?ooo`030000003oool0oooo03@0oooo0`0000030?ooo`040000003oool0
oooo000003L0oooo00<000000?ooo`3oool0CP3oool001@0oooo0P0000040?ooo`800000=`3oool0
10000000oooo0?ooo`3oool4000003D0oooo00<000000?ooo`3oool00P3oool2000003P0oooo1000
001=0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003`3ooooo000000D00000
3@3oool001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo0P00000:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo002[0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool05@3oool2000000`0oooo00<000000?ooo`3oool04@3oool0
0:`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`800000303oool00`00
0000oooo0?ooo`0A0?ooo`00[@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`000000303oool200000180oooo002^0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0503oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0140
oooo002_0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0oooo0140oooo002_0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0503oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0140
oooo002`0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0503oool010000000oooo
0?ooo`00000;0?ooo`8000004P3oool00;40oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`0A0?ooo`00
/P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0
oooo0000000;0?ooo`030000003oool0oooo0140oooo002c0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3o
ool04@3oool00;@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0C0?ooo`050000
003oool0oooo0?ooo`0000002`3oool200000180oooo002d0?ooo`800000103oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0A0?ooo`00]@3oool500000140oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0140oooo003<0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`00c03oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00P0oooo0P00000B0?ooo`00c03oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool00<`0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo0P0000001`3oool00000
0?ooo`3oool000000?ooo`0000000P3oool3000000D0oooo00<000000?ooo`3oool04@3oool00<`0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool00P0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0A0?ooo`00c@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`02000000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`8000004P3oool00<d0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool00P0000040?ooo`030000003oool0oooo00<000001@3oool00`000000oooo0?oo
o`0A0?ooo`00c@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`02000000@0oooo00@000000?ooo`3oool000001`3o
ool00`000000oooo0?ooo`0A0?ooo`00c@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`0000050?ooo`040000003o
ool0oooo000000L0oooo00<000000?ooo`3oool04@3oool00<d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo0`0000050?ooo`030000003o
ool0oooo00@00000103oool200000180oooo003=0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`00c@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00<h0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo003>0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool200000180oooo003>0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`00cP3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool0
0<h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0140oooo003>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool200000180
oooo003>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0A0?ooo`00cP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool04@3oool00<l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0140oooo003?0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01`3oool200000180oooo003?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0A0?ooo`00c`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0000000<00000103oool00`000000oooo0?ooo`0A0?ooo`00c`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`060?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool04@3oool00<l0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool01P3oool010000000oooo0?ooo`0000050?ooo`8000004P3oool00=00oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool01P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0140oooo
003@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`0A0?ooo`00d03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`@000001@3oool00`000000oooo0?oo
o`0A0?ooo`00d@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000D0oooo0P00
000B0?ooo`00d@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool04@3oool00=40oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0140oooo003A0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0A0?ooo`00dP3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo0P00000B0?ooo`00dP3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool04@3oool00=80oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo003B0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00d`3oool01@000000
oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00D0oooo0P00000B0?ooo`00d`3oool010000000oooo0?ooo`00000C0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0140oooo003C0?ooo`040000003oool0oooo000001<0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool04@3oool00=@0oooo0P00000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo003Z0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`800000
4P3oool00>X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool04@3oool00>X0oooo00<000000?ooo`3oool02`3oool4
000000<0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool04@3oool0
0>X0oooo00<000000?ooo`3oool02`3oool00`000000oooo000000090?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool04@3oool00>/0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo000000090?ooo`040000003oool0oooo000000@0oooo0P00000B0?ooo`00j`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0000000T0oooo0`0000050?ooo`030000003oool0oooo
0140oooo003[0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`0000002@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0140oooo003[0?ooo`030000003oool0oooo00X0oooo
0`0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00>/0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo000000090?ooo`@00000103oool200000180oooo003[
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0140oooo003[0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0140oooo003[0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0140oooo003[0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`040?ooo`8000004P3oool00>/0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3o
ool00>/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool04@3oool00>/0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00>/0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0
oooo0P00000B0?ooo`00k03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0A0?ooo`00k03oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0A0?ooo`00k03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0A0?ooo`00k03oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool200000180oooo003/0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0140oooo003/0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2P3oool4000000@0oooo00<000000?ooo`3oool04@3oool00>`0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0:0?ooo`8000001P3oool00`000000oooo0?ooo`0A0?ooo`00k03oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool2
00000180oooo003/0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool20000
00D0oooo00<000000?ooo`3oool04@3oool00>`0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0<0?ooo`800000103oool00`000000oooo0?ooo`0A0?ooo`00k03oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00/0oooo00@000000?ooo`0000000000103oool00`000000
oooo0?ooo`0A0?ooo`00k03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo
0P0000050?ooo`8000004P3oool00>`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00>`0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool04@3oool00>d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00>d0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo0P00000B0?ooo`00
k@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0A0?ooo`00k@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`00k@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0A0?ooo`00k@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool00`3oool200000180oooo003]0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140
oooo003]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0140oooo003]0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo003]
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`03
0?ooo`8000004P3oool00>d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00>d0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`04000000<0oooo00<000000?ooo`3oool00P3oool3000000D0
oooo00<000000?ooo`3oool04@3oool00>d0oooo00<000000?ooo`3oool01@3oool010000000oooo
0?ooo`00000>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00>d0oooo
00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3o
ool00P3oool200000180oooo003]0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`070?ooo`@00000103oool00`000000oooo0?ooo`0A0?ooo`00k@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0140oooo003^0?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`060?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool04@3oool00>h0oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`3oool2000000T0oooo100000040?ooo`8000004P3oool00>h0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool04@3oool00>h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00>h0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool04@3oool00>h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0080oooo0P00000B0?ooo`00kP3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`00
kP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0A0?ooo`00kP3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`00kP3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool2
00000180oooo003_0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo003_0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140
oooo003_0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0140oooo003_0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`8000004P3oool00>l0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`050000003oool0oooo0?ooo`0000004`3o
ool00>l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`80000000<0oooo
0000003oool00P3oool00`000000oooo0?ooo`0A0?ooo`00k`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo
0140oooo003_0?ooo`050000003oool0oooo0?ooo`0000004`3oool2000000<0oooo0P00000B0?oo
o`00l03oool010000000oooo0?ooo`00000A0?ooo`80000000<0oooo0000003oool00P3oool00`00
0000oooo0?ooo`0A0?ooo`00l03oool010000000oooo0?ooo`00000C0?ooo`8000000`3oool00`00
0000oooo0?ooo`0A0?ooo`00l03oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo
008000000`3oool00`000000oooo0?ooo`0A0?ooo`00l03oool010000000oooo0?ooo`00000A0?oo
o`80000000<0oooo0000003oool00P3oool200000180oooo003`0?ooo`030000003oool0000001D0
oooo00D000000?ooo`3oool0oooo0000000C0?ooo`00l@3oool2000001D0oooo00D000000?ooo`3o
ool0oooo0000000C0?ooo`00o`3oool90?ooo`050000003oool0oooo0?ooo`0000004`3oool00?l0
oooo2@3oool010000000oooo0?ooo`3oool200000180oooo003o0?ooo`T0oooo00D000000?ooo`3o
ool0oooo0000000C0?ooo`00o`3oool90?ooo`050000003oool0oooo0?ooo`0000004`3oool00?l0
oooo2@3oool01@000000oooo0?ooo`3oool0000001<0oooo003o0?ooo`T0oooo00@000000?ooo`3o
ool0oooo0P00000B0?ooo`00o`3oool90?ooo`050000003oool0oooo0?ooo`0000004`3oool00?l0
oooo2P3oool010000000oooo0?ooo`00000C0?ooo`00o`3oool:0?ooo`040000003oool0oooo0000
01<0oooo003o0?ooo`X0oooo00<000000?ooo`3oool00P00000B0?ooo`00o`3oool:0?ooo`040000
003oool0oooo000001<0oooo003i0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<00000
0P3oool010000000oooo0?ooo`00000C0?ooo`00n03oool010000000oooo0?ooo`00000;0?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool04@3oool00?/0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo000000020?ooo`8000004P3oool00?T0oooo0P0000090?ooo`<000000P3o
ool010000000oooo0?ooo`00000C0?ooo`00n`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000004`3oool00?P0oooo00@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000001<0oooo003i0?ooo`800000
2@3oool4000000040?ooo`000000oooo0?ooo`8000004P3oool00?l0oooo2P3oool010000000oooo
0?ooo`00000C0?ooo`00o`3oool:0?ooo`040000003oool0oooo000001<0oooo003o0?ooo`X0oooo
00@000000?ooo`3oool000004`3oool00?l0oooo2P3oool00`000000oooo0?ooo`0200000180oooo
003o0?ooo`X0oooo00@000000?ooo`3oool000004`3oool00?l0oooo2P3oool010000000oooo0?oo
o`00000C0?ooo`00o`3oool:0?ooo`040000003oool0oooo000001<0oooo003o0?ooo`/0oooo00@0
00000?ooo`00000000004P3oool00?l0oooo2`3oool00`000000oooo0000000C0?ooo`00o`3oool;
0?ooo`030000003oool0000001<0oooo003o0?ooo`/0oooo00<000000?ooo`0000004`3oool00?l0
oooo2`3oool010000000oooo00000000000B0?ooo`00o`3oool;0?ooo`030000003oool0000001<0
oooo003o0?ooo`L0oooo00L000000?ooo`3oool0oooo0000003oool0000001<0oooo003o0?ooo`L0
oooo00L000000?ooo`3oool0oooo0000003oool0000001<0oooo003o0?ooo`@0oooo1@0000020?oo
o`040000003oool0000000000180oooo003o0?ooo`@0oooo00@000000?ooo`3oool000006@3oool0
0?l0oooo1@3oool00`000000oooo0000000I0?ooo`00o`3oool60?ooo`8000006@3oool00?l0oooo
1`3oool00`000000oooo0?ooo`0G0?ooo`00\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {365.188, 223.875}} -> {-31.0405, \
6.69418, 0.0811648, 0.0250148}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.97619 0.047619 0 0.154508 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.96369 .07725 -18 -4.5 ]
[.96369 .07725 0 4.5 ]
[.96369 .15451 -6 -4.5 ]
[.96369 .15451 0 4.5 ]
[.96369 .23176 -18 -4.5 ]
[.96369 .23176 0 4.5 ]
[.96369 .30902 -6 -4.5 ]
[.96369 .30902 0 4.5 ]
[.96369 .38627 -18 -4.5 ]
[.96369 .38627 0 4.5 ]
[.96369 .46353 -6 -4.5 ]
[.96369 .46353 0 4.5 ]
[.96369 .54078 -18 -4.5 ]
[.96369 .54078 0 4.5 ]
[.96369 .61803 -6 -4.5 ]
[.96369 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-15)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(-10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(-5)] .7381 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.97619 .07725 m
.98244 .07725 L
s
[(0.5)] .96369 .07725 1 0 Mshowa
.97619 .15451 m
.98244 .15451 L
s
[(1)] .96369 .15451 1 0 Mshowa
.97619 .23176 m
.98244 .23176 L
s
[(1.5)] .96369 .23176 1 0 Mshowa
.97619 .30902 m
.98244 .30902 L
s
[(2)] .96369 .30902 1 0 Mshowa
.97619 .38627 m
.98244 .38627 L
s
[(2.5)] .96369 .38627 1 0 Mshowa
.97619 .46353 m
.98244 .46353 L
s
[(3)] .96369 .46353 1 0 Mshowa
.97619 .54078 m
.98244 .54078 L
s
[(3.5)] .96369 .54078 1 0 Mshowa
.97619 .61803 m
.98244 .61803 L
s
[(4)] .96369 .61803 1 0 Mshowa
.125 Mabswid
.97619 .01545 m
.97994 .01545 L
s
.97619 .0309 m
.97994 .0309 L
s
.97619 .04635 m
.97994 .04635 L
s
.97619 .0618 m
.97994 .0618 L
s
.97619 .09271 m
.97994 .09271 L
s
.97619 .10816 m
.97994 .10816 L
s
.97619 .12361 m
.97994 .12361 L
s
.97619 .13906 m
.97994 .13906 L
s
.97619 .16996 m
.97994 .16996 L
s
.97619 .18541 m
.97994 .18541 L
s
.97619 .20086 m
.97994 .20086 L
s
.97619 .21631 m
.97994 .21631 L
s
.97619 .24721 m
.97994 .24721 L
s
.97619 .26266 m
.97994 .26266 L
s
.97619 .27812 m
.97994 .27812 L
s
.97619 .29357 m
.97994 .29357 L
s
.97619 .32447 m
.97994 .32447 L
s
.97619 .33992 m
.97994 .33992 L
s
.97619 .35537 m
.97994 .35537 L
s
.97619 .37082 m
.97994 .37082 L
s
.97619 .40172 m
.97994 .40172 L
s
.97619 .41717 m
.97994 .41717 L
s
.97619 .43262 m
.97994 .43262 L
s
.97619 .44807 m
.97994 .44807 L
s
.97619 .47898 m
.97994 .47898 L
s
.97619 .49443 m
.97994 .49443 L
s
.97619 .50988 m
.97994 .50988 L
s
.97619 .52533 m
.97994 .52533 L
s
.97619 .55623 m
.97994 .55623 L
s
.97619 .57168 m
.97994 .57168 L
s
.97619 .58713 m
.97994 .58713 L
s
.97619 .60258 m
.97994 .60258 L
s
.25 Mabswid
.97619 0 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.45681 0 m
.45765 7e-05 L
.46302 .00061 L
.47285 .00199 L
.48371 .00414 L
.49285 .00621 L
.49803 .00732 L
.50285 .0082 L
.5053 .00856 L
.5076 .00885 L
.50888 .00898 L
.51026 .0091 L
.51151 .00919 L
.51268 .00925 L
.51392 .0093 L
.51458 .00931 L
.51529 .00932 L
.51604 .00933 L
.51674 .00933 L
.51806 .0093 L
.5193 .00926 L
.52044 .0092 L
.52169 .00912 L
.52303 .00901 L
.52803 .00844 L
.53274 .00773 L
.54153 .00633 L
.54378 .00604 L
.5462 .00579 L
.54758 .00568 L
.54884 .00561 L
.55011 .00556 L
.55131 .00555 L
.55256 .00556 L
.55319 .00558 L
.55388 .00562 L
.55511 .0057 L
.55626 .00581 L
.55761 .00598 L
.55885 .00618 L
.56164 .00678 L
.56387 .00741 L
.56594 .00812 L
.57065 .01018 L
.57523 .01277 L
.58012 .0161 L
.60006 .0332 L
.61056 .04199 L
.6163 .04601 L
.62166 .049 L
Mistroke
.62412 .05009 L
.62645 .05093 L
.62773 .05131 L
.62913 .05165 L
.6304 .0519 L
.63158 .05208 L
.63288 .0522 L
.63409 .05226 L
.63479 .05227 L
.63543 .05225 L
.63613 .05222 L
.63687 .05216 L
.63754 .05208 L
.63826 .05198 L
.63955 .05174 L
.64109 .05135 L
.64249 .0509 L
.64495 .0499 L
.64722 .04873 L
.65236 .04523 L
.65688 .04122 L
.66168 .03619 L
.67109 .02493 L
.67629 .0188 L
.68122 .01374 L
.68343 .01188 L
.68579 .01026 L
.68715 .00952 L
.68838 .00899 L
.68961 .0086 L
.69078 .00837 L
.69184 .00828 L
.69297 .00831 L
.69393 .00846 L
.69498 .00874 L
.69611 .00919 L
.69733 .00985 L
.69952 .01152 L
.70209 .01428 L
.70481 .01819 L
.7097 .02772 L
.71496 .04138 L
.72077 .05983 L
.73127 .09762 L
.73586 .11356 L
.74089 .12874 L
.74325 .13466 L
.74578 .13991 L
.747 .14202 L
.74816 .14372 L
Mistroke
.74919 .14499 L
.75032 .14612 L
.75152 .14698 L
.7528 .14752 L
.75398 .14766 L
.75508 .14747 L
.75638 .14685 L
.75757 .1459 L
.75894 .14435 L
.76024 .14242 L
.76275 .13747 L
.76542 .13045 L
.77022 .1136 L
.7811 .06055 L
.79142 .00521 L
Mfstroke
.79142 .00521 m
.79258 0 L
s
.82386 0 m
.82781 .02434 L
.8333 .066 L
.84325 .15155 L
.84789 .19031 L
.85286 .22709 L
.85528 .24227 L
.85756 .25469 L
.85964 .26413 L
.86185 .27206 L
.86297 .27521 L
.86421 .27797 L
.86534 .27982 L
.86639 .28098 L
.86764 .2816 L
.86877 .28146 L
.87003 .28053 L
.87134 .27867 L
.87259 .27609 L
.87392 .27244 L
.87632 .26361 L
.87917 .24952 L
.88177 .23356 L
.8926 .14293 L
.90283 .0458 L
.90784 .00494 L
s
.90784 .00494 m
.90863 0 L
s
.9328 0 m
.93664 .03393 L
.94127 .08579 L
.97619 .49074 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`004`3oool4000000<0oooo0P00000e0?ooo`@000000P3oool3000003@0
oooo100000030?ooo`800000>03oool3000004h0oooo000C0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool00000=P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0B`3oool001@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000f0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1;0?ooo`003@3oool40000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02`0oooo10000004
0?ooo`040000003oool0oooo0?ooo`<00000;P3oool4000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo02l0oooo100000020?ooo`<00000CP3oool001H0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`050000003oool0oooo0?ooo`00
0000>03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`1>0?ooo`004`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000003@0oooo0`0000030?ooo`030000003oool0oooo03@0oooo0`0000030?ooo`040000003oool0
oooo000003L0oooo00<000000?ooo`3oool0CP3oool001@0oooo0P0000040?ooo`800000=`3oool0
10000000oooo0?ooo`3oool4000003D0oooo00<000000?ooo`3oool00P3oool2000003P0oooo1000
001=0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003`3ooooo000000D00000
3@3oool001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0103oool6000000T0oooo1`0000080?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`0000001`3oool010000000oooo0?ooo`00000;0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool2000000X0oooo00<000000?ooo`3oool0
4@3oool00900oooo2P0000060?ooo`@000007@3oool4000001L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0A0?ooo`00Y03oool00`000000oooo0?ooo`0H0?ooo`8000000`3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04@3oool0
0:D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0203oool200000180oooo002V0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool04@3oool00:L0oooo0P00000D0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo
002Y0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00:X0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01`3oool200000180oooo002[0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool04@3oool00:`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`00
[@3oool2000000X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00:l0oooo00<000000?ooo`3oool01@3o
ool200000100oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`8000004P3o
ool00;00oooo1`00000B0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0A0?ooo`00bP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool04@3oool00<X0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0140oooo003:0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool200000180oooo003:0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`00b`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03P3oool3000000@0oooo00@00000
0?ooo`3oool0oooo100000050?ooo`030000003oool0oooo0140oooo003;0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`040000003oool0
oooo000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0140oooo
003;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0>0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`80
00004P3oool00</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00h0oooo00@000000?ooo`3oool000001`3oool4000000D0oooo00<000000?ooo`3o
ool04@3oool00</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00h0oooo00@000000?ooo`3oool000001`3oool2000000L0oooo00<000000?ooo`3o
ool04@3oool00<`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00d0oooo00@000000?ooo`3oool000001`3oool2000000L0oooo00<000000?ooo`3o
ool04@3oool00<`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00d0oooo0`0000080?ooo`D00000103oool200000180oooo003<0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`00c@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool0
0<d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0140oooo003>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool200000180
oooo003>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0A0?ooo`00cP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool04@3oool00<l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0140oooo003?0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool01@3oool200000180oooo003?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0A0?ooo`00c`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00<l0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo003@0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool01@3oool200000180oooo003@0?ooo`8000000P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo003A0?ooo`<000005@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo100000040?ooo`030000003oool0oooo0140
oooo003Y0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
000000050?ooo`030000003oool0oooo0140oooo003Y0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0303oool2000000D0oooo0P00000B0?ooo`00j@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00d0oooo0P0000050?ooo`030000003oool0oooo0140oooo003Z0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool2000000D0oooo00<000000?oo
o`3oool04@3oool00>X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0<0?ooo`<0
00001@3oool00`000000oooo0?ooo`0A0?ooo`00jP3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00d0oooo0P0000050?ooo`8000004P3oool00>X0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3o
ool00>X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool04@3oool00>/0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00>/0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0
oooo0P00000B0?ooo`00j`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0A0?ooo`00j`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0A0?ooo`00j`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0A0?ooo`00j`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool200000180oooo003[0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0140oooo003/0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo003/0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0140oooo003/0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`030?ooo`8000004P3oool00>`0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00>`0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`@000000`3oool00`000000
oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`0A0?ooo`00k03oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool2000000@0oooo
00<000000?ooo`3oool04@3oool00>`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00T0oooo0P0000040?ooo`8000004P3oool00>d0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo0`000005
0?ooo`030000003oool0oooo0140oooo003]0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0000000D0oooo00<000000?oo
o`3oool04@3oool00>d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<0
00002@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0140oooo003]0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`@0
0000103oool200000180oooo003]0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo003]0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0140oooo003^0?ooo`050000003oool0oooo0?ooo`000000503oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0140oooo003^0?ooo`050000003oool0oooo0?ooo`000000503o
ool00`000000oooo0?ooo`020?ooo`8000004P3oool00>h0oooo00D000000?ooo`3oool0oooo0000
000D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00>h0oooo00@00000
0?ooo`3oool000005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo003^
0?ooo`040000003oool0oooo000001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0A0?ooo`00k`3oool00`000000oooo0000000E0?ooo`030000003oool0oooo0080oooo0P00000B
0?ooo`00k`3oool2000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?oo
o`00o`3oool80?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00?l0oooo
2@3oool01@000000oooo0?ooo`3oool0000001<0oooo003o0?ooo`T0oooo00@000000?ooo`3oool0
oooo0P00000B0?ooo`00o`3oool90?ooo`050000003oool0oooo0?ooo`0000004`3oool00?l0oooo
1@3oool5000000<0oooo00<000000?ooo`3oool04@3oool00?l0oooo1@3oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`3oool04@3oool00?l0oooo1P3oool010000000oooo0?oo
o`0000030?ooo`8000004P3oool00?l0oooo1`3oool00`000000oooo000000030?ooo`030000003o
ool0oooo0140oooo003o0?ooo`P0oooo0P0000030?ooo`030000003oool0oooo0140oooo003o0?oo
o`D0oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo0140oooo003o0?ooo`H0
oooo0P0000000`3oool000000?ooo`020?ooo`8000004P3oool00?l0oooo2@3oool01@000000oooo
0?ooo`3oool0000001<0oooo003o0?ooo`T0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`00
o`3oool:0?ooo`040000003oool0oooo000001<0oooo003o0?ooo`X0oooo00<000000?ooo`3oool0
0P00000B0?ooo`00o`3oool:0?ooo`040000003oool0oooo000001<0oooo003o0?ooo`X0oooo00@0
00000?ooo`3oool000004`3oool00?l0oooo2P3oool010000000oooo0?ooo`00000C0?ooo`00o`3o
ool:0?ooo`030000003oool0oooo008000004P3oool00?l0oooo2P3oool010000000oooo0?ooo`00
000C0?ooo`00o`3oool:0?ooo`040000003oool0oooo000001<0oooo003o0?ooo`X0oooo00@00000
0?ooo`3oool000004`3oool00?l0oooo2P3oool00`000000oooo0?ooo`0200000180oooo003o0?oo
o`X0oooo00@000000?ooo`3oool000004`3oool00?P0oooo100000030?ooo`030000003oool0oooo
0080oooo0`0000030?ooo`030000003oool0000001<0oooo003h0?ooo`030000003oool0oooo00`0
oooo00H000000?ooo`3oool000000?ooo`00000C0?ooo`00n@3oool00`000000oooo0?ooo`0;0?oo
o`050000003oool0oooo0000003oool00P00000B0?ooo`00nP3oool00`000000oooo0?ooo`070?oo
o`<000000`3oool00`000000oooo0000000C0?ooo`00n`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`0000004`3oool00?P0oooo00@000000?ooo`3oool0
0000203oool00`000000oooo0?ooo`030?ooo`030000003oool0000001<0oooo003i0?ooo`800000
2@3oool400000080oooo00@000000?ooo`00000000004P3oool00?l0oooo2`3oool00`000000oooo
0000000C0?ooo`00o`3oool;0?ooo`030000003oool0000001<0oooo003o0?ooo`/0oooo00<00000
0?ooo`0000004`3oool00?l0oooo2`3oool010000000oooo00000000000B0?ooo`00o`3oool;0?oo
o`030000003oool0000001<0oooo003o0?ooo``0oooo0P00000C0?ooo`00o`3oool<0?ooo`800000
4`3oool00?l0oooo303oool300000180oooo003o0?ooo``0oooo0P00000C0?ooo`00o`3oool<0?oo
o`8000004`3oool00?l0oooo303oool2000001<0oooo003o0?ooo``0oooo0`00000B0?ooo`00o`3o
ool<0?ooo`8000004`3oool00?l0oooo1P3oool2000000@0oooo0P00000C0?ooo`00o`3oool50?oo
o`040000003oool0oooo000000<0oooo0P00000C0?ooo`00o`3oool80?ooo`040000003oool0oooo
0?ooo`<000004P3oool00?l0oooo1P3oool2000000@0oooo0P00000C0?ooo`00o`3oool80?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00?l0oooo1@3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0140oooo003o0?ooo`H0oooo0P0000050?ooo`800000
4P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0
oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool200000180
oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?oo
o`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo0P00000B0?oo
o`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool0
4@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`8000004P3oool0
0?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00n@3oool2000000@0oooo00<000000?ooo`3o
ool00P3oool3000000D0oooo00<000000?ooo`3oool04@3oool00?P0oooo00@000000?ooo`3oool0
00002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo003k0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool200000180oooo003i0?ooo`8000002@3o
ool3000000D0oooo00<000000?ooo`3oool04@3oool00?/0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo003h0?ooo`040000003oool0oooo
000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00n@3oool20000
00T0oooo100000040?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00
o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3o
ool00?l0oooo3@3oool200000180oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0
oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo
003o0?ooo`d0oooo0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?oo
o`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00
o`3oool=0?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool7
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00?l0oooo1`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo003o0?ooo`@0oooo1@0000040?ooo`80
00004P3oool00?l0oooo103oool010000000oooo0?ooo`00000I0?ooo`00o`3oool50?ooo`030000
003oool0000001T0oooo003o0?ooo`H0oooo0P00000I0?ooo`00o`3oool70?ooo`030000003oool0
oooo01L0oooo0000\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {513.875, 372.562}} -> {-31.0405, \
11.3434, 0.0811648, 0.0250148}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.97619 0.047619 0 0.154508 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.96369 .07725 -18 -4.5 ]
[.96369 .07725 0 4.5 ]
[.96369 .15451 -6 -4.5 ]
[.96369 .15451 0 4.5 ]
[.96369 .23176 -18 -4.5 ]
[.96369 .23176 0 4.5 ]
[.96369 .30902 -6 -4.5 ]
[.96369 .30902 0 4.5 ]
[.96369 .38627 -18 -4.5 ]
[.96369 .38627 0 4.5 ]
[.96369 .46353 -6 -4.5 ]
[.96369 .46353 0 4.5 ]
[.96369 .54078 -18 -4.5 ]
[.96369 .54078 0 4.5 ]
[.96369 .61803 -6 -4.5 ]
[.96369 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-15)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(-10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(-5)] .7381 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.97619 .07725 m
.98244 .07725 L
s
[(0.5)] .96369 .07725 1 0 Mshowa
.97619 .15451 m
.98244 .15451 L
s
[(1)] .96369 .15451 1 0 Mshowa
.97619 .23176 m
.98244 .23176 L
s
[(1.5)] .96369 .23176 1 0 Mshowa
.97619 .30902 m
.98244 .30902 L
s
[(2)] .96369 .30902 1 0 Mshowa
.97619 .38627 m
.98244 .38627 L
s
[(2.5)] .96369 .38627 1 0 Mshowa
.97619 .46353 m
.98244 .46353 L
s
[(3)] .96369 .46353 1 0 Mshowa
.97619 .54078 m
.98244 .54078 L
s
[(3.5)] .96369 .54078 1 0 Mshowa
.97619 .61803 m
.98244 .61803 L
s
[(4)] .96369 .61803 1 0 Mshowa
.125 Mabswid
.97619 .01545 m
.97994 .01545 L
s
.97619 .0309 m
.97994 .0309 L
s
.97619 .04635 m
.97994 .04635 L
s
.97619 .0618 m
.97994 .0618 L
s
.97619 .09271 m
.97994 .09271 L
s
.97619 .10816 m
.97994 .10816 L
s
.97619 .12361 m
.97994 .12361 L
s
.97619 .13906 m
.97994 .13906 L
s
.97619 .16996 m
.97994 .16996 L
s
.97619 .18541 m
.97994 .18541 L
s
.97619 .20086 m
.97994 .20086 L
s
.97619 .21631 m
.97994 .21631 L
s
.97619 .24721 m
.97994 .24721 L
s
.97619 .26266 m
.97994 .26266 L
s
.97619 .27812 m
.97994 .27812 L
s
.97619 .29357 m
.97994 .29357 L
s
.97619 .32447 m
.97994 .32447 L
s
.97619 .33992 m
.97994 .33992 L
s
.97619 .35537 m
.97994 .35537 L
s
.97619 .37082 m
.97994 .37082 L
s
.97619 .40172 m
.97994 .40172 L
s
.97619 .41717 m
.97994 .41717 L
s
.97619 .43262 m
.97994 .43262 L
s
.97619 .44807 m
.97994 .44807 L
s
.97619 .47898 m
.97994 .47898 L
s
.97619 .49443 m
.97994 .49443 L
s
.97619 .50988 m
.97994 .50988 L
s
.97619 .52533 m
.97994 .52533 L
s
.97619 .55623 m
.97994 .55623 L
s
.97619 .57168 m
.97994 .57168 L
s
.97619 .58713 m
.97994 .58713 L
s
.97619 .60258 m
.97994 .60258 L
s
.25 Mabswid
.97619 0 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.41022 0 m
.41462 .00084 L
.42026 .00225 L
.4415 .00918 L
.44638 .01066 L
.45155 .01201 L
.45633 .01301 L
.46081 .01371 L
.4654 .01422 L
.46783 .01442 L
.47044 .01458 L
.47324 .01471 L
.4759 .01482 L
.48089 .01499 L
.48316 .01509 L
.48559 .01521 L
.48995 .01551 L
.49263 .01576 L
.49514 .01604 L
.49984 .01671 L
.53843 .02416 L
.54342 .02488 L
.54877 .02573 L
.55381 .02677 L
.5584 .02802 L
.56357 .02992 L
.56845 .03227 L
.57948 .0396 L
.59772 .05465 L
.60272 .05808 L
.60535 .05955 L
.60811 .06081 L
.61054 .06165 L
.61191 .062 L
.61319 .06224 L
.61437 .06239 L
.61544 .06246 L
.61668 .06248 L
.61785 .06242 L
.61899 .06229 L
.62025 .06207 L
.62157 .06175 L
.6228 .06137 L
.62499 .0605 L
.62735 .05931 L
.63274 .0557 L
.63765 .05151 L
.64856 .04074 L
.65336 .03612 L
.65867 .03163 L
Mistroke
.66096 .02999 L
.66343 .02846 L
.66556 .02736 L
.6679 .02641 L
.66919 .02601 L
.67039 .02571 L
.67166 .02549 L
.67237 .0254 L
.67302 .02535 L
.67418 .02531 L
.67544 .02536 L
.67662 .02548 L
.67772 .02568 L
.67891 .02596 L
.6802 .02637 L
.68251 .02733 L
.68527 .02888 L
.68779 .03066 L
.69327 .03564 L
.69847 .04162 L
.70879 .05592 L
.71851 .07016 L
.72723 .08098 L
.72962 .08327 L
.73215 .08527 L
.7343 .08659 L
.73553 .08716 L
.73667 .08758 L
.73789 .08789 L
.73858 .088 L
.73922 .08806 L
.74039 .08806 L
.74164 .08791 L
.74275 .08764 L
.74379 .08725 L
.74494 .0867 L
.74617 .08593 L
.74876 .08375 L
.75148 .08061 L
.75635 .07283 L
.76154 .06167 L
.76637 .04899 L
.77732 .01537 L
Mfstroke
.77732 .01537 m
.78229 0 L
s
.82084 0 m
.82135 .00176 L
.82588 .02068 L
.83606 .06951 L
.84496 .11013 L
.84946 .12644 L
.85204 .1339 L
.85441 .13929 L
.85559 .14143 L
.85688 .14332 L
.85759 .14416 L
.85824 .14481 L
.85954 .14572 L
.86076 .14611 L
.86187 .14608 L
.86315 .14558 L
.86435 .14464 L
.86547 .14338 L
.86665 .14163 L
.86876 .13745 L
.87104 .13148 L
.87354 .12325 L
.87872 .10123 L
.88428 .07178 L
.89431 .01215 L
s
.89431 .01215 m
.89648 0 L
s
.93482 0 m
.93565 .00519 L
.94645 .09297 L
.95671 .18169 L
.96117 .21545 L
.96592 .24517 L
.96865 .25864 L
.97113 .26825 L
.97233 .27196 L
.97362 .27526 L
.97484 .27768 L
.97596 .27931 L
.97619 .27957 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`004`3oool4000000<0oooo0P00000e0?ooo`@000000P3oool3000003@0
oooo100000030?ooo`800000>03oool3000004h0oooo000C0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool00000=P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0B`3oool001@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000f0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1;0?ooo`003@3oool40000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02`0oooo10000004
0?ooo`040000003oool0oooo0?ooo`<00000;P3oool4000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo02l0oooo100000020?ooo`<00000CP3oool001H0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`050000003oool0oooo0?ooo`00
0000>03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`1>0?ooo`004`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000003@0oooo0`0000030?ooo`030000003oool0oooo03@0oooo0`0000030?ooo`040000003oool0
oooo000003L0oooo00<000000?ooo`3oool0CP3oool001@0oooo0P0000040?ooo`800000=`3oool0
10000000oooo0?ooo`3oool4000003D0oooo00<000000?ooo`3oool00P3oool2000003P0oooo1000
001=0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003`3ooooo000000D00000
3@3oool001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00<0oooo0P0000040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0?ooo`00000;0?ooo`050000003oool0oooo0?ooo`000000203oool2000000X0
oooo00<000000?ooo`3oool04@3oool00800oooo0`00001F0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool04@3oool008<0oooo1@00001A0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool04@3oool008P0oooo2`0000150?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo0P00000B
0?ooo`00T`3oool500000400oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?oo
o`00V03oool6000001l0oooo0P00000H0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool04@3oool009h0oooo0`00000J0?ooo`8000000P3oool2000001H0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0A0?ooo`00X@3oool2000001H0oooo0P0000060?ooo`800000503o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`070?ooo`8000004P3oool00:<0oooo0P00000C0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0140oooo002U0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool00:H0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`00Y`3oool2000000`0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo
0P00000B0?ooo`00Z@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo002Z
0?ooo`030000003oool0oooo00D0oooo0P00000C0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`00Z`3oool2000000@0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool04@3oool00:`0oooo1@00000G0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool01P3oool200000180oooo00390?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0A0?ooo`00b@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`800000103o
ool010000000oooo0?ooo`3oool4000000D0oooo00<000000?ooo`3oool04@3oool00<X0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo0140oooo003:0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000103oool20000
0180oooo003;0?ooo`8000001@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00H0oooo0`0000050?oo
o`030000003oool0oooo0140oooo003=0?ooo`030000003oool0oooo008000005`3oool00`000000
oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00<h0oooo0P00000I0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000080?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00>T0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`030?ooo`8000002@3oool4000000@0oooo0P00000B0?ooo`00
j@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0A0?ooo`00jP3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00jP3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0A0?ooo`00jP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0103oool200000180oooo003Z0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0140
oooo003Z0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0140oooo003[0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0140oooo003[
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`04
0?ooo`8000004P3oool00>/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00>`0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool04@3oool00>`0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool04@3oool00>`0oooo0P0000020?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool00`3oool200000180oooo003]0?ooo`030000003oool0000001H0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`00kP3oool2000001@0oooo10000004
0?ooo`030000003oool0oooo0140oooo003o0?ooo`L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0A0?ooo`00o`3oool70?ooo`030000003oool0oooo00<0oooo0P00000B0?ooo`00
o`3oool70?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00?l0oooo1`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo003o0?ooo`D0oooo0`000005
0?ooo`030000003oool0oooo0140oooo003o0?ooo`L0oooo0P0000040?ooo`8000004P3oool00?l0
oooo203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo003o0?ooo`P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool80?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool04@3oool00?l0oooo203oool00`000000oooo0?ooo`02
0?ooo`8000004P3oool00?l0oooo203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0140oooo003o0?ooo`P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`00
o`3oool80?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00?l0oooo2@3o
ool010000000oooo0?ooo`3oool200000180oooo003o0?ooo`T0oooo00D000000?ooo`3oool0oooo
0000000C0?ooo`00o`3oool90?ooo`050000003oool0oooo0?ooo`0000004`3oool00?l0oooo2@3o
ool01@000000oooo0?ooo`3oool0000001<0oooo003o0?ooo`T0oooo00@000000?ooo`3oool0oooo
0P00000B0?ooo`00o`3oool90?ooo`050000003oool0oooo0?ooo`0000004`3oool00?P0oooo1000
00030?ooo`030000003oool0oooo0080oooo0`0000000`3oool000000?ooo`020?ooo`030000003o
ool0oooo0140oooo003j0?ooo`030000003oool0oooo00X0oooo0P0000030?ooo`030000003oool0
oooo0140oooo003j0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`0000000P3oool20000
0180oooo003j0?ooo`030000003oool0oooo00L0oooo0`0000020?ooo`040000003oool0oooo0000
01<0oooo003j0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`00000C0?ooo`00n03oool3000000T0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`00000C0?ooo`00nP3oool00`000000oooo0?ooo`070?ooo`@0000000@0oooo0000003o
ool0oooo0P00000B0?ooo`00o`3oool;0?ooo`030000003oool0000001<0oooo003o0?ooo`/0oooo
00<000000?ooo`0000004`3oool00?l0oooo2`3oool00`000000oooo0000000C0?ooo`00o`3oool<
0?ooo`<000004P3oool00?l0oooo303oool2000001<0oooo003o0?ooo``0oooo0P00000C0?ooo`00
o`3oool<0?ooo`8000004`3oool00?l0oooo303oool300000180oooo003o0?ooo`d0oooo00<00000
0?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`03
0000003oool0oooo0140oooo003o0?ooo`d0oooo0P00000B0?ooo`00o`3oool=0?ooo`030000003o
ool0oooo0140oooo003o0?ooo`D0oooo100000040?ooo`030000003oool0oooo0140oooo003o0?oo
o`D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool60?ooo`03
0000003oool0oooo00@0oooo0P00000B0?ooo`00o`3oool70?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool04@3oool00?l0oooo203oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0140oooo003o0?ooo`D0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0A0?ooo`00o`3oool60?ooo`8000001@3oool200000180oooo003o0?ooo`d0oooo00<000000?oo
o`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000
003oool0oooo0140oooo003o0?ooo`d0oooo0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0
oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000
oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo0?oo
o`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?oo
o`3oool04@3oool00?l0oooo3@3oool200000180oooo003o0?ooo`d0oooo00<000000?ooo`3oool0
4@3oool00?P0oooo100000030?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003o
ool0oooo0140oooo003h0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0A0?ooo`00n@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0080oooo0P00000B0?ooo`00nP3oool00`000000oooo0?ooo`070?ooo`<000001@3oool00`000000
oooo0?ooo`0A0?ooo`00n`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool04@3oool00?P0oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0140oooo003i0?ooo`8000002@3oool4000000@0oooo0P00
000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?oo
o`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`800000
4P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0
oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool200000180
oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?oo
o`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo0P00000B0?oo
o`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`H0oooo0P0000050?ooo`030000
003oool0oooo0140oooo003o0?ooo`D0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`0A0?ooo`00o`3oool80?ooo`030000003oool0oooo0080oooo0P00000B0?ooo`00o`3oool6
0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool80?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool04@3oool00?l0oooo1@3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo0140oooo003o0?ooo`H0oooo0P0000050?ooo`8000004P3oool00?l0oooo
3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o
0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool200000180oooo003o0?ooo`d0
oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3o
ool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo0P00000B0?ooo`00o`3oool=0?oo
o`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo
3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`8000004P3oool00?l0oooo3@3oool0
0`000000oooo0?ooo`0A0?ooo`00n@3oool2000000@0oooo00<000000?ooo`3oool00P3oool30000
00D0oooo00<000000?ooo`3oool04@3oool00?P0oooo00@000000?ooo`3oool000002`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo003k0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00P3oool200000180oooo003i0?ooo`8000002@3oool3000000D0oooo
00<000000?ooo`3oool04@3oool00?/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0140oooo003h0?ooo`040000003oool0oooo000000P0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00n@3oool2000000T0oooo10000004
0?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`03
0000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3o
ool200000180oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`00
0000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo
0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<00000
0?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`80
00004P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool70?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool04@3oool00?l0oooo1`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0140oooo003o0?ooo`@0oooo1@0000040?ooo`8000004P3oool00?l0
oooo103oool010000000oooo0?ooo`00000I0?ooo`00o`3oool50?ooo`030000003oool0000001T0
oooo003o0?ooo`H0oooo0P00000I0?ooo`00o`3oool70?ooo`030000003oool0oooo01L0oooo0000
\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {662.562, 521.25}} -> {-31.0405, \
15.9926, 0.0811648, 0.0250148}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.97619 0.047619 0 0.154508 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.96369 .07725 -18 -4.5 ]
[.96369 .07725 0 4.5 ]
[.96369 .15451 -6 -4.5 ]
[.96369 .15451 0 4.5 ]
[.96369 .23176 -18 -4.5 ]
[.96369 .23176 0 4.5 ]
[.96369 .30902 -6 -4.5 ]
[.96369 .30902 0 4.5 ]
[.96369 .38627 -18 -4.5 ]
[.96369 .38627 0 4.5 ]
[.96369 .46353 -6 -4.5 ]
[.96369 .46353 0 4.5 ]
[.96369 .54078 -18 -4.5 ]
[.96369 .54078 0 4.5 ]
[.96369 .61803 -6 -4.5 ]
[.96369 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-15)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(-10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(-5)] .7381 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.97619 .07725 m
.98244 .07725 L
s
[(0.5)] .96369 .07725 1 0 Mshowa
.97619 .15451 m
.98244 .15451 L
s
[(1)] .96369 .15451 1 0 Mshowa
.97619 .23176 m
.98244 .23176 L
s
[(1.5)] .96369 .23176 1 0 Mshowa
.97619 .30902 m
.98244 .30902 L
s
[(2)] .96369 .30902 1 0 Mshowa
.97619 .38627 m
.98244 .38627 L
s
[(2.5)] .96369 .38627 1 0 Mshowa
.97619 .46353 m
.98244 .46353 L
s
[(3)] .96369 .46353 1 0 Mshowa
.97619 .54078 m
.98244 .54078 L
s
[(3.5)] .96369 .54078 1 0 Mshowa
.97619 .61803 m
.98244 .61803 L
s
[(4)] .96369 .61803 1 0 Mshowa
.125 Mabswid
.97619 .01545 m
.97994 .01545 L
s
.97619 .0309 m
.97994 .0309 L
s
.97619 .04635 m
.97994 .04635 L
s
.97619 .0618 m
.97994 .0618 L
s
.97619 .09271 m
.97994 .09271 L
s
.97619 .10816 m
.97994 .10816 L
s
.97619 .12361 m
.97994 .12361 L
s
.97619 .13906 m
.97994 .13906 L
s
.97619 .16996 m
.97994 .16996 L
s
.97619 .18541 m
.97994 .18541 L
s
.97619 .20086 m
.97994 .20086 L
s
.97619 .21631 m
.97994 .21631 L
s
.97619 .24721 m
.97994 .24721 L
s
.97619 .26266 m
.97994 .26266 L
s
.97619 .27812 m
.97994 .27812 L
s
.97619 .29357 m
.97994 .29357 L
s
.97619 .32447 m
.97994 .32447 L
s
.97619 .33992 m
.97994 .33992 L
s
.97619 .35537 m
.97994 .35537 L
s
.97619 .37082 m
.97994 .37082 L
s
.97619 .40172 m
.97994 .40172 L
s
.97619 .41717 m
.97994 .41717 L
s
.97619 .43262 m
.97994 .43262 L
s
.97619 .44807 m
.97994 .44807 L
s
.97619 .47898 m
.97994 .47898 L
s
.97619 .49443 m
.97994 .49443 L
s
.97619 .50988 m
.97994 .50988 L
s
.97619 .52533 m
.97994 .52533 L
s
.97619 .55623 m
.97994 .55623 L
s
.97619 .57168 m
.97994 .57168 L
s
.97619 .58713 m
.97994 .58713 L
s
.97619 .60258 m
.97994 .60258 L
s
.25 Mabswid
.97619 0 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.29329 0 m
.29532 .00031 L
.30041 .00093 L
.30506 .00135 L
.30729 .00149 L
.30847 .00155 L
.30973 .0016 L
.31082 .00164 L
.31203 .00167 L
.31312 .00169 L
.31415 .00169 L
.31534 .00169 L
.3166 .00168 L
.31767 .00166 L
.31884 .00164 L
.32011 .0016 L
.32146 .00156 L
.3239 .00145 L
.32947 .00118 L
.3322 .00105 L
.33473 .00095 L
.33591 .00091 L
.33702 .00089 L
.33818 .00087 L
.33945 .00085 L
.34074 .00085 L
.34192 .00087 L
.34257 .00088 L
.34327 .0009 L
.34456 .00094 L
.3459 .00101 L
.34713 .00108 L
.3499 .00131 L
.35234 .00158 L
.35492 .00194 L
.35939 .00273 L
.36429 .0038 L
.38528 .00938 L
.40648 .01365 L
.41651 .0156 L
.42578 .01807 L
.43538 .02156 L
.44581 .02602 L
.45052 .02802 L
.45559 .02995 L
.45997 .03135 L
.46476 .03251 L
.46736 .03296 L
.46862 .03313 L
.46977 .03325 L
Mistroke
.47095 .03335 L
.47207 .03343 L
.47325 .03348 L
.47453 .03351 L
.47561 .03351 L
.4768 .03349 L
.47803 .03345 L
.47919 .03339 L
.48126 .03324 L
.48348 .03303 L
.48867 .03243 L
.49151 .0321 L
.49419 .03182 L
.49645 .03163 L
.49773 .03155 L
.4989 .03149 L
.50011 .03146 L
.50079 .03145 L
.50143 .03145 L
.50272 .03147 L
.50344 .0315 L
.5041 .03153 L
.5054 .03163 L
.50661 .03175 L
.50793 .03192 L
.50933 .03214 L
.51168 .03262 L
.51426 .03329 L
.51998 .03533 L
.52533 .03783 L
.54545 .04897 L
.55042 .0513 L
.55585 .05337 L
.56097 .05485 L
.56342 .0554 L
.56572 .05584 L
.56799 .05619 L
.57043 .05651 L
.5747 .05691 L
.57712 .05708 L
.57968 .05722 L
.58426 .05741 L
.58681 .0575 L
.58923 .05757 L
.59142 .05762 L
.59263 .05765 L
.59375 .05767 L
.59496 .05768 L
.5956 .05769 L
.59629 .05769 L
Mistroke
.59751 .05769 L
.59863 .05768 L
.59986 .05766 L
.60056 .05764 L
.60121 .05762 L
.60252 .05757 L
.60393 .05749 L
.60516 .0574 L
.6063 .0573 L
.60887 .05699 L
.61114 .05663 L
.61354 .05613 L
.6177 .05496 L
.62227 .05317 L
.6275 .05045 L
.63245 .04727 L
.64175 .04019 L
.65188 .03246 L
.65699 .02933 L
.65991 .02795 L
.66122 .02745 L
.66265 .02699 L
.66382 .02668 L
.66508 .02643 L
.66577 .02632 L
.6664 .02624 L
.66763 .02615 L
.66876 .02614 L
.66998 .0262 L
.67114 .02633 L
.67221 .02652 L
.67344 .0268 L
.67459 .02714 L
.67722 .02817 L
.67977 .02949 L
.68252 .03123 L
.70093 .04749 L
.70583 .05153 L
.70851 .05338 L
.71104 .05483 L
.71248 .0555 L
.71404 .0561 L
.71546 .05651 L
.71676 .05678 L
.71799 .05694 L
.71869 .05698 L
.71935 .05699 L
.72066 .05692 L
.7214 .05682 L
.72207 .05671 L
Mistroke
.72332 .0564 L
.72464 .05596 L
.72702 .05484 L
.72957 .05319 L
.73239 .05083 L
.73743 .04528 L
.74217 .03871 L
.76065 .00573 L
Mfstroke
.76065 .00573 m
.76394 0 L
s
.81877 0 m
.82201 .0062 L
.83152 .02671 L
.83674 .03707 L
.84169 .04525 L
.84393 .04824 L
.8463 .05083 L
.84753 .05192 L
.84889 .05291 L
.85013 .0536 L
.8513 .05407 L
.85242 .05435 L
.85349 .05444 L
.85446 .05439 L
.85551 .05418 L
.85664 .05378 L
.85786 .05313 L
.859 .05232 L
.86004 .05142 L
.86236 .04883 L
.86491 .04508 L
.87005 .03477 L
.87927 .00891 L
s
.87927 .00891 m
.88196 0 L
s
.93626 0 m
.94048 .02006 L
.97619 .14882 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`004`3oool4000000<0oooo0P00000e0?ooo`@000000P3oool3000003@0
oooo100000030?ooo`800000>03oool3000004h0oooo000C0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool00000=P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0B`3oool001@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000f0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1;0?ooo`003@3oool40000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02`0oooo10000004
0?ooo`040000003oool0oooo0?ooo`<00000;P3oool4000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo02l0oooo100000020?ooo`<00000CP3oool001H0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`050000003oool0oooo0?ooo`00
0000>03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`1>0?ooo`004`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000003@0oooo0`0000030?ooo`030000003oool0oooo03@0oooo0`0000030?ooo`040000003oool0
oooo000003L0oooo00<000000?ooo`3oool0CP3oool001@0oooo0P0000040?ooo`800000=`3oool0
10000000oooo0?ooo`3oool4000003D0oooo00<000000?ooo`3oool00P3oool2000003P0oooo1000
001=0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003`3ooooo000000D00000
3@3oool001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool6000000L0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00X0oooo0P00000:0?ooo`030000
003oool0oooo0140oooo001a0?ooo`D00000G@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0140oooo001f0?ooo`@00000F@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0140oooo001j0?ooo`D00000D`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`8000004P3oool007l0
oooo0P00001A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00840oooo
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo
00220?ooo`<00000=03oool700000140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0A0?ooo`00Q@3ooolA00000280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00D0oooo0P00000B0?ooo`00UP3oool00`000000oooo0?ooo`0M0?oo
o`8000002@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool04@3oool009L0oooo0P00000L0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo002I0?ooo`800000
6@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0A0?ooo`00V`3oool2000001D0oooo0P00000@0?ooo`800000203o
ool00`000000oooo0?ooo`0H0?ooo`8000000`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00@0oooo0P00000B0?ooo`00W@3oool200000180oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00P00000F
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool009l0oooo1@0000090?oo
o`@000005@3oool3000000040?ooo`0000000000000001h0oooo0`00000G0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool04@3oool00:@0oooo2P00000K0?ooo`800000>`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo003o0?ooo`L0oooo00<000000?ooo`3o
ool00`3oool200000180oooo003o0?ooo`L0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0A0?ooo`00n@3oool2000000@0oooo00<000000?ooo`3oool00P3oool4000000@0oooo00<0
00000?ooo`3oool04@3oool00?P0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0140oooo003h0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool00P3oool200000180oooo003h0?ooo`040000003oool0oooo000000P0oooo1000
00040?ooo`030000003oool0oooo0140oooo003h0?ooo`040000003oool0oooo000000P0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0140oooo003h0?ooo`040000003o
ool0oooo000000P0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0140
oooo003i0?ooo`8000002@3oool5000000<0oooo0P00000B0?ooo`00o`3oool90?ooo`050000003o
ool0oooo0?ooo`0000004`3oool00?l0oooo2P3oool010000000oooo0?ooo`00000C0?ooo`00o`3o
ool:0?ooo`040000003oool0oooo000001<0oooo003o0?ooo`X0oooo00<000000?ooo`3oool00P00
000B0?ooo`00o`3oool;0?ooo`030000003oool0000001<0oooo003o0?ooo`/0oooo00<000000?oo
o`0000004`3oool00?l0oooo2`3oool00`000000oooo0000000C0?ooo`00o`3oool;0?ooo`040000
003oool0000000000180oooo003o0?ooo``0oooo0P00000C0?ooo`00o`3oool<0?ooo`8000004`3o
ool00?l0oooo303oool2000001<0oooo003o0?ooo``0oooo0`00000B0?ooo`00o`3oool=0?ooo`03
0000003oool0oooo0140oooo003o0?ooo`D0oooo100000040?ooo`030000003oool0oooo0140oooo
003o0?ooo`L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool7
0?ooo`030000003oool0oooo00<0oooo0P00000B0?ooo`00o`3oool70?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool04@3oool00?l0oooo1`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0140oooo003o0?ooo`D0oooo0`0000050?ooo`030000003oool0oooo0140oooo
003o0?ooo`L0oooo00<000000?ooo`3oool00`3oool200000180oooo003o0?ooo`d0oooo00<00000
0?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`03
0000003oool0oooo0140oooo003o0?ooo`d0oooo0P00000B0?ooo`00o`3oool=0?ooo`030000003o
ool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`00
0000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo
0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<00000
0?ooo`3oool04@3oool00?l0oooo3@3oool200000180oooo003o0?ooo`d0oooo00<000000?ooo`3o
ool04@3oool00?P0oooo100000030?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000
003oool0oooo0140oooo003j0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0A0?ooo`00nP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0080oooo0P00000B0?ooo`00nP3oool00`000000oooo0?ooo`070?ooo`<000001@3oool00`00
0000oooo0?ooo`0A0?ooo`00nP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool04@3oool00?P0oooo0`0000090?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool04@3oool00?X0oooo00<000000?ooo`3oool01`3oool4000000@0oooo0P00
000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?oo
o`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`800000
4P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0
oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool200000180
oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?oo
o`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo0P00000B0?oo
o`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`D0oooo100000040?ooo`030000
003oool0oooo0140oooo003o0?ooo`D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0A0?ooo`00o`3oool60?ooo`030000003oool0oooo00@0oooo0P00000B0?ooo`00o`3oool70?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00?l0oooo203oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0140oooo003o0?ooo`D0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0A0?ooo`00o`3oool60?ooo`8000001@3oool200000180oooo
003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A
0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo0P00000B0?ooo`00
o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3o
ool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`8000004P3oool00?l0
oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo
003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool200000180oooo003o0?oo
o`d0oooo00<000000?ooo`3oool04@3oool00?P0oooo100000030?ooo`030000003oool0oooo0080
oooo0`0000050?ooo`030000003oool0oooo0140oooo003h0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`00n@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0080oooo0P00000B0?ooo`00nP3oool00`000000oooo0?ooo`07
0?ooo`<000001@3oool00`000000oooo0?ooo`0A0?ooo`00n`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00?P0oooo00@000000?ooo`3o
ool00000203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo003i0?ooo`80
00002@3oool4000000@0oooo0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo
003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A
0?ooo`00o`3oool=0?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00
o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3o
ool00?l0oooo3@3oool200000180oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0
oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo
003o0?ooo`d0oooo0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?oo
o`H0oooo0P0000050?ooo`030000003oool0oooo0140oooo003o0?ooo`D0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`0A0?ooo`00o`3oool80?ooo`030000003oool0oooo0080
oooo0P00000B0?ooo`00o`3oool60?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`00o`3o
ool80?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00?l0oooo1@3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0140oooo003o0?ooo`H0oooo0P000005
0?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`03
0000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3o
ool200000180oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`00
0000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo
0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<00000
0?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`80
00004P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00n@3oool2000000@0oooo00<0
00000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool04@3oool00?P0oooo00@00000
0?ooo`3oool000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo003k
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool200000180oooo003i0?oo
o`8000002@3oool3000000D0oooo00<000000?ooo`3oool04@3oool00?/0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo003h0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00
n@3oool2000000T0oooo100000040?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo0?oo
o`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?oo
o`3oool04@3oool00?l0oooo3@3oool200000180oooo003o0?ooo`d0oooo00<000000?ooo`3oool0
4@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0
oooo0140oooo003o0?ooo`d0oooo0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140
oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?oo
o`0A0?ooo`00o`3oool=0?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?oo
o`00o`3oool70?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00?l0oooo
1`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo003o0?ooo`@0oooo1@00
00040?ooo`8000004P3oool00?l0oooo103oool010000000oooo0?ooo`00000I0?ooo`00o`3oool5
0?ooo`030000003oool0000001T0oooo003o0?ooo`H0oooo0P00000I0?ooo`00o`3oool70?ooo`03
0000003oool0oooo01L0oooo0000\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {216.5, 75.1875}} -> {-31.0405, \
2.04494, 0.0811648, 0.0250148}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.97619 0.047619 0 0.154508 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.96369 .07725 -18 -4.5 ]
[.96369 .07725 0 4.5 ]
[.96369 .15451 -6 -4.5 ]
[.96369 .15451 0 4.5 ]
[.96369 .23176 -18 -4.5 ]
[.96369 .23176 0 4.5 ]
[.96369 .30902 -6 -4.5 ]
[.96369 .30902 0 4.5 ]
[.96369 .38627 -18 -4.5 ]
[.96369 .38627 0 4.5 ]
[.96369 .46353 -6 -4.5 ]
[.96369 .46353 0 4.5 ]
[.96369 .54078 -18 -4.5 ]
[.96369 .54078 0 4.5 ]
[.96369 .61803 -6 -4.5 ]
[.96369 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-15)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(-10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(-5)] .7381 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.97619 .07725 m
.98244 .07725 L
s
[(0.5)] .96369 .07725 1 0 Mshowa
.97619 .15451 m
.98244 .15451 L
s
[(1)] .96369 .15451 1 0 Mshowa
.97619 .23176 m
.98244 .23176 L
s
[(1.5)] .96369 .23176 1 0 Mshowa
.97619 .30902 m
.98244 .30902 L
s
[(2)] .96369 .30902 1 0 Mshowa
.97619 .38627 m
.98244 .38627 L
s
[(2.5)] .96369 .38627 1 0 Mshowa
.97619 .46353 m
.98244 .46353 L
s
[(3)] .96369 .46353 1 0 Mshowa
.97619 .54078 m
.98244 .54078 L
s
[(3.5)] .96369 .54078 1 0 Mshowa
.97619 .61803 m
.98244 .61803 L
s
[(4)] .96369 .61803 1 0 Mshowa
.125 Mabswid
.97619 .01545 m
.97994 .01545 L
s
.97619 .0309 m
.97994 .0309 L
s
.97619 .04635 m
.97994 .04635 L
s
.97619 .0618 m
.97994 .0618 L
s
.97619 .09271 m
.97994 .09271 L
s
.97619 .10816 m
.97994 .10816 L
s
.97619 .12361 m
.97994 .12361 L
s
.97619 .13906 m
.97994 .13906 L
s
.97619 .16996 m
.97994 .16996 L
s
.97619 .18541 m
.97994 .18541 L
s
.97619 .20086 m
.97994 .20086 L
s
.97619 .21631 m
.97994 .21631 L
s
.97619 .24721 m
.97994 .24721 L
s
.97619 .26266 m
.97994 .26266 L
s
.97619 .27812 m
.97994 .27812 L
s
.97619 .29357 m
.97994 .29357 L
s
.97619 .32447 m
.97994 .32447 L
s
.97619 .33992 m
.97994 .33992 L
s
.97619 .35537 m
.97994 .35537 L
s
.97619 .37082 m
.97994 .37082 L
s
.97619 .40172 m
.97994 .40172 L
s
.97619 .41717 m
.97994 .41717 L
s
.97619 .43262 m
.97994 .43262 L
s
.97619 .44807 m
.97994 .44807 L
s
.97619 .47898 m
.97994 .47898 L
s
.97619 .49443 m
.97994 .49443 L
s
.97619 .50988 m
.97994 .50988 L
s
.97619 .52533 m
.97994 .52533 L
s
.97619 .55623 m
.97994 .55623 L
s
.97619 .57168 m
.97994 .57168 L
s
.97619 .58713 m
.97994 .58713 L
s
.97619 .60258 m
.97994 .60258 L
s
.25 Mabswid
.97619 0 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.23384 0 m
.23588 .00041 L
.24093 .00129 L
.24553 .00193 L
.24787 .00218 L
.2504 .00241 L
.25307 .0026 L
.2556 .00273 L
.25692 .00278 L
.25838 .00282 L
.25991 .00286 L
.26133 .00289 L
.26408 .00292 L
.26662 .00296 L
.26903 .00299 L
.27037 .00302 L
.27159 .00306 L
.27293 .0031 L
.27438 .00317 L
.27701 .00332 L
.27951 .00352 L
.28216 .0038 L
.28688 .00448 L
.29146 .00537 L
.29572 .00637 L
.30541 .00902 L
.31043 .0104 L
.31588 .01172 L
.31837 .01223 L
.32102 .01269 L
.32331 .01303 L
.32578 .01331 L
.32694 .01342 L
.32816 .01352 L
.32929 .0136 L
.33033 .01365 L
.3314 .0137 L
.33238 .01373 L
.33345 .01376 L
.33461 .01378 L
.33586 .01379 L
.33701 .01379 L
.33828 .01378 L
.33891 .01378 L
.33962 .01377 L
.3408 .01376 L
.34207 .01375 L
.34326 .01374 L
.34434 .01373 L
.34563 .01373 L
Mistroke
.34684 .01374 L
.34815 .01376 L
.34889 .01378 L
.34956 .01381 L
.35071 .01386 L
.35197 .01394 L
.35329 .01404 L
.35451 .01416 L
.35686 .01447 L
.359 .01484 L
.3638 .01601 L
.36648 .01688 L
.36895 .01783 L
.37455 .02042 L
.3847 .02629 L
.39372 .03173 L
.39869 .03439 L
.40342 .03652 L
.40608 .03751 L
.40898 .03841 L
.41165 .03907 L
.41406 .03953 L
.41657 .03989 L
.41794 .04003 L
.41924 .04014 L
.42044 .04022 L
.42154 .04027 L
.42276 .04031 L
.42404 .04034 L
.42526 .04035 L
.42595 .04035 L
.42658 .04034 L
.42775 .04033 L
.42899 .04032 L
.43117 .04028 L
.43231 .04026 L
.43351 .04024 L
.43481 .04023 L
.436 .04022 L
.43712 .04023 L
.43834 .04024 L
.43904 .04026 L
.43967 .04028 L
.4411 .04033 L
.44242 .0404 L
.44367 .04049 L
.44589 .04069 L
.44824 .04098 L
.45246 .04167 L
.457 .04266 L
Mistroke
.462 .04394 L
.47197 .04663 L
.47688 .04773 L
.47927 .04817 L
.48144 .04849 L
.48397 .04878 L
.48535 .04889 L
.48666 .04898 L
.48735 .04901 L
.48809 .04904 L
.4894 .04907 L
.49013 .04908 L
.49081 .04908 L
.49155 .04907 L
.49235 .04905 L
.49364 .04902 L
.49436 .04898 L
.49503 .04895 L
.49757 .0488 L
.50233 .04842 L
.50697 .04806 L
.50824 .04798 L
.50958 .04791 L
.51073 .04787 L
.51197 .04785 L
.51316 .04784 L
.51424 .04786 L
.51549 .0479 L
.51666 .04796 L
.51775 .04804 L
.51876 .04814 L
.52102 .04843 L
.52349 .04887 L
.52579 .04939 L
.53104 .05098 L
.54163 .0554 L
.54663 .05761 L
.55206 .05973 L
.55455 .06052 L
.5572 .06119 L
.55828 .06141 L
.55946 .0616 L
.56074 .06176 L
.56195 .06186 L
.56312 .06191 L
.5642 .06191 L
.56539 .06187 L
.56666 .06176 L
.5673 .06169 L
.568 .06159 L
Mistroke
.56926 .06136 L
.57162 .06078 L
.57386 .06004 L
.57624 .05907 L
.5805 .05688 L
.60026 .04268 L
.60891 .03675 L
.61834 .03179 L
.6235 .02981 L
.62829 .02837 L
.63776 .02631 L
.64851 .02449 L
.65864 .02288 L
.66343 .0222 L
.6685 .02161 L
.67115 .02139 L
.67265 .02129 L
.67405 .02122 L
.67534 .02118 L
.67652 .02115 L
.67717 .02115 L
.67788 .02115 L
.67916 .02116 L
.68031 .02118 L
.68139 .02122 L
.68258 .02127 L
.68385 .02135 L
.68645 .02155 L
.68883 .02178 L
.69777 .0228 L
.70021 .02303 L
.70141 .02312 L
.70252 .02319 L
.70379 .02324 L
.70446 .02325 L
.70517 .02326 L
.70632 .02325 L
.70758 .02321 L
.70877 .02313 L
.70985 .02303 L
.71111 .02286 L
.71229 .02266 L
.7144 .0222 L
.7167 .0215 L
.71943 .02041 L
.72191 .01916 L
.72745 .01541 L
.73258 .01078 L
.73741 .00551 L
Mfstroke
.73741 .00551 m
.74163 0 L
s
.82176 0 m
.82194 .00019 L
.82654 .00423 L
.82909 .00604 L
.83185 .00759 L
.83307 .00813 L
.83437 .00861 L
.83548 .00893 L
.8367 .0092 L
.83785 .00936 L
.83907 .00943 L
.84011 .00941 L
.84124 .0093 L
.84247 .00909 L
.84378 .00875 L
.84502 .00831 L
.84615 .00783 L
.84834 .00663 L
.85071 .00497 L
.85503 .00103 L
s
.85503 .00103 m
.85582 0 L
s
.93915 0 m
.9451 .01782 L
.95442 .04312 L
.95931 .05344 L
.96207 .05803 L
.96465 .06138 L
.96587 .06263 L
.96702 .06361 L
.96807 .06433 L
.96918 .06491 L
.97038 .06532 L
.9715 .0655 L
.9727 .06547 L
.97401 .06519 L
.97514 .06473 L
.97619 .06412 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`004`3oool4000000<0oooo0P00000e0?ooo`@000000P3oool3000003@0
oooo100000030?ooo`800000>03oool3000004h0oooo000C0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool00000=P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0B`3oool001@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000f0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1;0?ooo`003@3oool40000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02`0oooo10000004
0?ooo`040000003oool0oooo0?ooo`<00000;P3oool4000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo02l0oooo100000020?ooo`<00000CP3oool001H0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`050000003oool0oooo0?ooo`00
0000>03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`1>0?ooo`004`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000003@0oooo0`0000030?ooo`030000003oool0oooo03@0oooo0`0000030?ooo`040000003oool0
oooo000003L0oooo00<000000?ooo`3oool0CP3oool001@0oooo0P0000040?ooo`800000=`3oool0
10000000oooo0?ooo`3oool4000003D0oooo00<000000?ooo`3oool00P3oool2000003P0oooo1000
001=0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003`3ooooo000000D00000
3@3oool001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo``000000P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo0`0000030?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo0140oooo001M0?ooo`@00000K@3oool00`000000oooo0?ooo`0E0?ooo`H000005`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo001Q0?ooo`/00000H03oool2
000003H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00J`3oool50000
05/0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`050?ooo`8000004P3oool00700
oooo00<000000?ooo`3oool0B@3oool7000000H0oooo0P00000i0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool04@3oool00740oooo0P0000130?ooo`H000001`3oool6000003`0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0A0?ooo`00L`3oool2000003`0oooo1@00
001?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool007D0oooo00<00000
0?ooo`3oool0=P3oool3000005@0oooo00<000000?ooo`3oool0103oool200000180oooo001f0?oo
o`800000=@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool04@3oool007P0oooo3000000W0?ooo`800000F@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0140oooo00240?ooo`D000008@3oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool008T0oooo1@0000000`3oool000000000
000700000140oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`030?ooo`8000004P3o
ool008d0oooo0`0000070?ooo`<000003@3oool2000005h0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0A0?ooo`00VP3oool3000000T0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo002M0?ooo`<00000103oool200000680
oooo00D000000?ooo`3oool0oooo0000000C0?ooo`00W`3oool5000006D0oooo0P0000000`3oool0
00000000000B0?ooo`00o`3oool;0?ooo`<000004`3oool00?T0oooo0P0000040?ooo`030000003o
ool0oooo0080oooo0`0000050?ooo`030000003oool0oooo0140oooo003h0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`00n03oool0
10000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo0P00000B0?ooo`00n03oool0
10000000oooo0?ooo`0000080?ooo`<000001@3oool00`000000oooo0?ooo`0A0?ooo`00n03oool0
10000000oooo0?ooo`0000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3o
ool00?P0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0140oooo003i0?ooo`8000002@3oool4000000@0oooo0P00000B0?ooo`00o`3oool=0?oo
o`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo
3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`8000004P3oool00?l0oooo3@3oool0
0`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0
oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool200000180oooo003o0?ooo`d0oooo00<0
00000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?oo
o`030000003oool0oooo0140oooo003o0?ooo`d0oooo0P00000B0?ooo`00o`3oool=0?ooo`030000
003oool0oooo0140oooo003o0?ooo`D0oooo100000040?ooo`030000003oool0oooo0140oooo003o
0?ooo`L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool70?oo
o`030000003oool0oooo00<0oooo0P00000B0?ooo`00o`3oool70?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool04@3oool00?l0oooo1`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0140oooo003o0?ooo`D0oooo0`0000050?ooo`030000003oool0oooo0140oooo003o
0?ooo`L0oooo00<000000?ooo`3oool00`3oool200000180oooo003o0?ooo`d0oooo00<000000?oo
o`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000
003oool0oooo0140oooo003o0?ooo`d0oooo0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0
oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000
oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo0?oo
o`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?oo
o`3oool04@3oool00?l0oooo3@3oool200000180oooo003o0?ooo`d0oooo00<000000?ooo`3oool0
4@3oool00?P0oooo100000030?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003o
ool0oooo0140oooo003j0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0A0?ooo`00nP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0080oooo0P00000B0?ooo`00nP3oool00`000000oooo0?ooo`070?ooo`<000001@3oool00`000000
oooo0?ooo`0A0?ooo`00nP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool04@3oool00?P0oooo0`0000090?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool04@3oool00?X0oooo00<000000?ooo`3oool01`3oool4000000@0oooo0P00000B
0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3o
ool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`8000004P3o
ool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo
0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool200000180oooo
003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A
0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo0P00000B0?ooo`00
o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`D0oooo100000040?ooo`030000003o
ool0oooo0140oooo003o0?ooo`D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A
0?ooo`00o`3oool60?ooo`030000003oool0oooo00@0oooo0P00000B0?ooo`00o`3oool70?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00?l0oooo203oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0140oooo003o0?ooo`D0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0A0?ooo`00o`3oool60?ooo`8000001@3oool200000180oooo003o
0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?oo
o`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo0P00000B0?ooo`00o`3o
ool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool0
0?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`8000004P3oool00?l0oooo
3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o
0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool200000180oooo003o0?ooo`d0
oooo00<000000?ooo`3oool04@3oool00?P0oooo100000030?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`030000003oool0oooo0140oooo003h0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`00n@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0080oooo0P00000B0?ooo`00nP3oool00`000000oooo0?ooo`070?oo
o`<000001@3oool00`000000oooo0?ooo`0A0?ooo`00n`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00?P0oooo00@000000?ooo`3oool0
0000203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo003i0?ooo`800000
2@3oool4000000@0oooo0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o
0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?oo
o`00o`3oool=0?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3o
ool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool0
0?l0oooo3@3oool200000180oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo
3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o
0?ooo`d0oooo0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`H0
oooo0P0000050?ooo`030000003oool0oooo0140oooo003o0?ooo`D0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0A0?ooo`00o`3oool80?ooo`030000003oool0oooo0080oooo
0P00000B0?ooo`00o`3oool60?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool8
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00?l0oooo1@3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0140oooo003o0?ooo`H0oooo0P0000050?oo
o`8000004P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000
003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool2
00000180oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000
oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo0P00
000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?oo
o`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`800000
4P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00n@3oool2000000@0oooo00<00000
0?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool04@3oool00?P0oooo00@000000?oo
o`3oool000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo003k0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool200000180oooo003i0?ooo`80
00002@3oool3000000D0oooo00<000000?ooo`3oool04@3oool00?/0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo003h0?ooo`040000003o
ool0oooo000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00n@3o
ool2000000T0oooo100000040?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A
0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3o
ool04@3oool00?l0oooo3@3oool200000180oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3o
ool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo
0140oooo003o0?ooo`d0oooo0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo
003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A
0?ooo`00o`3oool=0?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00
o`3oool70?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00?l0oooo1`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo003o0?ooo`@0oooo1@000004
0?ooo`8000004P3oool00?l0oooo103oool010000000oooo0?ooo`00000I0?ooo`00o`3oool50?oo
o`030000003oool0000001T0oooo003o0?ooo`H0oooo0P00000I0?ooo`00o`3oool70?ooo`030000
003oool0oooo01L0oooo0000\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {365.188, 223.875}} -> {-31.0405, \
6.69418, 0.0811648, 0.0250148}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.97619 0.047619 0 0.154508 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.96369 .07725 -18 -4.5 ]
[.96369 .07725 0 4.5 ]
[.96369 .15451 -6 -4.5 ]
[.96369 .15451 0 4.5 ]
[.96369 .23176 -18 -4.5 ]
[.96369 .23176 0 4.5 ]
[.96369 .30902 -6 -4.5 ]
[.96369 .30902 0 4.5 ]
[.96369 .38627 -18 -4.5 ]
[.96369 .38627 0 4.5 ]
[.96369 .46353 -6 -4.5 ]
[.96369 .46353 0 4.5 ]
[.96369 .54078 -18 -4.5 ]
[.96369 .54078 0 4.5 ]
[.96369 .61803 -6 -4.5 ]
[.96369 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-15)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(-10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(-5)] .7381 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.97619 .07725 m
.98244 .07725 L
s
[(0.5)] .96369 .07725 1 0 Mshowa
.97619 .15451 m
.98244 .15451 L
s
[(1)] .96369 .15451 1 0 Mshowa
.97619 .23176 m
.98244 .23176 L
s
[(1.5)] .96369 .23176 1 0 Mshowa
.97619 .30902 m
.98244 .30902 L
s
[(2)] .96369 .30902 1 0 Mshowa
.97619 .38627 m
.98244 .38627 L
s
[(2.5)] .96369 .38627 1 0 Mshowa
.97619 .46353 m
.98244 .46353 L
s
[(3)] .96369 .46353 1 0 Mshowa
.97619 .54078 m
.98244 .54078 L
s
[(3.5)] .96369 .54078 1 0 Mshowa
.97619 .61803 m
.98244 .61803 L
s
[(4)] .96369 .61803 1 0 Mshowa
.125 Mabswid
.97619 .01545 m
.97994 .01545 L
s
.97619 .0309 m
.97994 .0309 L
s
.97619 .04635 m
.97994 .04635 L
s
.97619 .0618 m
.97994 .0618 L
s
.97619 .09271 m
.97994 .09271 L
s
.97619 .10816 m
.97994 .10816 L
s
.97619 .12361 m
.97994 .12361 L
s
.97619 .13906 m
.97994 .13906 L
s
.97619 .16996 m
.97994 .16996 L
s
.97619 .18541 m
.97994 .18541 L
s
.97619 .20086 m
.97994 .20086 L
s
.97619 .21631 m
.97994 .21631 L
s
.97619 .24721 m
.97994 .24721 L
s
.97619 .26266 m
.97994 .26266 L
s
.97619 .27812 m
.97994 .27812 L
s
.97619 .29357 m
.97994 .29357 L
s
.97619 .32447 m
.97994 .32447 L
s
.97619 .33992 m
.97994 .33992 L
s
.97619 .35537 m
.97994 .35537 L
s
.97619 .37082 m
.97994 .37082 L
s
.97619 .40172 m
.97994 .40172 L
s
.97619 .41717 m
.97994 .41717 L
s
.97619 .43262 m
.97994 .43262 L
s
.97619 .44807 m
.97994 .44807 L
s
.97619 .47898 m
.97994 .47898 L
s
.97619 .49443 m
.97994 .49443 L
s
.97619 .50988 m
.97994 .50988 L
s
.97619 .52533 m
.97994 .52533 L
s
.97619 .55623 m
.97994 .55623 L
s
.97619 .57168 m
.97994 .57168 L
s
.97619 .58713 m
.97994 .58713 L
s
.97619 .60258 m
.97994 .60258 L
s
.25 Mabswid
.97619 0 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00249 m
0 0 rlineto s
.02381 .00249 m
.03064 0 L
s
.07641 0 m
.07941 .00078 L
.08454 .00192 L
.08696 .00234 L
.08922 .00266 L
.09046 .0028 L
.09158 .0029 L
.09283 .00298 L
.09352 .00301 L
.09417 .00304 L
.09542 .00306 L
.09606 .00306 L
.09676 .00304 L
.09799 .003 L
.09916 .00293 L
.10052 .00281 L
.10177 .00267 L
.10458 .00226 L
s
.10458 .00226 m
.11396 0 L
s
.16108 0 m
.16263 .00052 L
.16788 .00227 L
.17075 .00311 L
.17342 .00377 L
.1759 .00426 L
.17815 .0046 L
.17944 .00475 L
.18065 .00485 L
.18194 .00492 L
.18266 .00495 L
.18333 .00496 L
.18452 .00496 L
.18576 .00492 L
.18682 .00487 L
.18798 .00479 L
.18924 .00467 L
.19058 .00451 L
.19299 .00416 L
.20204 .00245 L
.20471 .00195 L
.2076 .00151 L
.20893 .00134 L
.21033 .00121 L
.21153 .00112 L
.21284 .00106 L
.21412 .00105 L
.21529 .00107 L
.21594 .00109 L
.21664 .00114 L
.21791 .00125 L
.21911 .00139 L
.22037 .00159 L
.22265 .00207 L
.22503 .00273 L
.22753 .0036 L
.23201 .00555 L
.2421 .01116 L
.24702 .01403 L
.25167 .01651 L
.25619 .01851 L
.26037 .0199 L
.26259 .02043 L
.26372 .02065 L
.26494 .02084 L
.26616 .02098 L
.2673 .02108 L
.268 .02113 L
.26866 .02116 L
.2699 .02118 L
Mistroke
.27112 .02116 L
.27243 .02111 L
.27366 .02102 L
.27477 .02092 L
.27751 .02058 L
.28009 .02018 L
.28431 .01943 L
.28884 .01868 L
.29018 .0185 L
.29144 .01835 L
.29267 .01823 L
.29381 .01814 L
.29489 .01809 L
.29603 .01806 L
.29718 .01806 L
.29845 .0181 L
.29971 .01818 L
.30087 .01829 L
.30215 .01845 L
.30349 .01868 L
.30575 .01917 L
.30822 .01986 L
.31357 .0219 L
.31854 .02431 L
.32741 .02917 L
.33702 .03395 L
.33968 .035 L
.3425 .03596 L
.34511 .03669 L
.34755 .03725 L
.34983 .03766 L
.35228 .038 L
.35501 .03827 L
.35749 .03845 L
.36213 .0387 L
.36441 .03882 L
.3665 .03896 L
.36892 .03917 L
.37153 .03948 L
.37375 .03983 L
.37608 .04031 L
.3808 .04162 L
.38596 .04361 L
.39512 .04827 L
.4007 .05141 L
.40598 .05421 L
.40847 .05537 L
.41112 .05646 L
.41357 .05729 L
.41586 .05791 L
Mistroke
.41801 .05833 L
.41922 .0585 L
.42033 .0586 L
.42153 .05867 L
.42285 .05869 L
.42409 .05865 L
.42524 .05857 L
.42588 .0585 L
.42657 .05841 L
.42783 .05822 L
.43017 .05772 L
.43291 .05695 L
.43543 .05608 L
.44625 .05147 L
.45154 .04931 L
.45385 .0485 L
.45636 .04775 L
.45878 .04718 L
.45985 .04698 L
.46102 .04679 L
.46213 .04666 L
.46316 .04656 L
.46426 .04649 L
.46544 .04646 L
.46662 .04647 L
.46791 .04653 L
.46856 .04657 L
.46926 .04663 L
.47052 .04678 L
.47296 .04718 L
.47518 .04766 L
.48592 .05099 L
.49064 .05256 L
.49315 .05332 L
.49583 .05402 L
.49835 .05456 L
.50065 .05494 L
.50175 .05507 L
.50295 .05519 L
.50409 .05526 L
.50515 .0553 L
.50644 .05532 L
.50765 .05529 L
.50875 .05523 L
.50992 .05514 L
.51121 .055 L
.51257 .05481 L
.51501 .05437 L
.52014 .05307 L
.52493 .05154 L
Mistroke
.5358 .04774 L
.54082 .04617 L
.54628 .04474 L
.55619 .0428 L
.5608 .042 L
.56577 .04103 L
.57046 .03987 L
.57475 .03848 L
.57934 .03657 L
.58417 .03406 L
.59456 .02701 L
.60472 .01895 L
.61031 .0147 L
.61557 .01116 L
.62055 .00844 L
.62317 .0073 L
.62594 .00632 L
.62827 .00569 L
.62951 .00542 L
.63084 .00519 L
.63205 .00502 L
.63317 .0049 L
.63429 .00482 L
.63535 .00477 L
.6364 .00475 L
.63756 .00476 L
.63877 .00481 L
.63991 .00488 L
.64097 .00497 L
.64195 .00506 L
.64414 .00534 L
.65372 .00701 L
.65845 .00777 L
.65981 .00795 L
.6611 .00809 L
.66227 .0082 L
.6635 .00828 L
.66459 .00834 L
.66578 .00837 L
.66686 .00837 L
.66787 .00835 L
.66907 .0083 L
.67016 .00822 L
.67142 .0081 L
.67261 .00795 L
.6751 .00753 L
.67775 .00692 L
.68251 .00543 L
.68817 .00307 L
.6933 .00048 L
Mistroke
Mfstroke
.6933 .00048 m
.69414 0 L
s
.94163 0 m
.94947 .00997 L
.95427 .01435 L
.95697 .01619 L
.95945 .01744 L
.96078 .01793 L
.96201 .01828 L
.96272 .01843 L
.96337 .01853 L
.96411 .01862 L
.96482 .01866 L
.9655 .01866 L
.96623 .01863 L
.96753 .01847 L
.96825 .01833 L
.96893 .01817 L
.97047 .01767 L
.972 .01701 L
.97346 .01623 L
.97619 .01438 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`004`3oool4000000<0oooo0P00000e0?ooo`@000000P3oool3000003@0
oooo100000030?ooo`800000>03oool3000004h0oooo000C0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool00000=P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0B`3oool001@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000f0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1;0?ooo`003@3oool40000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02`0oooo10000004
0?ooo`040000003oool0oooo0?ooo`<00000;P3oool4000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo02l0oooo100000020?ooo`<00000CP3oool001H0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`050000003oool0oooo0?ooo`00
0000>03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`1>0?ooo`004`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000003@0oooo0`0000030?ooo`030000003oool0oooo03@0oooo0`0000030?ooo`040000003oool0
oooo000003L0oooo00<000000?ooo`3oool0CP3oool001@0oooo0P0000040?ooo`800000=`3oool0
10000000oooo0?ooo`3oool4000003D0oooo00<000000?ooo`3oool00P3oool2000003P0oooo1000
001=0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003`3ooooo000000D00000
3@3oool001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`@00000103o
ool00`000000oooo0?ooo`090?ooo`P00000103oool00`000000oooo0?ooo`03000000L0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`L000001`3oool4000000/0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0
4@3oool004`0oooo0P00001Q0?ooo`8000001`3oool7000004H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0A0?ooo`00CP3oool2000005h0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo001@0?ooo`030000003oool0oooo
00P0oooo0P00001@0?ooo`030000003oool0oooo05H0oooo0`0000000`3oool00000000000020000
0180oooo001A0?ooo`/0000000<0oooo0000000000000P00001;0?ooo`030000003oool0oooo05T0
oooo0`0000000`3oool000000?ooo`0B0?ooo`00H@3oool2000004L0oooo0P00001P0?ooo`030000
003oool0oooo0140oooo001S0?ooo`800000A03oool00`000000oooo0?ooo`1P0?ooo`030000003o
ool0oooo0140oooo001U0?ooo`030000003oool0oooo03l0oooo0P00001S0?ooo`8000004P3oool0
06H0oooo1000000k0?ooo`800000I@3oool00`000000oooo0?ooo`0A0?ooo`00J@3oool9000002l0
oooo1000001W0?ooo`030000003oool0oooo0140oooo001b0?ooo`<000009`3oool5000006/0oooo
00<000000?ooo`3oool04@3oool007D0oooo0P00000=0?ooo`P000003@3oool300000700oooo0P00
000B0?ooo`00M`3oool00`000000oooo0?ooo`070?ooo`@000001`3oool3000000P0oooo0P00001c
0?ooo`030000003oool0oooo0140oooo001h0?ooo`8000001P3oool00`000000oooo0?ooo`0<0?oo
o`P00000M@3oool00`000000oooo0?ooo`0A0?ooo`00NP3oool6000008`0oooo00<000000?ooo`3o
ool04@3oool00?l0oooo3@3oool200000180oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3o
ool00?T0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0
oooo0140oooo003h0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0A0?ooo`00n03oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo0080oooo0P00000B0?ooo`00n03oool010000000oooo0?ooo`0000080?ooo`<000001@3oool0
0`000000oooo0?ooo`0A0?ooo`00n03oool010000000oooo0?ooo`0000080?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool04@3oool00?P0oooo00@000000?ooo`3oool00000203oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo003i0?ooo`8000002@3oool40000
00@0oooo0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo
00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=
0?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`03
0000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3o
ool200000180oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`00
0000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo
0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`D0oooo10000004
0?ooo`030000003oool0oooo0140oooo003o0?ooo`L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0A0?ooo`00o`3oool70?ooo`030000003oool0oooo00<0oooo0P00000B0?ooo`00
o`3oool70?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00?l0oooo1`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo003o0?ooo`D0oooo0`000005
0?ooo`030000003oool0oooo0140oooo003o0?ooo`L0oooo00<000000?ooo`3oool00`3oool20000
0180oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo
0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo0P00000B
0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3o
ool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`8000004P3o
ool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo
0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool200000180oooo
003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?P0oooo100000030?ooo`030000003oool0
oooo0080oooo0`0000050?ooo`030000003oool0oooo0140oooo003j0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`00nP3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo0P00000B0?ooo`00nP3oool00`000000oooo
0?ooo`070?ooo`<000001@3oool00`000000oooo0?ooo`0A0?ooo`00nP3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00?P0oooo0`000009
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00?X0oooo00<000000?oo
o`3oool01`3oool4000000@0oooo0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140
oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?oo
o`0A0?ooo`00o`3oool=0?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?oo
o`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool0
4@3oool00?l0oooo3@3oool200000180oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool0
0?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140
oooo003o0?ooo`d0oooo0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o
0?ooo`D0oooo100000040?ooo`030000003oool0oooo0140oooo003o0?ooo`D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool60?ooo`030000003oool0oooo00@0
oooo0P00000B0?ooo`00o`3oool70?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
4@3oool00?l0oooo203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo003o
0?ooo`D0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0A0?ooo`00o`3oool6
0?ooo`8000001@3oool200000180oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0
oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo
003o0?ooo`d0oooo0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?oo
o`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00
o`3oool=0?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=
0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0
oooo3@3oool200000180oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?P0oooo1000
00030?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo0140oooo003h
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A
0?ooo`00n@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo0P00000B0?oo
o`00nP3oool00`000000oooo0?ooo`070?ooo`<000001@3oool00`000000oooo0?ooo`0A0?ooo`00
n`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
4@3oool00?P0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0140oooo003i0?ooo`8000002@3oool4000000@0oooo0P00000B0?ooo`00o`3oool=
0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0
oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`8000004P3oool00?l0oooo3@3o
ool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?oo
o`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool200000180oooo003o0?ooo`d0oooo
00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=
0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo0P00000B0?ooo`00o`3oool=0?ooo`03
0000003oool0oooo0140oooo003o0?ooo`H0oooo0P0000050?ooo`030000003oool0oooo0140oooo
003o0?ooo`D0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0A0?ooo`00o`3o
ool80?ooo`030000003oool0oooo0080oooo0P00000B0?ooo`00o`3oool60?ooo`8000001@3oool0
0`000000oooo0?ooo`0A0?ooo`00o`3oool80?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool04@3oool00?l0oooo1@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0140oooo003o0?ooo`H0oooo0P0000050?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo
0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<00000
0?ooo`3oool04@3oool00?l0oooo3@3oool200000180oooo003o0?ooo`d0oooo00<000000?ooo`3o
ool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003o
ool0oooo0140oooo003o0?ooo`d0oooo0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo
0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo
0?ooo`0A0?ooo`00o`3oool=0?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A
0?ooo`00n@3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?oo
o`3oool04@3oool00?P0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0140oooo003k0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00P3oool200000180oooo003i0?ooo`8000002@3oool3000000D0oooo00<000000?ooo`3oool0
4@3oool00?/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0140oooo003h0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0A0?ooo`00n@3oool2000000T0oooo100000040?ooo`8000004P3oool0
0?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140
oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool200000180oooo003o
0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?oo
o`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo0P00000B0?ooo`00o`3o
ool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool0
0?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`8000004P3oool00?l0oooo
3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool70?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool04@3oool00?l0oooo1`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0140oooo003o0?ooo`@0oooo1@0000040?ooo`8000004P3oool00?l0oooo103oool010000000
oooo0?ooo`00000I0?ooo`00o`3oool50?ooo`030000003oool0000001T0oooo003o0?ooo`H0oooo
0P00000I0?ooo`00o`3oool70?ooo`030000003oool0oooo01L0oooo0000\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {513.875, 372.562}} -> {-31.0405, \
11.3434, 0.0811648, 0.0250148}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.97619 0.047619 0 0.154508 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.96369 .07725 -18 -4.5 ]
[.96369 .07725 0 4.5 ]
[.96369 .15451 -6 -4.5 ]
[.96369 .15451 0 4.5 ]
[.96369 .23176 -18 -4.5 ]
[.96369 .23176 0 4.5 ]
[.96369 .30902 -6 -4.5 ]
[.96369 .30902 0 4.5 ]
[.96369 .38627 -18 -4.5 ]
[.96369 .38627 0 4.5 ]
[.96369 .46353 -6 -4.5 ]
[.96369 .46353 0 4.5 ]
[.96369 .54078 -18 -4.5 ]
[.96369 .54078 0 4.5 ]
[.96369 .61803 -6 -4.5 ]
[.96369 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-15)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(-10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(-5)] .7381 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.97619 .07725 m
.98244 .07725 L
s
[(0.5)] .96369 .07725 1 0 Mshowa
.97619 .15451 m
.98244 .15451 L
s
[(1)] .96369 .15451 1 0 Mshowa
.97619 .23176 m
.98244 .23176 L
s
[(1.5)] .96369 .23176 1 0 Mshowa
.97619 .30902 m
.98244 .30902 L
s
[(2)] .96369 .30902 1 0 Mshowa
.97619 .38627 m
.98244 .38627 L
s
[(2.5)] .96369 .38627 1 0 Mshowa
.97619 .46353 m
.98244 .46353 L
s
[(3)] .96369 .46353 1 0 Mshowa
.97619 .54078 m
.98244 .54078 L
s
[(3.5)] .96369 .54078 1 0 Mshowa
.97619 .61803 m
.98244 .61803 L
s
[(4)] .96369 .61803 1 0 Mshowa
.125 Mabswid
.97619 .01545 m
.97994 .01545 L
s
.97619 .0309 m
.97994 .0309 L
s
.97619 .04635 m
.97994 .04635 L
s
.97619 .0618 m
.97994 .0618 L
s
.97619 .09271 m
.97994 .09271 L
s
.97619 .10816 m
.97994 .10816 L
s
.97619 .12361 m
.97994 .12361 L
s
.97619 .13906 m
.97994 .13906 L
s
.97619 .16996 m
.97994 .16996 L
s
.97619 .18541 m
.97994 .18541 L
s
.97619 .20086 m
.97994 .20086 L
s
.97619 .21631 m
.97994 .21631 L
s
.97619 .24721 m
.97994 .24721 L
s
.97619 .26266 m
.97994 .26266 L
s
.97619 .27812 m
.97994 .27812 L
s
.97619 .29357 m
.97994 .29357 L
s
.97619 .32447 m
.97994 .32447 L
s
.97619 .33992 m
.97994 .33992 L
s
.97619 .35537 m
.97994 .35537 L
s
.97619 .37082 m
.97994 .37082 L
s
.97619 .40172 m
.97994 .40172 L
s
.97619 .41717 m
.97994 .41717 L
s
.97619 .43262 m
.97994 .43262 L
s
.97619 .44807 m
.97994 .44807 L
s
.97619 .47898 m
.97994 .47898 L
s
.97619 .49443 m
.97994 .49443 L
s
.97619 .50988 m
.97994 .50988 L
s
.97619 .52533 m
.97994 .52533 L
s
.97619 .55623 m
.97994 .55623 L
s
.97619 .57168 m
.97994 .57168 L
s
.97619 .58713 m
.97994 .58713 L
s
.97619 .60258 m
.97994 .60258 L
s
.25 Mabswid
.97619 0 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .02503 m
.04262 .00975 L
.0522 .00047 L
s
.0522 .00047 m
.0528 0 L
s
.07875 0 m
.08255 .00329 L
.08813 .00891 L
.09403 .01482 L
.09906 .01906 L
.10191 .0209 L
.10319 .02156 L
.10458 .02216 L
.10588 .02259 L
.10707 .02289 L
.10822 .02307 L
.10944 .02316 L
.11052 .02314 L
.11154 .02304 L
.11266 .02284 L
.11387 .02253 L
.11508 .02211 L
.1164 .02153 L
.11906 .02002 L
.12383 .01635 L
.13473 .00559 L
.13989 .00093 L
s
.13989 .00093 m
.14114 0 L
s
.16247 0 m
.16426 .00141 L
.17425 .01177 L
.17954 .0176 L
.18521 .02297 L
.18799 .02505 L
.19062 .0266 L
.19298 .0276 L
.19431 .02801 L
.19555 .02827 L
.19669 .02843 L
.19777 .02849 L
.19895 .02848 L
.20022 .02836 L
.20149 .02815 L
.20212 .02801 L
.20281 .02783 L
.20518 .02703 L
.20796 .02578 L
.21047 .02442 L
.21611 .02099 L
.22105 .01812 L
.22374 .01683 L
.22506 .01631 L
.22626 .0159 L
.22736 .01558 L
.22856 .01532 L
.22983 .01513 L
.23103 .01503 L
.23235 .01504 L
.23302 .01508 L
.23375 .01516 L
.23505 .01538 L
.23627 .01569 L
.2374 .01606 L
.23858 .01654 L
.2407 .01761 L
.24549 .02096 L
.25554 .03078 L
.26107 .03649 L
.2663 .04118 L
.2687 .04295 L
.27125 .04449 L
.27258 .04515 L
.27404 .04575 L
.27538 .04618 L
.27662 .04648 L
.27784 .04668 L
.27899 .04678 L
.28002 .04681 L
Mistroke
.28115 .04676 L
.28237 .04663 L
.28367 .0464 L
.2849 .0461 L
.28601 .04576 L
.29056 .04386 L
.29547 .04116 L
.29977 .03866 L
.30437 .03625 L
.30695 .03517 L
.30929 .03443 L
.31043 .03416 L
.31165 .03395 L
.31281 .03382 L
.31389 .03377 L
.31513 .03379 L
.31629 .03389 L
.31757 .03409 L
.31829 .03424 L
.31895 .03441 L
.32157 .03533 L
.32289 .03594 L
.32433 .03671 L
.32961 .04039 L
.33524 .04538 L
.3454 .055 L
.35038 .05897 L
.3531 .06072 L
.35565 .06204 L
.3584 .06309 L
.35986 .06348 L
.36068 .06365 L
.36143 .06378 L
.36274 .06392 L
.36348 .06397 L
.36416 .06398 L
.36542 .06395 L
.36612 .0639 L
.36676 .06383 L
.36802 .06365 L
.36936 .06337 L
.37175 .06271 L
.37433 .06178 L
.37715 .06056 L
.38691 .05577 L
.38944 .05463 L
.39218 .05354 L
.39459 .05274 L
.39716 .05207 L
.39827 .05184 L
Mistroke
.39946 .05164 L
.40077 .05147 L
.402 .05136 L
.4032 .0513 L
.40434 .05129 L
.40536 .05131 L
.40648 .05136 L
.40716 .05142 L
.40789 .05148 L
.40923 .05164 L
.41173 .05204 L
.41733 .05327 L
.42254 .05452 L
.42509 .05506 L
.42741 .05545 L
.42854 .05561 L
.42976 .05574 L
.43092 .05583 L
.43199 .05588 L
.43313 .0559 L
.43438 .05587 L
.43568 .05579 L
.43691 .05567 L
.43818 .05549 L
.43953 .05524 L
.44193 .05465 L
.44451 .05381 L
.44734 .05267 L
.45837 .04673 L
.4684 .04118 L
.47324 .03918 L
.47597 .03834 L
.47727 .03803 L
.47848 .03778 L
.47963 .03759 L
.48068 .03745 L
.48185 .03734 L
.48311 .03727 L
.48431 .03725 L
.48562 .03728 L
.48686 .03734 L
.488 .03744 L
.48932 .03759 L
.49074 .0378 L
.49333 .03828 L
.49815 .03938 L
.50374 .0407 L
.50646 .04124 L
.50766 .04144 L
.50895 .04162 L
Mistroke
.51018 .04175 L
.51131 .04184 L
.5124 .0419 L
.51355 .04191 L
.51476 .04189 L
.51589 .04182 L
.51713 .04169 L
.51783 .0416 L
.51847 .0415 L
.52091 .04098 L
.52228 .04059 L
.52356 .04016 L
.52892 .03774 L
.53426 .03441 L
.53911 .03078 L
.54999 .02174 L
.55933 .01459 L
.56444 .01138 L
.56921 .00893 L
.57437 .00685 L
.58004 .00514 L
.59001 .00294 L
.60044 .00058 L
Mfstroke
.60044 .00058 m
.60231 0 L
s
.94491 0 m
.94659 .00098 L
.94907 .00204 L
.95026 .00244 L
.95138 .00276 L
.9524 .00301 L
.9535 .00321 L
.95451 .00335 L
.95543 .00343 L
.95644 .00347 L
.95754 .00346 L
.95869 .00339 L
.95976 .00327 L
.96078 .0031 L
.96189 .00287 L
.96391 .00231 L
.96587 .00159 L
.96769 .0008 L
s
.96769 .0008 m
.96901 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`004`3oool4000000<0oooo0P00000e0?ooo`@000000P3oool3000003@0
oooo100000030?ooo`800000>03oool3000004h0oooo000C0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool00000=P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0B`3oool001@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000f0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1;0?ooo`003@3oool40000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02`0oooo10000004
0?ooo`040000003oool0oooo0?ooo`<00000;P3oool4000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo02l0oooo100000020?ooo`<00000CP3oool001H0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`050000003oool0oooo0?ooo`00
0000>03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`1>0?ooo`004`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000003@0oooo0`0000030?ooo`030000003oool0oooo03@0oooo0`0000030?ooo`040000003oool0
oooo000003L0oooo00<000000?ooo`3oool0CP3oool001@0oooo0P0000040?ooo`800000=`3oool0
10000000oooo0?ooo`3oool4000003D0oooo00<000000?ooo`3oool00P3oool2000003P0oooo1000
001=0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003`3ooooo000000D00000
3@3oool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00800000203oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo1@00000;0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0080oooo100000030?ooo`030000003oool0oooo0140oooo000J0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo06@0oooo0`00001W0?ooo`030000003oool0oooo0140oooo000I0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0680oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0A0?ooo`005`3oool20000
00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00P0oooo1P00001A0?ooo`800000J`3oool200000180oooo000F0?ooo`030000003oool0oooo00l0
oooo0`0000020?ooo`8000003`3oool00`000000oooo0?ooo`050?ooo`8000001P3oool00`000000
oooo0?ooo`1<0?ooo`800000K@3oool00`000000oooo0?ooo`0A0?ooo`005@3oool00`000000oooo
0?ooo`0B0?ooo`@000004@3oool2000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool04@3oool00400oooo1@00
000;0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?oo
o`0A0?ooo`00D@3oool00`000000oooo0?ooo`160?ooo`800000L03oool200000180oooo001B0?oo
o`8000002P3oool6000002P0oooo0P00000;0?ooo`030000003oool0oooo0700oooo00<000000?oo
o`3oool04@3oool005@0oooo00<000000?ooo`3oool0103oool3000000H0oooo00<000000?ooo`3o
ool08@3oool4000000030?ooo`000000000000@000000`3oool3000007<0oooo00<000000?ooo`3o
ool04@3oool005@0oooo0P0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`080?ooo`@00000MP3oool00`000000oooo0?ooo`0A0?ooo`00E@3o
ool5000000`0oooo00<000000?ooo`3oool0703oool2000008D0oooo0P00000B0?ooo`00I`3oool0
0`000000oooo0?ooo`0;0?ooo`H00000203oool2000008L0oooo00<000000?ooo`3oool04@3oool0
06P0oooo0P0000080?ooo`<000001P3oool8000008T0oooo00<000000?ooo`3oool04@3oool006X0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0140
oooo001Z0?ooo`L00000V`3oool200000180oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3o
ool00?T0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0
oooo0140oooo003h0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0A0?ooo`00n03oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo0080oooo0P00000B0?ooo`00n03oool010000000oooo0?ooo`0000080?ooo`<000001@3oool0
0`000000oooo0?ooo`0A0?ooo`00n03oool010000000oooo0?ooo`0000080?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool04@3oool00?P0oooo00@000000?ooo`3oool00000203oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo003i0?ooo`8000002@3oool40000
00@0oooo0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo
00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=
0?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`03
0000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3o
ool200000180oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`00
0000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo
0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`D0oooo10000004
0?ooo`030000003oool0oooo0140oooo003o0?ooo`L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0A0?ooo`00o`3oool70?ooo`030000003oool0oooo00<0oooo0P00000B0?ooo`00
o`3oool70?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00?l0oooo1`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo003o0?ooo`D0oooo0`000005
0?ooo`030000003oool0oooo0140oooo003o0?ooo`L0oooo00<000000?ooo`3oool00`3oool20000
0180oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo
0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo0P00000B
0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3o
ool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`8000004P3o
ool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo
0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool200000180oooo
003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?P0oooo100000030?ooo`030000003oool0
oooo0080oooo0`0000050?ooo`030000003oool0oooo0140oooo003j0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`00nP3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo0P00000B0?ooo`00nP3oool00`000000oooo
0?ooo`070?ooo`<000001@3oool00`000000oooo0?ooo`0A0?ooo`00nP3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00?P0oooo0`000009
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00?X0oooo00<000000?oo
o`3oool01`3oool4000000@0oooo0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140
oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?oo
o`0A0?ooo`00o`3oool=0?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?oo
o`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool0
4@3oool00?l0oooo3@3oool200000180oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool0
0?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140
oooo003o0?ooo`d0oooo0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o
0?ooo`D0oooo100000040?ooo`030000003oool0oooo0140oooo003o0?ooo`D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool60?ooo`030000003oool0oooo00@0
oooo0P00000B0?ooo`00o`3oool70?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
4@3oool00?l0oooo203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo003o
0?ooo`D0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0A0?ooo`00o`3oool6
0?ooo`8000001@3oool200000180oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0
oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo
003o0?ooo`d0oooo0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?oo
o`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00
o`3oool=0?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=
0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0
oooo3@3oool200000180oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?P0oooo1000
00030?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo0140oooo003h
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A
0?ooo`00n@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo0P00000B0?oo
o`00nP3oool00`000000oooo0?ooo`070?ooo`<000001@3oool00`000000oooo0?ooo`0A0?ooo`00
n`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
4@3oool00?P0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0140oooo003i0?ooo`8000002@3oool4000000@0oooo0P00000B0?ooo`00o`3oool=
0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0
oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`8000004P3oool00?l0oooo3@3o
ool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?oo
o`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool200000180oooo003o0?ooo`d0oooo
00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=
0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo0P00000B0?ooo`00o`3oool=0?ooo`03
0000003oool0oooo0140oooo003o0?ooo`H0oooo0P0000050?ooo`030000003oool0oooo0140oooo
003o0?ooo`D0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0A0?ooo`00o`3o
ool80?ooo`030000003oool0oooo0080oooo0P00000B0?ooo`00o`3oool60?ooo`8000001@3oool0
0`000000oooo0?ooo`0A0?ooo`00o`3oool80?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool04@3oool00?l0oooo1@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0140oooo003o0?ooo`H0oooo0P0000050?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo
0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<00000
0?ooo`3oool04@3oool00?l0oooo3@3oool200000180oooo003o0?ooo`d0oooo00<000000?ooo`3o
ool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003o
ool0oooo0140oooo003o0?ooo`d0oooo0P00000B0?ooo`00o`3oool=0?ooo`030000003oool0oooo
0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo
0?ooo`0A0?ooo`00o`3oool=0?ooo`8000004P3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A
0?ooo`00n@3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?oo
o`3oool04@3oool00?P0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0140oooo003k0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00P3oool200000180oooo003i0?ooo`8000002@3oool3000000D0oooo00<000000?ooo`3oool0
4@3oool00?/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0140oooo003h0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0A0?ooo`00n@3oool2000000T0oooo100000040?ooo`8000004P3oool0
0?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`030000003oool0oooo0140
oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool200000180oooo003o
0?ooo`d0oooo00<000000?ooo`3oool04@3oool00?l0oooo3@3oool00`000000oooo0?ooo`0A0?oo
o`00o`3oool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo0P00000B0?ooo`00o`3o
ool=0?ooo`030000003oool0oooo0140oooo003o0?ooo`d0oooo00<000000?ooo`3oool04@3oool0
0?l0oooo3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool=0?ooo`8000004P3oool00?l0oooo
3@3oool00`000000oooo0?ooo`0A0?ooo`00o`3oool70?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool04@3oool00?l0oooo1`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0140oooo003o0?ooo`@0oooo1@0000040?ooo`8000004P3oool00?l0oooo103oool010000000
oooo0?ooo`00000I0?ooo`00o`3oool50?ooo`030000003oool0000001T0oooo003o0?ooo`H0oooo
0P00000I0?ooo`00o`3oool70?ooo`030000003oool0oooo01L0oooo0000\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {662.562, 521.25}} -> {-31.0405, \
15.9926, 0.0811648, 0.0250148}}]
}, Open  ]]
}, Open  ]],

Cell["\<\
CTDL makes a nice approximation for the characteristics of the \
transmitted wave. Below is a movie of that approximation vs. the incedent \
wave in the absence of a barrier. Notice the periodicity in the transmitted \
wave because we approximated the integration with a sum.\
\>", "Text"],

Cell[BoxData[{
    \(\[CapitalPsi]initialnostep[x_, 
        t_] := \((\[CapitalPsi]initial[x, t, 
            k0]\[IndentingNewLine] + \[CapitalPsi]initial[x, t, 
            k0 + deltak/2]\[IndentingNewLine] + \[CapitalPsi]initial[x, t, 
            k0 - deltak/2]\[IndentingNewLine] + \[CapitalPsi]initial[x, t, 
            k0 + deltak]\[IndentingNewLine] + \[CapitalPsi]initial[x, t, 
            k0 - deltak]\[IndentingNewLine] + \[CapitalPsi]initial[x, t, 
            k0 + 3*deltak/2]\[IndentingNewLine] + \[CapitalPsi]initial[x, t, 
            k0 - 3*deltak/2]\[IndentingNewLine] + \[CapitalPsi]initial[x, t, 
            k0 + 2*deltak]\[IndentingNewLine] + \[CapitalPsi]initial[x, t, 
            k0 - 2*deltak])\)\), "\[IndentingNewLine]", 
    \(\[CapitalPsi]initialnostepconj[x_, 
        t_] := \((\[CapitalPsi]initialconj[x, t, 
            k0]\[IndentingNewLine] + \[CapitalPsi]initialconj[x, t, 
            k0 + deltak/2]\[IndentingNewLine] + \[CapitalPsi]initialconj[x, 
            t, k0 - deltak/2]\[IndentingNewLine] + \[CapitalPsi]initialconj[
            x, t, k0 + deltak]\[IndentingNewLine] + \[CapitalPsi]initialconj[
            x, t, k0 - deltak]\[IndentingNewLine] + \[CapitalPsi]initialconj[
            x, t, k0 + 
              3*deltak/2]\[IndentingNewLine] + \[CapitalPsi]initialconj[x, t, 
            k0 - 3*deltak/2]\[IndentingNewLine] + \[CapitalPsi]initialconj[x, 
            t, k0 + 2*deltak]\[IndentingNewLine] + \[CapitalPsi]initialconj[
            x, t, k0 - 2*deltak])\)\)}], "Input"],

Cell["\<\
The approximate width of the transmitted wave, and its reciporical: \
the coefficient of x in the wave equations.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(deltatransmit = \@\(k0\^2 - K0\^2\)/k0\), "\[IndentingNewLine]", 
    \(1/deltatransmit\)}], "Input"],

Cell[BoxData[
    \(0.21821789023599245`\)], "Output"],

Cell[BoxData[
    \(4.582575694955839`\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(For[time = 10, 
      time < 18, \(time++\), \[IndentingNewLine]Plot[\[IndentingNewLine]{Re[
            A2[k0]^2*\[CapitalPsi]initialnostep[x*4.5, 
                time]*\[CapitalPsi]initialnostepconj[x*4.5, 
                time]], \[IndentingNewLine]\[CapitalPsi]initialnostep[x, 
              time]*\[CapitalPsi]initialnostepconj[x, 
              time]}, \[IndentingNewLine]{x, 0, 
          20}\[IndentingNewLine]]\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.0147151 0.0740367 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .16279 -6 -4.5 ]
[.01131 .16279 0 4.5 ]
[.01131 .31086 -6 -4.5 ]
[.01131 .31086 0 4.5 ]
[.01131 .45894 -6 -4.5 ]
[.01131 .45894 0 4.5 ]
[.01131 .60701 -6 -4.5 ]
[.01131 .60701 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(10)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(15)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(20)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16279 m
.03006 .16279 L
s
[(2)] .01131 .16279 1 0 Mshowa
.02381 .31086 m
.03006 .31086 L
s
[(4)] .01131 .31086 1 0 Mshowa
.02381 .45894 m
.03006 .45894 L
s
[(6)] .01131 .45894 1 0 Mshowa
.02381 .60701 m
.03006 .60701 L
s
[(8)] .01131 .60701 1 0 Mshowa
.125 Mabswid
.02381 .05173 m
.02756 .05173 L
s
.02381 .08875 m
.02756 .08875 L
s
.02381 .12577 m
.02756 .12577 L
s
.02381 .19981 m
.02756 .19981 L
s
.02381 .23683 m
.02756 .23683 L
s
.02381 .27384 m
.02756 .27384 L
s
.02381 .34788 m
.02756 .34788 L
s
.02381 .3849 m
.02756 .3849 L
s
.02381 .42192 m
.02756 .42192 L
s
.02381 .49595 m
.02756 .49595 L
s
.02381 .53297 m
.02756 .53297 L
s
.02381 .56999 m
.02756 .56999 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .20751 m
.04262 .39414 L
.0522 .49686 L
.05746 .5443 L
.06005 .56348 L
.06244 .5782 L
.06506 .59065 L
.06644 .59557 L
.06714 .59763 L
.0679 .5995 L
.06911 .60173 L
.07026 .60296 L
.07095 .6033 L
.07161 .60332 L
.07286 .60259 L
.07402 .601 L
.07526 .59835 L
.07643 .59495 L
.07749 .59114 L
.0801 .57892 L
.08255 .56393 L
.08806 .51982 L
.09313 .46975 L
.10458 .34434 L
.11366 .25241 L
.1234 .17346 L
.12899 .13785 L
.13409 .11082 L
.13893 .08934 L
.14407 .07039 L
.14878 .05615 L
.15398 .04359 L
.15871 .03482 L
.16315 .02864 L
.16569 .02591 L
.16836 .02359 L
.17067 .02199 L
.17314 .02064 L
.17581 .01952 L
.17829 .01873 L
.18123 .01805 L
.18391 .01759 L
.18876 .01698 L
.19389 .01647 L
.2031 .01561 L
.20787 .01522 L
.2105 .01505 L
.213 .01493 L
.21441 .01488 L
.21515 .01485 L
Mistroke
.21594 .01483 L
.21667 .01482 L
.21734 .01481 L
.21863 .01479 L
.21993 .01478 L
.22067 .01478 L
.22134 .01478 L
.22258 .01479 L
.22389 .0148 L
.22878 .01488 L
.23118 .01492 L
.2334 .01495 L
.23464 .01497 L
.23595 .01498 L
.23727 .01498 L
.23802 .01498 L
.23872 .01498 L
.23994 .01498 L
.24106 .01497 L
.24228 .01496 L
.24357 .01494 L
.24852 .01486 L
.25095 .01481 L
.25319 .01478 L
.25523 .01475 L
.25625 .01474 L
.25738 .01473 L
.25851 .01472 L
.25973 .01472 L
.26087 .01472 L
.26192 .01472 L
.26314 .01473 L
.26427 .01473 L
.26551 .01475 L
.26683 .01476 L
.27149 .01483 L
.27382 .01487 L
.27634 .0149 L
.27778 .01491 L
.2791 .01492 L
.28037 .01493 L
.281 .01493 L
.2817 .01493 L
.28294 .01493 L
.28411 .01492 L
.28516 .01492 L
.2863 .01491 L
.28886 .01487 L
.29122 .01484 L
.29359 .0148 L
Mistroke
.29585 .01477 L
.29691 .01476 L
.29804 .01474 L
.29909 .01473 L
.30008 .01473 L
.30125 .01472 L
.30231 .01472 L
.30348 .01472 L
.30474 .01472 L
.30601 .01473 L
.30665 .01473 L
.30736 .01474 L
.30976 .01477 L
.3145 .01486 L
.31882 .01493 L
.32009 .01495 L
.32147 .01497 L
.32277 .01498 L
.32397 .01498 L
.32524 .01498 L
.32597 .01498 L
.32665 .01498 L
.32736 .01498 L
.32802 .01497 L
.32949 .01496 L
.33181 .01493 L
.33434 .01488 L
.337 .01484 L
.33817 .01482 L
.33945 .0148 L
.34068 .01479 L
.34199 .01478 L
.34268 .01478 L
.34341 .01478 L
.34411 .01479 L
.34474 .01479 L
.34597 .01481 L
.34666 .01482 L
.3473 .01484 L
.34856 .01487 L
.34973 .01491 L
.35211 .01502 L
.35426 .01515 L
.35908 .01552 L
.36927 .01647 L
.37484 .01703 L
.37756 .01735 L
.38003 .0177 L
.38242 .01814 L
.38467 .01867 L
Mistroke
.38705 .0194 L
.38964 .02044 L
.39229 .02186 L
.39511 .02382 L
.39754 .02596 L
.40016 .0288 L
.40471 .03519 L
.40896 .04308 L
.41402 .05511 L
.41865 .06885 L
.42849 .10794 L
.43763 .15896 L
.44766 .2356 L
.45835 .34156 L
.46863 .45464 L
.47404 .50972 L
.47699 .53623 L
.47975 .55779 L
.48237 .57487 L
.48476 .58721 L
.48603 .59241 L
.48741 .59696 L
.48817 .59894 L
.48887 .60046 L
.48954 .60161 L
.49025 .60251 L
.49139 .60328 L
.49262 .60315 L
.49378 .60212 L
.49485 .60042 L
.49603 .59768 L
.49732 .59368 L
.49992 .58254 L
.50245 .56796 L
.5052 .54841 L
.51019 .50468 L
.51952 .40578 L
.52949 .29795 L
.54047 .19888 L
.55073 .13091 L
.56034 .08576 L
.56563 .06695 L
.57048 .053 L
.57607 .0404 L
.5788 .0355 L
.58138 .03159 L
.5838 .02849 L
.58642 .02571 L
.59098 .02212 L
.59357 .02067 L
Mistroke
.59631 .01952 L
.59865 .01877 L
.60121 .01815 L
.60362 .01771 L
.60581 .01739 L
.61073 .01683 L
.61961 .01598 L
.62443 .01554 L
.62707 .01532 L
.62954 .01514 L
.63182 .01501 L
.63391 .01491 L
.63501 .01487 L
.63623 .01484 L
.63744 .01481 L
.63872 .01479 L
.6394 .01479 L
.64013 .01478 L
.64082 .01478 L
.64145 .01478 L
.64266 .01479 L
.64393 .0148 L
.64459 .01481 L
.6453 .01482 L
.64658 .01483 L
.64949 .01489 L
.65217 .01493 L
.65349 .01495 L
.65472 .01496 L
.65583 .01497 L
.657 .01498 L
.65819 .01498 L
.65949 .01498 L
.6607 .01498 L
.66183 .01497 L
.66307 .01496 L
.6644 .01494 L
.66956 .01485 L
.674 .01477 L
.67521 .01476 L
.6765 .01474 L
.6776 .01473 L
.67881 .01472 L
.67954 .01472 L
.6802 .01472 L
.68097 .01472 L
.6817 .01472 L
.683 .01472 L
.68374 .01473 L
.68442 .01473 L
Mistroke
.68699 .01476 L
.68972 .0148 L
.69455 .01487 L
.69698 .0149 L
.69836 .01491 L
.69965 .01492 L
.70035 .01493 L
.701 .01493 L
.70224 .01493 L
.70293 .01493 L
.70357 .01493 L
.70427 .01492 L
.70501 .01492 L
.70622 .01491 L
.70735 .0149 L
.70994 .01487 L
.71277 .01482 L
.71575 .01478 L
.71829 .01475 L
.71973 .01473 L
.72037 .01473 L
.72107 .01472 L
.72233 .01472 L
.72353 .01472 L
.72469 .01472 L
.72576 .01472 L
.72692 .01473 L
.7282 .01475 L
.73078 .01478 L
.74124 .01496 L
.74253 .01497 L
.74375 .01498 L
.74442 .01498 L
.74515 .01498 L
.74642 .01498 L
.74716 .01498 L
.74794 .01498 L
.74861 .01497 L
.74935 .01496 L
.75206 .01493 L
.75702 .01485 L
.75845 .01482 L
.7598 .0148 L
.76101 .01479 L
.76233 .01478 L
.76352 .01478 L
.76484 .01479 L
.7655 .01479 L
.76622 .0148 L
.76751 .01483 L
Mistroke
.76879 .01486 L
.77001 .0149 L
.7723 .01501 L
.7746 .01514 L
.77674 .01529 L
.78159 .0157 L
.79126 .01661 L
.79601 .0171 L
.80038 .01768 L
.80283 .01812 L
.80542 .01874 L
.80803 .01957 L
.81089 .0208 L
.81326 .02214 L
.81582 .02397 L
.82042 .0285 L
.82298 .03179 L
.8257 .03598 L
.83058 .04546 L
.83584 .0587 L
.84164 .07736 L
.84663 .09716 L
.85201 .12298 L
.86176 .18392 L
.87132 .26444 L
.88178 .3735 L
.89283 .49296 L
.89805 .54077 L
.90287 .57481 L
.90522 .58698 L
.90642 .59195 L
.9077 .59632 L
.90899 .59966 L
.9102 .60182 L
.91094 .60268 L
.91164 .60317 L
.91295 .60323 L
.91409 .60237 L
.91531 .60052 L
.91646 .5979 L
.9175 .5948 L
.92006 .58439 L
.92246 .57112 L
.92771 .53205 L
.93253 .48657 L
.94341 .36835 L
.97619 .10571 L
Mfstroke
.02381 .08624 m
.06244 .11496 L
.10458 .15195 L
.14415 .18744 L
.16408 .20336 L
.18221 .21558 L
.19159 .22083 L
.20178 .22556 L
.20738 .22769 L
.21254 .22936 L
.21744 .23067 L
.22272 .23177 L
.22531 .23219 L
.22777 .23252 L
.22997 .23275 L
.23124 .23286 L
.23238 .23294 L
.23348 .233 L
.23466 .23305 L
.23591 .23309 L
.23708 .2331 L
.23819 .2331 L
.23935 .23309 L
.24035 .23306 L
.24144 .23302 L
.24283 .23295 L
.24414 .23286 L
.24659 .23263 L
.24923 .23231 L
.25211 .23187 L
.25728 .23082 L
.26207 .22958 L
.27169 .22632 L
.28073 .22235 L
.30133 .21039 L
.34002 .17983 L
.38116 .14251 L
.42079 .10863 L
.45889 .0815 L
.49945 .05931 L
.5385 .04354 L
.55841 .03722 L
.58 .03152 L
.59904 .02738 L
.61998 .02373 L
.63986 .02106 L
.65085 .01988 L
.6609 .01898 L
.68035 .01765 L
.69106 .01711 L
Mistroke
.70124 .01671 L
.71085 .01641 L
.72108 .01616 L
.73948 .01584 L
.7498 .01572 L
.76094 .0156 L
.78112 .01543 L
.82217 .01511 L
.84264 .01496 L
.85262 .0149 L
.86171 .01485 L
.87051 .01481 L
.88008 .01478 L
.88533 .01477 L
.89018 .01476 L
.89482 .01475 L
.89716 .01475 L
.89974 .01474 L
.90209 .01474 L
.90343 .01474 L
.90467 .01474 L
.90599 .01474 L
.90718 .01474 L
.90784 .01474 L
.90856 .01474 L
.90986 .01474 L
.91097 .01474 L
.9122 .01474 L
.91348 .01474 L
.91468 .01474 L
.91682 .01474 L
.91912 .01474 L
.92472 .01475 L
.93003 .01475 L
.93999 .01477 L
.97619 .01481 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00CP3oool3000003X0oooo100000030?ooo`800000>03oool400000080
oooo0`00000g0?ooo`@000000`3oool2000000/0oooo001A0?ooo`030000003oool0oooo03T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000002P3oool00540oooo00<000000?ooo`3oool0>@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000:0?ooo`00CP3oool30000
03`0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03L0oooo00@00000
0?ooo`3oool0oooo0`00000i0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`080?ooo`00CP3oool00`000000oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0g0?ooo`050000003oool0oooo0?ooo`000000?03oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00P0oooo001>0?ooo`030000003oool0oooo03X0
oooo0`0000030?ooo`040000003oool0oooo000003L0oooo0`0000030?ooo`030000003oool0oooo
03L0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000:0?ooo`00403oool0
0`000000oooo0?ooo`0k0?ooo`@00000>`3oool00`000000oooo0?ooo`020?ooo`800000>P3oool0
10000000oooo0?ooo`3oool4000003L0oooo0P0000040?ooo`8000002`3oool00100oooo00<00000
0?ooo`3oool0o`3oool>0?ooo`00403oool00`000000oooo0?ooo`3o0?ooo`h0oooo000@0?ooo`03
0000003oool0oooo0?l0oooo3P3oool000T0ooooo`00000A000000L0oooo000@0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00@000001P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`D000000`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`H000001`3oool?000000/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0000
0004000000H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0303oool00100oooo00<000000?ooo`3oool0903oool2
000001L0oooo00<000000?ooo`3oool0803oool2000001/0oooo00<000000?ooo`3oool05P3oool2
000000<0oooo2P00000I0?ooo`030000003oool0oooo0100oooo0`00000Z0?ooo`030000003oool0
oooo00`0oooo000@0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0?03oool00`00
0000oooo0?ooo`0`0?ooo`H00000>@3oool00`000000oooo0?ooo`0f0?ooo`00403oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo03d0oooo0P00000^0?ooo`@00000?P3oool00`000000
oooo0?ooo`0f0?ooo`00403oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool0:03oool3000000030?ooo`000000oooo0400oooo00<000000?ooo`3oool0
=@3oool00100oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo02D0oooo0`0000040?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0=@3o
ool00100oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo0280oooo0P0000060?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0=03oool0
0100oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
01l0oooo0`0000080?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0<`3oool00100
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo01`0
oooo0`00000:0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0<`3oool00100oooo
0P00000P0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool06@3oool2000000d0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0b0?ooo`00403oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05P3oool3000000l0oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`0b0?ooo`00403oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0503oool200000140oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`0b0?ooo`00403oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool04@3oool2000001<0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0b0?ooo`00403oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool2000001@0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`0a0?ooo`00403oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool03@3oool2000001H0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0a0?ooo`00403oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool02`3oool2000001P0oooo00<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`0`0?ooo`00403oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool0203oool2000001T0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`0`0?ooo`00403oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool0<03oool00100oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo00D0oooo0P00000L0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool0<03oool00100oooo0P00000M0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0;`3oool00100oooo00@000000?ooo`00000000006`3oool00`000000oooo
0?ooo`1:0?ooo`040000003oool0oooo0?ooo`8000007`3oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo02l0oooo000@0?ooo`050000003oool0oooo0?ooo`0000006P3oool00`000000
oooo0?ooo`1:0?ooo`040000003oool0oooo00000200oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`0_0?ooo`00403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0000000Q0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool0;`3oool00100oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo04/0oooo0P00000R0?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool0;P3oool00100oooo00<000000?ooo`3oool0103oool2000001D0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0000000R0?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0<0?ooo`00403oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0B@3oool010000000oooo0?ooo`00
000Q0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0<0?ooo`00403oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0A`3oool2000000<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0303oool00100oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0<0?ooo`00403oool00`000000oooo0?ooo`090?ooo`80
00003`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool03@3oool00100oooo0P00000<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00d0oooo000@0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool03@3oool00100oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo04<0oooo0P00000;0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo00d0oooo000@0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool03@3oool00100
oooo00<000000?ooo`3oool03`3oool2000000P0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0D03oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00d0oooo000@0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool03@3oool00100oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0=0?ooo`00403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00h0oooo00070?oo
o`@000001@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00h0oooo00070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool010000000oooo0?ooo`00000o0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1A0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool03P3oool000P0oooo00<000000?ooo`3o
ool01@3oool2000001L0oooo00<000000?ooo`000000?P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00h0oooo00090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
5`3oool2000003d0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0>0?ooo`002P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0D`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00h0oooo00070?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool0603oool2000003X0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0>0?ooo`00203oool2000000H0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0000000h0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03P3oool0
0100oooo00<000000?ooo`3oool0603oool010000000oooo0?ooo`00000f0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1C0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool03`3oool00100oooo00<000000?ooo`3oool0603oool01@00
0000oooo0?ooo`3oool0000003@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0?
0?ooo`00403oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0;`3oool2000001d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool03`3oool00100oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`040?ooo`800000;P3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00l0oooo000@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
3`3oool00100oooo0P00000H0?ooo`030000003oool0oooo00L0oooo0P00000Y0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool03`3oool00100oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo02@0oooo0P00000R0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00l0oooo000@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02P3oool20000
02<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
05D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?ooo`00403oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00`0oooo0P00000O0?ooo`8000009@3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0@0?ooo`00403oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool06P3oool2000002L0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0403oool00100oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01L0oooo0P00
000Z0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo0100oooo000@0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool04@3oool2000001D0oooo0P00000/0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0100oooo000@0?oo
o`8000005`3oool00`000000oooo0?ooo`0C0?ooo`@000003`3oool2000002h0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0403oool00100oooo0P00000G0?ooo`030000003oool0oooo01L0oooo0`0000080?ooo`@0
0000<03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0@0?ooo`00403oool2000001L0oooo00<000000?ooo`3oool0
6P3oool8000003@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0403oool00100oooo0P00000G0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0403oool00100oooo0P00000F0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool04@3oool00100oooo0P00000F0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool04@3oool00100oooo0P00000F0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool04@3oool00100oooo0P00000F0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool04@3oool00100oooo0P00000F0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool04@3oool00100oooo0P00000F0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool04@3oool00100oooo00<000000?ooo`0000005@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo0140oooo000@0?ooo`030000003oool0000001D0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0A0?ooo`00403oool00`000000oooo0000000E0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00100oooo0`00000E0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1I0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool04P3oool00100oooo00<000000?ooo`000000503oool0
0`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0F@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo000@0?ooo`030000003oool00000
01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
05/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`00403oool00`000000
oooo0000000D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`1K0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00100oooo
00<000000?ooo`000000503oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo
000@0?ooo`030000003oool0000001@0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0B0?ooo`00403oool00`000000oooo0000000D0?ooo`030000003oool0oooo05X0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool04P3oool00100oooo00@000000?ooo`3oool000004`3oool00`000000oooo0?ooo`1J
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo01<0oooo00090?ooo`030000003oool0oooo00@0oooo00@000000?oo
o`3oool000004`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01<0oooo00090?oo
o`030000003oool0oooo00@0oooo00@000000?ooo`3oool000004`3oool00`000000oooo0?ooo`1J
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo01<0oooo00060?ooo`D000001@3oool2000000030?ooo`000000oooo
0180oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
05/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0C0?ooo`001P3oool010000000
oooo0?ooo`0000060?ooo`040000003oool0oooo000001<0oooo00<000000?ooo`3oool0FP3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0C0?ooo`001`3oool00`000000oooo000000060?ooo`040000003oool0oooo
000001<0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo05`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0C0?ooo`00203oool20000
00H0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo01<0oooo00090?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000004P3oool0
0`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0G@3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01<0oooo000@0?ooo`040000003oool0oooo
00000180oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo05d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`00403oool01000
0000oooo0?ooo`00000B0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`1M0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool0
0100oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000003oool0oooo05`0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0503oool00100oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000003oool0
oooo05`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0503oool00100oooo00D000000?ooo`3oool0oooo0000000A
0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1M
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00100oooo0P0000020?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo05d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?oo
o`00403oool01@000000oooo0?ooo`3oool000000140oooo00<000000?ooo`3oool0G03oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0D0?ooo`00403oool01@000000oooo0?ooo`3oool000000140oooo00<000000?oo
o`3oool0G03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05h0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0D0?ooo`00403oool01@000000oooo0?ooo`3oool00000
0140oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
05h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0E0?ooo`00403oool01@000000
oooo0?ooo`3oool000000140oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo05h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0E0?oo
o`00403oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0E0?ooo`00403oool01@000000oooo0?ooo`3oool000000100oooo00<000000?oo
o`3oool0GP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05h0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0E0?ooo`00403oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo05h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0E0?ooo`00
403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
GP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0E0?ooo`00403oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo05l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0E0?ooo`00403oool2
000000<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo01D0oooo000@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0G`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo01D0oooo000@0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01H0
oooo000@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`1N0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0H03oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo01H0oooo000@0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01H0oooo000@
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1O
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo01H0oooo000@0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0H03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01H0oooo000@0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1P0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo01H0oooo000@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
H03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01H0oooo000@0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1P0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo01H0oooo000@0?ooo`800000103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0600oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1P0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool05P3oool00100oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1Q0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool05P3oool00100
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0600
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool05`3oool00100oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`1R0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool00100oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0640oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool05`3oool00100oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1R
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool00100oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0640oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool05`3oool00100oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo0640oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1R0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool000P0oooo0P0000060?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1R0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo01L0oooo00070?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
5`3oool000L0oooo00@000000?ooo`3oool000001@3oool2000000@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
H`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01L0oooo00070?ooo`<000001P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0HP3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0G0?ooo`001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01P0oooo00070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`1S0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0603oool000P0
oooo0`0000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`1R0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0I03oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo01P0oooo000@0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01P0oooo
000@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01P0oooo000@0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01P0oooo000@0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1T0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01P0oooo000@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0I@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01P0oooo000@0?ooo`800000
1@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
603oool00100oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo06@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1U0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0603oool00100oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0603oool0
0100oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0603oool00100oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`1U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool06@3oool00100oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06D0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool06@3oool00100oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`1V0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool00100oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool06@3oool00100oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo06H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1V0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool00100oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool06@3oool00100oooo0P0000070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
IP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0I0?ooo`00403oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo06L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`00403oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0IP3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0I0?ooo`00403oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
06L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`00403oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J03oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0I0?ooo`00403oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`00403oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0J0?ooo`00403oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0J03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`00403oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo06T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?oo
o`00403oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0J@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0J0?ooo`00403oool2000000P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
J@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo000@0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1Z0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01X0oooo000@0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1Z0?ooo`050000003oool0oooo0?ooo`000000K03oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01X0oooo000@0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`1Z0?ooo`050000003oool0oooo0?ooo`000000K@3o
ool01@000000oooo0?ooo`3oool0000001d0oooo000@0?ooo`030000003oool0oooo00P0oooo00D0
00000?ooo`3oool0oooo0000001/0?ooo`050000003oool0oooo0?ooo`000000K@3oool01@000000
oooo0?ooo`3oool0000001d0oooo000@0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3o
ool00000K@3oool01@000000oooo0?ooo`3oool0000006d0oooo00D000000?ooo`3oool0oooo0000
000M0?ooo`00403oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000006h0oooo00@0
00000?ooo`3oool00000K@3oool010000000oooo0?ooo`00000N0?ooo`00403oool00`000000oooo
0?ooo`080?ooo`040000003oool0oooo000006h0oooo00<000000?ooo`000000K`3oool00`000000
oooo0000000N0?ooo`00203oool2000000H0oooo00<000000?ooo`3oool02@3oool3000006h0oooo
00<000000?ooo`000000K`3oool00`000000oooo0000000N0?ooo`001`3oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo00T0oooo0P00001`0?ooo`800000K`3oool2000001l0oooo
00070?ooo`040000003oool0oooo000000D0oooo0P00003o0?ooo`l0oooo00080?ooo`8000001P3o
ool00`000000oooo0?ooo`3o0?ooo`h0oooo00070?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool0o`3oool>0?ooo`001`3oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo0?l0oooo3P3oool000P0oooo0P00003o0?oooaL0oooo0000\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {536.062, 394.75}} -> {-10.1859, \
24.0882, 0.0778514, 0.0500726}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.0147151 0.0778267 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .09254 -6 -4.5 ]
[.01131 .09254 0 4.5 ]
[.01131 .17037 -6 -4.5 ]
[.01131 .17037 0 4.5 ]
[.01131 .2482 -6 -4.5 ]
[.01131 .2482 0 4.5 ]
[.01131 .32602 -6 -4.5 ]
[.01131 .32602 0 4.5 ]
[.01131 .40385 -6 -4.5 ]
[.01131 .40385 0 4.5 ]
[.01131 .48168 -6 -4.5 ]
[.01131 .48168 0 4.5 ]
[.01131 .5595 -6 -4.5 ]
[.01131 .5595 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(10)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(15)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(20)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09254 m
.03006 .09254 L
s
[(1)] .01131 .09254 1 0 Mshowa
.02381 .17037 m
.03006 .17037 L
s
[(2)] .01131 .17037 1 0 Mshowa
.02381 .2482 m
.03006 .2482 L
s
[(3)] .01131 .2482 1 0 Mshowa
.02381 .32602 m
.03006 .32602 L
s
[(4)] .01131 .32602 1 0 Mshowa
.02381 .40385 m
.03006 .40385 L
s
[(5)] .01131 .40385 1 0 Mshowa
.02381 .48168 m
.03006 .48168 L
s
[(6)] .01131 .48168 1 0 Mshowa
.02381 .5595 m
.03006 .5595 L
s
[(7)] .01131 .5595 1 0 Mshowa
.125 Mabswid
.02381 .03028 m
.02756 .03028 L
s
.02381 .04585 m
.02756 .04585 L
s
.02381 .06141 m
.02756 .06141 L
s
.02381 .07698 m
.02756 .07698 L
s
.02381 .10811 m
.02756 .10811 L
s
.02381 .12367 m
.02756 .12367 L
s
.02381 .13924 m
.02756 .13924 L
s
.02381 .1548 m
.02756 .1548 L
s
.02381 .18593 m
.02756 .18593 L
s
.02381 .2015 m
.02756 .2015 L
s
.02381 .21706 m
.02756 .21706 L
s
.02381 .23263 m
.02756 .23263 L
s
.02381 .26376 m
.02756 .26376 L
s
.02381 .27933 m
.02756 .27933 L
s
.02381 .29489 m
.02756 .29489 L
s
.02381 .31046 m
.02756 .31046 L
s
.02381 .34159 m
.02756 .34159 L
s
.02381 .35715 m
.02756 .35715 L
s
.02381 .37272 m
.02756 .37272 L
s
.02381 .38828 m
.02756 .38828 L
s
.02381 .41941 m
.02756 .41941 L
s
.02381 .43498 m
.02756 .43498 L
s
.02381 .45054 m
.02756 .45054 L
s
.02381 .46611 m
.02756 .46611 L
s
.02381 .49724 m
.02756 .49724 L
s
.02381 .51281 m
.02756 .51281 L
s
.02381 .52837 m
.02756 .52837 L
s
.02381 .54394 m
.02756 .54394 L
s
.02381 .57507 m
.02756 .57507 L
s
.02381 .59063 m
.02756 .59063 L
s
.02381 .6062 m
.02756 .6062 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12722 m
.03279 .18156 L
.04262 .2581 L
.06244 .45551 L
.06786 .50795 L
.07298 .55022 L
.07581 .5692 L
.07889 .58547 L
.08024 .59107 L
.08168 .5959 L
.08291 .59909 L
.08361 .60051 L
.08426 .60158 L
.08491 .60239 L
.08561 .60299 L
.0869 .60331 L
.08807 .60274 L
.08931 .60124 L
.09002 .59997 L
.09078 .59828 L
.09216 .59435 L
.09475 .58412 L
.09724 .57093 L
.09987 .55376 L
.10458 .51602 L
.12444 .31643 L
.13312 .23779 L
.14255 .16827 L
.15257 .11186 L
.16206 .07264 L
.16733 .05629 L
.17292 .0429 L
.1777 .03445 L
.18022 .03098 L
.18298 .02787 L
.18535 .02571 L
.18789 .02384 L
.19057 .0223 L
.19307 .02119 L
.19556 .0203 L
.19792 .01963 L
.20232 .01866 L
.21233 .01697 L
.21794 .01615 L
.22068 .0158 L
.22318 .01551 L
.22536 .01531 L
.22774 .01513 L
.22905 .01505 L
.23026 .01499 L
Mistroke
.2314 .01494 L
.23264 .01491 L
.23335 .01489 L
.23401 .01488 L
.23529 .01486 L
.23646 .01486 L
.23769 .01486 L
.23833 .01486 L
.23901 .01487 L
.24025 .01489 L
.24305 .01493 L
.24577 .01498 L
.2472 .01501 L
.24871 .01503 L
.25004 .01504 L
.25079 .01505 L
.2515 .01505 L
.25274 .01506 L
.25343 .01506 L
.25407 .01506 L
.25528 .01505 L
.25641 .01504 L
.25764 .01502 L
.25896 .015 L
.2641 .01489 L
.26909 .01478 L
.2703 .01476 L
.2716 .01475 L
.27235 .01474 L
.27303 .01473 L
.27372 .01473 L
.27437 .01472 L
.27506 .01472 L
.27581 .01472 L
.27644 .01472 L
.27714 .01472 L
.27789 .01472 L
.27869 .01473 L
.27946 .01474 L
.28015 .01474 L
.28275 .01478 L
.28548 .01483 L
.29014 .01491 L
.29148 .01492 L
.29274 .01494 L
.29388 .01495 L
.29511 .01496 L
.29577 .01496 L
.29649 .01496 L
.29724 .01496 L
Mistroke
.29795 .01496 L
.29921 .01495 L
.29992 .01495 L
.30057 .01494 L
.30317 .01491 L
.30565 .01487 L
.31059 .01479 L
.31177 .01477 L
.31301 .01475 L
.31417 .01474 L
.31524 .01473 L
.31647 .01472 L
.31712 .01472 L
.31782 .01472 L
.31857 .01472 L
.31928 .01472 L
.31992 .01472 L
.32061 .01473 L
.32183 .01474 L
.32313 .01476 L
.32547 .0148 L
.33014 .0149 L
.33269 .01496 L
.33507 .01501 L
.33611 .01502 L
.3371 .01503 L
.33823 .01505 L
.33927 .01505 L
.34041 .01506 L
.34147 .01506 L
.34263 .01505 L
.34386 .01504 L
.34497 .01503 L
.34617 .01502 L
.34833 .01498 L
.35068 .01494 L
.35324 .01489 L
.35392 .01488 L
.35465 .01487 L
.35595 .01486 L
.35665 .01486 L
.3573 .01486 L
.35852 .01486 L
.35973 .01488 L
.36084 .0149 L
.36206 .01493 L
.36335 .01498 L
.36553 .01509 L
.36786 .01526 L
.37207 .01567 L
Mistroke
.38163 .01699 L
.39184 .01872 L
.39464 .01932 L
.3976 .02009 L
.40014 .02094 L
.40293 .02213 L
.40554 .02358 L
.40793 .02525 L
.41051 .02751 L
.41332 .03059 L
.41832 .03795 L
.42306 .04754 L
.42837 .0616 L
.43338 .07828 L
.44273 .11898 L
.4528 .17817 L
.4637 .2631 L
.48324 .45834 L
.48859 .50989 L
.49433 .55617 L
.49711 .5738 L
.49975 .587 L
.50211 .59567 L
.50345 .59916 L
.50469 .60146 L
.50587 .6028 L
.50695 .60331 L
.50813 .60306 L
.50938 .60188 L
.51047 .6001 L
.51148 .59781 L
.51259 .59461 L
.51378 .59042 L
.51649 .57801 L
.51904 .56288 L
.52383 .52693 L
.54416 .32421 L
.55388 .23572 L
.56417 .16122 L
.57295 .11249 L
.58262 .07248 L
.58783 .05633 L
.59277 .04428 L
.59721 .03601 L
.60206 .0294 L
.60481 .02661 L
.6073 .0246 L
.61018 .02278 L
.61289 .02147 L
.61772 .01982 L
Mistroke
.62044 .01915 L
.62294 .01864 L
.63205 .01709 L
.63706 .01634 L
.6418 .01572 L
.64448 .01544 L
.6474 .01519 L
.64868 .0151 L
.65005 .01502 L
.65123 .01497 L
.6525 .01492 L
.65377 .01489 L
.65494 .01487 L
.65606 .01486 L
.65724 .01486 L
.65854 .01486 L
.65974 .01487 L
.66106 .01489 L
.66247 .01491 L
.66746 .015 L
.66867 .01502 L
.66997 .01504 L
.67072 .01505 L
.6714 .01505 L
.67209 .01506 L
.67274 .01506 L
.67343 .01506 L
.67417 .01506 L
.67481 .01506 L
.6755 .01505 L
.67625 .01505 L
.67706 .01504 L
.67852 .01502 L
.6813 .01497 L
.68385 .01491 L
.6863 .01485 L
.68893 .0148 L
.69021 .01477 L
.69141 .01476 L
.6925 .01474 L
.69366 .01473 L
.6949 .01472 L
.69603 .01472 L
.69726 .01472 L
.69795 .01472 L
.6986 .01473 L
.6993 .01473 L
.69996 .01474 L
.70121 .01475 L
.70401 .01479 L
Mistroke
.70895 .01488 L
.71137 .01492 L
.71243 .01493 L
.7136 .01494 L
.71485 .01495 L
.71554 .01496 L
.71618 .01496 L
.71688 .01496 L
.71752 .01496 L
.71826 .01496 L
.71896 .01496 L
.72017 .01495 L
.72129 .01494 L
.72252 .01493 L
.72382 .01491 L
.72803 .01484 L
.73024 .0148 L
.73256 .01476 L
.7338 .01475 L
.73446 .01474 L
.73516 .01473 L
.73639 .01472 L
.73754 .01472 L
.7388 .01472 L
.73999 .01472 L
.74105 .01473 L
.74221 .01474 L
.74344 .01475 L
.74457 .01477 L
.7471 .01482 L
.75168 .01492 L
.75424 .01498 L
.75558 .01501 L
.75702 .01503 L
.75773 .01504 L
.7584 .01504 L
.75965 .01505 L
.76083 .01506 L
.76209 .01506 L
.76341 .01505 L
.76464 .01504 L
.76534 .01503 L
.76599 .01503 L
.76743 .015 L
.77013 .01496 L
.77306 .0149 L
.77437 .01488 L
.77508 .01487 L
.77575 .01487 L
.77694 .01486 L
Mistroke
.77824 .01486 L
.77947 .01487 L
.7806 .01488 L
.7819 .01491 L
.78314 .01495 L
.78438 .015 L
.78572 .01507 L
.78816 .01524 L
.79271 .01568 L
.79803 .01637 L
.80292 .01711 L
.81186 .01862 L
.81636 .01961 L
.81892 .02034 L
.82131 .02119 L
.8239 .02236 L
.8263 .02373 L
.82894 .02565 L
.83174 .02823 L
.83645 .03412 L
.84164 .0433 L
.84624 .05414 L
.8512 .06891 L
.86019 .10429 L
.86975 .15525 L
.88021 .22929 L
.9013 .4333 L
.90614 .48207 L
.91138 .52966 L
.91378 .54857 L
.91633 .56605 L
.91853 .57875 L
.9209 .58964 L
.92231 .59468 L
.92359 .5983 L
.92489 .60097 L
.92612 .60258 L
.92681 .60309 L
.92754 .60332 L
.92824 .60324 L
.92887 .60291 L
.92961 .60223 L
.93041 .60111 L
.93117 .59971 L
.93187 .59813 L
.93418 .59086 L
.93549 .58541 L
.93672 .57949 L
.94184 .54684 L
.95107 .46408 L
Mistroke
.95981 .37361 L
.97619 .22123 L
Mfstroke
.02381 .05646 m
.06244 .07563 L
.10458 .10226 L
.14415 .13271 L
.18221 .16511 L
.22272 .19821 L
.24141 .21113 L
.26171 .22231 L
.27279 .22688 L
.27765 .22852 L
.28302 .23004 L
.28772 .23113 L
.29279 .23204 L
.29559 .23242 L
.29814 .2327 L
.29937 .2328 L
.30071 .2329 L
.3019 .23297 L
.30316 .23303 L
.30379 .23305 L
.30448 .23307 L
.30571 .23309 L
.3064 .2331 L
.30714 .2331 L
.30783 .23309 L
.30847 .23308 L
.3097 .23305 L
.31039 .23302 L
.31104 .23299 L
.31347 .23284 L
.31563 .23266 L
.31801 .23239 L
.32283 .23167 L
.32803 .23061 L
.33365 .22914 L
.3438 .22568 L
.36384 .216 L
.38494 .20239 L
.42305 .17207 L
.46361 .13738 L
.50266 .10667 L
.54415 .0795 L
.58413 .05888 L
.6226 .04356 L
.64209 .03732 L
.66352 .03158 L
.68411 .02711 L
.70292 .02388 L
.72237 .02132 L
.73321 .0202 L
Mistroke
.74326 .01934 L
.76229 .0181 L
.77233 .01761 L
.78302 .0172 L
.79334 .01688 L
.80448 .0166 L
.82466 .01622 L
.86571 .01563 L
.88618 .01538 L
.90525 .01516 L
.92362 .01499 L
.93304 .01492 L
.94328 .01486 L
.95207 .01482 L
.95593 .01481 L
.96019 .01479 L
.96393 .01479 L
.96795 .01478 L
.97017 .01477 L
.9722 .01477 L
.97415 .01477 L
.97619 .01477 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00CP3oool3000003X0oooo100000030?ooo`800000>03oool400000080
oooo0`00000h0?ooo`@000000`3oool2000000X0oooo001A0?ooo`030000003oool0oooo03T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000002@3oool00540oooo00<000000?ooo`3oool0>@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000090?ooo`00CP3oool30000
03`0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03L0oooo00@00000
0?ooo`3oool0oooo0`00000j0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`070?ooo`00CP3oool00`000000oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0g0?ooo`050000003oool0oooo0?ooo`000000?@3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo001>0?ooo`030000003oool0oooo03X0
oooo0`0000030?ooo`040000003oool0oooo000003L0oooo0`0000030?ooo`030000003oool0oooo
03P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`003`3oool0
0`000000oooo0?ooo`0l0?ooo`@00000>`3oool00`000000oooo0?ooo`020?ooo`800000>P3oool0
10000000oooo0?ooo`3oool4000003P0oooo0P0000040?ooo`8000002P3oool000l0oooo00<00000
0?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`03
0000003oool0oooo0?l0oooo3`3oool000P0ooooo`00000C000000H0oooo000?0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00@0oooo1`00000<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`030?ooo`L00000303oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`D000000P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo4`0000000`3oool000000000
0003000000<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02`3oool000l0oooo00<000000?ooo`3oool0:@3oool3
00000180oooo00<000000?ooo`3oool08P3oool3000001P0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0D0?ooo`T000000P3oool00`000000oooo0?ooo`0C0?ooo`<00000:03oool0
0`000000oooo0?ooo`0;0?ooo`003`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
03T0oooo0P00000d0?ooo`8000004`3oool4000002@0oooo00<000000?ooo`3oool0<`3oool000l0
oooo0P00000X0?ooo`800000?P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0100
oooo0`00000Y0?ooo`030000003oool0oooo0380oooo000?0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00/0oooo
1@00000]0?ooo`030000003oool0oooo0340oooo000?0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00P0oooo1000
000c0?ooo`030000003oool0oooo0300oooo000?0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00H0oooo0P00000g
0?ooo`030000003oool0oooo0300oooo000?0?ooo`8000009P3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0103oool3000003X0oooo00<000000?oo
o`3oool0;`3oool000l0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool3000003d0oooo00<000000?ooo`3o
ool0;`3oool000l0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`130?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool00P0000110?ooo`030000003oool0oooo02h0oooo
000?0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`0Y0?ooo`@00000@`3oool00`000000oooo0?ooo`0^0?ooo`003`3oool3000002@0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`0W0?ooo`800000AP3oool00`000000oooo0?ooo`0^
0?ooo`003`3oool2000000030?ooo`00000000000240oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0U0?ooo`80000000<0oooo0000003oool0AP3oool00`000000oooo0?ooo`0]0?oo
o`003`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`0S0?ooo`8000000P3oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo02d0oooo000?0?ooo`030000003oool0oooo00<0oooo0P00000M0?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool0803oool2000000@0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0]0?ooo`003`3oool00`000000oooo0?ooo`050?ooo`8000006`3o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo01h0oooo0P0000060?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool0;@3oool000l0oooo0P0000080?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0L0?ooo`800000203oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo02`0oooo000?0?ooo`030000003oool0oooo
00P0oooo0P00000H0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0;03oool000H0
oooo100000050?ooo`030000003oool0oooo00X0oooo0P00000E0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool0603oool2000000X0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`0/0?ooo`00203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo
0P00000C0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0:`3oool000P0oooo00<0
00000?ooo`3oool0103oool2000000l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo01D0oooo0P00000=0?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool0:`3oool000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?
0?ooo`800000403oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo01<0oooo0P00000>
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0:`3oool000P0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0A0?ooo`8000003P3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo02X0oooo00060?ooo`<000001P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0?0?ooo`80
00004@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02X0oooo00080?ooo`030000
003oool0oooo00@0oooo0P00000E0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`0Z0?ooo`003`3oool00`000000oooo0?ooo`0E0?ooo`8000002@3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo02X0oooo000?0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo00X0oooo0P00000D0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0:P3oool0
00l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool0:@3oool000l0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0:@3oool000l0oooo
0P00000K0?ooo`8000000`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo02T0oooo
000?0?ooo`030000003oool0oooo01`0oooo00@000000?ooo`3oool00000D03oool00`000000oooo
0?ooo`040?ooo`800000603oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo02T0oooo
000?0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`000000D03oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`0Y0?ooo`003`3oool00`000000oooo0?ooo`0N0?ooo`800000D03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0Y
0?ooo`003`3oool200000200oooo0P00001?0?ooo`050000003oool0oooo0?ooo`000000703oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo02T0oooo000?0?ooo`8000007`3oool01000
0000oooo0?ooo`00001>0?ooo`040000003oool00000000001d0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0X0?ooo`003`3oool2000001l0oooo00D000000?ooo`3oool0oooo0000
001=0?ooo`8000007`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo02P0oooo000?
0?ooo`8000007`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04X0oooo0P00000N
0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0:03oool000l0oooo0P00000O0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0B03oool00`000000oooo0000000N0?oo
o`030000003oool0oooo0500oooo00<000000?ooo`3oool0:03oool000l0oooo0P00000O0?ooo`03
0000003oool0oooo00@0oooo0P0000170?ooo`040000003oool0oooo000001h0oooo00<000000?oo
o`3oool0D03oool00`000000oooo0?ooo`0X0?ooo`001P3oool4000000D0oooo0P00000N0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0@P3oool2000000<0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo02P0oooo00060?ooo`030000
003oool0oooo00H0oooo0P00000N0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
D03oool00`000000oooo0?ooo`0X0?ooo`001`3oool00`000000oooo0?ooo`050?ooo`<000007@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool09`3o
ool000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000M0?ooo`030000003oool0
oooo00X0oooo0P00000m0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`1A0?ooo`030000003oool0oooo02L0oooo00090?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000007@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool09`3oool000H0oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0000000M0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0=P3oool20000
00X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo
02L0oooo00070?ooo`8000001P3oool00`000000oooo0000000L0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0W0?ooo`003`3oool3000001`0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo02L0oooo
000?0?ooo`030000003oool0000001`0oooo00<000000?ooo`3oool04@3oool200000340oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool09P3oool000l0oooo00@000000?ooo`3oool000006`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo02`0oooo0P00000@0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`0V0?ooo`003`3oool010000000oooo0?ooo`00
000K0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`0V0?ooo`003`3oool2000000030?ooo`000000oooo01X0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo02H0oooo000?0?ooo`040000003oool0oooo
000001X0oooo00<000000?ooo`3oool05`3oool2000002H0oooo0P00000D0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0V0?ooo`003`3oool01000
0000oooo0?ooo`00000J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`0V0?ooo`003`3oool010000000oooo0?ooo`00000J0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool07`3oool2000001L0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo02H0oooo000?0?ooo`80000000<0oooo0000
003oool06@3oool00`000000oooo0?ooo`0K0?ooo`8000007P3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0U0?oo
o`003`3oool01@000000oooo0?ooo`3oool0000001T0oooo00<000000?ooo`3oool07@3oool20000
01X0oooo0P00000J0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00/0oooo000?0?ooo`050000003oool0oooo0?oo
o`0000006@3oool00`000000oooo0?ooo`0O0?ooo`8000005P3oool2000001d0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool02`3oool000l0oooo00D000000?ooo`3oool0oooo0000000H0?ooo`030000003oool0oooo
0280oooo1000000>0?ooo`@000007`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`003`3oool200000080
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0V0?ooo`H000000P3oool6000002<0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool02`3oool000l0oooo00D000000?ooo`3oool0oooo0000000H0?ooo`03
0000003oool0oooo02`0oooo0`00000X0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00/0oooo000?0?ooo`050000
003oool0oooo0?ooo`000000603oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00/0
oooo00070?ooo`8000001P3oool01@000000oooo0?ooo`3oool0000001P0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0<0?ooo`001P3oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo00`0oooo00090?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0<0?ooo`001`3o
ool2000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0303oool000T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0<0?ooo`001P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1I0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo00`0oooo00070?ooo`8000001P3oool2000000<0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`1I0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo000?0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0
oooo000?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`1I0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00`0oooo000?0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo000?
0?ooo`800000103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05T0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool03@3oool000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1I0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool000l0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool03@3oool000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool000l0oooo0P0000040?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo05T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`003`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0F`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
05T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`003`3oool2000000@0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00d0oooo000?
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00d0oooo00080?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool03P3oool000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`00
1@3oool5000000D0oooo0P0000050?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
G03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0>0?ooo`001@3oool010000000oooo0?ooo`0000060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1L0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00h0oooo00060?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03P3o
ool000L0oooo0P0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0F`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00080?ooo`030000003oool0oooo
00@0oooo0P0000050?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05`0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0G@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0>0?ooo`003`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0G@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05d0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0>0?ooo`003`3oool2000000H0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0G@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo000?0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1M0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00l0oooo000?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0G@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo000?0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1N0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00l0oooo000?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo000?0?ooo`8000001P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`1M0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool0
00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
05l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool03`3oool000l0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`1O0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool000l0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05l0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03`3oool000l0oooo0P0000060?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0G`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`003`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@
0?ooo`001P3oool3000000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo05l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1O0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool000T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0G`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0@0?ooo`002@3oool00`000000oooo0?ooo`030?ooo`800000
1`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
403oool000H0oooo0`0000060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0G`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo00060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0600oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1P0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0403oool000H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0H03oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0@0?ooo`001P3oool4000000D0oooo0P0000070?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0640
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0H@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0640oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0A
0?ooo`003`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0H@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0640oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`003`3oool2000000P0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0H@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo000?0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1R0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0140oooo000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0HP3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo000?0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0140oooo000?0?ooo`800000203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0680oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool04P3oool000l0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`1R0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04P3oool000l0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool04P3oool000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`1S0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04P3oool000l0oooo0P000008
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B
0?ooo`003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0H`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo06<0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`001`3oool2000000H0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool04P3oool000H0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo06<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`00
1P3oool010000000oooo0?ooo`0000050?ooo`8000002@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo06<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1T0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool04P3oool000H0oooo0`0000060?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0180oooo00060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04`3o
ool000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0C0?ooo`001`3oool30000
00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
06@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool04`3oool000l0oooo0P00000:0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`003`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0I@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0C0?ooo`003`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0I@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`003`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0C
0?ooo`003`3oool2000000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01<0oooo000?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0I`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01<0oooo000?0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1U0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo01<0oooo000?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0I`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01<0oooo000?0?ooo`8000002`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool0
00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
06L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0503oool000l0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool000l0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0503oool000l0oooo0P00000;0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0I`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`003`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D
0?ooo`003`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0J@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06P0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`001`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1Y0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01@0oooo00070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
503oool000P0oooo00<000000?ooo`3oool0103oool2000000`0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo00080?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool05@3oool000T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0JP3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0E0?ooo`001P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01D0oooo00060?ooo`@000001@3oool2000000`0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`1Z0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0J`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo000?0?ooo`030000003oool0oooo00`0oooo
00D000000?ooo`3oool0oooo0000001]0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0J`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo000?0?ooo`030000
003oool0oooo00`0oooo00D000000?ooo`3oool0oooo0000001]0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0
oooo000?0?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo0000001]0?ooo`05
0000003oool0oooo0?ooo`000000KP3oool01@000000oooo0?ooo`3oool0000001P0oooo000?0?oo
o`8000003@3oool010000000oooo0?ooo`00001_0?ooo`040000003oool0oooo000006h0oooo00D0
00000?ooo`3oool0oooo0000000H0?ooo`003`3oool00`000000oooo0?ooo`0<0?ooo`040000003o
ool0oooo000006l0oooo00@000000?ooo`3oool00000K`3oool010000000oooo0?ooo`00000H0?oo
o`003`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000006l0oooo00@000000?ooo`3o
ool00000K`3oool00`000000oooo0000000I0?ooo`003`3oool00`000000oooo0?ooo`0=0?ooo`<0
0000L03oool200000700oooo0`00000I0?ooo`003`3oool200000?l0oooo403oool000l0oooo00<0
00000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?oo
o`030000003oool0oooo0?l0oooo3`3oool00001\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {684.75, 543.438}} -> {-10.0009, \
31.4775, 0.0771421, 0.0472001}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.0147151 0.0820453 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .09676 -6 -4.5 ]
[.01131 .09676 0 4.5 ]
[.01131 .17881 -6 -4.5 ]
[.01131 .17881 0 4.5 ]
[.01131 .26085 -6 -4.5 ]
[.01131 .26085 0 4.5 ]
[.01131 .3429 -6 -4.5 ]
[.01131 .3429 0 4.5 ]
[.01131 .42494 -6 -4.5 ]
[.01131 .42494 0 4.5 ]
[.01131 .50699 -6 -4.5 ]
[.01131 .50699 0 4.5 ]
[.01131 .58903 -6 -4.5 ]
[.01131 .58903 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(10)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(15)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(20)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09676 m
.03006 .09676 L
s
[(1)] .01131 .09676 1 0 Mshowa
.02381 .17881 m
.03006 .17881 L
s
[(2)] .01131 .17881 1 0 Mshowa
.02381 .26085 m
.03006 .26085 L
s
[(3)] .01131 .26085 1 0 Mshowa
.02381 .3429 m
.03006 .3429 L
s
[(4)] .01131 .3429 1 0 Mshowa
.02381 .42494 m
.03006 .42494 L
s
[(5)] .01131 .42494 1 0 Mshowa
.02381 .50699 m
.03006 .50699 L
s
[(6)] .01131 .50699 1 0 Mshowa
.02381 .58903 m
.03006 .58903 L
s
[(7)] .01131 .58903 1 0 Mshowa
.125 Mabswid
.02381 .03112 m
.02756 .03112 L
s
.02381 .04753 m
.02756 .04753 L
s
.02381 .06394 m
.02756 .06394 L
s
.02381 .08035 m
.02756 .08035 L
s
.02381 .11317 m
.02756 .11317 L
s
.02381 .12958 m
.02756 .12958 L
s
.02381 .14599 m
.02756 .14599 L
s
.02381 .1624 m
.02756 .1624 L
s
.02381 .19521 m
.02756 .19521 L
s
.02381 .21162 m
.02756 .21162 L
s
.02381 .22803 m
.02756 .22803 L
s
.02381 .24444 m
.02756 .24444 L
s
.02381 .27726 m
.02756 .27726 L
s
.02381 .29367 m
.02756 .29367 L
s
.02381 .31008 m
.02756 .31008 L
s
.02381 .32649 m
.02756 .32649 L
s
.02381 .35931 m
.02756 .35931 L
s
.02381 .37571 m
.02756 .37571 L
s
.02381 .39212 m
.02756 .39212 L
s
.02381 .40853 m
.02756 .40853 L
s
.02381 .44135 m
.02756 .44135 L
s
.02381 .45776 m
.02756 .45776 L
s
.02381 .47417 m
.02756 .47417 L
s
.02381 .49058 m
.02756 .49058 L
s
.02381 .5234 m
.02756 .5234 L
s
.02381 .53981 m
.02756 .53981 L
s
.02381 .55621 m
.02756 .55621 L
s
.02381 .57262 m
.02756 .57262 L
s
.02381 .60544 m
.02756 .60544 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .07417 m
.06244 .32106 L
.07216 .41411 L
.08255 .511 L
.08852 .55639 L
.09135 .5734 L
.09396 .586 L
.09658 .59535 L
.09796 .59887 L
.09866 .60028 L
.09942 .6015 L
.10069 .60284 L
.10187 .60331 L
.1026 .60322 L
.10329 .60287 L
.10458 .60152 L
.10586 .59929 L
.10707 .59639 L
.10933 .58894 L
.11176 .57812 L
.11439 .56339 L
.1235 .49323 L
.14415 .29775 L
.15446 .21402 L
.16409 .15031 L
.17413 .09838 L
.17945 .07687 L
.18516 .05844 L
.19044 .04548 L
.19533 .03669 L
.19788 .03317 L
.20069 .03001 L
.20367 .02736 L
.20639 .02545 L
.21139 .02289 L
.21401 .02188 L
.21677 .02096 L
.22652 .01834 L
.23143 .01723 L
.23606 .01633 L
.23862 .01592 L
.2414 .01557 L
.24393 .01532 L
.24505 .01524 L
.24626 .01516 L
.2474 .0151 L
.24845 .01506 L
.24951 .01503 L
.25051 .01501 L
.25167 .015 L
Mistroke
.25274 .01499 L
.25392 .015 L
.25518 .01501 L
.25641 .01503 L
.25773 .01505 L
.26014 .0151 L
.26249 .01514 L
.26351 .01515 L
.26462 .01516 L
.26585 .01517 L
.26701 .01518 L
.26765 .01518 L
.26833 .01518 L
.26956 .01517 L
.27069 .01516 L
.27174 .01514 L
.27415 .01509 L
.27961 .01494 L
.28199 .01487 L
.2846 .0148 L
.28584 .01478 L
.28717 .01475 L
.28842 .01474 L
.28955 .01473 L
.29084 .01472 L
.29156 .01472 L
.29223 .01472 L
.29345 .01473 L
.29475 .01474 L
.29605 .01476 L
.29744 .01478 L
.29996 .01483 L
.30273 .01488 L
.30568 .01494 L
.30689 .01496 L
.30819 .01498 L
.30893 .01499 L
.30961 .01499 L
.31027 .015 L
.31095 .015 L
.31216 .015 L
.31328 .015 L
.31452 .015 L
.31584 .01499 L
.31727 .01497 L
.31881 .01494 L
.32163 .01489 L
.32414 .01483 L
.32689 .01478 L
.32816 .01476 L
Mistroke
.32952 .01474 L
.3308 .01473 L
.33197 .01472 L
.33329 .01472 L
.33404 .01472 L
.33473 .01473 L
.336 .01474 L
.33671 .01475 L
.33736 .01475 L
.33974 .0148 L
.34233 .01487 L
.34701 .015 L
.34933 .01507 L
.35056 .0151 L
.35186 .01513 L
.35299 .01515 L
.35425 .01516 L
.35538 .01517 L
.35645 .01518 L
.3571 .01518 L
.35778 .01518 L
.359 .01517 L
.36031 .01516 L
.36106 .01515 L
.36175 .01514 L
.36657 .01505 L
.36802 .01503 L
.36873 .01502 L
.36938 .01501 L
.37061 .015 L
.37126 .015 L
.37194 .01499 L
.37262 .015 L
.37335 .015 L
.37467 .01502 L
.37548 .01504 L
.37624 .01507 L
.37767 .01513 L
.37892 .0152 L
.38025 .01529 L
.38263 .01551 L
.38547 .01586 L
.38803 .01626 L
.39782 .0183 L
.40297 .0196 L
.40839 .02116 L
.41316 .0229 L
.41586 .02416 L
.41837 .02561 L
.4228 .02902 L
Mistroke
.42528 .03155 L
.42754 .03433 L
.43237 .04207 L
.43749 .05339 L
.44186 .0659 L
.44668 .08291 L
.4574 .13309 L
.46746 .19541 L
.48599 .34936 L
.49578 .44426 L
.50622 .53636 L
.50917 .55729 L
.51196 .57394 L
.51446 .58597 L
.51575 .59101 L
.51717 .59559 L
.5185 .59894 L
.51974 .60123 L
.52106 .60274 L
.52179 .60318 L
.52247 .60332 L
.52366 .60296 L
.52497 .60169 L
.5262 .59964 L
.52734 .59703 L
.52973 .58938 L
.53197 .57962 L
.53708 .54906 L
.54743 .46176 L
.5659 .28692 L
.57636 .20398 L
.5861 .14161 L
.59579 .09341 L
.60121 .07244 L
.60613 .05714 L
.61134 .04468 L
.61408 .03953 L
.61698 .03503 L
.61952 .03181 L
.62232 .02894 L
.62723 .02525 L
.62972 .02389 L
.63244 .02267 L
.63739 .02093 L
.64667 .01843 L
.65192 .01723 L
.6548 .01665 L
.65751 .01617 L
.66004 .0158 L
.66278 .01547 L
Mistroke
.66399 .01536 L
.66527 .01526 L
.66646 .01518 L
.66756 .01512 L
.66878 .01507 L
.66941 .01505 L
.67011 .01503 L
.67128 .01501 L
.67253 .015 L
.67365 .015 L
.67486 .015 L
.67601 .01501 L
.67706 .01503 L
.68192 .01512 L
.68325 .01514 L
.68398 .01515 L
.68467 .01516 L
.68531 .01517 L
.68601 .01517 L
.68723 .01518 L
.6883 .01518 L
.68949 .01517 L
.69072 .01516 L
.69188 .01515 L
.69296 .01513 L
.69395 .01511 L
.69617 .01506 L
.70063 .01493 L
.70318 .01485 L
.70557 .01479 L
.70669 .01477 L
.70788 .01475 L
.70917 .01474 L
.71036 .01473 L
.71162 .01472 L
.7128 .01472 L
.71408 .01473 L
.71481 .01473 L
.71546 .01474 L
.71772 .01477 L
.72017 .01482 L
.72462 .01491 L
.72593 .01494 L
.72733 .01496 L
.72863 .01498 L
.72986 .01499 L
.73052 .015 L
.73124 .015 L
.7325 .015 L
.73323 .015 L
Mistroke
.73401 .015 L
.73475 .015 L
.73541 .01499 L
.7367 .01498 L
.73788 .01497 L
.74054 .01492 L
.74537 .01482 L
.74779 .01477 L
.74897 .01476 L
.75007 .01474 L
.75133 .01473 L
.752 .01473 L
.75271 .01472 L
.75385 .01472 L
.75511 .01473 L
.75629 .01473 L
.75737 .01475 L
.75855 .01477 L
.7598 .01479 L
.7642 .0149 L
.76897 .01504 L
.7716 .01511 L
.77288 .01514 L
.77407 .01515 L
.77475 .01516 L
.77548 .01517 L
.7762 .01517 L
.777 .01518 L
.77766 .01518 L
.77838 .01518 L
.77966 .01517 L
.78033 .01516 L
.78106 .01516 L
.78238 .01514 L
.78487 .0151 L
.78743 .01505 L
.78878 .01502 L
.78951 .01501 L
.7902 .01501 L
.79145 .015 L
.79211 .01499 L
.79281 .015 L
.79407 .015 L
.79521 .01502 L
.79641 .01506 L
.79752 .0151 L
.79874 .01516 L
.80003 .01524 L
.8022 .01542 L
.80458 .01568 L
Mistroke
.8098 .01647 L
.81542 .01762 L
.82068 .01887 L
.82557 .02017 L
.83086 .02182 L
.83566 .02381 L
.83841 .02531 L
.841 .02708 L
.84376 .02944 L
.84669 .03259 L
.85171 .03994 L
.85633 .04932 L
.86131 .0626 L
.86677 .0813 L
.87696 .12795 L
.88626 .18378 L
.90717 .35578 L
.91719 .45295 L
.92269 .50336 L
.92785 .54465 L
.93222 .57259 L
.93469 .58474 L
.93694 .59334 L
.93815 .59689 L
.93928 .5995 L
.94052 .6016 L
.94184 .60293 L
.9425 .60324 L
.94323 .60331 L
.94454 .6027 L
.94581 .60121 L
.94699 .59906 L
.94867 .59473 L
.95048 .58846 L
.95374 .57311 L
.95762 .54885 L
.96117 .52191 L
.97619 .38179 L
Mfstroke
.02381 .03677 m
.06244 .05007 L
.10458 .06914 L
.14415 .09142 L
.18221 .11694 L
.22272 .1479 L
.26171 .17909 L
.28158 .19416 L
.30316 .20876 L
.32216 .21937 L
.33296 .22422 L
.34309 .22787 L
.35264 .23046 L
.35801 .23154 L
.36292 .23228 L
.3656 .23259 L
.36808 .23281 L
.36948 .2329 L
.3708 .23298 L
.37153 .23301 L
.37232 .23304 L
.37304 .23306 L
.3737 .23308 L
.37494 .23309 L
.3756 .2331 L
.3763 .23309 L
.37704 .23309 L
.37773 .23307 L
.37904 .23304 L
.38026 .23299 L
.38139 .23293 L
.38395 .23276 L
.38637 .23253 L
.38858 .23227 L
.39358 .23151 L
.39798 .23063 L
.40262 .22952 L
.41246 .22648 L
.42322 .22219 L
.44283 .21203 L
.46378 .19846 L
.50528 .1667 L
.54526 .13486 L
.58372 .10672 L
.62464 .08109 L
.66405 .06076 L
.70193 .04515 L
.72301 .03813 L
.74227 .03278 L
.76242 .02822 L
Mistroke
.7811 .02491 L
.80012 .02233 L
.81081 .02119 L
.82086 .0203 L
.83074 .01957 L
.84142 .01891 L
.86004 .01804 L
.88002 .01736 L
.9011 .01681 L
.93912 .016 L
.97619 .01535 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00CP3oool3000003X0oooo100000030?ooo`800000>03oool400000080
oooo0`00000h0?ooo`@000000`3oool2000000X0oooo001A0?ooo`030000003oool0oooo03T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000002@3oool00540oooo00<000000?ooo`3oool0>@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000090?ooo`00CP3oool30000
03`0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03L0oooo00@00000
0?ooo`3oool0oooo0`00000j0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`070?ooo`00CP3oool00`000000oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0g0?ooo`050000003oool0oooo0?ooo`000000?@3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo001>0?ooo`030000003oool0oooo03X0
oooo0`0000030?ooo`040000003oool0oooo000003L0oooo0`0000030?ooo`030000003oool0oooo
03P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`003`3oool0
0`000000oooo0?ooo`0l0?ooo`@00000>`3oool00`000000oooo0?ooo`020?ooo`800000>P3oool0
10000000oooo0?ooo`3oool4000003P0oooo0P0000040?ooo`8000002P3oool000l0oooo00<00000
0?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`03
0000003oool0oooo0?l0oooo3`3oool000P0ooooo`00000C000000H0oooo000?0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`0000000P0000080?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`<00000303oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`@000002@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool01@3ooolM00000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0;0?ooo`003`3oool00`000000oooo0?ooo`0_0?ooo`@000002`3oool00`000000oooo0?ooo`0T
0?ooo`<000005P3oool00`000000oooo0?ooo`0Q0?ooo`<000006P3oool00`000000oooo0?ooo`0<
0?ooo`L00000103oool2000002D0oooo00<000000?ooo`3oool02`3oool000l0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool09@3oool5000000d0oooo00<000000?ooo`3oool0<03oool000l0oooo0P00000^0?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0Q0?ooo`D0
00004`3oool00`000000oooo0?ooo`0_0?ooo`003`3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo03/0oooo0P00000c0?ooo`030000003oool0oooo01`0oooo1P00000I0?ooo`030000
003oool0oooo02h0oooo000?0?ooo`800000;03oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool06@3oool400000200oooo00<000000?ooo`3oool0;@3o
ool000l0oooo00@000000?ooo`0000000000:P3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool05`3oool2000002@0oooo00<000000?ooo`3oool0;@3o
ool000l0oooo00@000000?ooo`3oool0oooo0`00000V0?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0E0?ooo`<000009`3oool00`000000oooo0?oo
o`0/0?ooo`003`3oool2000000D0oooo0P00000T0?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0C0?ooo`800000:`3oool00`000000oooo0?ooo`0[
0?ooo`003`3oool00`000000oooo0?ooo`060?ooo`<000008@3oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool04P3oool2000002d0oooo00<000000?oo
o`3oool0:`3oool000l0oooo00<000000?ooo`3oool02@3oool2000001h0oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0100oooo0P00000`0?ooo`03
0000003oool0oooo02X0oooo000?0?ooo`030000003oool0oooo00/0oooo0`00000K0?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0?0?ooo`800000
<P3oool00`000000oooo0?ooo`0Z0?ooo`003`3oool2000000l0oooo0P00000I0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0<0?ooo`<00000=03o
ool00`000000oooo0?ooo`0Z0?ooo`003`3oool00`000000oooo0?ooo`0@0?ooo`8000005P3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02P3oool2
000003L0oooo00<000000?ooo`3oool0:P3oool000l0oooo00<000000?ooo`3oool04P3oool20000
01@0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
00T0oooo0P00000i0?ooo`030000003oool0oooo02X0oooo000?0?ooo`030000003oool0oooo01@0
oooo0P00000A0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`070?ooo`800000?03oool00`000000oooo0?ooo`0Y0?ooo`003`3oool00`000000oooo
0?ooo`0F0?ooo`8000003`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool01@3oool2000003h0oooo00<000000?ooo`3oool0:@3oool000l0oooo0P00
000I0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo00<0oooo0P0000100?ooo`030000003oool0oooo02T0oooo000?
0?ooo`030000003oool0oooo01T0oooo0P00000<0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`020?ooo`800000@P3oool00`000000oooo0?ooo`0Y
0?ooo`001P3oool4000000D0oooo0P00000L0?ooo`8000002P3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo02H0oooo00D000000?ooo`3oool0oooo000000140?ooo`030000003oool0
oooo02T0oooo00080?ooo`030000003oool0oooo00@0oooo0P00000N0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0V0?ooo`040000003oool00000
000004H0oooo00<000000?ooo`3oool0:03oool000P0oooo00<000000?ooo`3oool0103oool20000
01l0oooo0P0000060?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool09@3oool20000
04P0oooo00<000000?ooo`3oool0:03oool000P0oooo00<000000?ooo`3oool0103oool200000240
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02@0
oooo0P0000190?ooo`030000003oool0oooo02P0oooo00080?ooo`030000003oool0oooo00@0oooo
0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0280oooo
0`00001:0?ooo`030000003oool0oooo02P0oooo00060?ooo`<000001P3oool2000002@0oooo0P00
00000`3oool000000?ooo`190?ooo`030000003oool0oooo0240oooo00@000000?ooo`3oool00000
B`3oool00`000000oooo0?ooo`0W0?ooo`00203oool00`000000oooo0?ooo`040?ooo`8000009P3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo01l0oooo00D000000?ooo`3oool0oooo
0000001;0?ooo`030000003oool0oooo02L0oooo000?0?ooo`<000009@3oool3000004X0oooo00<0
00000?ooo`3oool07@3oool2000000@0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`0W0?ooo`003`3oool00`000000oooo0000000U0?ooo`040000003oool0oooo000004T0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool09`3oool000l0oooo00<000000?ooo`0000009@3oool010000000oooo0?ooo`3o
ool2000004L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool09P3oool000l0oooo00<000000?ooo`0000009@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool09P3oool0
00l0oooo0`00000T0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`0G0?ooo`800000203oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo
02H0oooo000?0?ooo`030000003oool0000002@0oooo00<000000?ooo`3oool01P3oool2000004@0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool09P3oool000l0oooo00@000000?ooo`3oool000008`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool09P3oool000l0oooo
00@000000?ooo`3oool000008`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool04`3oool2000000/0oooo00<000000?ooo`3oool0C@3oool00`000000
oooo0?ooo`0U0?ooo`003`3oool010000000oooo0?ooo`00000R0?ooo`030000003oool0oooo00/0
oooo0P0000110?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo02D0oooo000?0?ooo`80000000<0oooo0000003oool0
8@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
9@3oool000l0oooo00@000000?ooo`3oool000008P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo03d0oooo00<000000?ooo`3oool03P3oool2000000l0oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`0U0?ooo`003`3oool010000000oooo0?ooo`00000R0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0U0?ooo`003`3o
ool010000000oooo0?ooo`00000R0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0T0?ooo`003`3oool200000080oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0B0?ooo`800000>`3oool00`000000oooo0?ooo`0:0?ooo`8000004P3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo02@0oooo000?0?ooo`050000003oool0
oooo0?ooo`000000803oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0903oool000l0oooo00D000000?ooo`3oool0oooo0000000P0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0T0?ooo`001P3oool4
000000D0oooo00D000000?ooo`3oool0oooo0000000P0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`050?ooo`8000005P3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo02@0oooo00060?ooo`030000003oool0oooo00H0oooo00D00000
0?ooo`3oool0oooo0000000P0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0D@3o
ool00`000000oooo0?ooo`0S0?ooo`001`3oool00`000000oooo0?ooo`050?ooo`8000000P3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`0S0?ooo`00203oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`0000007`3oool00`000000oooo0?ooo`0J0?ooo`800000=@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0S
0?ooo`002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03<0oooo00@000000?oo
o`3oool000006P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo02<0oooo00060?oo
o`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo01d0oooo0P00000c0?ooo`<000006`3oool00`000000oooo0?ooo`1A
0?ooo`030000003oool0oooo02<0oooo00070?ooo`8000001P3oool2000000<0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo02<0oooo000?0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0P0?ooo`80
0000;`3oool2000001`0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0S0?ooo`00
3`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0Z0?ooo`80000000<0oooo0000003oool06`3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo0280oooo000?0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0T0?ooo`800000:@3oool01@000000oooo0?oo
o`3oool0000001`0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0R0?ooo`003`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0T0?ooo`800000103oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool08P3oool000l0oooo0P0000040?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool09`3oool2000002<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool08P3oool0
00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
02T0oooo0P00000O0?ooo`800000203oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool08P3oool000l0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo02/0oooo0P00000K0?ooo`8000002P3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool08P3oool000l0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02d0oooo
0`00000F0?ooo`800000303oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool08P3oool000l0oooo0P0000040?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0<@3oool300000100oooo0`00000>0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`0R0?ooo`003`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0=03oool600000080oooo2000000A
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0R
0?ooo`003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0>P3oool2000001T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo0280oooo000?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0Q0?ooo`003`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool08@3oool000l0oooo0P0000050?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool08@3oool000l0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0240oooo00070?ooo`8000001P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool08@3oool000H0
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool08@3oool000T0oooo00<000000?ooo`3oool00`3oool2000000H0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0Q0?ooo`001`3oool2000000H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0240oooo
00090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo0240oooo00060?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0200oooo0007
0?ooo`8000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0803oool000l0oooo0P0000060?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool0803oool000l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo0200oooo000?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0P0?ooo`003`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0803oool000l0oooo0P0000070?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0803oool000l0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo0200oooo000?0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0P0?ooo`003`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0FP3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool07`3oool000l0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01l0oooo000?
0?ooo`800000203oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05X0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01l0oooo000?0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1J0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0O0?oo
o`003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0F`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool07`3oool000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo05/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo01l0oooo000?0?ooo`800000203oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo05/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1J0?ooo`030000003o
ool0oooo01l0oooo000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0FP3oool0
0`000000oooo0?ooo`0O0?ooo`00203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0O0?ooo`00203oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`1L0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0FP3oool00`000000
oooo0?ooo`0O0?ooo`001@3oool5000000D0oooo0P0000090?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05`0oooo
00<000000?ooo`3oool07P3oool000D0oooo00@000000?ooo`3oool000001P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0G03oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool07P3oool000H0oooo00<0
00000?ooo`0000001P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0G03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05`0oooo00<0
00000?ooo`3oool07P3oool000L0oooo0P0000060?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0G03oool00`000000oooo0?ooo`0N0?ooo`00203oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1M0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0N0?oo
o`003`3oool2000000T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1M0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0N0?ooo`00
3`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
G@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
7P3oool000l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1L0?ooo`030000003o
ool0oooo01h0oooo000?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0G03oool0
0`000000oooo0?ooo`0N0?ooo`003`3oool2000000X0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`0M0?ooo`003`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool07@3oool000l0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`1N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool000l0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool02`3oool000l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1N
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool000l0oooo0P00000:0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo05h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?oo
o`003`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0G`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0;0?ooo`003`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`003`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0G`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0<0?ooo`003`3oool2000000/0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0G`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo000?0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00`0oooo000?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`1O0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00060?ooo`<000001P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0G`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0<0?ooo`002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo0009
0?ooo`030000003oool0oooo00<0oooo0P00000;0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0H03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0600oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`001P3oool3000000H0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0600oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0303oool000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0600oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`00
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
H@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00060?ooo`@000001@3o
ool2000000`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1Q0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00d0oooo000?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0H@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo000?0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00d0oooo000?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`1Q0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0HP3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo000?0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo
000?0?ooo`800000303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0640oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool03@3oool000l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1R
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool000l0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0680oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool03@3oool000l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0680oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool000l0oooo0P00000=0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo06<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`003`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0H`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo06<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`003`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06@0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`003`3oool2000000d0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo
000?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00h0oooo00070?ooo`8000001P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>
0?ooo`001P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00060?oo
o`040000003oool0oooo000000D0oooo0P00000>0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`001P3oool3000000H0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo06D0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03`3oool000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo06D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`00
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
I@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00l0oooo00070?ooo`<000001@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0IP3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0?0?ooo`003`3oool2000000h0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0IP3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00l0oooo000?0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00l0oooo000?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0I`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00l0oooo000?0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00l0oooo
000?0?ooo`8000003`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0403oool000l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1W
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool000l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06P0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0403oool000l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo06P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1W0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool000l0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
403oool000l0oooo0P00000?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo06T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0@0?ooo`003`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0JP3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`003`3oool200000100oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo
000?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1Z0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0140oooo000?0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0J`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00070?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo06X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1[0?oo
o`050000003oool0oooo0?ooo`000000503oool000L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`000000K@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo06/0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`00203oool0
0`000000oooo0?ooo`040?ooo`8000004@3oool01@000000oooo0?ooo`3oool0000006h0oooo00D0
00000?ooo`3oool0oooo0000001^0?ooo`040000003oool0oooo000001@0oooo00080?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0000006h0
oooo00D000000?ooo`3oool0oooo0000001^0?ooo`040000003oool0oooo000001@0oooo00090?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0000001`0?oo
o`030000003oool0000006l0oooo00<000000?ooo`0000005@3oool000H0oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`0A0?ooo`<00000L03oool200000740oooo0P00000E0?oo
o`001P3oool4000000D0oooo0P00003o0?oooa00oooo000?0?ooo`030000003oool0oooo0?l0oooo
3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o
0?ooo`l0oooo0000\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {216.5, 75.1875}} -> {-10.0009, \
3.65269, 0.0771421, 0.0447732}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.0147151 0.0866885 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .1014 -6 -4.5 ]
[.01131 .1014 0 4.5 ]
[.01131 .18809 -6 -4.5 ]
[.01131 .18809 0 4.5 ]
[.01131 .27478 -6 -4.5 ]
[.01131 .27478 0 4.5 ]
[.01131 .36147 -6 -4.5 ]
[.01131 .36147 0 4.5 ]
[.01131 .44816 -6 -4.5 ]
[.01131 .44816 0 4.5 ]
[.01131 .53485 -6 -4.5 ]
[.01131 .53485 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(10)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(15)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(20)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .1014 m
.03006 .1014 L
s
[(1)] .01131 .1014 1 0 Mshowa
.02381 .18809 m
.03006 .18809 L
s
[(2)] .01131 .18809 1 0 Mshowa
.02381 .27478 m
.03006 .27478 L
s
[(3)] .01131 .27478 1 0 Mshowa
.02381 .36147 m
.03006 .36147 L
s
[(4)] .01131 .36147 1 0 Mshowa
.02381 .44816 m
.03006 .44816 L
s
[(5)] .01131 .44816 1 0 Mshowa
.02381 .53485 m
.03006 .53485 L
s
[(6)] .01131 .53485 1 0 Mshowa
.125 Mabswid
.02381 .03205 m
.02756 .03205 L
s
.02381 .04939 m
.02756 .04939 L
s
.02381 .06673 m
.02756 .06673 L
s
.02381 .08407 m
.02756 .08407 L
s
.02381 .11874 m
.02756 .11874 L
s
.02381 .13608 m
.02756 .13608 L
s
.02381 .15342 m
.02756 .15342 L
s
.02381 .17075 m
.02756 .17075 L
s
.02381 .20543 m
.02756 .20543 L
s
.02381 .22277 m
.02756 .22277 L
s
.02381 .24011 m
.02756 .24011 L
s
.02381 .25744 m
.02756 .25744 L
s
.02381 .29212 m
.02756 .29212 L
s
.02381 .30946 m
.02756 .30946 L
s
.02381 .32679 m
.02756 .32679 L
s
.02381 .34413 m
.02756 .34413 L
s
.02381 .37881 m
.02756 .37881 L
s
.02381 .39614 m
.02756 .39614 L
s
.02381 .41348 m
.02756 .41348 L
s
.02381 .43082 m
.02756 .43082 L
s
.02381 .4655 m
.02756 .4655 L
s
.02381 .48283 m
.02756 .48283 L
s
.02381 .50017 m
.02756 .50017 L
s
.02381 .51751 m
.02756 .51751 L
s
.02381 .55218 m
.02756 .55218 L
s
.02381 .56952 m
.02756 .56952 L
s
.02381 .58686 m
.02756 .58686 L
s
.02381 .6042 m
.02756 .6042 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04306 m
.02846 .05254 L
.03279 .06409 L
.04262 .10119 L
.0522 .15179 L
.06244 .21987 L
.0841 .40116 L
.09475 .49539 L
.09943 .53198 L
.10458 .56553 L
.10698 .57802 L
.10956 .58888 L
.11081 .5931 L
.112 .59646 L
.11317 .59913 L
.11423 .60099 L
.11545 .60248 L
.11676 .60326 L
.11797 .60325 L
.11912 .60258 L
.11977 .60192 L
.12045 .601 L
.12168 .59879 L
.123 .59563 L
.12445 .59122 L
.12727 .58004 L
.12984 .56702 L
.13561 .52939 L
.14603 .44241 L
.16672 .2618 L
.17582 .19454 L
.18587 .13237 L
.19048 .1086 L
.19546 .08665 L
.19975 .07087 L
.20446 .05693 L
.20947 .04562 L
.21203 .04112 L
.21476 .03712 L
.21965 .03167 L
.2242 .02808 L
.22953 .02501 L
.23444 .02278 L
.23973 .02071 L
.24555 .01871 L
.25027 .01736 L
.25533 .01627 L
.25813 .01584 L
.26069 .01555 L
.26192 .01545 L
Mistroke
.26326 .01537 L
.26452 .01531 L
.2657 .01527 L
.26699 .01524 L
.26764 .01523 L
.26835 .01523 L
.26961 .01523 L
.27079 .01524 L
.27151 .01524 L
.27218 .01525 L
.27345 .01527 L
.27629 .01532 L
.2775 .01534 L
.27878 .01535 L
.27987 .01536 L
.28107 .01537 L
.28236 .01537 L
.28309 .01536 L
.28375 .01536 L
.28497 .01534 L
.28626 .01532 L
.28849 .01526 L
.29087 .01518 L
.29516 .01501 L
.29988 .01484 L
.30226 .01478 L
.30292 .01476 L
.30362 .01475 L
.30488 .01474 L
.30557 .01473 L
.30631 .01473 L
.30702 .01473 L
.30768 .01473 L
.30891 .01473 L
.31023 .01475 L
.31143 .01477 L
.31257 .01479 L
.31515 .01485 L
.31797 .01492 L
.32095 .01499 L
.32217 .01501 L
.32349 .01503 L
.32424 .01504 L
.32493 .01505 L
.32561 .01506 L
.32627 .01506 L
.32744 .01506 L
.32869 .01506 L
.32975 .01506 L
.33092 .01504 L
Mistroke
.33217 .01503 L
.33352 .015 L
.33597 .01495 L
.33859 .01488 L
.34139 .01481 L
.34275 .01479 L
.34404 .01476 L
.34519 .01475 L
.34643 .01473 L
.34765 .01473 L
.34835 .01473 L
.34899 .01473 L
.3503 .01474 L
.35103 .01475 L
.3517 .01475 L
.35289 .01478 L
.35419 .01481 L
.35654 .01488 L
.3619 .01508 L
.36483 .01519 L
.36758 .01528 L
.36874 .01531 L
.36997 .01534 L
.37061 .01535 L
.37131 .01535 L
.37254 .01536 L
.37326 .01537 L
.37392 .01537 L
.37467 .01537 L
.37538 .01536 L
.37665 .01535 L
.37736 .01534 L
.37802 .01533 L
.38061 .01529 L
.38188 .01527 L
.38307 .01525 L
.38413 .01524 L
.38527 .01523 L
.38653 .01523 L
.38767 .01523 L
.38883 .01525 L
.39009 .01528 L
.39127 .01533 L
.39235 .01539 L
.39352 .01547 L
.3948 .01558 L
.39738 .01588 L
.39965 .01623 L
.40207 .0167 L
.40645 .01777 L
Mistroke
.41726 .02138 L
.4271 .02575 L
.43193 .02873 L
.43705 .03314 L
.44142 .03847 L
.44623 .04662 L
.4514 .05869 L
.45696 .07612 L
.46701 .12006 L
.47711 .17941 L
.48814 .25916 L
.50823 .43392 L
.51835 .52009 L
.52332 .55494 L
.52789 .57988 L
.53046 .59025 L
.53177 .59444 L
.53317 .59805 L
.53391 .59958 L
.53458 .60075 L
.5359 .60241 L
.53663 .60298 L
.53743 .6033 L
.53819 .60332 L
.53889 .60308 L
.54007 .60215 L
.54118 .60066 L
.54241 .59834 L
.54372 .59505 L
.5464 .58595 L
.54886 .57489 L
.5536 .54713 L
.55866 .50992 L
.56777 .43126 L
.58847 .25209 L
.59871 .17866 L
.60981 .11441 L
.6149 .09104 L
.62029 .07079 L
.62489 .05713 L
.62996 .04568 L
.63245 .04127 L
.63517 .03726 L
.63756 .03432 L
.64011 .03172 L
.64493 .02794 L
.6494 .02534 L
.66036 .02067 L
.67028 .01749 L
.67517 .01639 L
Mistroke
.67763 .01598 L
.67904 .01579 L
.68033 .01564 L
.68264 .01544 L
.6839 .01536 L
.68511 .0153 L
.68621 .01527 L
.68724 .01524 L
.68837 .01523 L
.68956 .01523 L
.69085 .01523 L
.69202 .01524 L
.69331 .01526 L
.69467 .01528 L
.69699 .01532 L
.69827 .01534 L
.69947 .01536 L
.70015 .01536 L
.70089 .01537 L
.70217 .01537 L
.70348 .01536 L
.70469 .01535 L
.70601 .01533 L
.70746 .0153 L
.71039 .01521 L
.71518 .01503 L
.7177 .01493 L
.72039 .01484 L
.72273 .01478 L
.72337 .01477 L
.72406 .01475 L
.72531 .01474 L
.72647 .01473 L
.72769 .01473 L
.72873 .01473 L
.72987 .01474 L
.7306 .01475 L
.7313 .01476 L
.7326 .01478 L
.73553 .01484 L
.73827 .01491 L
.7408 .01497 L
.74312 .01502 L
.74429 .01504 L
.74558 .01505 L
.74687 .01506 L
.7476 .01506 L
.74826 .01506 L
.74955 .01506 L
.75077 .01505 L
Mistroke
.75201 .01504 L
.75336 .01502 L
.7558 .01496 L
.76036 .01485 L
.76295 .01479 L
.76436 .01477 L
.76568 .01475 L
.76681 .01473 L
.76802 .01473 L
.76871 .01473 L
.76936 .01473 L
.77058 .01474 L
.77164 .01475 L
.7728 .01476 L
.77402 .01479 L
.77516 .01482 L
.77939 .01496 L
.78435 .01516 L
.78677 .01524 L
.78897 .0153 L
.79014 .01533 L
.79124 .01535 L
.79241 .01536 L
.79367 .01537 L
.79497 .01537 L
.79562 .01536 L
.79634 .01536 L
.79762 .01535 L
.79881 .01533 L
.80137 .01529 L
.8038 .01525 L
.80445 .01524 L
.80514 .01523 L
.8059 .01523 L
.8066 .01523 L
.80729 .01523 L
.80794 .01523 L
.80916 .01525 L
.81024 .01527 L
.81142 .01532 L
.81265 .01538 L
.8138 .01545 L
.81585 .01564 L
.81806 .0159 L
.82064 .01631 L
.82309 .0168 L
.82767 .01796 L
.83735 .02122 L
.84265 .02337 L
.84762 .02576 L
Mistroke
.85184 .02831 L
.85639 .03198 L
.85898 .03468 L
.86144 .03778 L
.86606 .04528 L
.87108 .05648 L
.87563 .0698 L
.88584 .1116 L
.8953 .16453 L
.90422 .22541 L
.92295 .38142 L
.93319 .47342 L
.93819 .51487 L
.94275 .54797 L
.94643 .57009 L
.95044 .58834 L
.9515 .59205 L
.95264 .59544 L
.95369 .59806 L
.95467 .60004 L
.95559 .60148 L
.95658 .60257 L
.95768 .60323 L
.95869 .60332 L
.95971 .60291 L
.96079 .60191 L
.96182 .60045 L
.96276 .59868 L
.96505 .59263 L
.96721 .58474 L
.97152 .56329 L
.97619 .53262 L
Mfstroke
.02381 .02523 m
.04262 .02835 L
.06244 .03261 L
.10458 .04537 L
.14264 .06128 L
.18314 .08235 L
.22214 .10615 L
.26358 .13475 L
.30351 .16437 L
.34193 .19228 L
.36137 .20498 L
.38279 .21692 L
.39258 .22145 L
.40311 .22558 L
.41298 .22869 L
.42214 .23085 L
.42704 .23172 L
.43225 .23242 L
.43523 .23271 L
.43669 .23282 L
.43803 .23291 L
.43923 .23297 L
.44055 .23303 L
.44188 .23307 L
.4426 .23308 L
.44328 .2331 L
.44453 .2331 L
.44523 .2331 L
.44588 .2331 L
.44708 .23308 L
.44835 .23305 L
.44948 .233 L
.45055 .23295 L
.45297 .2328 L
.45558 .23258 L
.45798 .23232 L
.46337 .23156 L
.46811 .23068 L
.47317 .22954 L
.48229 .22694 L
.50299 .21867 L
.52434 .20721 L
.54449 .19433 L
.58296 .16657 L
.62388 .13616 L
.66328 .10877 L
.70117 .08527 L
.74151 .06379 L
.78033 .04704 L
.80008 .04015 L
Mistroke
.82161 .03394 L
.84247 .02919 L
.86137 .02586 L
.88108 .02325 L
.90207 .02124 L
.92135 .01992 L
.94218 .01885 L
.97619 .01755 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00CP3oool3000003X0oooo100000030?ooo`800000>03oool400000080
oooo0`00000h0?ooo`@000000`3oool2000000X0oooo001A0?ooo`030000003oool0oooo03T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000002@3oool00540oooo00<000000?ooo`3oool0>@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000090?ooo`00CP3oool30000
03`0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03L0oooo00@00000
0?ooo`3oool0oooo0`00000j0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`070?ooo`00CP3oool00`000000oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0g0?ooo`050000003oool0oooo0?ooo`000000?@3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo001>0?ooo`030000003oool0oooo03X0
oooo0`0000030?ooo`040000003oool0oooo000003L0oooo0`0000030?ooo`030000003oool0oooo
03P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`003`3oool0
0`000000oooo0?ooo`0l0?ooo`@00000>`3oool00`000000oooo0?ooo`020?ooo`800000>P3oool0
10000000oooo0?ooo`3oool4000003P0oooo0P0000040?ooo`8000002P3oool000l0oooo00<00000
0?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`03
0000003oool0oooo0?l0oooo3`3oool000P0ooooo`00000C000000H0oooo000?0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0103oool3000000<0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo0`00000:0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0103oool2000000@0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003o
ool0oooo00H0oooo4P00000=0?ooo`003`3oool00`000000oooo0?ooo`0f0?ooo`8000001P3oool0
0`000000oooo0?ooo`0V0?ooo`<00000503oool00`000000oooo0?ooo`0X0?ooo`<000004`3oool0
0`000000oooo0?ooo`0H0?ooo`<000001`3oool;00000140oooo00<000000?ooo`3oool02`3oool0
00l0oooo0`00000d0?ooo`800000=03oool2000003/0oooo0P00000d0?ooo`030000003oool00000
00@00000:P3oool000l0oooo00<000000?ooo`3oool01@00000^0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0`0?ooo`L00000;P3oool000l0oooo
0P0000060?ooo`D00000:03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03@0oooo
0P00000_0?ooo`@000001`3oool00`000000oooo0?ooo`0[0?ooo`003`3oool00`000000oooo0?oo
o`0:0?ooo`@000008`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0380oooo00<0
00000?ooo`3oool0;03oool3000000`0oooo00<000000?ooo`3oool0:P3oool000l0oooo00<00000
0?ooo`3oool03P3oool4000001h0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo02T0oooo0`00000@0?ooo`030000003oool0oooo02T0oooo000?0?oo
o`030000003oool0oooo0180oooo0`00000J0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`0X0?ooo`8000004`3oool00`000000oooo0?ooo`0Y0?oo
o`003`3oool2000001H0oooo0P00000H0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0U0?ooo`<000005P3oool00`000000oooo0?ooo`0X0?ooo`00
3`3oool2000001P0oooo0P00000E0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0R0?ooo`<000006@3oool00`000000oooo0?ooo`0X0?ooo`003`3o
ool2000001X0oooo0P00000C0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0Q0?ooo`8000007@3oool00`000000oooo0?ooo`0W0?ooo`003`3oool0
0`000000oooo0000000K0?ooo`8000004@3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool07P3oool3000001l0oooo00<000000?ooo`3oool09`3oool0
00l0oooo00<000000?ooo`0000007@3oool2000000l0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo01d0oooo0P00000S0?ooo`030000003oool0oooo
02H0oooo000?0?ooo`<000007`3oool2000000`0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo01/0oooo0P00000U0?ooo`030000003oool0oooo02H0
oooo000?0?ooo`040000003oool0oooo00000200oooo0P00000:0?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0J0?ooo`8000009`3oool00`000000
oooo0?ooo`0V0?ooo`003`3oool010000000oooo0?ooo`00000R0?ooo`800000203oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0603oool2000002T0
oooo00<000000?ooo`3oool09P3oool000l0oooo00@000000?ooo`3oool00000903oool2000000D0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01H0
oooo0P00000/0?ooo`030000003oool0oooo02D0oooo000?0?ooo`040000003oool0oooo000002H0
oooo0P0000030?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0D0?ooo`800000;P3oool00`000000oooo0?ooo`0U0?ooo`003`3oool200000080oooo
00<000000?ooo`3oool09@3oool3000004L0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool09@3oool000l0oooo00D0
00000?ooo`3oool0oooo0000000Y0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0B0?ooo`800000<@3oool00`000000oooo0?ooo`0U0?ooo`003`3o
ool01@000000oooo0?ooo`3oool0000002T0oooo0`0000160?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02@0oooo
00060?ooo`@000001@3oool01@000000oooo0?ooo`3oool0000002T0oooo00<000000?ooo`3oool0
0P0000140?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03`3oool2000003D0oooo
00<000000?ooo`3oool0903oool000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo02@0oooo00080?ooo`030000003oool0oooo00@0oooo0P000003
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0103oool200000440oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool0903oool000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool0303oool2000003X0oooo00<000000?oo
o`3oool08`3oool000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool01`3oool2000003l0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool08`3oool000H0oooo0`0000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0:0?ooo`800000?@3oool00`000000oooo0?ooo`0S0?ooo`00203o
ool00`000000oooo0?ooo`040?ooo`800000103oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0S0?ooo`003`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool02`3oool2
000003/0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`070?ooo`800000@03oool0
0`000000oooo0?ooo`0S0?ooo`003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool01@3oool2000004<0oooo00<000000?ooo`3oool08P3oool000l0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0R0?ooo`003`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0403oool2000003P0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`030?ooo`800000AP3oool00`000000oooo
0?ooo`0R0?ooo`003`3oool2000000@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool08P3oool000l0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01<0oooo0P00000e
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P0000190?ooo`030000003oool0
oooo0280oooo000?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0000001;0?ooo`030000003oool0oooo0280oooo000?0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool08P3oool2000004`0oooo00<000000?ooo`3oool08P3oool000l0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01P0oooo
0P00000b0?ooo`030000003oool0oooo0200oooo0P00001=0?ooo`030000003oool0oooo0280oooo
000?0?ooo`8000001@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0O0?ooo`800000C`3oool00`000000oooo0?oo
o`0Q0?ooo`003`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`000000C`3oool00`000000oooo0?ooo`0Q0?ooo`003`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0703oool2000002h0oooo00<000000?oo
o`3oool0703oool200000080oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0Q0?oo
o`003`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0240oooo000?0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`800000
:`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`0Q0?ooo`003`3oool2000000H0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool05`3o
ool2000000D0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0Q0?ooo`003`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool08`3oool2
000002T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool0803oool000H0oooo100000050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool0803oool000H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo0200oooo00070?ooo`030000003oool0oooo00D0oooo
0P0000070?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:03oool2000002D0oooo
00<000000?ooo`3oool04P3oool2000000X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`0P0?ooo`00203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0803oool000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0:`3oool2000002<0oooo00<00000
0?ooo`3oool03P3oool2000000d0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0O
0?ooo`001P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0303oool2000000l0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0O
0?ooo`001`3oool2000000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo02h0oooo0P00000P0?ooo`030000003oool0oooo00X0oooo0P00000@0?oo
o`030000003oool0oooo0540oooo00<000000?ooo`3oool07`3oool000l0oooo0P0000070?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1A0?ooo`03
0000003oool0oooo01l0oooo000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0a0?ooo`8000007@3oool00`000000oooo0?ooo`070?ooo`800000
4`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo01l0oooo000?0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0d0?ooo`8000006`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0D@3o
ool00`000000oooo0?ooo`0O0?ooo`003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0=P3oool2000001T0oooo00<000000?ooo`3oool0103oool2
000001H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0N0?ooo`003`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0>03oool30000
01L0oooo00@000000?ooo`3oool0oooo0P00000H0?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`3oool07P3oool000l0oooo0P0000080?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0>`3oool3000001@0oooo00@000000?ooo`00000000006P3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo01h0oooo000?0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0n0?ooo`<00000403oool3000001`0oooo00<000000?oo
o`3oool0DP3oool00`000000oooo0?ooo`0N0?ooo`003`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0@@3oool600000080oooo200000000`3oool0
00000?ooo`0L0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07P3oool000l0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo04H0oooo
0`0000090?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0DP3oool00`000000oooo
0?ooo`0N0?ooo`003`3oool2000000T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`1B0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`0N0?ooo`003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0DP3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool07@3oool000l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo05<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo01d0oooo000?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0M0?ooo`003`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool07@3oool000l0oooo0P0000090?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool07@3oool000l0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo01d0oooo000?0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0M0?ooo`001`3oool2000000H0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05@0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo01d0
oooo00060?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01`0oooo00090?ooo`030000003oool0oooo00<0oooo
0P00000:0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0E@3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0703oool000L0oooo0P00
00060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0L0?ooo`002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0L0?ooo`001P3oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0L
0?ooo`001`3oool2000000H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01`0oooo000?0?ooo`8000002P3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo01`0oooo000?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0L0?ooo`003`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool0703oool000l0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01/0oooo000?0?ooo`8000002`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01/0oooo000?0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0K0?ooo`003`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool06`3oool000l0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01/0oooo000?
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0K
0?ooo`003`3oool2000000`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0K0?oo
o`003`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool06`3oool000l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo05T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo01/0oooo000?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`0J0?ooo`003`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo05X0oooo00<000000?ooo`3oool06P3oool000l0oooo0P00000<0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool06P3oool000l0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`1J0?ooo`030000003oool0oooo01X0oooo000?0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0J0?ooo`00203oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?oo
o`0J0?ooo`00203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0J0?ooo`001@3oool5000000D0oooo0P00000=0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo05/0oooo00<000000?ooo`3oool06P3oool000D0oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0F`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05`0oooo00<000000?oo
o`3oool06@3oool000H0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo05`0oooo00<000000?ooo`3oool06@3oool000L0oooo0P0000060?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1L0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0I0?ooo`00203o
ool00`000000oooo0?ooo`040?ooo`8000003@3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo05`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1L0?ooo`030000003o
ool0oooo01T0oooo000?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0G03oool0
0`000000oooo0?ooo`0I0?ooo`003`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
05`0oooo00<000000?ooo`3oool06@3oool000l0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`1M0?ooo`030000003oool0oooo01T0oooo000?0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0I0?ooo`003`3oool2000000h0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0G@3oool00`000000oooo0?ooo`0I0?ooo`003`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0603oool000l0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05h0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo01P0oooo000?0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1N0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0H0?ooo`00
3`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
GP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0
603oool000l0oooo0P00000>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0GP3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0603o
ool000l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo05h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0
oooo01P0oooo000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`1O0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0G`3oool00`00
0000oooo0?ooo`0H0?ooo`003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo05l0
oooo00<000000?ooo`3oool0603oool000l0oooo0P00000?0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0600oooo
00<000000?ooo`3oool05`3oool000l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`1P0?ooo`030000003oool0oooo01L0oooo000?0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0H03oool00`000000oooo0?ooo`0G0?ooo`001P3oool3000000H0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0600oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo01L0oooo00090?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0600oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1P0?ooo`03
0000003oool0oooo01L0oooo00090?ooo`030000003oool0oooo00<0oooo0P00000@0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0640oooo00<000000?ooo`3oool05`3oool000H0oooo0`0000060?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1P0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0G0?ooo`001P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0H@3oool0
0`000000oooo0?ooo`0G0?ooo`001P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0F0?ooo`001P3oool4000000D0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0680
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo01H0
oooo000?0?ooo`800000403oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0680oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo01H0oooo
000?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?oo
o`0F0?ooo`003`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0HP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo06<0oooo00<00000
0?ooo`3oool05P3oool000l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0680oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1S0?oo
o`030000003oool0oooo01H0oooo000?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0H`3oool00`000000oooo0?ooo`0F0?ooo`003`3oool200000140oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
H`3oool00`000000oooo0?ooo`0F0?ooo`003`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo06<0oooo00<000000?ooo`3oool05P3oool000l0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`1S0?ooo`030000003oool0oooo01H0oooo000?0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0E0?ooo`003`3oool200000140
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0E0?ooo`003`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0I03oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool05@3oool000l0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06@0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo01D0oooo000?
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1T
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0E
0?ooo`003`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0I03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06D0oooo00<000000?oo
o`3oool05@3oool000l0oooo0P00000B0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0I@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3o
ool05@3oool000l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo06D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1U0?ooo`030000
003oool0oooo01D0oooo000?0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`0E0?ooo`001`3oool2000000H0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`1U0?ooo`030000003oool0oooo01D0oooo00060?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo06H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool02`3oool000H0oooo00@000000?ooo`3oool000001@3oool2
00000180oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00/0oooo00060?ooo`<000001P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
06L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`001P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`1V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0I`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool02`3oool000L0oooo0`0000050?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0I`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo000?
0?ooo`8000004`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06P0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0303oool000l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo06P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1X0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool000l0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0303oool000l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1Y0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0303oool000l0oooo0P00000D0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo06T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`003`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0<0?ooo`003`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
06T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0JP3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`003`3oool2000001D0oooo00D0
00000?ooo`3oool0oooo0000001^0?ooo`050000003oool0oooo0?ooo`000000K@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo000?0?ooo`030000003oool0oooo01@0oooo
00D000000?ooo`3oool0oooo0000001^0?ooo`050000003oool0oooo0?ooo`000000KP3oool01000
0000oooo0?ooo`00000@0?ooo`003`3oool00`000000oooo0?ooo`0D0?ooo`050000003oool0oooo
0?ooo`000000KP3oool010000000oooo0?ooo`00001_0?ooo`040000003oool0oooo00000100oooo
000?0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`000000L03oool00`000000oooo0000
001_0?ooo`040000003oool0oooo00000100oooo000?0?ooo`030000003oool0oooo01D0oooo0`00
001`0?ooo`<00000K`3oool300000140oooo000?0?ooo`800000o`3oool@0?ooo`003`3oool00`00
0000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000l0oooo
00<000000?ooo`3oool0o`3oool?0?ooo`00\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {365.188, 223.875}} -> {-10.0009, \
11.3328, 0.0771421, 0.0423751}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.0147151 0.091724 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .10644 -6 -4.5 ]
[.01131 .10644 0 4.5 ]
[.01131 .19816 -6 -4.5 ]
[.01131 .19816 0 4.5 ]
[.01131 .28989 -6 -4.5 ]
[.01131 .28989 0 4.5 ]
[.01131 .38161 -6 -4.5 ]
[.01131 .38161 0 4.5 ]
[.01131 .47334 -6 -4.5 ]
[.01131 .47334 0 4.5 ]
[.01131 .56506 -6 -4.5 ]
[.01131 .56506 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(10)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(15)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(20)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10644 m
.03006 .10644 L
s
[(1)] .01131 .10644 1 0 Mshowa
.02381 .19816 m
.03006 .19816 L
s
[(2)] .01131 .19816 1 0 Mshowa
.02381 .28989 m
.03006 .28989 L
s
[(3)] .01131 .28989 1 0 Mshowa
.02381 .38161 m
.03006 .38161 L
s
[(4)] .01131 .38161 1 0 Mshowa
.02381 .47334 m
.03006 .47334 L
s
[(5)] .01131 .47334 1 0 Mshowa
.02381 .56506 m
.03006 .56506 L
s
[(6)] .01131 .56506 1 0 Mshowa
.125 Mabswid
.02381 .03306 m
.02756 .03306 L
s
.02381 .0514 m
.02756 .0514 L
s
.02381 .06975 m
.02756 .06975 L
s
.02381 .08809 m
.02756 .08809 L
s
.02381 .12478 m
.02756 .12478 L
s
.02381 .14313 m
.02756 .14313 L
s
.02381 .16147 m
.02756 .16147 L
s
.02381 .17982 m
.02756 .17982 L
s
.02381 .21651 m
.02756 .21651 L
s
.02381 .23485 m
.02756 .23485 L
s
.02381 .2532 m
.02756 .2532 L
s
.02381 .27154 m
.02756 .27154 L
s
.02381 .30823 m
.02756 .30823 L
s
.02381 .32658 m
.02756 .32658 L
s
.02381 .34492 m
.02756 .34492 L
s
.02381 .36327 m
.02756 .36327 L
s
.02381 .39996 m
.02756 .39996 L
s
.02381 .4183 m
.02756 .4183 L
s
.02381 .43665 m
.02756 .43665 L
s
.02381 .45499 m
.02756 .45499 L
s
.02381 .49168 m
.02756 .49168 L
s
.02381 .51002 m
.02756 .51002 L
s
.02381 .52837 m
.02756 .52837 L
s
.02381 .54671 m
.02756 .54671 L
s
.02381 .5834 m
.02756 .5834 L
s
.02381 .60175 m
.02756 .60175 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .03157 m
.02846 .0357 L
.03279 .04072 L
.03754 .04814 L
.04262 .05903 L
.04795 .07455 L
.053 .09356 L
.06244 .14078 L
.08265 .28216 L
.10458 .46477 L
.10951 .50359 L
.11482 .54087 L
.11974 .56927 L
.12217 .58051 L
.12442 .58908 L
.12692 .59633 L
.12824 .59915 L
.12891 .60032 L
.12964 .60137 L
.13093 .60268 L
.13215 .60326 L
.13333 .60323 L
.13442 .60267 L
.13575 .60132 L
.13698 .5994 L
.13833 .59658 L
.13978 .59272 L
.14275 .58233 L
.14545 .5701 L
.15536 .50718 L
.16453 .43364 L
.18529 .26183 L
.19427 .19571 L
.20396 .13483 L
.2095 .10626 L
.21458 .08463 L
.21941 .06819 L
.22456 .05472 L
.22969 .04493 L
.23436 .03847 L
.23905 .03365 L
.24348 .03011 L
.25341 .02398 L
.25898 .02118 L
.26418 .019 L
.26875 .01751 L
.27131 .01687 L
.27365 .01642 L
.2762 .01605 L
.27765 .0159 L
Mistroke
.27899 .01579 L
.28028 .01571 L
.28144 .01566 L
.28209 .01564 L
.28279 .01562 L
.28406 .0156 L
.28538 .01559 L
.2866 .0156 L
.28731 .0156 L
.28795 .01561 L
.28939 .01562 L
.29078 .01564 L
.29151 .01565 L
.29229 .01566 L
.29296 .01566 L
.29371 .01567 L
.29502 .01567 L
.29633 .01566 L
.29753 .01565 L
.29884 .01563 L
.30023 .01559 L
.30256 .01551 L
.3051 .0154 L
.30996 .01514 L
.31251 .01501 L
.31521 .01489 L
.31758 .01481 L
.31823 .01479 L
.31892 .01477 L
.32018 .01475 L
.32141 .01474 L
.32257 .01474 L
.32361 .01474 L
.32475 .01475 L
.32606 .01477 L
.32752 .0148 L
.33046 .01488 L
.333 .01496 L
.33574 .01504 L
.33705 .01507 L
.33842 .0151 L
.3396 .01512 L
.34088 .01514 L
.34209 .01515 L
.34338 .01515 L
.3446 .01514 L
.34571 .01513 L
.3469 .01511 L
.34802 .01509 L
.35055 .01503 L
Mistroke
.35568 .01487 L
.35795 .01481 L
.35907 .01478 L
.36011 .01477 L
.3613 .01475 L
.3626 .01474 L
.3637 .01474 L
.36488 .01474 L
.36556 .01475 L
.36628 .01476 L
.36757 .01479 L
.36897 .01483 L
.37049 .01488 L
.37578 .01514 L
.38052 .01539 L
.38301 .0155 L
.38566 .0156 L
.38696 .01563 L
.3877 .01564 L
.38839 .01565 L
.3896 .01566 L
.39091 .01567 L
.39217 .01567 L
.39281 .01566 L
.3935 .01566 L
.39473 .01565 L
.39588 .01563 L
.39699 .01562 L
.3982 .01561 L
.39933 .0156 L
.40038 .01559 L
.40161 .0156 L
.4029 .01562 L
.40399 .01564 L
.40519 .01569 L
.40586 .01572 L
.40659 .01577 L
.40791 .01587 L
.4092 .016 L
.4104 .01614 L
.41311 .01658 L
.416 .01721 L
.42131 .01886 L
.42611 .02083 L
.43617 .02608 L
.44541 .03245 L
.45025 .03704 L
.45555 .04395 L
.45823 .04846 L
.46109 .05424 L
Mistroke
.46625 .06755 L
.47155 .08567 L
.47646 .10669 L
.48754 .16873 L
.50768 .31874 L
.51746 .40093 L
.52799 .48793 L
.53308 .52576 L
.53792 .55669 L
.54227 .57877 L
.54473 .58841 L
.54702 .59531 L
.54825 .59818 L
.54939 .60027 L
.55064 .60194 L
.55196 .603 L
.55311 .60332 L
.55418 .60311 L
.55536 .60232 L
.55662 .60083 L
.55774 .59895 L
.55895 .59631 L
.56117 .59 L
.56532 .5732 L
.57024 .54598 L
.57546 .51023 L
.58484 .43534 L
.60453 .27181 L
.62258 .14568 L
.632 .09727 L
.63673 .0786 L
.64192 .06248 L
.64714 .05039 L
.65001 .04525 L
.65272 .04121 L
.65798 .03513 L
.66277 .03102 L
.67249 .02478 L
.6778 .02199 L
.68277 .01975 L
.68736 .01807 L
.69156 .01693 L
.69395 .01645 L
.69622 .01611 L
.69746 .01597 L
.69861 .01586 L
.69988 .01576 L
.70057 .01572 L
.70122 .01569 L
.70247 .01564 L
Mistroke
.70313 .01562 L
.70384 .01561 L
.70458 .0156 L
.70528 .01559 L
.70659 .01559 L
.70782 .0156 L
.70896 .01561 L
.71153 .01564 L
.71277 .01566 L
.71346 .01566 L
.7141 .01567 L
.71481 .01567 L
.71556 .01567 L
.71622 .01567 L
.71693 .01566 L
.71769 .01566 L
.71837 .01565 L
.71916 .01563 L
.7199 .01562 L
.72267 .01553 L
.73247 .01504 L
.73486 .01492 L
.73742 .01483 L
.73888 .01479 L
.74022 .01476 L
.74087 .01475 L
.74157 .01474 L
.74285 .01474 L
.74408 .01474 L
.74524 .01475 L
.74651 .01477 L
.74789 .0148 L
.75069 .01487 L
.75325 .01495 L
.75568 .01502 L
.75794 .01508 L
.75918 .01511 L
.76031 .01513 L
.76155 .01514 L
.76224 .01515 L
.76289 .01515 L
.76395 .01515 L
.76513 .01514 L
.76635 .01513 L
.76749 .01511 L
.76954 .01507 L
.77174 .01501 L
.7764 .01487 L
.77762 .01483 L
.77895 .0148 L
Mistroke
.78012 .01477 L
.78135 .01475 L
.78204 .01475 L
.78278 .01474 L
.7841 .01474 L
.78539 .01474 L
.78659 .01476 L
.78782 .01478 L
.78894 .01481 L
.79146 .0149 L
.79713 .01518 L
.79973 .01532 L
.80249 .01546 L
.80487 .01555 L
.80622 .0156 L
.80749 .01563 L
.80865 .01565 L
.80972 .01566 L
.81089 .01567 L
.81212 .01567 L
.81337 .01566 L
.81407 .01566 L
.81471 .01565 L
.81712 .01562 L
.81847 .01561 L
.81923 .0156 L
.81993 .0156 L
.82122 .01559 L
.82187 .0156 L
.82258 .0156 L
.82388 .01563 L
.82508 .01566 L
.8264 .01572 L
.8278 .01582 L
.82914 .01594 L
.8304 .01608 L
.83275 .01642 L
.83508 .01687 L
.83722 .0174 L
.84204 .01894 L
.84689 .02095 L
.85221 .02358 L
.85772 .0267 L
.86293 .03014 L
.86784 .03412 L
.87317 .03989 L
.87801 .04716 L
.88249 .05625 L
.88732 .06924 L
.89264 .08793 L
Mistroke
.90342 .14048 L
.91354 .20575 L
.92281 .27531 L
.94368 .44895 L
.9512 .50852 L
.95922 .5611 L
.96159 .57333 L
.96383 .58314 L
.96601 .59095 L
.96802 .59651 L
.969 .59866 L
.96992 .6003 L
.97089 .60164 L
.97194 .60266 L
.97301 .60322 L
.97399 .6033 L
.97512 .60289 L
.97619 .602 L
Mfstroke
.02381 .02097 m
.04262 .02233 L
.06244 .02417 L
.08255 .02667 L
.10458 .03038 L
.12415 .03473 L
.14509 .04064 L
.18653 .05637 L
.22646 .07625 L
.26488 .09879 L
.30574 .12536 L
.3451 .15251 L
.38293 .17876 L
.42322 .20431 L
.44176 .21422 L
.46199 .22303 L
.47295 .22676 L
.48312 .2295 L
.49285 .23141 L
.49828 .23217 L
.50063 .23243 L
.50321 .23267 L
.50574 .23285 L
.50809 .23297 L
.50939 .23302 L
.51057 .23306 L
.51123 .23307 L
.51194 .23308 L
.51324 .23309 L
.51434 .23309 L
.51556 .23308 L
.51683 .23306 L
.51803 .23302 L
.51914 .23298 L
.52016 .23293 L
.52246 .2328 L
.52497 .2326 L
.5273 .23238 L
.5326 .23171 L
.53777 .23086 L
.54328 .22973 L
.55352 .22705 L
.56463 .22333 L
.58478 .21465 L
.6257 .19119 L
.6651 .16456 L
.70299 .13813 L
.74333 .11101 L
.78215 .08693 L
.82343 .06455 L
Mistroke
.86319 .04724 L
.90143 .0352 L
.92115 .03072 L
.94213 .02707 L
.95968 .02476 L
.97619 .02307 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00CP3oool3000003X0oooo100000030?ooo`800000>03oool400000080
oooo0`00000h0?ooo`@000000`3oool2000000X0oooo001A0?ooo`030000003oool0oooo03T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000002@3oool00540oooo00<000000?ooo`3oool0>@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000090?ooo`00CP3oool30000
03`0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03L0oooo00@00000
0?ooo`3oool0oooo0`00000j0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`070?ooo`00CP3oool00`000000oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0g0?ooo`050000003oool0oooo0?ooo`000000?@3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo001>0?ooo`030000003oool0oooo03X0
oooo0`0000030?ooo`040000003oool0oooo000003L0oooo0`0000030?ooo`030000003oool0oooo
03P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`003`3oool0
0`000000oooo0?ooo`0l0?ooo`@00000>`3oool00`000000oooo0?ooo`020?ooo`800000>P3oool0
10000000oooo0?ooo`3oool4000003P0oooo0P0000040?ooo`8000002P3oool000l0oooo00<00000
0?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`03
0000003oool0oooo0?l0oooo3`3oool000P0ooooo`00000C000000H0oooo000?0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool3000000X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`090?ooo`040000003oool0oooo0?ooo`8000001`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00P0oooo1000000;0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool4000000T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00/0oooo000?0?ooo`P00000=P3oool4000002/0oooo0P00
000B0?ooo`030000003oool0oooo02d0oooo0P00000?0?ooo`030000003oool0oooo01/0oooo0`00
000N0?ooo`<000003@3oool000l0oooo00<000000?ooo`3oool01@3oool<000002T0oooo00<00000
0?ooo`3oool0;`3oool2000003h0oooo0P00000b0?ooo`030000003oool0oooo0140oooo2P00000@
0?ooo`003`3oool00`000000oooo0?ooo`0A0?ooo`D000008P3oool2000003@0oooo0P00000k0?oo
o`030000003oool0oooo03<0oooo0P00000=0?ooo`@000006P3oool000l0oooo0P00000G0?ooo`@0
00007@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`080?ooo`8000007P3oool000l0oooo0P00000K0?ooo`<00000
6@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03D0oooo0P00000i0?ooo`030000
003oool0oooo00@0oooo0`00000P0?ooo`003`3oool00`000000oooo0000000M0?ooo`<000005P3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`04000002<0oooo000?0?ooo`040000003oool0oooo000001l0oooo0`00
000B0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`0j0?ooo`<000009`3oool000l0oooo00@000000?ooo`3oool000008P3oool2000000l0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo03L0oooo0`00
00020?ooo`030000003oool0oooo02D0oooo000?0?ooo`8000000P3oool00`000000oooo0?ooo`0Q
0?ooo`<00000303oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool0=@3oool2000000H0oooo00<000000?ooo`3oool0903oool000l0oooo00D000000?oo
o`3oool0oooo0000000V0?ooo`8000002@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool0=03oool2000000P0oooo00<000000?ooo`3oool0903oool0
00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0U0?ooo`8000001`3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0<P3oool20000
00X0oooo00<000000?ooo`3oool0903oool000l0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0W0?ooo`8000001@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0<@3oool2000000d0oooo00<000000?ooo`3oool08`3oool000l0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`8000000P3oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;P3oool3000000l0oooo
00<000000?ooo`3oool08`3oool000l0oooo0P0000040?ooo`030000003oool0oooo02X0oooo0`00
00120?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;03oool200000180oooo00<0
00000?ooo`3oool08`3oool000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0/
0?ooo`800000@P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02/0oooo0P00000D
0?ooo`030000003oool0oooo02<0oooo000?0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0;03oool00`000000oooo000000110?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0:@3oool2000001L0oooo00<000000?ooo`3oool08P3oool000l0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0oooo0?ooo`800000@03oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo02L0oooo0P00000I0?ooo`030000003oool0oooo
0280oooo000?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`030?ooo`800000?P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02H0
oooo0P00000L0?ooo`030000003oool0oooo0240oooo000?0?ooo`8000001P3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0Q0?ooo`003`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool01`3oool2000003/0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0T0?ooo`8000007`3oool00`000000oooo0?ooo`0Q0?ooo`003`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool2000003X0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0R0?ooo`8000008@3oool00`000000oooo0?ooo`0Q
0?ooo`001P3oool4000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?oo
o`00203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0=0?ooo`800000=`3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo01l0oooo0P00000U0?ooo`030000003oool0oooo0200oooo00080?ooo`030000
003oool0oooo00@0oooo0P0000070?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
7@3oool2000002L0oooo00<000000?ooo`3oool0803oool000P0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0403o
ool2000003@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0803oool000P0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool04P3oool2
00000380oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0K0?ooo`800000:P3oool0
0`000000oooo0?ooo`0P0?ooo`001P3oool3000000H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0P0?ooo`00203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0E0?ooo`800000<03oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`0P0?ooo`003`3oool2000000L0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0G0?ooo`800000;P3oool00`000000oooo0?ooo`0P0?ooo`003`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool06@3oool2000002d0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool07`3oool000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0O
0?ooo`003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0503oool2000003<0oooo00<000000?ooo`3oool07`3oool000l0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01d0oooo0P00000Z0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo01l0oooo000?0?ooo`800000203oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo0140oooo0P00000f0?ooo`030000003oool0oooo01l0oooo000?0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool07`3oool000l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0280oooo0P00000V0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool03P3oool2000003X0oooo00<000000?ooo`3oool07P3oool0
00l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00`0oooo0P00000l0?ooo`030000003oool0oooo01h0oooo000?0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0U0?ooo`8000008`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`0N0?ooo`003`3oool2000000T0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0:0?ooo`800000?`3oool00`000000oooo0?ooo`0N0?ooo`003`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0:03oool200000240oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool07P3oool000l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo02/0oooo0P00000O0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool01`3oool200000480oooo00<000000?ooo`3oool07P3oool000l0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0@`3oool00`000000oooo0?ooo`0M0?ooo`003`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0;P3oool2000001`0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`040?ooo`800000AP3oool00`000000oooo0?ooo`0M0?ooo`00
3`3oool2000000X0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool000l0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0340oooo0P00000J0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo01d0oooo000?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool07`3oool0
10000000oooo0?ooo`3oool2000004X0oooo00<000000?ooo`3oool07@3oool000H0oooo10000005
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0e
0?ooo`8000005`3oool00`000000oooo0?ooo`0O0?ooo`040000003oool0oooo000004`0oooo00<0
00000?ooo`3oool07@3oool000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0=`3oool2000001D0oooo00<00000
0?ooo`3oool07`3oool3000004h0oooo00<000000?ooo`3oool0703oool000L0oooo00<000000?oo
o`3oool01@3oool2000000X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool07P3oool200000500oooo00<000000?oo
o`3oool0703oool000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0>P3oool200000180oooo00<000000?ooo`3o
ool0703oool2000000030?ooo`000000oooo04l0oooo00<000000?ooo`3oool0703oool000T0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0?03oool200000100oooo00<000000?ooo`3oool06P3oool2000000<0oooo
00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0L0?ooo`001P3oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0n0?ooo`8000003`3oool00`000000oooo0?ooo`0G0?ooo`8000001@3oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo01`0oooo00070?ooo`8000001P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0@@3oool2000000d0oooo00<0
00000?ooo`3oool05@3oool2000000H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0L0?ooo`003`3oool2000000/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`13
0?ooo`8000002`3oool00`000000oooo0?ooo`0C0?ooo`800000203oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo01`0oooo000?0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`150?ooo`8000002@3oool00`000000oooo0?ooo`0A0?oo
o`8000002P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo01/0oooo000?0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`170?ooo`80
00001`3oool00`000000oooo0?ooo`0?0?ooo`800000303oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo01/0oooo000?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`190?ooo`<00000103oool00`000000oooo0?ooo`0<0?ooo`<00000
3P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo01/0oooo000?0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1<0?ooo`T000000P3o
ool800000140oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0K0?ooo`003`3oool2
000000`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1A0?ooo`030000003oool0
oooo00<00000603oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo01/0oooo000?0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1A0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0K0?oo
o`003`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0D@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool06P3oool000l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo01X0oooo000?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0DP3o
ool00`000000oooo0?ooo`0J0?ooo`003`3oool2000000d0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0DP3oool0
0`000000oooo0?ooo`0J0?ooo`003`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool06P3oool000l0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo01X0oooo000?0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0I0?ooo`003`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool06@3oool000l0oooo0P00000>
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool06@3oool000l0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo01T0oooo000?0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0I0?ooo`00
1`3oool2000000H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo01T0oooo00060?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo01T0oooo00090?ooo`030000003o
ool0oooo00<0oooo0P00000>0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool06@3o
ool000L0oooo0P0000060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0H0?ooo`002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0H0?ooo`001P3oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0H0?ooo`001`3oool2000000H0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01P0oooo000?0?ooo`8000003`3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo01P0oooo000?0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0H0?ooo`003`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0603oool000l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01P0oooo000?0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0H0?ooo`00
3`3oool2000000l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0H0?ooo`003`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool05`3o
ool000l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01L0oooo000?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0G0?ooo`003`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool05`3oool000l0oooo0P00000@0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool05`3oool000l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01L0oooo000?0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0G0?ooo`003`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool05`3oool000l0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01L0oooo000?0?ooo`800000
4@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01H0oooo000?0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1J0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0F0?ooo`003`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0FP3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool05P3oool0
00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool05P3oool000P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0FP3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool05P3oool000D0oooo
1@0000050?ooo`8000004@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05/0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01H0oooo
00050?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`1J0?ooo`030000003oool0oooo01H0oooo00060?ooo`030000003oool0000000H0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05/0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo01H0oooo0007
0?ooo`8000001P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0G03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05/0oooo00<00000
0?ooo`3oool05P3oool000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo05`0oooo00<000000?ooo`3oool05@3oool000l0oooo0P00000B0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo05`0oooo00<000000?ooo`3oool05@3oool000l0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01D0oooo000?0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1L0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0E0?ooo`003`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0G03oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool05@3oool0
00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
05d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo
01D0oooo000?0?ooo`8000004P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05d0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01D0
oooo000?0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`1N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0G@3oool00`000000oooo
0?ooo`0E0?ooo`003`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0GP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05d0oooo00<0
00000?ooo`3oool05@3oool000l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1M
0?ooo`030000003oool0oooo01D0oooo000?0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0GP3oool00`000000oooo0?ooo`0D0?ooo`003`3oool2000001<0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`0D0?ooo`003`3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool0503oool000l0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo01@0oooo000?0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0D0?ooo`003`3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0H03oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0503oool000l0
oooo0P00000D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0503oool000l0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0600oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo01<0oooo
000?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`1P0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?oo
o`0C0?ooo`001P3oool3000000H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1P
0?ooo`030000003oool0oooo01<0oooo00090?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0600oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo01<0oooo00090?ooo`03
0000003oool0oooo00<0oooo0P00000D0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0HP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool04`3oool000H0oooo0`0000060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
H@3oool00`000000oooo0?ooo`0C0?ooo`001P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1R0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0B0?ooo`001P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0HP3oool0
0`000000oooo0?ooo`0B0?ooo`001P3oool4000000D0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1R0?ooo`030000003oool0oooo0180oooo000?0?ooo`8000005@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`1R0?ooo`030000003oool0oooo0180oooo000?0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0B0?ooo`003`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool04P3oool000l0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06<0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0140oooo000?0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1T0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0A0?oo
o`003`3oool2000001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1T0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0A0?ooo`00
3`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
I03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0
4@3oool000l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo06@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1T0?ooo`030000003o
ool0oooo0140oooo000?0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`0A0?ooo`003`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool0403oool000l0oooo0P00000F0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06D0
oooo00<000000?ooo`3oool0403oool000l0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`1V0?ooo`030000003oool0oooo0100oooo000?0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0IP3oool00`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0403oool000l0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo06H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0100oooo000?0?ooo`80
00005`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0100oooo000?0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1W0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0?0?ooo`003`3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0J03o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool03`3o
ool000L0oooo0P0000060?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0J03oool0
0`000000oooo0?ooo`0?0?ooo`001P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1X0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0?0?ooo`001P3oool01000
0000oooo0?ooo`0000050?ooo`800000603oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo06P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0
oooo00l0oooo00060?ooo`<000001P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
06T0oooo00<000000?ooo`3oool03`3oool000H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool03`3oool000H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06T0oooo
00<000000?ooo`3oool03`3oool000L0oooo0`0000050?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0JP3oool00`000000oooo0?ooo`0>0?ooo`003`3oool2000001P0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`1[0?ooo`050000003oool0oooo0?ooo`000000K@3o
ool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0J`3oool01@000000oooo0?ooo`3oool0000006h0oooo00<0
00000?ooo`3oool03@3oool000l0oooo00<000000?ooo`3oool0603oool01@000000oooo0?ooo`3o
ool0000006h0oooo00D000000?ooo`3oool0oooo0000001^0?ooo`030000003oool0oooo00d0oooo
000?0?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool00000KP3oool01@000000oooo
0?ooo`3oool0000006h0oooo00<000000?ooo`3oool03@3oool000l0oooo00<000000?ooo`3oool0
6@3oool010000000oooo00000000001_0?ooo`040000003oool00000000006h0oooo00<000000?oo
o`3oool03@3oool000l0oooo0P00000J0?ooo`<00000L03oool300000700oooo0P00000=0?ooo`00
3`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3o
ool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?oo
o`l0oooo0000\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {513.875, 372.562}} -> {-10.0009, \
18.1541, 0.0771421, 0.0400487}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.0147151 0.0971242 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .11184 -6 -4.5 ]
[.01131 .11184 0 4.5 ]
[.01131 .20896 -6 -4.5 ]
[.01131 .20896 0 4.5 ]
[.01131 .30609 -6 -4.5 ]
[.01131 .30609 0 4.5 ]
[.01131 .40321 -6 -4.5 ]
[.01131 .40321 0 4.5 ]
[.01131 .50034 -6 -4.5 ]
[.01131 .50034 0 4.5 ]
[.01131 .59746 -6 -4.5 ]
[.01131 .59746 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(10)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(15)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(20)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11184 m
.03006 .11184 L
s
[(1)] .01131 .11184 1 0 Mshowa
.02381 .20896 m
.03006 .20896 L
s
[(2)] .01131 .20896 1 0 Mshowa
.02381 .30609 m
.03006 .30609 L
s
[(3)] .01131 .30609 1 0 Mshowa
.02381 .40321 m
.03006 .40321 L
s
[(4)] .01131 .40321 1 0 Mshowa
.02381 .50034 m
.03006 .50034 L
s
[(5)] .01131 .50034 1 0 Mshowa
.02381 .59746 m
.03006 .59746 L
s
[(6)] .01131 .59746 1 0 Mshowa
.125 Mabswid
.02381 .03414 m
.02756 .03414 L
s
.02381 .05356 m
.02756 .05356 L
s
.02381 .07299 m
.02756 .07299 L
s
.02381 .09241 m
.02756 .09241 L
s
.02381 .13126 m
.02756 .13126 L
s
.02381 .15069 m
.02756 .15069 L
s
.02381 .17011 m
.02756 .17011 L
s
.02381 .18954 m
.02756 .18954 L
s
.02381 .22839 m
.02756 .22839 L
s
.02381 .24781 m
.02756 .24781 L
s
.02381 .26724 m
.02756 .26724 L
s
.02381 .28666 m
.02756 .28666 L
s
.02381 .32551 m
.02756 .32551 L
s
.02381 .34494 m
.02756 .34494 L
s
.02381 .36436 m
.02756 .36436 L
s
.02381 .38379 m
.02756 .38379 L
s
.02381 .42264 m
.02756 .42264 L
s
.02381 .44206 m
.02756 .44206 L
s
.02381 .46149 m
.02756 .46149 L
s
.02381 .48091 m
.02756 .48091 L
s
.02381 .51976 m
.02756 .51976 L
s
.02381 .53919 m
.02756 .53919 L
s
.02381 .55861 m
.02756 .55861 L
s
.02381 .57804 m
.02756 .57804 L
s
.02381 .61689 m
.02756 .61689 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .02492 m
.03279 .03167 L
.04262 .04132 L
.04758 .04799 L
.05288 .05752 L
.05789 .06968 L
.06244 .08408 L
.07283 .13069 L
.0841 .20189 L
.10458 .36165 L
.12403 .51124 L
.12935 .54491 L
.13229 .56093 L
.13509 .57414 L
.13767 .58439 L
.1405 .5932 L
.14174 .59624 L
.14306 .5989 L
.14431 .60085 L
.14545 .60213 L
.14662 .60297 L
.14791 .60332 L
.14856 .60327 L
.14926 .60304 L
.15052 .60218 L
.15177 .60077 L
.15296 .59891 L
.15518 .5941 L
.1578 .58631 L
.16022 .57717 L
.16571 .55036 L
.17496 .49046 L
.1848 .41523 L
.20449 .25721 L
.21311 .19349 L
.22255 .13422 L
.23197 .09001 L
.23711 .07261 L
.24189 .06022 L
.24718 .05 L
.25198 .04307 L
.26275 .03208 L
.27273 .02457 L
.27749 .0217 L
.28194 .01954 L
.28445 .01857 L
.28675 .01784 L
.2893 .01721 L
.29072 .01694 L
.29204 .01673 L
Mistroke
.29342 .01655 L
.29466 .01642 L
.29605 .01632 L
.29681 .01627 L
.29752 .01624 L
.29883 .01619 L
.30003 .01616 L
.30134 .01615 L
.30201 .01615 L
.30273 .01614 L
.30404 .01615 L
.30525 .01615 L
.30588 .01615 L
.30658 .01615 L
.30731 .01615 L
.30799 .01615 L
.30924 .01614 L
.31039 .01612 L
.31164 .0161 L
.31296 .01606 L
.31408 .01602 L
.31527 .01597 L
.31742 .01586 L
.32228 .01553 L
.32793 .01511 L
.3307 .01495 L
.33192 .01489 L
.33325 .01484 L
.33445 .0148 L
.33558 .01478 L
.33676 .01476 L
.33803 .01476 L
.3387 .01476 L
.33942 .01477 L
.34074 .01478 L
.34202 .01481 L
.34321 .01485 L
.34758 .015 L
.35218 .01517 L
.35334 .0152 L
.35458 .01523 L
.3553 .01525 L
.35595 .01526 L
.35722 .01527 L
.35836 .01527 L
.3596 .01527 L
.36077 .01525 L
.36185 .01524 L
.36312 .01521 L
.3643 .01517 L
Mistroke
.36701 .01508 L
.36986 .01497 L
.37247 .01487 L
.37365 .01484 L
.37493 .0148 L
.37615 .01478 L
.37727 .01476 L
.37859 .01476 L
.37978 .01476 L
.38044 .01477 L
.38115 .01478 L
.38244 .01481 L
.38369 .01485 L
.38482 .0149 L
.38737 .01503 L
.39196 .01535 L
.39738 .01575 L
.39977 .0159 L
.40112 .01597 L
.4024 .01602 L
.40371 .01607 L
.40491 .0161 L
.4062 .01613 L
.40687 .01613 L
.40758 .01614 L
.40826 .01615 L
.40898 .01615 L
.41028 .01615 L
.41107 .01615 L
.41182 .01615 L
.41249 .01615 L
.41322 .01614 L
.41446 .01615 L
.41578 .01615 L
.417 .01617 L
.41814 .0162 L
.41883 .01623 L
.41948 .01626 L
.42071 .01633 L
.42203 .01644 L
.42347 .01659 L
.42603 .01698 L
.42748 .01726 L
.4288 .01758 L
.4312 .01827 L
.43382 .01922 L
.43838 .02135 L
.44319 .02418 L
.45406 .03232 L
.46418 .0426 L
Mistroke
.46921 .04977 L
.47467 .06029 L
.47983 .07383 L
.48459 .09012 L
.49361 .13212 L
.50316 .19173 L
.52291 .34397 L
.54099 .48625 L
.54574 .51929 L
.55093 .55095 L
.55583 .57516 L
.55802 .58381 L
.56039 .59149 L
.56181 .59522 L
.56312 .59805 L
.56436 .60019 L
.56569 .60186 L
.56687 .60282 L
.56798 .60327 L
.56919 .60324 L
.57049 .60262 L
.57121 .60201 L
.57188 .60129 L
.57338 .59906 L
.57471 .59643 L
.57612 .59297 L
.57857 .58543 L
.58126 .57494 L
.58618 .55061 L
.59135 .51899 L
.6006 .45218 L
.62145 .28506 L
.63172 .20697 L
.64141 .14358 L
.65011 .09961 L
.65502 .08085 L
.65955 .06721 L
.66408 .05663 L
.66907 .04782 L
.67428 .0409 L
.67915 .03578 L
.68925 .02736 L
.69488 .02353 L
.7001 .02061 L
.705 .01855 L
.70774 .01771 L
.71022 .01713 L
.71296 .01667 L
.7145 .01649 L
.71591 .01636 L
Mistroke
.71715 .01628 L
.71852 .01622 L
.7192 .0162 L
.71994 .01618 L
.72063 .01616 L
.72126 .01615 L
.72251 .01615 L
.72314 .01614 L
.72384 .01614 L
.72506 .01615 L
.72621 .01615 L
.72687 .01615 L
.72756 .01615 L
.7288 .01615 L
.72949 .01614 L
.73013 .01614 L
.73084 .01613 L
.73159 .01611 L
.73286 .01608 L
.73423 .01604 L
.73671 .01593 L
.73913 .01579 L
.74136 .01563 L
.74605 .01528 L
.74863 .0151 L
.75108 .01495 L
.75335 .01485 L
.75463 .01481 L
.75582 .01478 L
.75682 .01477 L
.75792 .01476 L
.75907 .01476 L
.76016 .01477 L
.76136 .01479 L
.76268 .01482 L
.76533 .0149 L
.77009 .01508 L
.77277 .01517 L
.77424 .01521 L
.77497 .01523 L
.77564 .01524 L
.77693 .01526 L
.77762 .01527 L
.77834 .01527 L
.77952 .01527 L
.78081 .01526 L
.78209 .01524 L
.78329 .01521 L
.786 .01513 L
.79095 .01495 L
Mistroke
.79326 .01486 L
.79544 .0148 L
.79664 .01478 L
.79795 .01476 L
.79913 .01476 L
.80022 .01476 L
.80143 .01478 L
.80272 .0148 L
.80395 .01484 L
.80506 .01489 L
.80779 .01503 L
.81038 .0152 L
.81547 .01558 L
.81818 .01577 L
.8211 .01594 L
.82237 .016 L
.8237 .01605 L
.82484 .01609 L
.82608 .01611 L
.82725 .01613 L
.8285 .01615 L
.82969 .01615 L
.83076 .01615 L
.83199 .01615 L
.83329 .01614 L
.83397 .01614 L
.83472 .01614 L
.83604 .01615 L
.83728 .01617 L
.83797 .01618 L
.83861 .0162 L
.83984 .01625 L
.84102 .01632 L
.84218 .01641 L
.84323 .01651 L
.84559 .01681 L
.84778 .01722 L
.84983 .01771 L
.85445 .01927 L
.85944 .02164 L
.86897 .02785 L
.87942 .03677 L
.88469 .04259 L
.89033 .05078 L
.89565 .06137 L
.9005 .07431 L
.90533 .09098 L
.91044 .11322 L
.91963 .16482 L
.94041 .31953 L
Mistroke
.97619 .57449 L
Mfstroke
.02381 .0185 m
.06244 .02089 L
.08255 .02235 L
.10458 .02422 L
.1253 .02639 L
.14415 .02891 L
.16372 .03226 L
.18466 .03691 L
.22459 .04952 L
.263 .0666 L
.30387 .08934 L
.34322 .11416 L
.38106 .13927 L
.42134 .16604 L
.46012 .19044 L
.47983 .20172 L
.50134 .21264 L
.52217 .2214 L
.54105 .22743 L
.55118 .22982 L
.56072 .2315 L
.56597 .23217 L
.5708 .23262 L
.57332 .2328 L
.5761 .23295 L
.57749 .23301 L
.57826 .23303 L
.57899 .23305 L
.57967 .23306 L
.58041 .23308 L
.58169 .23309 L
.58291 .2331 L
.58403 .23309 L
.58525 .23307 L
.58654 .23305 L
.58767 .23301 L
.58872 .23298 L
.59109 .23286 L
.59372 .23269 L
.59611 .2325 L
.60147 .23193 L
.60665 .2312 L
.61228 .23022 L
.62248 .22793 L
.64235 .22174 L
.6634 .21297 L
.70128 .19283 L
.74162 .16765 L
.78045 .1419 L
.82172 .11448 L
Mistroke
.86148 .08939 L
.89973 .06797 L
.94043 .04968 L
.97619 .0381 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00CP3oool3000003X0oooo100000030?ooo`800000>03oool400000080
oooo0`00000h0?ooo`@000000`3oool2000000X0oooo001A0?ooo`030000003oool0oooo03T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000002@3oool00540oooo00<000000?ooo`3oool0>@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000090?ooo`00CP3oool30000
03`0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03L0oooo00@00000
0?ooo`3oool0oooo0`00000j0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`070?ooo`00CP3oool00`000000oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0g0?ooo`050000003oool0oooo0?ooo`000000?@3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo001>0?ooo`030000003oool0oooo03X0
oooo0`0000030?ooo`040000003oool0oooo000003L0oooo0`0000030?ooo`030000003oool0oooo
03P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`003`3oool0
0`000000oooo0?ooo`0l0?ooo`@00000>`3oool00`000000oooo0?ooo`020?ooo`800000>P3oool0
10000000oooo0?ooo`3oool4000003P0oooo0P0000040?ooo`8000002P3oool000l0oooo00<00000
0?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`03
0000003oool0oooo0?l0oooo3`3oool000P0ooooo`00000C000000H0oooo000?0?ooo`H000001`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo100000040?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`@000000`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool0oooo
100000050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool010000000oooo
0?ooo`3oool3000000H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00/0oooo000?0?ooo`030000003oool0oooo00<0oooo3P00000]0?ooo`030000
003oool0oooo00800000:`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0380oooo
0`0000090?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0;0?ooo`003`3oool00`000000oooo0?ooo`0A0?ooo`X000009@3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0;03oool2000002/0oooo000?
0?ooo`800000703oool6000001h0oooo00<000000?ooo`3oool0;P3oool2000003l0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0X0?ooo`003`3oool300000240oooo1@00000H0?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0a0?oo
o`800000:03oool000l0oooo00<000000?ooo`3oool00P00000T0?ooo`@000004`3oool00`000000
oooo0?ooo`0c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0F0?ooo`8000003@3oool000l0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0U0?ooo`@000003P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0C0?ooo`8000003`3oool000l0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`@000002@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0A0?ooo`8000004@3oool000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0/
0?ooo`<000001P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0>0?ooo`8000004`3oool000l0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0^0?ooo`8000000`3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0:0?oo
o`<000005@3oool000l0oooo0P0000050?ooo`030000003oool0oooo0300oooo0`00000m0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`070?ooo`<0
0000603oool000l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0`0?ooo`<00000
?@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
0`3oool3000001/0oooo000?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`02000003/0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0m0?ooo`030000003oool0oooo00<000007P3oool000l0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0080oooo0P00000j0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool0?P3oool200000240oooo000?0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`050?ooo`800000>03oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo03`0oooo0`00000R0?ooo`003`3oool2000000L0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`070?ooo`800000=P3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo03X0oooo0P0000030?ooo`030000003oool0oooo01l0
oooo000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`090?ooo`800000=03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo03X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`003`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0303oool200000380oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0h0?ooo`8000001P3oool00`000000oooo0?oo
o`0O0?ooo`003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool03P3oool200000340oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0f
0?ooo`8000002@3oool00`000000oooo0?ooo`0N0?ooo`003`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01h0oooo000?0?ooo`800000203oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo0180oooo0P00000^0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool0=03oool2000000`0oooo00<000000?ooo`3oool07P3oool000l0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0N0?ooo`003`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool05@3oool2000002`0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0b0?ooo`8000003`3oool00`000000oooo0?ooo`0N0?ooo`001P3oool4
000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo01L0oooo0P00000Z0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0<03oool2
00000180oooo00<000000?ooo`3oool07@3oool000P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo01d0oooo00080?ooo`030000003oool0oooo00@0
oooo0P00000:0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool06`3oool2000002L0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0]0?ooo`8000005@3oool00`000000
oooo0?ooo`0M0?ooo`00203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool07@3oool000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool07P3oool2000002D0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0[0?ooo`800000603oool00`000000oooo0?oo
o`0M0?ooo`001P3oool3000000H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0M
0?ooo`00203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0Q0?ooo`8000008P3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0L0?oo
o`003`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool09`3oool2000001d0oooo00<000000?ooo`3oool0703oool000l0oooo0P00000;0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01`0oooo000?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0V0?ooo`8000007`3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0L0?ooo`003`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0903oool2
00000280oooo00<000000?ooo`3oool06`3oool000l0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo02T0oooo0P00000L0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
01/0oooo000?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0Q0?ooo`8000009@3oool00`000000oooo0?ooo`0K0?ooo`003`3oool2000000`0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0]0?ooo`8000006P3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0K0?ooo`003`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0;`3oool2000001P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0O0?ooo`800000:03oool00`000000oooo0?ooo`0K0?ooo`003`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool07@3oool2000002/0oooo00<00000
0?ooo`3oool06P3oool000l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo0380oooo0P00000E0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01X0oooo000?0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0J0?ooo`80
0000;P3oool00`000000oooo0?ooo`0J0?ooo`003`3oool2000000d0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0f0?ooo`8000004P3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0J0?ooo`003`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool05`3o
ool200000340oooo00<000000?ooo`3oool06P3oool000l0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03T0oooo0P00000@0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo01X0oooo000?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0k0?ooo`8000003P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
01D0oooo0P00000e0?ooo`030000003oool0oooo01T0oooo000?0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0C0?ooo`800000=`3oool00`000000
oooo0?ooo`0I0?ooo`003`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0?`3oool2000000/0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool06@3oool000l0oooo0P00
000>0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0403oool2000003X0oooo00<0
00000?ooo`3oool06@3oool000l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo0480oooo0P0000080?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool03P3oool2000003`0oooo00<000000?ooo`3oool06@3oool000l0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo04@0oooo0P0000060?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool03@3oool2000003h0oooo00<000000?oo
o`3oool06@3oool000H0oooo100000050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`160?ooo`800000103oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo00/0oooo0P0000100?ooo`030000003oool0oooo01T0oooo00060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo04P0oooo0P0000030?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
2@3oool2000004<0oooo00<000000?ooo`3oool0603oool000L0oooo00<000000?ooo`3oool01@3o
ool2000000h0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1:0?ooo`80000000<0
oooo0000003oool0803oool00`000000oooo0?ooo`070?ooo`800000A@3oool00`000000oooo0?oo
o`0H0?ooo`00203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`1=0?ooo`8000008@3oool00`000000oooo0?ooo`05
0?ooo`800000A`3oool00`000000oooo0?ooo`0H0?ooo`002@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1>0?oo
o`@000007P3oool00`000000oooo0?ooo`020?ooo`<00000B@3oool00`000000oooo0?ooo`0H0?oo
o`001P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`1>0?ooo`040000003oool0oooo0?ooo`<000006`3oool0
0`000000oooo00000002000004`0oooo00<000000?ooo`3oool0603oool000L0oooo0P0000060?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo00@0oooo0P00000I0?ooo`800000C`3oool00`000000oooo0?ooo`0H0?oo
o`003`3oool2000000l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo00H0oooo0`00000C0?ooo`<00000D@3oool00`000000oooo0?ooo`0H0?ooo`00
3`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`080?ooo`T0000000<0oooo0000000000001`0000020?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool05`3oool000l0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403o
ool3000000X0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0G0?ooo`003`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool05`3oool0
00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0500oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo
01L0oooo000?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`1@0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0D03oool00`000000
oooo0?ooo`0G0?ooo`003`3oool200000100oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`1@0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0D03oool00`000000oooo
0?ooo`0G0?ooo`003`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool05`3oool000l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1A
0?ooo`030000003oool0oooo01H0oooo000?0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`0F0?ooo`003`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool05P3oool000l0oooo0P00000@0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool05P3oool000l0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01H0oooo000?0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0F0?ooo`003`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0DP3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool05P3oool000l0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01D0
oooo000?0?ooo`8000004@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01D0oooo
000?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`0E0?ooo`003`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo05<0oooo00<00000
0?ooo`3oool05@3oool000L0oooo0P0000060?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`0E0?ooo`001P3oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0E0?oo
o`002@3oool00`000000oooo0?ooo`030?ooo`8000004P3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo01D0oooo00070?ooo`8000001P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool0503oool000T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0503o
ool000H0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool0503oool000L0oooo0P0000060?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1E0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0D0?ooo`003`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0503oool000l0
oooo0P00000C0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0503oool000l0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01@0oooo
000?0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0C0?ooo`003`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool04`3oool000l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01<0oooo000?0?ooo`8000004`3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01<0oooo000?0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0C0?ooo`003`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool04`3oool000l0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000?0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`003`3oool2000001@0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0B0?ooo`003`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool04P3oool000l0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05T0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0180oooo000?
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0B
0?ooo`003`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool04P3oool000l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo05T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1I0?ooo`03
0000003oool0oooo0180oooo000?0?ooo`8000005@3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo05T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo0180oooo000?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`0B0?ooo`003`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo05/0oooo00<000000?ooo`3oool04@3oool000P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool04@3oool000P0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05/0
oooo00<000000?ooo`3oool04@3oool000D0oooo1@0000050?ooo`8000005@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`1K0?ooo`030000003oool0oooo0140oooo00050?ooo`040000003oool0oooo000000H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05/0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0140oooo
00060?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`1L0?ooo`030000003oool0oooo0140oooo00070?ooo`8000001P3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool04@3oool000P0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0G03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05`0oooo00<000000?oo
o`3oool04@3oool000l0oooo0P00000F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0G03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3o
ool0403oool000l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo05`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1M0?ooo`030000
003oool0oooo0100oooo000?0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo05d0oooo00<000000?ooo`3oool0403oool000l0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo0100oooo000?0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0@0?ooo`003`3oool2000001L0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool03`3oool000l0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00l0oooo000?0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1O0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0?0?oo
o`003`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0G`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3o
ool03`3oool000l0oooo0P00000G0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
G`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0
3`3oool000l0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo05l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1P0?ooo`030000003o
ool0oooo00l0oooo000?0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0H03oool0
0`000000oooo0?ooo`0?0?ooo`003`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0600oooo00<000000?ooo`3oool03`3oool000l0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`1Q0?ooo`030000003oool0oooo00h0oooo000?0?ooo`800000603oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`1Q0?ooo`030000003oool0oooo00h0oooo000?0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0H@3oool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool03P3oool000H0oooo0`0000060?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Q0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0>0?oo
o`002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0HP3oool00`000000oooo0?ooo`0>0?ooo`002@3oool00`000000oooo0?ooo`030?ooo`800000
6@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00h0oooo00060?ooo`<000001P3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0HP3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool03P3o
ool000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo06<0oooo00<000000?ooo`3oool03@3oool000H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool03@3oool000H0
oooo100000050?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`1S0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0I03oool00`000000
oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06@0oooo
00<000000?ooo`3oool03@3oool000l0oooo0P00000I0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0H`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06@0oooo00<0
00000?ooo`3oool03@3oool000l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1T
0?ooo`030000003oool0oooo00d0oooo000?0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0I03oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo06@0oooo00<000000?ooo`3oool03@3oool000l0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00`0oooo000?0?ooo`8000006P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00`0oooo000?0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0<0?ooo`003`3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0IP3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0303oool000l0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo06H0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00`0
oooo000?0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`1V0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo
0?ooo`0<0?ooo`003`3oool2000001/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`1W0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`0<0?ooo`003`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0I`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06H0oooo00<00000
0?ooo`3oool0303oool000l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo06P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1X0?oo
o`030000003oool0oooo00/0oooo000?0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0J03oool00`000000oooo0?ooo`0;0?ooo`003`3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo06P0oooo00<000000?ooo`3oool02`3oool000l0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00/0oooo000?0?ooo`8000007@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`1f0?ooo`003`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
07L0oooo000?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1[0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0M`3oool000L0oooo
0P0000060?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1[0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0M`3oool000H0oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`0L0?ooo`050000003oool0oooo0?ooo`00
0000KP3oool01@000000oooo0?ooo`3oool0000007X0oooo00060?ooo`040000003oool0oooo0000
00D0oooo0P00000N0?ooo`040000003oool0oooo000006l0oooo00@000000?ooo`0000000000NP3o
ool000H0oooo0`0000060?ooo`030000003oool0oooo01d0oooo0`00001`0?ooo`<00000N`3oool0
00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3oool?0?ooo`001`3oool3000000D0oooo
00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool200000?l0oooo403oool00001\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {662.562, 521.25}} -> {-10.0009, \
24.1743, 0.0771421, 0.037822}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.0147151 0.102828 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .11754 -6 -4.5 ]
[.01131 .11754 0 4.5 ]
[.01131 .22037 -6 -4.5 ]
[.01131 .22037 0 4.5 ]
[.01131 .3232 -6 -4.5 ]
[.01131 .3232 0 4.5 ]
[.01131 .42603 -6 -4.5 ]
[.01131 .42603 0 4.5 ]
[.01131 .52886 -6 -4.5 ]
[.01131 .52886 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(10)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(15)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(20)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11754 m
.03006 .11754 L
s
[(1)] .01131 .11754 1 0 Mshowa
.02381 .22037 m
.03006 .22037 L
s
[(2)] .01131 .22037 1 0 Mshowa
.02381 .3232 m
.03006 .3232 L
s
[(3)] .01131 .3232 1 0 Mshowa
.02381 .42603 m
.03006 .42603 L
s
[(4)] .01131 .42603 1 0 Mshowa
.02381 .52886 m
.03006 .52886 L
s
[(5)] .01131 .52886 1 0 Mshowa
.125 Mabswid
.02381 .03528 m
.02756 .03528 L
s
.02381 .05585 m
.02756 .05585 L
s
.02381 .07641 m
.02756 .07641 L
s
.02381 .09698 m
.02756 .09698 L
s
.02381 .13811 m
.02756 .13811 L
s
.02381 .15867 m
.02756 .15867 L
s
.02381 .17924 m
.02756 .17924 L
s
.02381 .19981 m
.02756 .19981 L
s
.02381 .24094 m
.02756 .24094 L
s
.02381 .2615 m
.02756 .2615 L
s
.02381 .28207 m
.02756 .28207 L
s
.02381 .30263 m
.02756 .30263 L
s
.02381 .34377 m
.02756 .34377 L
s
.02381 .36433 m
.02756 .36433 L
s
.02381 .3849 m
.02756 .3849 L
s
.02381 .40546 m
.02756 .40546 L
s
.02381 .44659 m
.02756 .44659 L
s
.02381 .46716 m
.02756 .46716 L
s
.02381 .48772 m
.02756 .48772 L
s
.02381 .50829 m
.02756 .50829 L
s
.02381 .54942 m
.02756 .54942 L
s
.02381 .56999 m
.02756 .56999 L
s
.02381 .59055 m
.02756 .59055 L
s
.02381 .61112 m
.02756 .61112 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01892 m
.02846 .02085 L
.03279 .02339 L
.04262 .03151 L
.0522 .04191 L
.06244 .05675 L
.06788 .06782 L
.07379 .084 L
.07936 .10443 L
.08451 .1284 L
.09425 .18715 L
.10458 .26406 L
.12434 .42159 L
.13298 .48423 L
.14241 .54231 L
.14757 .56752 L
.15009 .57768 L
.15237 .58555 L
.15456 .59186 L
.15694 .59719 L
.15825 .59943 L
.15946 .60105 L
.16061 .6022 L
.16182 .60298 L
.16312 .60332 L
.16431 .60319 L
.16496 .60293 L
.16568 .60251 L
.16697 .60135 L
.16818 .59981 L
.16947 .59771 L
.17178 .59275 L
.17446 .58514 L
.17697 .57629 L
.1827 .55058 L
.19253 .49216 L
.20289 .41754 L
.22139 .26979 L
.23093 .19761 L
.24113 .13393 L
.24608 .10979 L
.25075 .09124 L
.25527 .0769 L
.2595 .06624 L
.26413 .05697 L
.26922 .04884 L
.27951 .03618 L
.28841 .02757 L
.29304 .02398 L
.29796 .02099 L
Mistroke
.30072 .01972 L
.30322 .01881 L
.30573 .01812 L
.3081 .01765 L
.30944 .01746 L
.31086 .01729 L
.31207 .01718 L
.3134 .0171 L
.31484 .01703 L
.31564 .017 L
.31637 .01698 L
.31779 .01695 L
.31914 .01693 L
.32157 .01689 L
.3228 .01687 L
.32415 .01683 L
.3253 .01679 L
.32654 .01674 L
.32877 .01662 L
.33144 .01643 L
.33424 .01617 L
.33924 .01566 L
.34161 .01542 L
.34417 .01518 L
.34642 .01502 L
.34766 .01494 L
.34881 .01489 L
.35014 .01484 L
.35084 .01482 L
.3516 .0148 L
.35229 .0148 L
.35294 .01479 L
.35416 .0148 L
.35537 .01481 L
.35649 .01484 L
.35772 .01487 L
.35902 .01492 L
.36322 .01512 L
.36543 .01523 L
.36775 .01533 L
.36899 .01537 L
.36965 .01539 L
.37035 .01541 L
.37158 .01543 L
.37273 .01544 L
.37399 .01545 L
.37518 .01544 L
.37624 .01542 L
.3774 .0154 L
.38234 .0152 L
Mistroke
.38507 .01507 L
.38765 .01495 L
.38882 .0149 L
.39005 .01486 L
.39076 .01484 L
.39141 .01482 L
.39267 .0148 L
.3938 .01479 L
.39503 .0148 L
.39619 .01482 L
.39725 .01484 L
.39845 .01489 L
.39958 .01494 L
.40212 .01511 L
.40727 .01558 L
.41255 .01613 L
.41533 .01639 L
.41829 .01661 L
.42087 .01675 L
.42234 .01681 L
.42372 .01685 L
.42499 .01688 L
.42614 .0169 L
.42875 .01694 L
.42987 .01696 L
.43106 .01699 L
.43236 .01703 L
.43358 .01708 L
.43495 .01717 L
.43624 .01728 L
.4374 .01741 L
.43866 .01758 L
.44089 .01799 L
.44335 .01862 L
.44592 .01949 L
.44832 .02053 L
.45261 .02294 L
.45722 .02627 L
.46736 .03582 L
.47271 .04191 L
.47841 .04945 L
.48388 .05843 L
.48884 .06888 L
.49383 .08251 L
.49851 .09894 L
.50831 .14638 L
.51865 .21473 L
.53714 .36106 L
.54737 .44058 L
.55705 .50768 L
Mistroke
.56574 .55676 L
.57065 .57787 L
.57299 .5859 L
.57518 .59213 L
.57736 .597 L
.57848 .59898 L
.5797 .60072 L
.58039 .60151 L
.58103 .60212 L
.5823 .60296 L
.58345 .6033 L
.58467 .60323 L
.58598 .60265 L
.58672 .6021 L
.58739 .60145 L
.58864 .59989 L
.58995 .59776 L
.59224 .59288 L
.59474 .58585 L
.59997 .56604 L
.60557 .53805 L
.61568 .47421 L
.63548 .3215 L
.64592 .23835 L
.65703 .16059 L
.66686 .10864 L
.67246 .08714 L
.67771 .07174 L
.68252 .06095 L
.68692 .0531 L
.69686 .03971 L
.70666 .02957 L
.71134 .0256 L
.71577 .02252 L
.71829 .02109 L
.72101 .01981 L
.72328 .01896 L
.72578 .01824 L
.72848 .01768 L
.72996 .01746 L
.73134 .0173 L
.73263 .01718 L
.73381 .0171 L
.73446 .01707 L
.73518 .01704 L
.73647 .01699 L
.75617 .01603 L
.76149 .01548 L
.7644 .01521 L
.76711 .015 L
Mistroke
.7683 .01494 L
.76942 .01488 L
.77072 .01484 L
.7719 .01481 L
.77321 .01479 L
.77442 .01479 L
.77505 .0148 L
.77575 .01481 L
.77647 .01482 L
.77716 .01484 L
.77975 .01493 L
.78212 .01504 L
.78746 .0153 L
.78872 .01535 L
.79005 .01539 L
.79082 .01541 L
.79152 .01542 L
.79223 .01543 L
.79289 .01544 L
.79358 .01545 L
.79432 .01545 L
.79563 .01544 L
.79636 .01543 L
.79704 .01542 L
.7986 .01538 L
.80328 .01518 L
.80826 .01494 L
.80951 .01489 L
.81085 .01485 L
.81162 .01483 L
.81233 .01481 L
.81301 .0148 L
.81372 .01479 L
.81497 .01479 L
.81613 .0148 L
.81741 .01483 L
.81813 .01486 L
.81878 .01488 L
.82135 .01502 L
.8228 .01512 L
.82414 .01523 L
.82921 .01573 L
.83391 .01622 L
.83641 .01644 L
.8391 .01663 L
.84034 .0167 L
.84152 .01676 L
.84268 .0168 L
.84374 .01684 L
.84583 .01688 L
Mistroke
.84693 .0169 L
.8481 .01692 L
.84934 .01694 L
.85068 .01696 L
.85194 .017 L
.8531 .01704 L
.85416 .01709 L
.85531 .01716 L
.85652 .01726 L
.85764 .01738 L
.8589 .01754 L
.86024 .01776 L
.86265 .01829 L
.86524 .01906 L
.8681 .02019 L
.8732 .02299 L
.878 .02648 L
.88693 .03483 L
.89656 .04616 L
.90119 .05292 L
.90613 .06179 L
.91156 .07447 L
.9166 .08998 L
.92229 .11273 L
.92766 .1398 L
.93771 .20418 L
.97618 .49875 L
.97619 .49882 L
Mfstroke
.02381 .01628 m
.04262 .01691 L
.06244 .01784 L
.10458 .02064 L
.14264 .02393 L
.16385 .02608 L
.18314 .02834 L
.22214 .03442 L
.24128 .03855 L
.26207 .0442 L
.30293 .0595 L
.34228 .07953 L
.38012 .10259 L
.42041 .12919 L
.45918 .15481 L
.5004 .18045 L
.54011 .20222 L
.57831 .21893 L
.59798 .22533 L
.6089 .22812 L
.61895 .23016 L
.62924 .23171 L
.63465 .23229 L
.63741 .23253 L
.64036 .23274 L
.64296 .23289 L
.64534 .23299 L
.64648 .23302 L
.64772 .23305 L
.64889 .23308 L
.64998 .23309 L
.65123 .2331 L
.65241 .2331 L
.6537 .23309 L
.65443 .23308 L
.6551 .23307 L
.65636 .23304 L
.65774 .233 L
.66053 .23288 L
.66307 .23274 L
.66582 .23255 L
.67081 .23209 L
.67567 .23152 L
.68014 .23088 L
.69032 .22904 L
.70109 .22651 L
.72067 .22053 L
.73898 .21346 L
.77781 .19472 L
.81908 .17076 L
Mistroke
.85884 .14528 L
.89709 .11981 L
.93779 .09345 L
.97619 .07132 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00CP3oool3000003X0oooo100000030?ooo`800000>03oool400000080
oooo0`00000h0?ooo`@000000`3oool2000000X0oooo001A0?ooo`030000003oool0oooo03T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000002@3oool00540oooo00<000000?ooo`3oool0>@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000090?ooo`00CP3oool30000
03`0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03L0oooo00@00000
0?ooo`3oool0oooo0`00000j0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`070?ooo`00CP3oool00`000000oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0g0?ooo`050000003oool0oooo0?ooo`000000?@3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo001>0?ooo`030000003oool0oooo03X0
oooo0`0000030?ooo`040000003oool0oooo000003L0oooo0`0000030?ooo`030000003oool0oooo
03P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`003`3oool0
0`000000oooo0?ooo`0l0?ooo`@00000>`3oool00`000000oooo0?ooo`020?ooo`800000>P3oool0
10000000oooo0?ooo`3oool4000003P0oooo0P0000040?ooo`8000002P3oool000l0oooo00<00000
0?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`03
0000003oool0oooo0?l0oooo3`3oool000P0ooooo`00000C000000H0oooo000?0?ooo`030000003o
ool0oooo00h000002@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`P00000203oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0080oooo2@00000<0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool01P3oool7000000X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0000
000800000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo000?0?ooo`<000003P3ooolC000001d0oooo00<000000?ooo`3oool01@3oool2
000002P0oooo0`00000;0?ooo`030000003oool0oooo03P0oooo0P0000040?ooo`030000003oool0
oooo0280oooo0P00000J0?ooo`030000003oool0oooo00/0oooo000?0?ooo`040000003oool0oooo
00000200oooo1@00000O0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02D0oooo000?0?ooo`050000003oool0oooo
0?ooo`000000903oool8000001H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0903oool000l0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0Y0?ooo`P000003@3oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0S0?oo
o`003`3oool2000000@0oooo00<000000?ooo`3oool0<03oool4000000P0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool08P3oool000l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0c0?ooo`<00000
103oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0Q0?ooo`003`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo03D0oooo0`0000000`3oool000000?ooo`0e0?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0Q0?ooo`003`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo03L0oooo0`00000f0?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`0P0?ooo`003`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo03H0oooo00@000000?ooo`3oool0oooo0P00000d0?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0O0?ooo`003`3oool20000
00P0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`040?ooo`<00000<P3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool07`3oool000l0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00L0
oooo0P00000`0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`0N0?ooo`003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0380oooo
00<000000?ooo`3oool02P3oool2000002h0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo01h0oooo000?0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0<0?ooo`800000;@3oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool07@3oool000l0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`003`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool0403oool2000002/0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00`0oooo0P00000>0?oo
o`003`3oool2000000/0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0B0?ooo`80
0000:@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool02P3oool200000100oooo000?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
403oool000l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo01H0oooo0P00000W0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`060?ooo`8000004`3oool000l0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01P0oooo0P00000U0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`040?ooo`8000005@3oool0
00l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
01/0oooo0P00000T0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo000?0?ooo`800000303oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo01d0oooo0P00000R0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`02000001P0oooo000?0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0O0?ooo`800000
803oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0440oooo00<000000?ooo`000000
6P3oool000l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo0480oooo0P00000K0?ooo`003`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool08`3oool2000001d0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`110?ooo`800000703oool000H0oooo100000050?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`100?ooo`040000003oool0oooo
000001/0oooo00080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo02H0oooo0P00000K0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0?`3oool01@000000oooo0?ooo`3oool0000001/0oooo00080?oo
o`030000003oool0oooo00@0oooo0P00000>0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0:03oool2000001T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0m0?oo
o`800000103oool00`000000oooo0?ooo`0I0?ooo`00203oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool000P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
;03oool2000001L0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0k0?ooo`800000
1`3oool00`000000oooo0?ooo`0I0?ooo`001P3oool3000000H0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0H0?ooo`00203oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0_0?ooo`800000503oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo03P0oooo0P00000;0?ooo`030000003oool0
oooo01P0oooo000?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0f0?ooo`8000003@3oool00`000000oooo0?ooo`0H0?ooo`003`3oool2000000l0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0b0?ooo`8000004P3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0H0?ooo`003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0=03oool200000100oooo00<000000?ooo`3oool0603oool000l0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0H0?ooo`003`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0=`3oool2000000h0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0a0?ooo`800000503oool00`000000oooo0?ooo`0G
0?ooo`003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0>@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01L0oooo000?0?ooo`80
0000403oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03X0oooo0P00000;0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0;`3oool2000001L0oooo00<000000?ooo`3o
ool05`3oool000l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo03`0oooo0P00000:0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
;@3oool2000001T0oooo00<000000?ooo`3oool05`3oool000l0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03h0oooo0P0000080?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01L0oooo000?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0Z0?ooo`800000703oool00`000000oooo0?ooo`0G0?ooo`003`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0@P3oool20000
00D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool05P3oool000l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo04@0oooo0P0000030?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0:03oool200000200oooo00<000000?ooo`3oool05P3oool000l0oooo
0P00000A0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0AP3oool010000000oooo
0?ooo`00000U0?ooo`030000003oool0oooo02H0oooo0P00000R0?ooo`030000003oool0oooo01H0
oooo000?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`170?ooo`80000000<0oooo0000003oool08`3oool00`000000oooo0?ooo`0T0?ooo`800000
903oool00`000000oooo0?ooo`0F0?ooo`003`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0B@3oool2000002@0oooo00<000000?ooo`3oool08P3o
ool2000002H0oooo00<000000?ooo`3oool05P3oool000l0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo04/0oooo0P00000S0?ooo`030000003oool0
oooo0200oooo0P00000X0?ooo`030000003oool0oooo01H0oooo000?0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1;0?ooo`040000003oool00000
00000240oooo00<000000?ooo`3oool07P3oool2000002/0oooo00<000000?ooo`3oool05@3oool0
00l0oooo0P00000A0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0B`3oool01000
0000oooo0?ooo`3oool2000001l0oooo00<000000?ooo`3oool0703oool2000002d0oooo00<00000
0?ooo`3oool05@3oool000l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo04/0oooo00<000000?ooo`3oool00`3oool2000001`0oooo00<000000?oo
o`3oool06`3oool2000002l0oooo00<000000?ooo`3oool05@3oool000l0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0103oool2000001X0oooo00<000000?ooo`3oool06@3oool200000340oooo00<000000?ooo`3o
ool05@3oool000l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo04`0oooo00<000000?ooo`3oool01P3oool2000001P0oooo00<000000?ooo`3oool0
5`3oool2000003<0oooo00<000000?ooo`3oool05@3oool000H0oooo100000050?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo00P0oooo0P00000F0?ooo`030000003oool0oooo01D0oooo0P00000e0?ooo`030000003o
ool0oooo01D0oooo00060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool02P3oool2
000001@0oooo00<000000?ooo`3oool04`3oool2000003L0oooo00<000000?ooo`3oool05@3oool0
00L0oooo00<000000?ooo`3oool01@3oool200000180oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`1=0?ooo`030000003oool0oooo00`0oooo1000000@0?ooo`030000003oool0oooo
0100oooo0`00000j0?ooo`030000003oool0oooo01@0oooo00080?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool0403oool4000000`0oooo00<000000?ooo`3oool03@3oool3000003d0
oooo00<000000?ooo`3oool0503oool000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo
0?ooo`0D0?ooo`<00000203oool00`000000oooo0?ooo`080?ooo`H00000@03oool00`000000oooo
0?ooo`0D0?ooo`001P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo01H0oooo
2@0000020?ooo`P00000AP3oool00`000000oooo0?ooo`0D0?ooo`001`3oool2000000H0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool07P3oool4000004d0oooo00<000000?ooo`3oool0503oool000l0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo01@0oooo000?0?oo
o`8000004`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo01@0oooo000?0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0D0?ooo`00
3`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
4`3oool000l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo01<0oooo000?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0D03oool0
0`000000oooo0?ooo`0C0?ooo`003`3oool2000001@0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`1A0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0D03oool00`00
0000oooo0?ooo`0C0?ooo`003`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0500
oooo00<000000?ooo`3oool04`3oool000l0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`1@0?ooo`030000003oool0oooo01<0oooo000?0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`0C0?ooo`003`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool04`3oool000l0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0540oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0180oooo000?0?ooo`80
00005@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0180oooo000?0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1A0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0B0?ooo`003`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0D`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04P3o
ool000l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo05<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0
oooo0180oooo000?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0DP3oool00`00
0000oooo0?ooo`0B0?ooo`003`3oool2000001D0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0DP3oool00`000000
oooo0?ooo`0B0?ooo`003`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0580oooo
00<000000?ooo`3oool04P3oool000l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo0140oooo000?0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`001`3oool2000000H0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo00060?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo05D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo0140oooo00090?ooo`030000003oool0oooo00<0oooo0P00000F0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool000L0oooo0P0000060?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1E0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`002@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`0A0?ooo`001P3oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`001`3oool2
000000H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1E0?ooo`030000003oool0
oooo0100oooo000?0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0@0?ooo`003`3oool2000001L0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool0403oool000l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo0100oooo000?0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool0403oool000l0oooo0P00000G0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool0403oool000l0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00l0oooo000?0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0?0?ooo`003`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool03`3oool0
00l0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
00l0oooo000?0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0?0?ooo`003`3oool2000001P0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`1I0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0?0?ooo`003`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0F@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool03`3oool000l0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo00l0oooo000?0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool03P3oool000l0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00h0oooo000?0?ooo`8000006@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00h0oooo000?0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0>0?ooo`003`3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool03P3oool000P0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05X0
oooo00<000000?ooo`3oool03P3oool000P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0F`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool03P3oool000D0oooo1@00
00050?ooo`8000006@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05/0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00d0oooo0005
0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`1L0?ooo`030000003oool0oooo00d0oooo00060?ooo`030000003oool0000000H0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05/0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00d0oooo00070?oo
o`8000001P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0F`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05`0oooo00<000000?oo
o`3oool03@3oool000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo05`0oooo00<000000?ooo`3oool03@3oool000l0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00d0oooo000?0?ooo`8000006P3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00d0oooo000?0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1M0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0303oool000l0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05d0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00`0
oooo000?0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`1M0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0GP3oool00`000000oooo
0?ooo`0<0?ooo`003`3oool2000001X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`1M0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`0<0?ooo`003`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0G@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05h0oooo00<00000
0?ooo`3oool0303oool000l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo05h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1N0?oo
o`030000003oool0oooo00`0oooo000?0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`0<0?ooo`003`3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool0303oool000l0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00/0oooo000?0?ooo`8000006`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00/0oooo000?0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0;0?ooo`003`3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool02`3oool000l0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0600oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1P0?ooo`800000303oool000l0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0640oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`1^0?ooo`003`3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo06h0oooo000?0?ooo`800000703oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0640oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1_0?oo
o`003`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0H@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo06l0oooo000?0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1Q0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0K`3oool000H0oooo0`0000060?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1R0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0K`3oool000T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0H`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo06l0oooo00090?ooo`030000003oool0oooo
00<0oooo0P00000M0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo06l0oooo00060?ooo`<000001P3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0H`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0700oooo00060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1`0?ooo`001P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`1S0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0L03oool000H0oooo10000005
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1T
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0L03oool000l0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06D0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`1`0?ooo`003`3oool2000001h0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0L03oool000l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo06D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1a0?ooo`003`3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0IP3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0740oooo000?0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0L@3oool000l0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`1a0?ooo`003`3oool2000001l0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0L@3oool000l0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1b0?ooo`003`3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0780oooo000?0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0LP3oool000l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo06T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?oo
o`003`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0J@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07<0oooo000?0?ooo`800000
8@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1c0?ooo`003`3oool00`000000oooo0?ooo`0Q0?ooo`050000003o
ool0oooo0?ooo`000000KP3oool01@000000oooo0?ooo`3oool0000007D0oooo000?0?ooo`030000
003oool0oooo0240oooo00@000000?ooo`3oool00000K`3oool010000000oooo0?ooo`00001f0?oo
o`003`3oool00`000000oooo0?ooo`0R0?ooo`<00000K`3oool4000007H0oooo000?0?ooo`030000
003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool2
00000?l0oooo403oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`00\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {216.5, 75.1875}} -> {-10.0009, \
2.91444, 0.0771421, 0.035724}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.0147151 0.108754 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .12347 -6 -4.5 ]
[.01131 .12347 0 4.5 ]
[.01131 .23222 -6 -4.5 ]
[.01131 .23222 0 4.5 ]
[.01131 .34098 -6 -4.5 ]
[.01131 .34098 0 4.5 ]
[.01131 .44973 -6 -4.5 ]
[.01131 .44973 0 4.5 ]
[.01131 .55849 -6 -4.5 ]
[.01131 .55849 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(10)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(15)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(20)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .12347 m
.03006 .12347 L
s
[(1)] .01131 .12347 1 0 Mshowa
.02381 .23222 m
.03006 .23222 L
s
[(2)] .01131 .23222 1 0 Mshowa
.02381 .34098 m
.03006 .34098 L
s
[(3)] .01131 .34098 1 0 Mshowa
.02381 .44973 m
.03006 .44973 L
s
[(4)] .01131 .44973 1 0 Mshowa
.02381 .55849 m
.03006 .55849 L
s
[(5)] .01131 .55849 1 0 Mshowa
.125 Mabswid
.02381 .03647 m
.02756 .03647 L
s
.02381 .05822 m
.02756 .05822 L
s
.02381 .07997 m
.02756 .07997 L
s
.02381 .10172 m
.02756 .10172 L
s
.02381 .14522 m
.02756 .14522 L
s
.02381 .16697 m
.02756 .16697 L
s
.02381 .18872 m
.02756 .18872 L
s
.02381 .21047 m
.02756 .21047 L
s
.02381 .25397 m
.02756 .25397 L
s
.02381 .27573 m
.02756 .27573 L
s
.02381 .29748 m
.02756 .29748 L
s
.02381 .31923 m
.02756 .31923 L
s
.02381 .36273 m
.02756 .36273 L
s
.02381 .38448 m
.02756 .38448 L
s
.02381 .40623 m
.02756 .40623 L
s
.02381 .42798 m
.02756 .42798 L
s
.02381 .47148 m
.02756 .47148 L
s
.02381 .49323 m
.02756 .49323 L
s
.02381 .51498 m
.02756 .51498 L
s
.02381 .53674 m
.02756 .53674 L
s
.02381 .58024 m
.02756 .58024 L
s
.02381 .60199 m
.02756 .60199 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01808 m
.02605 .01818 L
.02729 .01825 L
.02846 .01834 L
.02954 .01844 L
.03072 .01857 L
.03279 .01887 L
.03397 .0191 L
.03527 .0194 L
.0379 .0202 L
.04033 .02119 L
.04262 .02236 L
.04761 .0258 L
.05217 .02998 L
.06244 .04241 L
.07277 .05837 L
.07823 .06884 L
.08405 .08282 L
.08963 .10029 L
.09469 .12057 L
.10458 .1742 L
.12545 .33373 L
.1346 .40706 L
.14465 .47921 L
.15369 .53303 L
.15867 .55714 L
.16339 .57581 L
.16596 .5841 L
.16875 .59151 L
.17129 .59674 L
.1725 .59871 L
.17363 .60025 L
.17478 .60149 L
.17584 .60235 L
.17701 .60299 L
.17827 .60331 L
.17942 .60326 L
.18067 .60285 L
.18198 .60201 L
.1832 .60086 L
.18447 .59927 L
.18582 .59718 L
.18825 .59236 L
.19085 .58569 L
.19372 .57668 L
.20365 .5331 L
.21326 .47562 L
.22224 .41105 L
.24082 .26113 L
.25062 .18833 L
Mistroke
.26107 .12797 L
.26683 .10356 L
.27205 .08638 L
.28224 .06263 L
.28722 .05392 L
.2926 .04568 L
.30234 .03305 L
.30695 .02826 L
.31187 .02419 L
.3147 .02238 L
.31728 .02107 L
.31987 .02006 L
.32232 .01934 L
.32487 .01882 L
.32615 .01863 L
.32757 .01846 L
.32878 .01835 L
.33008 .01825 L
.33242 .01812 L
.3434 .01748 L
.35292 .01624 L
.35815 .01551 L
.36072 .01523 L
.36308 .01503 L
.36445 .01495 L
.36514 .01492 L
.36589 .01489 L
.36665 .01487 L
.36746 .01486 L
.36823 .01485 L
.36893 .01485 L
.37023 .01487 L
.37097 .01488 L
.37165 .0149 L
.3729 .01495 L
.37423 .01502 L
.37921 .01532 L
.38183 .01548 L
.38326 .01556 L
.38459 .01561 L
.38576 .01565 L
.38701 .01568 L
.38772 .01569 L
.3884 .0157 L
.38966 .0157 L
.39082 .01568 L
.39189 .01566 L
.39306 .01562 L
.39431 .01557 L
.39866 .01532 L
Mistroke
.40344 .01503 L
.40483 .01496 L
.40615 .01491 L
.40733 .01487 L
.40862 .01485 L
.40936 .01485 L
.41002 .01485 L
.41079 .01486 L
.41151 .01488 L
.4128 .01492 L
.41353 .01496 L
.4142 .01499 L
.41653 .01517 L
.41909 .01544 L
.42427 .01614 L
.42947 .01689 L
.43222 .01724 L
.43514 .01754 L
.43768 .01775 L
.44048 .01791 L
.44306 .01802 L
.44543 .01812 L
.44776 .01825 L
.44893 .01834 L
.45022 .01845 L
.45151 .0186 L
.45289 .0188 L
.45538 .0193 L
.45658 .01962 L
.45789 .02002 L
.46027 .02093 L
.46471 .02332 L
.4694 .02688 L
.47455 .03196 L
.48497 .04524 L
.49462 .06075 L
.50364 .08037 L
.50863 .09508 L
.51406 .11556 L
.52394 .167 L
.53357 .23389 L
.54248 .30516 L
.56133 .45309 L
.57124 .51672 L
.57665 .54538 L
.58169 .56757 L
.58703 .58571 L
.58985 .59286 L
.5913 .59583 L
.59288 .59851 L
Mistroke
.59431 .60045 L
.59495 .60114 L
.59564 .6018 L
.59691 .6027 L
.59761 .60302 L
.59826 .60322 L
.59949 .60332 L
.60061 .60308 L
.60192 .60243 L
.60315 .60143 L
.60442 .60002 L
.60557 .59841 L
.60816 .59368 L
.61055 .58794 L
.6128 .58139 L
.61786 .56286 L
.62334 .53739 L
.64327 .40709 L
.66433 .23763 L
.6738 .17098 L
.67902 .14084 L
.68396 .11714 L
.68855 .09921 L
.69355 .0836 L
.70229 .06351 L
.71168 .04777 L
.72206 .03397 L
.72727 .02844 L
.73 .02601 L
.73289 .02384 L
.73542 .02227 L
.73819 .02089 L
.74071 .01995 L
.74306 .01929 L
.74433 .01901 L
.74568 .01877 L
.74811 .01846 L
.74945 .01834 L
.75071 .01825 L
.75358 .0181 L
.75624 .01798 L
.75876 .01786 L
.76103 .01772 L
.76351 .01752 L
.76816 .01699 L
.77247 .01638 L
.77748 .01566 L
.77968 .01539 L
.78209 .01515 L
.78329 .01506 L
Mistroke
.78457 .01497 L
.78528 .01494 L
.78592 .01491 L
.78718 .01487 L
.78789 .01486 L
.78854 .01485 L
.78925 .01485 L
.79001 .01485 L
.79128 .01488 L
.792 .0149 L
.79268 .01492 L
.79519 .01504 L
.79748 .01518 L
.80016 .01535 L
.80265 .0155 L
.80474 .0156 L
.80592 .01564 L
.80698 .01567 L
.80815 .01569 L
.80942 .0157 L
.81062 .01569 L
.81172 .01567 L
.81286 .01565 L
.81393 .01561 L
.81636 .01549 L
.82126 .01519 L
.82368 .01504 L
.82501 .01497 L
.82625 .01492 L
.82695 .0149 L
.82759 .01488 L
.82831 .01486 L
.82908 .01485 L
.83035 .01485 L
.83099 .01486 L
.83169 .01487 L
.83299 .01491 L
.83416 .01496 L
.83552 .01505 L
.83681 .01515 L
.84158 .01569 L
.86013 .01786 L
.86513 .01809 L
.86639 .01815 L
.86758 .01821 L
.86983 .01837 L
.87095 .01848 L
.87218 .01862 L
.87472 .01904 L
.87607 .01935 L
Mistroke
.87751 .01974 L
.88011 .02065 L
.8825 .02174 L
.88509 .02323 L
.88978 .02676 L
.89855 .036 L
.90806 .04904 L
.91849 .06725 L
.92375 .07933 L
.92939 .09592 L
.93471 .11616 L
.93956 .13916 L
.95711 .25747 L
.97619 .41141 L
Mfstroke
.02381 .01596 m
.03279 .016 L
.04262 .01605 L
.04758 .01608 L
.05288 .01612 L
.06244 .01623 L
.06788 .01631 L
.07379 .01642 L
.08451 .01667 L
.09494 .017 L
.10458 .01738 L
.12331 .01835 L
.14393 .01977 L
.18422 .02351 L
.22299 .02804 L
.26421 .03403 L
.28481 .03783 L
.30392 .04212 L
.34212 .05374 L
.36264 .062 L
.38125 .07078 L
.42131 .09347 L
.45986 .11864 L
.50087 .14629 L
.54035 .17143 L
.57833 .19275 L
.61875 .21139 L
.63739 .21831 L
.65766 .22448 L
.66869 .22718 L
.6789 .22925 L
.68865 .23083 L
.69406 .23152 L
.69902 .23205 L
.70349 .23244 L
.70839 .23276 L
.71094 .23289 L
.71331 .23298 L
.7146 .23302 L
.71581 .23305 L
.71649 .23306 L
.71722 .23307 L
.71849 .23309 L
.71963 .2331 L
.72069 .2331 L
.72186 .2331 L
.72311 .23309 L
.72442 .23307 L
.72567 .23304 L
.728 .23298 L
Mistroke
.73018 .2329 L
.7322 .23281 L
.73677 .23253 L
.74186 .23211 L
.74736 .23153 L
.75733 .23015 L
.76704 .2284 L
.77595 .22645 L
.81549 .21421 L
.85352 .1976 L
.89399 .17566 L
.93295 .15133 L
.97437 .12353 L
.97619 .12229 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400000o`00o`00o`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00CP3oool3000003X0oooo100000030?ooo`800000>03oool400000080
oooo0`00000h0?ooo`@000000`3oool2000000X0oooo001A0?ooo`030000003oool0oooo03T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000002@3oool00540oooo00<000000?ooo`3oool0>@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000090?ooo`00CP3oool30000
03`0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03L0oooo00@00000
0?ooo`3oool0oooo0`00000j0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`070?ooo`00CP3oool00`000000oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0g0?ooo`050000003oool0oooo0?ooo`000000?@3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo001>0?ooo`030000003oool0oooo03X0
oooo0`0000030?ooo`040000003oool0oooo000003L0oooo0`0000030?ooo`030000003oool0oooo
03P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000090?ooo`003`3oool0
0`000000oooo0?ooo`0l0?ooo`@00000>`3oool00`000000oooo0?ooo`020?ooo`800000>P3oool0
10000000oooo0?ooo`3oool4000003P0oooo0P0000040?ooo`8000002P3oool000l0oooo00<00000
0?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`03
0000003oool0oooo0?l0oooo3`3oool000P0ooooo`00000C000000H0oooo000?0?ooo`@000002@3o
ool00`000000oooo0000000F000000030?ooo`000000oooo00/0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000L000000`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00@0oooo2@00000:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool:000000<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`030?ooo`P00000303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo000?
0?ooo`040000003oool0oooo0?ooo`800000803oool8000001<0oooo00<000000?ooo`3oool02`3o
ool2000002H0oooo0P0000080?ooo`030000003oool0oooo03d0oooo0P00000V0?ooo`<000005`3o
ool00`000000oooo0?ooo`0;0?ooo`003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo02D0oooo1P00000J0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0280oooo000?0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0:P3oool800000140oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool08@3oool000l0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0a0?ooo`T000001`3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0Q0?ooo`003`3oool2000000L0oooo00<000000?ooo`3oool0>@3oool5000000030?oo
o`000000oooo02l0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0200oooo000?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0?P3o
ool4000002h0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo01l0oooo000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`020?ooo`800000;@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool07P3oool000l0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo00D0oooo0`00000[0?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0M0?ooo`003`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0203oool2000002T0
oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01`0
oooo000?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0;0?ooo`<000009`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool0703oool000l0oooo0P00000;0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool03P3oool3000002@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo01/0oooo000?0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`0B0?ooo`<000008P3oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool06`3oool000l0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01D0oooo0P00000P0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0J0?oo
o`003`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0603oool2000001l0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo01X0oooo000?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0J0?ooo`8000007@3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool06@3oool000l0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01d0oooo0P00000L0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0I0?ooo`003`3oool2
000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0O0?ooo`8000006P3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool06@3oool0
00l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
0280oooo0P00000I0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0H0?ooo`003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0903oool2000001L0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0m0?ooo`030000003oool0oooo01P0oooo000?0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01L0oooo
000?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0W0?ooo`8000005@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool05`3oool000l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool05`3oool000l0oooo0P00000@0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool0:`3oool200000180oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01L0oooo000?0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`80
00004@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool05P3oool000l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool05P3oool000l0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0340oooo0P00000>0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0F0?ooo`001P3oool4
000000D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool05P3oool000P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0=03oool20000
00/0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool02`3oool000P0oooo00<000000?ooo`3oool0103oool200000140
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool02`3oool000P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`050?ooo`8000003P3oool000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0>@3oool2000000P0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03P3oool000H0oooo0`0000060?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0080oooo0P00000A
0?ooo`00203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo008000004`3oool000l0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo03h0
oooo0P0000050?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0000000E0?ooo`003`3oool2000001<0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`140?ooo`8000005P3oool000l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo0440oooo0P0000020?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0@`3oool2000001L0oooo000?0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`130?ooo`030000003oool0000002X0oooo00<00000
0?ooo`3oool0@@3oool200000080oooo00<000000?ooo`3oool0503oool000l0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo04@0oooo0`00000X0?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0D0?oo
o`003`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03l0oooo0P0000050?ooo`03
0000003oool0oooo01@0oooo000?0?ooo`800000503oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo04L0oooo0P00000W0?ooo`030000003oool0oooo03d0oooo0P0000070?ooo`030000
003oool0oooo01@0oooo000?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`170?ooo`040000003oool00000000002D0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01@0oooo000?0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`170?ooo`050000003o
ool0oooo0?ooo`000000903oool00`000000oooo0?ooo`0j0?ooo`8000002P3oool00`000000oooo
0?ooo`0D0?ooo`003`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`020?ooo`8000008P3oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04`3oool000l0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool00`3oool200000200oooo00<000000?ooo`3oool0=`3oool2000000h0oooo00<00000
0?ooo`3oool04`3oool000l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo04T0oooo00<000000?ooo`3oool01@3oool2000001h0oooo00<000000?oo
o`3oool0=@3oool200000100oooo00<000000?ooo`3oool04`3oool000l0oooo0P00000D0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`070?ooo`80
00006`3oool00`000000oooo0?ooo`0d0?ooo`8000004P3oool00`000000oooo0?ooo`0C0?ooo`00
3`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`090?ooo`8000006@3oool00`000000oooo0?ooo`0b0?ooo`800000
503oool00`000000oooo0?ooo`0C0?ooo`003`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0;0?ooo`8000005`3o
ool00`000000oooo0?ooo`0`0?ooo`8000005P3oool00`000000oooo0?ooo`0C0?ooo`003`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`0=0?ooo`8000005@3oool00`000000oooo0?ooo`0^0?ooo`8000006@3oool0
0`000000oooo0?ooo`0B0?ooo`003`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0>0?ooo`8000004`3oool00`00
0000oooo0?ooo`0[0?ooo`<000006`3oool00`000000oooo0?ooo`0B0?ooo`003`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0BP3oool00`000000
oooo0?ooo`0@0?ooo`8000004@3oool00`000000oooo0?ooo`0Y0?ooo`8000007P3oool00`000000
oooo0?ooo`0B0?ooo`003`3oool2000001D0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo0180oooo0P00000>0?ooo`030000003oool0oooo02L0oooo
0`00000P0?ooo`030000003oool0oooo0180oooo000?0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo01@0oooo1000
000:0?ooo`030000003oool0oooo02@0oooo0`00000S0?ooo`030000003oool0oooo0180oooo000?
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo01P0oooo100000060?ooo`030000003oool0oooo0280oooo0P00000V
0?ooo`030000003oool0oooo0180oooo000?0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo01`0oooo0P0000040?oo
o`030000003oool0oooo01l0oooo0`00000X0?ooo`030000003oool0oooo0180oooo00060?ooo`@0
00001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0C03oool00`000000oooo0?ooo`0M0?ooo`<0000000<0oooo0000003oool07P3oool2000002`0
oooo00<000000?ooo`3oool04@3oool000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0C03oool00`000000oooo
0?ooo`0P0?ooo`H000005@3oool6000002h0oooo00<000000?ooo`3oool04@3oool000L0oooo00<0
00000?ooo`3oool01@3oool2000001H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`1<0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00`3oool9000000<0oooo2@00
000d0?ooo`030000003oool0oooo0140oooo00080?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo04`0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0;0?ooo`@00000?@3oool00`000000oooo0?ooo`0A
0?ooo`002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`0A0?ooo`001P3oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0A0?oo
o`001`3oool2000000H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1=0?ooo`03
0000003oool0oooo0100oooo000?0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`0@0?ooo`003`3oool2000001L0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo04h0oooo00<000000?ooo`3oool0403oool000l0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000?0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`003`3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool000l0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000?
0?ooo`8000005`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00l0oooo000?0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0?0?oo
o`003`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool03`3oool000l0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo00l0oooo000?0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0D03o
ool00`000000oooo0?ooo`0?0?ooo`003`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo0500oooo00<000000?ooo`3oool03`3oool000l0oooo0P00000H0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0500oooo00<000000?ooo`3oool03`3oool000l0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`1@0?ooo`030000003oool0oooo00l0oooo000?0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool03P3oool000l0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0540oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00h0oooo000?0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1A0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0>0?oo
o`003`3oool2000001T0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1A0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0>0?ooo`00
3`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0
3P3oool000l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo0580oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1B0?ooo`030000003o
ool0oooo00h0oooo000?0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0DP3oool0
0`000000oooo0?ooo`0>0?ooo`001`3oool2000000H0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo00d0oooo00060?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
00d0oooo00090?ooo`030000003oool0oooo00<0oooo0P00000I0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool03@3oool000L0oooo0P0000060?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0=0?ooo`002@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`0=0?ooo`001P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`0=0?ooo`001`3oool2000000H0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00d0oooo000?0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0=0?oo
o`003`3oool2000001X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0=0?ooo`00
3`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
E@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0
303oool000l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo00`0oooo000?0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0<0?ooo`003`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
05D0oooo00<000000?ooo`3oool0303oool000l0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo00`0oooo000?0?ooo`8000006`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo00`0oooo000?0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`0<0?ooo`003`3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0303oool000l0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00/0oooo000?0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0;0?ooo`00
3`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
2`3oool000l0oooo0P00000L0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool02`3o
ool000l0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo00/0oooo000?0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0I@3oool000l0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1U0?ooo`003`3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo06H0oooo000?0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0IP3oool000l0oooo0P00000M0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0F@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo06H0oooo000?0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1I0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0IP3oool000l0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`1V0?ooo`003`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo06H0oooo00080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`1W0?ooo`00203oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0I`3oool000D0oooo1@0000050?ooo`8000007P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`1W0?ooo`001@3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0I`3oool000H0oooo00<000000?ooo`0000001P3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo06L0oooo00070?ooo`8000001P3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0F`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo06L0oooo00080?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05`0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`1X0?ooo`003`3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo06P0oooo000?0?ooo`8000007`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo05d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1X0?oo
o`003`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0G@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo06P0oooo000?0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1M0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0J03oool000l0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`1X0?ooo`003`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo06T0oooo000?0?ooo`8000007`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
05l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1Y0?ooo`003`3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0G`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo06T0oooo000?0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0J@3oool000l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`1Y0?ooo`003`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo06T0oooo000?0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0JP3oool000l0oooo0P00000P0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo06X0oooo000?0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
JP3oool000l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0640oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`003`3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0H@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo06X0oooo000?0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0JP3oool000l0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`1[0?ooo`003`3oool200000240oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`1R0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0J`3oool000l0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0680oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`1[0?ooo`003`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo06/0oooo000?0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0J`3oool000H0oooo0`0000060?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0J`3oool000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo06`0oooo00090?ooo`030000003oool0oooo00<0oooo0P00000R0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo06`0oooo00060?ooo`<000001P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo06`0oooo00060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`1/0?ooo`001P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0K@3oool000H0oooo100000050?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0K@3oool000l0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`1]0?ooo`003`3oool2000002@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1X
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0KP3oool000l0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06T0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1^0?ooo`003`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo06h0oooo000?0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
KP3oool000l0oooo00<000000?ooo`3oool09@3oool01@000000oooo0?ooo`3oool0000006d0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1_0?ooo`003`3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00800000KP3oool010000000oooo0?ooo`00001b0?ooo`003`3o
ool2000002H0oooo1000001_0?ooo`@00000LP3oool000l0oooo00<000000?ooo`3oool0o`3oool?
0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003oool0oooo0?l0
oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`00\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {365.188, 223.875}} -> {-10.0009, \
9.03348, 0.0771421, 0.0337774}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{766, 807},
WindowMargins->{{41, Automatic}, {Automatic, 20}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "afs", \
"athena.mit.edu", "user", "k", "y", "kyle2", "quantum3"}, "set1num1-2.nb.ps", \
CharacterEncoding -> "ISO8859-1"],
"Magnification"->1}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 28, 0, 45, "Subsection"],
Cell[1758, 54, 170, 4, 32, "Text"],
Cell[1931, 60, 166, 4, 75, "Input"],
Cell[2100, 66, 74, 0, 32, "Text"],
Cell[2177, 68, 81, 2, 43, "Input"],
Cell[2261, 72, 179, 3, 107, "Input"],
Cell[2443, 77, 192, 4, 50, "Text"],
Cell[2638, 83, 81, 2, 43, "Input"],
Cell[2722, 87, 163, 3, 85, "Input"],
Cell[2888, 92, 163, 4, 32, "Text"],
Cell[3054, 98, 299, 6, 106, "Input"],
Cell[3356, 106, 91, 3, 32, "Text"],
Cell[3450, 111, 139, 3, 64, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3626, 119, 36, 0, 45, "Subsection"],
Cell[3665, 121, 520, 10, 86, "Text"],
Cell[4188, 133, 1335, 24, 297, "Input"],
Cell[5526, 159, 234, 5, 50, "Text"],
Cell[5763, 166, 5206, 84, 891, "Input"],
Cell[10972, 252, 114, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[11111, 259, 81, 2, 43, "Input"],
Cell[11195, 263, 52, 1, 27, "Output"],
Cell[11250, 266, 52, 1, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11351, 273, 28, 0, 45, "Subsection"],
Cell[11382, 275, 64, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[11471, 279, 443, 8, 107, "Input"],

Cell[CellGroupData[{
Cell[11939, 291, 23377, 625, 186, 5653, 402, "GraphicsData", "PostScript", \
"Graphics"],
Cell[35319, 918, 23320, 620, 186, 5567, 396, "GraphicsData", "PostScript", \
"Graphics"],
Cell[58642, 1540, 24402, 667, 186, 6245, 438, "GraphicsData", "PostScript", \
"Graphics"],
Cell[83047, 2209, 25822, 682, 186, 6245, 436, "GraphicsData", "PostScript", \
"Graphics"],
Cell[108872, 2893, 27835, 711, 186, 6304, 441, "GraphicsData", "PostScript", \
"Graphics"],
Cell[136710, 3606, 28942, 730, 186, 6317, 446, "GraphicsData", "PostScript", \
"Graphics"],
Cell[165655, 4338, 29623, 717, 186, 5967, 421, "GraphicsData", "PostScript", \
"Graphics"],
Cell[195281, 5057, 29672, 699, 186, 5527, 397, "GraphicsData", "PostScript", \
"Graphics"],
Cell[224956, 5758, 27365, 672, 186, 5526, 398, "GraphicsData", "PostScript", \
"Graphics"],
Cell[252324, 6432, 23474, 643, 186, 5948, 422, "GraphicsData", "PostScript", \
"Graphics"],
Cell[275801, 7077, 20489, 594, 186, 5734, 407, "GraphicsData", "PostScript", \
"Graphics"],
Cell[296293, 7673, 19012, 620, 186, 6579, 462, "GraphicsData", "PostScript", \
"Graphics"],
Cell[315308, 8295, 18764, 658, 186, 7386, 513, "GraphicsData", "PostScript", \
"Graphics"],
Cell[334075, 8955, 18587, 663, 186, 7497, 522, "GraphicsData", "PostScript", \
"Graphics"],
Cell[352665, 9620, 18886, 650, 186, 7149, 501, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[371578, 10274, 299, 5, 50, "Text"],
Cell[371880, 10281, 1532, 23, 299, "Input"],
Cell[373415, 10306, 137, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[373577, 10313, 122, 2, 59, "Input"],
Cell[373702, 10317, 54, 1, 27, "Output"],
Cell[373759, 10320, 52, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[373848, 10326, 474, 8, 120, "Input"],

Cell[CellGroupData[{
Cell[374347, 10338, 41777, 1027, 186, 9470, 624, "GraphicsData", \
"PostScript", "Graphics"],
Cell[416127, 11367, 43330, 1103, 186, 10310, 691, "GraphicsData", \
"PostScript", "Graphics"],
Cell[459460, 12472, 42072, 1062, 186, 9806, 659, "GraphicsData", \
"PostScript", "Graphics"],
Cell[501535, 13536, 41219, 1036, 186, 9579, 641, "GraphicsData", \
"PostScript", "Graphics"],
Cell[542757, 14574, 40681, 1012, 186, 9227, 619, "GraphicsData", \
"PostScript", "Graphics"],
Cell[583441, 15588, 40501, 991, 186, 8912, 597, "GraphicsData", "PostScript", \
"Graphics"],
Cell[623945, 16581, 38987, 946, 186, 8375, 564, "GraphicsData", "PostScript", \
"Graphics"],
Cell[662935, 17529, 38061, 926, 186, 8264, 554, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

